/*
 * In a generated replay, this file is partially common, boilerplate code
 * included in every replay, and partially generated replay code. The following
 * header applies to the boilerplate code. A comment indicating "Auto-generated
 * below this comment" marks the separation between these two parts.
 *
 * Copyright (C) 2011, 2012 Purdue University
 * Written by Gregor Richards
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

(function() {
    // global eval alias
    var geval = eval;

    // detect if we're in a browser or not
    var inbrowser = false;
    var inharness = false;
    if (typeof window !== "undefined" && "document" in window) {
        inbrowser = true;
        if (window.parent && "JSBNG_handleResult" in window.parent) {
            inharness = true;
        }
    } else if (typeof global !== "undefined") {
        window = global;
        window.top = window;
    } else {
        window = (function() { return this; })();
        window.top = window;
    }

    if ("console" in window) {
        window.JSBNG_Console = window.console;
    }

    var callpath = [];

    // global state
    var JSBNG_Replay = window.top.JSBNG_Replay = {
        push: function(arr, fun) {
            arr.push(fun);
            return fun;
        },

        path: function(str) {
            verifyPath(str);
        }
    };

    // the actual replay runner
    function onload() {
        try {
            delete window.onload;
        } catch (ex) {}

        var jr = JSBNG_Replay$;
        var cb = function() {
            var end = new Date().getTime();

            var msg = "Time: " + (end - st) + "ms";
    
            if (inharness) {
                window.parent.JSBNG_handleResult({error:false, time:(end - st)});
            } else if (inbrowser) {
                var res = document.createElement("div");
    
                res.style.position = "fixed";
                res.style.left = "1em";
                res.style.top = "1em";
                res.style.width = "35em";
                res.style.height = "5em";
                res.style.padding = "1em";
                res.style.backgroundColor = "white";
                res.style.color = "black";
                res.appendChild(document.createTextNode(msg));
    
                document.body.appendChild(res);
            } else if (typeof console !== "undefined") {
                console.log(msg);
            } else if (typeof print !== "undefined") {
                // hopefully not the browser print() function :)
                print(msg);
            }
        };

        // force it to JIT
        jr(false);

        // then time it
        var st = new Date().getTime();
        while (jr !== null) {
            jr = jr(true, cb);
        }
    }

    // add a frame at replay time
    function iframe(pageid) {
        var iw;
        if (inbrowser) {
            // represent the iframe as an iframe (of course)
            var iframe = document.createElement("iframe");
            iframe.style.display = "none";
            document.body.appendChild(iframe);
            iw = iframe.contentWindow;
            iw.document.write("<script type=\"text/javascript\">Function.prototype.bind = null; var JSBNG_Replay_geval = eval;</script>");
            iw.document.close();
        } else {
            // no general way, just lie and do horrible things
            var topwin = window;
            (function() {
                var window = {};
                window.window = window;
                window.top = topwin;
                window.JSBNG_Replay_geval = function(str) {
                    eval(str);
                }
                iw = window;
            })();
        }
        return iw;
    }

    // called at the end of the replay stuff
    function finalize() {
        if (inbrowser) {
            setTimeout(onload, 0);
        } else {
            onload();
        }
    }

    // verify this recorded value and this replayed value are close enough
    function verify(rep, rec) {
        if (rec !== rep &&
            (rep === rep || rec === rec) /* NaN test */) {
            if (typeof rec !== "object" || rec === null ||
                !(("__JSBNG_unknown_" + typeof(rep)) in rec)) {
                return false;
            }
        }
        return true;
    }

    // general message
    var firstMessage = true;
    function replayMessage(msg) {
        if (inbrowser) {
            if (firstMessage)
                document.open();
            firstMessage = false;
            document.write(msg);
        } else {
            console.log(msg);
        }
    }

    // complain when there's an error
    function verificationError(msg) {
        if (inharness) {
            window.parent.JSBNG_handleResult({error:true, msg: msg});
        } else replayMessage(msg);
        throw new Error();
    }

    // to verify a set
    function verifySet(objstr, obj, prop, gvalstr, gval) {
        if (/^on/.test(prop)) {
            // these aren't instrumented compatibly
            return;
        }

        if (!verify(obj[prop], gval)) {
            var bval = obj[prop];
            var msg = "Verification failure! " + objstr + "." + prop + " is not " + gvalstr + ", it's " + bval + "!";
            verificationError(msg);
        }
    }

    // to verify a call or new
    function verifyCall(iscall, func, cthis, cargs) {
        var ok = true;
        var callArgs = func.callArgs[func.inst];
        iscall = iscall ? 1 : 0;
        if (cargs.length !== callArgs.length - 1) {
            ok = false;
        } else {
            if (iscall && !verify(cthis, callArgs[0])) ok = false;
            for (var i = 0; i < cargs.length; i++) {
                if (!verify(cargs[i], callArgs[i+1])) ok = false;
            }
        }
        if (!ok) {
            var msg = "Call verification failure!";
            verificationError(msg);
        }

        return func.returns[func.inst++];
    }

    // to verify the callpath
    function verifyPath(func) {
        var real = callpath.shift();
        if (real !== func) {
            var msg = "Call path verification failure! Expected " + real + ", found " + func;
            verificationError(msg);
        }
    }

    // figure out how to define getters
    var defineGetter;
    if (Object.defineProperty) {
        var odp = Object.defineProperty;
        defineGetter = function(obj, prop, getter) {
            odp(obj, prop, {"enumerable": true, "get": getter, "set": function(){}});
        };
    } else if (Object.prototype.__defineGetter__) {
        var opdg = Object.prototype.__defineGetter__;
        var opds = Object.prototype.__defineSetter__;
        defineGetter = function(obj, prop, getter) {
            opdg.call(obj, prop, getter);
            opds.call(obj, prop, function(){});
        };
    } else {
        defineGetter = function() {
            verificationError("This replay requires getters for correct behavior, and your JS engine appears to be incapable of defining getters. Sorry!");
        };
    }

    // for calling events
    var fpc = Function.prototype.call;

// resist the urge, don't put a })(); here!
/******************************************************************************
 * Auto-generated below this comment
 *****************************************************************************/
var ow693592812 = window;
var f693592812_0;
var o0;
var o1;
var o2;
var f693592812_4;
var f693592812_7;
var f693592812_10;
var f693592812_12;
var f693592812_13;
var f693592812_15;
var o3;
var o4;
var o5;
var o6;
var f693592812_54;
var f693592812_55;
var f693592812_134;
var f693592812_393;
var o7;
var f693592812_395;
var f693592812_396;
var o8;
var fo693592812_398_className;
var o9;
var f693592812_400;
var o10;
var o11;
var o12;
var f693592812_413;
var o13;
var f693592812_415;
var o14;
var o15;
var o16;
var o17;
var o18;
var o19;
var o20;
var o21;
var o22;
var o23;
var o24;
var o25;
var o26;
var o27;
var o28;
var o29;
var o30;
var o31;
var o32;
var o33;
var o34;
var o35;
var o36;
var fo693592812_1_cookie;
var f693592812_470;
var f693592812_474;
var f693592812_475;
var f693592812_478;
var f693592812_481;
var f693592812_483;
var f693592812_484;
var f693592812_487;
var o37;
var o38;
var f693592812_495;
var f693592812_500;
var o39;
var f693592812_513;
var f693592812_518;
var f693592812_523;
var f693592812_526;
var f693592812_530;
var f693592812_534;
var f693592812_536;
var f693592812_538;
var f693592812_541;
var fo693592812_542_length;
var f693592812_544;
var f693592812_549;
var f693592812_555;
var f693592812_559;
var f693592812_561;
var f693592812_563;
var f693592812_565;
var f693592812_567;
var f693592812_569;
var f693592812_571;
var f693592812_573;
var f693592812_575;
var fo693592812_552_backgroundColor;
var f693592812_581;
var f693592812_583;
var fo693592812_553_type;
var f693592812_586;
var fo693592812_553_value;
var f693592812_589;
var fo693592812_1_jQuery17109642799841240048;
var f693592812_592;
var f693592812_593;
var fo693592812_599_jQuery17109642799841240048;
var fo693592812_812_offsetWidth;
var fo693592812_820_offsetTop;
var f693592812_826;
var o40;
var o41;
var o42;
var o43;
var o44;
var o45;
var o46;
var o47;
var o48;
var o49;
var o50;
var o51;
var o52;
var o53;
var o54;
var o55;
var o56;
var o57;
var o58;
var o59;
var o60;
var o61;
var o62;
var o63;
var o64;
var o65;
var fo693592812_868_jQuery17109642799841240048;
var fo693592812_870_jQuery17109642799841240048;
var f693592812_880;
var fo693592812_884_jQuery17109642799841240048;
var fo693592812_412_jQuery17109642799841240048;
var fo693592812_888_jQuery17109642799841240048;
var fo693592812_916_jQuery17109642799841240048;
var fo693592812_454_jQuery17109642799841240048;
var fo693592812_921_jQuery17109642799841240048;
var f693592812_923;
var fo693592812_926_jQuery17109642799841240048;
var fo693592812_928_jQuery17109642799841240048;
var f693592812_1318;
var fo693592812_1317_readyState;
var f693592812_1322;
JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74 = [];
// 1
// record generated by JSBench c8b048872b28 at 2012-08-21T15:13:54.906Z
// 2
// 3
f693592812_0 = function() { return f693592812_0.returns[f693592812_0.inst++]; };
f693592812_0.returns = [];
f693592812_0.inst = 0;
// 4
ow693592812.JSBNG__Date = f693592812_0;
// 5
o0 = {};
// 6
ow693592812.JSBNG__document = o0;
// 7
o1 = {};
// 8
ow693592812.JSBNG__sessionStorage = o1;
// 9
o2 = {};
// 10
ow693592812.JSBNG__localStorage = o2;
// 11
f693592812_4 = function() { return f693592812_4.returns[f693592812_4.inst++]; };
f693592812_4.returns = [];
f693592812_4.inst = 0;
// 12
ow693592812.JSBNG__getComputedStyle = f693592812_4;
// 17
f693592812_7 = function() { return f693592812_7.returns[f693592812_7.inst++]; };
f693592812_7.returns = [];
f693592812_7.inst = 0;
// 18
ow693592812.JSBNG__addEventListener = f693592812_7;
// 19
ow693592812.JSBNG__top = ow693592812;
// 24
ow693592812.JSBNG__scrollX = 0;
// 25
ow693592812.JSBNG__scrollY = 0;
// 26
f693592812_10 = function() { return f693592812_10.returns[f693592812_10.inst++]; };
f693592812_10.returns = [];
f693592812_10.inst = 0;
// 27
ow693592812.JSBNG__scrollTo = f693592812_10;
// 30
f693592812_12 = function() { return f693592812_12.returns[f693592812_12.inst++]; };
f693592812_12.returns = [];
f693592812_12.inst = 0;
// 31
ow693592812.JSBNG__setTimeout = f693592812_12;
// 32
f693592812_13 = function() { return f693592812_13.returns[f693592812_13.inst++]; };
f693592812_13.returns = [];
f693592812_13.inst = 0;
// 33
ow693592812.JSBNG__setInterval = f693592812_13;
// 36
f693592812_15 = function() { return f693592812_15.returns[f693592812_15.inst++]; };
f693592812_15.returns = [];
f693592812_15.inst = 0;
// 37
ow693592812.JSBNG__clearInterval = f693592812_15;
// 42
ow693592812.JSBNG__frames = ow693592812;
// 43
o3 = {};
// 44
ow693592812.JSBNG__applicationCache = o3;
// 45
ow693592812.JSBNG__self = ow693592812;
// 46
o4 = {};
// 47
ow693592812.JSBNG__navigator = o4;
// 50
o5 = {};
// 51
ow693592812.JSBNG__history = o5;
// 62
ow693592812.JSBNG__closed = false;
// 65
ow693592812.JSBNG__opener = null;
// 66
ow693592812.JSBNG__defaultStatus = "";
// 67
o6 = {};
// 68
ow693592812.JSBNG__location = o6;
// 69
ow693592812.JSBNG__innerWidth = 800;
// 70
ow693592812.JSBNG__innerHeight = 540;
// 71
ow693592812.JSBNG__outerWidth = 800;
// 72
ow693592812.JSBNG__outerHeight = 600;
// 73
ow693592812.JSBNG__screenX = 473;
// 74
ow693592812.JSBNG__screenY = 166;
// 75
ow693592812.JSBNG__pageXOffset = 0;
// 76
ow693592812.JSBNG__pageYOffset = 0;
// 101
ow693592812.JSBNG__frameElement = null;
// 108
ow693592812.JSBNG__screenLeft = 473;
// 109
ow693592812.JSBNG__clientInformation = o4;
// 110
ow693592812.JSBNG__defaultstatus = "";
// 117
ow693592812.JSBNG__devicePixelRatio = 1;
// 120
ow693592812.JSBNG__offscreenBuffering = true;
// 121
ow693592812.JSBNG__screenTop = 166;
// 134
f693592812_54 = function() { return f693592812_54.returns[f693592812_54.inst++]; };
f693592812_54.returns = [];
f693592812_54.inst = 0;
// 135
ow693592812.JSBNG__openDatabase = f693592812_54;
// 136
f693592812_55 = function() { return f693592812_55.returns[f693592812_55.inst++]; };
f693592812_55.returns = [];
f693592812_55.inst = 0;
// 137
ow693592812.JSBNG__XMLHttpRequest = f693592812_55;
// 140
ow693592812.JSBNG__name = "";
// 147
ow693592812.JSBNG__status = "";
// 296
f693592812_134 = function() { return f693592812_134.returns[f693592812_134.inst++]; };
f693592812_134.returns = [];
f693592812_134.inst = 0;
// 297
ow693592812.JSBNG__Document = f693592812_134;
// 562
ow693592812.JSBNG__XMLDocument = f693592812_134;
// 801
ow693592812.JSBNG__orientation = 0;
// 816
f693592812_393 = function() { return f693592812_393.returns[f693592812_393.inst++]; };
f693592812_393.returns = [];
f693592812_393.inst = 0;
// 817
ow693592812.Math.JSBNG__random = f693592812_393;
// 818
// 820
// 821
o7 = {};
// 822
f693592812_0.returns.push(o7);
// 823
f693592812_395 = function() { return f693592812_395.returns[f693592812_395.inst++]; };
f693592812_395.returns = [];
f693592812_395.inst = 0;
// 824
o7.getTime = f693592812_395;
// undefined
o7 = null;
// 825
f693592812_395.returns.push(1345562128694);
// 826
// 827
o6.pathname = "/";
// 828
o6.hash = "#!/search/javascript?q=javascript";
// 834
f693592812_396 = function() { return f693592812_396.returns[f693592812_396.inst++]; };
f693592812_396.returns = [];
f693592812_396.inst = 0;
// 835
o0.getElementsByTagName = f693592812_396;
// 836
o7 = {};
// 837
f693592812_396.returns.push(o7);
// 838
o8 = {};
// 839
o7["0"] = o8;
// undefined
fo693592812_398_className = function() { return fo693592812_398_className.returns[fo693592812_398_className.inst++]; };
fo693592812_398_className.returns = [];
fo693592812_398_className.inst = 0;
defineGetter(o8, "className", fo693592812_398_className);
// undefined
fo693592812_398_className.returns.push("");
// 845
ow693592812.JSBNG__attachEvent = undefined;
// 847
o9 = {};
// 848
f693592812_396.returns.push(o9);
// 849
f693592812_400 = function() { return f693592812_400.returns[f693592812_400.inst++]; };
f693592812_400.returns = [];
f693592812_400.inst = 0;
// 850
o0.createElement = f693592812_400;
// 851
o10 = {};
// 852
f693592812_400.returns.push(o10);
// 853
o11 = {};
// 854
o9["0"] = o11;
// 855
o11.src = "http://twitter.com/JSBENCH_NG_RECORD_OBJECTS.js";
// 856
o12 = {};
// 857
o9["1"] = o12;
// 858
o12.src = "http://twitter.com/JSBENCH_NG_RECORD.js";
// undefined
o12 = null;
// 859
o12 = {};
// 860
o9["2"] = o12;
// 861
o12.src = "";
// undefined
o12 = null;
// 862
o12 = {};
// 863
o9["3"] = o12;
// 864
o12.src = "";
// undefined
o12 = null;
// 865
o12 = {};
// 866
o9["4"] = o12;
// 867
o12.src = "";
// undefined
o12 = null;
// 868
o12 = {};
// 869
o9["5"] = o12;
// 870
o12.src = "";
// undefined
o12 = null;
// 871
o12 = {};
// 872
o9["6"] = o12;
// 873
o12.src = "";
// undefined
o12 = null;
// 874
o12 = {};
// 875
o9["7"] = o12;
// 876
o12.src = "";
// undefined
o12 = null;
// 877
o12 = {};
// 878
o9["8"] = o12;
// 879
o12.src = "";
// undefined
o12 = null;
// 880
o12 = {};
// 881
o9["9"] = o12;
// 882
o12.src = "";
// undefined
o12 = null;
// 883
o9["10"] = void 0;
// 886
o12 = {};
// 887
o0.body = o12;
// 888
f693592812_413 = function() { return f693592812_413.returns[f693592812_413.inst++]; };
f693592812_413.returns = [];
f693592812_413.inst = 0;
// 889
o0.getElementById = f693592812_413;
// 890
o13 = {};
// 891
f693592812_413.returns.push(o13);
// 892
o6.href = "http://twitter.com/#!/search/javascript?q=javascript";
// 894
o13.tagName = "DIV";
// 895
f693592812_415 = function() { return f693592812_415.returns[f693592812_415.inst++]; };
f693592812_415.returns = [];
f693592812_415.inst = 0;
// 896
o13.getElementsByTagName = f693592812_415;
// 897
o14 = {};
// 898
f693592812_415.returns.push(o14);
// 899
o14.length = 27;
// 900
o15 = {};
// 901
o14["26"] = o15;
// 902
o15.className = "new-js-banners";
// undefined
o15 = null;
// 903
o15 = {};
// 904
o14["25"] = o15;
// 905
o15.className = "wrapper";
// 906
o16 = {};
// 907
o14["24"] = o16;
// 908
o16.className = "footer inline-list";
// undefined
o16 = null;
// 909
o16 = {};
// 910
o14["23"] = o16;
// 911
o16.className = "placeholding-input";
// 913
o16.tagName = "DIV";
// 914
o16.getElementsByTagName = f693592812_415;
// undefined
o16 = null;
// 915
o16 = {};
// 916
f693592812_415.returns.push(o16);
// 917
o17 = {};
// 918
o16["0"] = o17;
// 921
o18 = {};
// 922
f693592812_415.returns.push(o18);
// 923
o19 = {};
// 924
o18["0"] = o19;
// undefined
o18 = null;
// 925
// undefined
o19 = null;
// 926
// 927
// 928
o18 = {};
// 929
o14["22"] = o18;
// 930
o18.className = "placeholding-input";
// 932
o18.tagName = "DIV";
// 933
o18.getElementsByTagName = f693592812_415;
// undefined
o18 = null;
// 934
o18 = {};
// 935
f693592812_415.returns.push(o18);
// 936
o19 = {};
// 937
o18["0"] = o19;
// 940
o20 = {};
// 941
f693592812_415.returns.push(o20);
// 942
o21 = {};
// 943
o20["0"] = o21;
// undefined
o20 = null;
// 944
// undefined
o21 = null;
// 945
// 946
// 947
o20 = {};
// 948
o14["21"] = o20;
// 949
o20.className = "placeholding-input";
// 951
o20.tagName = "DIV";
// 952
o20.getElementsByTagName = f693592812_415;
// undefined
o20 = null;
// 953
o20 = {};
// 954
f693592812_415.returns.push(o20);
// 955
o21 = {};
// 956
o20["0"] = o21;
// 959
o22 = {};
// 960
f693592812_415.returns.push(o22);
// 961
o23 = {};
// 962
o22["0"] = o23;
// undefined
o22 = null;
// 963
// undefined
o23 = null;
// 964
// 965
// 966
o22 = {};
// 967
o14["20"] = o22;
// 968
o22.className = "front-signup js-front-signup";
// 969
o23 = {};
// 970
o14["19"] = o23;
// 971
o23.className = "remember-forgot";
// undefined
o23 = null;
// 972
o23 = {};
// 973
o14["18"] = o23;
// 974
o23.className = "placeholding-input password flex-table-form";
// 976
o23.tagName = "DIV";
// 977
o23.getElementsByTagName = f693592812_415;
// undefined
o23 = null;
// 978
o23 = {};
// 979
f693592812_415.returns.push(o23);
// 980
o24 = {};
// 981
o23["0"] = o24;
// 984
o25 = {};
// 985
f693592812_415.returns.push(o25);
// 986
o26 = {};
// 987
o25["0"] = o26;
// undefined
o25 = null;
// 988
// undefined
o26 = null;
// 989
// 990
// 991
o25 = {};
// 992
o14["17"] = o25;
// 993
o25.className = "placeholding-input username";
// 995
o25.tagName = "DIV";
// 996
o25.getElementsByTagName = f693592812_415;
// undefined
o25 = null;
// 997
o25 = {};
// 998
f693592812_415.returns.push(o25);
// 999
o26 = {};
// 1000
o25["0"] = o26;
// 1003
o27 = {};
// 1004
f693592812_415.returns.push(o27);
// 1005
o28 = {};
// 1006
o27["0"] = o28;
// undefined
o27 = null;
// 1007
// undefined
o28 = null;
// 1008
// 1009
// 1010
o27 = {};
// 1011
o14["16"] = o27;
// 1012
o27.className = "front-signin js-front-signin";
// 1013
o28 = {};
// 1014
o14["15"] = o28;
// 1015
o28.className = "front-welcome-text";
// undefined
o28 = null;
// 1016
o28 = {};
// 1017
o14["14"] = o28;
// 1018
o28.className = "front-welcome";
// undefined
o28 = null;
// 1019
o28 = {};
// 1020
o14["13"] = o28;
// 1021
o28.className = "front-card";
// undefined
o28 = null;
// 1022
o28 = {};
// 1023
o14["12"] = o28;
// 1024
o28.className = "front-warning";
// undefined
o28 = null;
// 1025
o28 = {};
// 1026
o14["11"] = o28;
// 1027
o28.className = "front-container   ";
// undefined
o28 = null;
// 1028
o28 = {};
// 1029
o14["10"] = o28;
// 1030
o28.className = "";
// 1031
o29 = {};
// 1032
o14["9"] = o29;
// 1033
o29.className = "alert-messages ";
// 1034
o30 = {};
// 1035
o14["8"] = o30;
// 1036
o30.className = "pull-right";
// 1037
o31 = {};
// 1038
o14["7"] = o31;
// 1039
o31.className = "js-front-language";
// 1040
o32 = {};
// 1041
o14["6"] = o32;
// 1042
o32.className = "divider";
// undefined
o32 = null;
// 1043
o32 = {};
// 1044
o14["5"] = o32;
// 1045
o32.className = "container";
// 1046
o33 = {};
// 1047
o14["4"] = o33;
// 1048
o33.className = "global-nav-inner";
// 1049
o34 = {};
// 1050
o14["3"] = o34;
// 1051
o34.className = "global-nav";
// 1052
o35 = {};
// 1053
o14["2"] = o35;
// 1054
o35.className = "js-banners";
// undefined
o35 = null;
// 1055
o35 = {};
// 1056
o14["1"] = o35;
// 1057
o35.className = "topbar js-topbar";
// 1058
o36 = {};
// 1059
o14["0"] = o36;
// 1060
o36.className = "push-loader";
// undefined
o36 = null;
// 1061
f693592812_13.returns.push(1);
// 1078
o22.tagName = "DIV";
// 1079
o22.getElementsByTagName = f693592812_415;
// undefined
o22 = null;
// 1080
o22 = {};
// 1081
f693592812_415.returns.push(o22);
// 1082
o36 = {};
// 1083
o22["0"] = o36;
// undefined
o22 = null;
// 1085
// undefined
o36 = null;
// 1095
o27.tagName = "DIV";
// 1096
o27.getElementsByTagName = f693592812_415;
// undefined
o27 = null;
// 1097
o22 = {};
// 1098
f693592812_415.returns.push(o22);
// 1099
o27 = {};
// 1100
o22["0"] = o27;
// undefined
o22 = null;
// 1102
// undefined
o27 = null;
// 1122
o31.tagName = "DIV";
// 1123
o31.getElementsByTagName = f693592812_415;
// undefined
o31 = null;
// 1124
o22 = {};
// 1125
f693592812_415.returns.push(o22);
// 1126
o27 = {};
// 1127
o22["0"] = o27;
// undefined
o22 = null;
// 1129
// undefined
o27 = null;
// 1144
o4.cookieEnabled = "true";
// 1146
o4.appName = "Netscape";
// 1148
f693592812_413.returns.push(null);
// undefined
fo693592812_1_cookie = function() { return fo693592812_1_cookie.returns[fo693592812_1_cookie.inst++]; };
fo693592812_1_cookie.returns = [];
fo693592812_1_cookie.inst = 0;
defineGetter(o0, "cookie", fo693592812_1_cookie);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198");
// 1150
f693592812_470 = function() { return f693592812_470.returns[f693592812_470.inst++]; };
f693592812_470.returns = [];
f693592812_470.inst = 0;
// 1151
o0.getElementsByName = f693592812_470;
// 1152
o22 = {};
// 1153
f693592812_470.returns.push(o22);
// 1154
o22.length = 2;
// 1155
o27 = {};
// 1156
o22["0"] = o27;
// 1157
// 1159
o31 = {};
// 1160
o22["1"] = o31;
// undefined
o22 = null;
// 1161
// undefined
o31 = null;
// 1166
f693592812_396.returns.push(o7);
// undefined
o7 = null;
// undefined
fo693592812_398_className.returns.push(" remove-prerendered-content");
// undefined
fo693592812_398_className.returns.push(" remove-prerendered-content");
// 1171
f693592812_413.returns.push(o28);
// 1173
f693592812_413.returns.push(o28);
// 1175
// 1177
f693592812_413.returns.push(o15);
// 1179
// 1180
// undefined
fo693592812_398_className.returns.push(" remove-prerendered-content");
// 1183
f693592812_474 = function() { return f693592812_474.returns[f693592812_474.inst++]; };
f693592812_474.returns = [];
f693592812_474.inst = 0;
// 1184
o8.getAttribute = f693592812_474;
// 1185
f693592812_474.returns.push("highlight-global-nav-home");
// undefined
fo693592812_398_className.returns.push(" ");
// 1188
f693592812_474.returns.push("highlight-global-nav-home");
// 1190
f693592812_475 = function() { return f693592812_475.returns[f693592812_475.inst++]; };
f693592812_475.returns = [];
f693592812_475.inst = 0;
// 1191
o8.removeAttribute = f693592812_475;
// 1192
f693592812_475.returns.push(undefined);
// 1194
f693592812_393.returns.push(0.6286677636671811);
// 1195
o6.hostname = "twitter.com";
// 1197
f693592812_413.returns.push(null);
// 1198
o6.protocol = "http:";
// 1199
o7 = {};
// 1200
f693592812_0.returns.push(o7);
// undefined
o7 = null;
// 1201
o7 = {};
// 1202
f693592812_0.returns.push(o7);
// undefined
o7 = null;
// 1203
f693592812_478 = function() { return f693592812_478.returns[f693592812_478.inst++]; };
f693592812_478.returns = [];
f693592812_478.inst = 0;
// 1204
o10.cloneNode = f693592812_478;
// undefined
o10 = null;
// 1205
o7 = {};
// 1206
f693592812_478.returns.push(o7);
// 1207
// 1208
// 1209
// 1210
// 1211
// 1212
// 1213
// 1215
o10 = {};
// 1216
o11.parentNode = o10;
// undefined
o11 = null;
// 1217
f693592812_481 = function() { return f693592812_481.returns[f693592812_481.inst++]; };
f693592812_481.returns = [];
f693592812_481.inst = 0;
// 1218
o10.insertBefore = f693592812_481;
// 1220
f693592812_481.returns.push(o7);
// 1222
o6.search = "";
// 1224
f693592812_393.returns.push(0.3293255034368485);
// 1225
o11 = {};
// 1226
f693592812_55.returns.push(o11);
// 1227
// 1228
f693592812_483 = function() { return f693592812_483.returns[f693592812_483.inst++]; };
f693592812_483.returns = [];
f693592812_483.inst = 0;
// 1229
o11.open = f693592812_483;
// 1230
f693592812_483.returns.push(undefined);
// 1231
f693592812_484 = function() { return f693592812_484.returns[f693592812_484.inst++]; };
f693592812_484.returns = [];
f693592812_484.inst = 0;
// 1232
o11.send = f693592812_484;
// 1233
f693592812_484.returns.push(undefined);
// 1235
o22 = {};
// 1236
f693592812_400.returns.push(o22);
// 1237
// 1238
o31 = {};
// 1239
o22.firstChild = o31;
// undefined
o22 = null;
// 1240
f693592812_487 = function() { return f693592812_487.returns[f693592812_487.inst++]; };
f693592812_487.returns = [];
f693592812_487.inst = 0;
// 1241
o31.JSBNG__addEventListener = f693592812_487;
// 1243
f693592812_487.returns.push(undefined);
// 1245
o12.insertBefore = f693592812_481;
// 1247
o22 = {};
// 1248
o12.firstChild = o22;
// undefined
o22 = null;
// 1249
f693592812_481.returns.push(o31);
// 1250
o22 = {};
// 1252
o11.readyState = 1;
// 1254
o36 = {};
// 1257
o37 = {};
// 1260
o38 = {};
// 1263
o11.responseText = "{\"requestCacheSeedData\":[],\"userProperties\":{},\"countryCode\":\"us\",\"twttr\":{\"pageLocale\":\"en\",\"doNotTrack\":false,\"payload\":{\"conditionalTemplates\":{},\"profiling\":false},\"languages\":[{\"name_en\":\"Arabic\",\"name\":\"\\u0627\\u0644\\u0639\\u0631\\u0628\\u064a\\u0629\",\"css_classes\":\"ar rtl\",\"code\":\"ar\",\"current\":false,\"localized_name\":\"Arabic\"},{\"name_en\":\"Basque\",\"name\":\"Euskara\",\"css_classes\":\"eu western\",\"code\":\"eu\",\"current\":false,\"localized_name\":\"Basque\"},{\"name_en\":\"Catalan\",\"name\":\"catal\\u00e0\",\"css_classes\":\"ca western\",\"code\":\"ca\",\"current\":false,\"localized_name\":\"Catalan\"},{\"name_en\":\"Czech\",\"name\":\"\\u010ce\\u0161tina\",\"css_classes\":\"cs western\",\"code\":\"cs\",\"current\":false,\"localized_name\":\"Czech\"},{\"name_en\":\"Danish\",\"name\":\"Dansk\",\"css_classes\":\"western da\",\"code\":\"da\",\"current\":false,\"localized_name\":\"Danish\"},{\"name_en\":\"Dutch\",\"name\":\"Nederlands\",\"css_classes\":\"western nl\",\"code\":\"nl\",\"current\":false,\"localized_name\":\"Dutch\"},{\"name_en\":\"English\",\"name\":\"English\",\"css_classes\":null,\"code\":\"en\",\"current\":true,\"localized_name\":\"English\"},{\"name_en\":\"Farsi\",\"name\":\"\\u0641\\u0627\\u0631\\u0633\\u06cc\",\"css_classes\":\"fa rtl\",\"code\":\"fa\",\"current\":false,\"localized_name\":\"Farsi\"},{\"name_en\":\"Filipino\",\"name\":\"Filipino\",\"css_classes\":\"western fil\",\"code\":\"fil\",\"current\":false,\"localized_name\":\"Filipino\"},{\"name_en\":\"Finnish\",\"name\":\"Suomi\",\"css_classes\":\"western fi\",\"code\":\"fi\",\"current\":false,\"localized_name\":\"Finnish\"},{\"name_en\":\"French\",\"name\":\"fran\\u00e7ais\",\"css_classes\":\"western fr\",\"code\":\"fr\",\"current\":false,\"localized_name\":\"French\"},{\"name_en\":\"German\",\"name\":\"Deutsch\",\"css_classes\":\"western de\",\"code\":\"de\",\"current\":false,\"localized_name\":\"German\"},{\"name_en\":\"Greek\",\"name\":\"\\u0395\\u03bb\\u03bb\\u03b7\\u03bd\\u03b9\\u03ba\\u03ac\",\"css_classes\":\"\",\"code\":\"el\",\"current\":false,\"localized_name\":\"Greek\"},{\"name_en\":\"Hebrew\",\"name\":\"\\u05e2\\u05b4\\u05d1\\u05b0\\u05e8\\u05b4\\u05d9\\u05ea\",\"css_classes\":\"he rtl\",\"code\":\"he\",\"current\":false,\"localized_name\":\"Hebrew\"},{\"name_en\":\"Hindi\",\"name\":\"\\u0939\\u093f\\u0928\\u094d\\u0926\\u0940\",\"css_classes\":\"asian hi\",\"code\":\"hi\",\"current\":false,\"localized_name\":\"Hindi\"},{\"name_en\":\"Hungarian\",\"name\":\"Magyar\",\"css_classes\":\"western hu\",\"code\":\"hu\",\"current\":false,\"localized_name\":\"Hungarian\"},{\"name_en\":\"Indonesian\",\"name\":\"Bahasa Indonesia\",\"css_classes\":\"western id\",\"code\":\"id\",\"current\":false,\"localized_name\":\"Indonesian\"},{\"name_en\":\"Italian\",\"name\":\"Italiano\",\"css_classes\":\"western it\",\"code\":\"it\",\"current\":false,\"localized_name\":\"Italian\"},{\"name_en\":\"Japanese\",\"name\":\"\\u65e5\\u672c\\u8a9e\",\"css_classes\":\"asian ja\",\"code\":\"ja\",\"current\":false,\"localized_name\":\"Japanese\"},{\"name_en\":\"Korean\",\"name\":\"\\ud55c\\uad6d\\uc5b4\",\"css_classes\":\"asian ko\",\"code\":\"ko\",\"current\":false,\"localized_name\":\"Korean\"},{\"name_en\":\"Malay\",\"name\":\"Bahasa Melayu\",\"css_classes\":\"western msa\",\"code\":\"msa\",\"current\":false,\"localized_name\":\"Malay\"},{\"name_en\":\"Norwegian\",\"name\":\"Norsk\",\"css_classes\":\"western no\",\"code\":\"no\",\"current\":false,\"localized_name\":\"Norwegian\"},{\"name_en\":\"Polish\",\"name\":\"Polski\",\"css_classes\":\"western pl\",\"code\":\"pl\",\"current\":false,\"localized_name\":\"Polish\"},{\"name_en\":\"Portuguese\",\"name\":\"Portugu\\u00eas\",\"css_classes\":\"western pt\",\"code\":\"pt\",\"current\":false,\"localized_name\":\"Portuguese\"},{\"name_en\":\"Russian\",\"name\":\"\\u0420\\u0443\\u0441\\u0441\\u043a\\u0438\\u0439\",\"css_classes\":\"western ru\",\"code\":\"ru\",\"current\":false,\"localized_name\":\"Russian\"},{\"name_en\":\"Simplified Chinese\",\"name\":\"\\u7b80\\u4f53\\u4e2d\\u6587\",\"css_classes\":\"asian zh-cn\",\"code\":\"zh-cn\",\"current\":false,\"localized_name\":\"Simplified Chinese\"},{\"name_en\":\"Spanish\",\"name\":\"Espa\\u00f1ol\",\"css_classes\":\"western es\",\"code\":\"es\",\"current\":false,\"localized_name\":\"Spanish\"},{\"name_en\":\"Swedish\",\"name\":\"Svenska\",\"css_classes\":\"western sv\",\"code\":\"sv\",\"current\":false,\"localized_name\":\"Swedish\"},{\"name_en\":\"Thai\",\"name\":\"\\u0e20\\u0e32\\u0e29\\u0e32\\u0e44\\u0e17\\u0e22\",\"css_classes\":\"th asian\",\"code\":\"th\",\"current\":false,\"localized_name\":\"Thai\"},{\"name_en\":\"Traditional Chinese\",\"name\":\"\\u7e41\\u9ad4\\u4e2d\\u6587\",\"css_classes\":\"asian zh-tw\",\"code\":\"zh-tw\",\"current\":false,\"localized_name\":\"Traditional Chinese\"},{\"name_en\":\"Turkish\",\"name\":\"T\\u00fcrk\\u00e7e\",\"css_classes\":\"western tr\",\"code\":\"tr\",\"current\":false,\"localized_name\":\"Turkish\"},{\"name_en\":\"Ukrainian\",\"name\":\"\\u0423\\u043a\\u0440\\u0430\\u0457\\u043d\\u0441\\u044c\\u043a\\u0430 \\u043c\\u043e\\u0432\\u0430\",\"css_classes\":\"uk western\",\"code\":\"uk\",\"current\":false,\"localized_name\":\"Ukrainian\"},{\"name_en\":\"Urdu\",\"name\":\"\\u0627\\u0631\\u062f\\u0648\",\"css_classes\":\"ur rtl\",\"code\":\"ur\",\"current\":false,\"localized_name\":\"Urdu\"}],\"cdnBase\":{\"unversioned\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\"],\"http\":[\"http:\\/\\/a0.twimg.com\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\"]},\"versioned\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\\/a\\/1345479106\"],\"http\":[\"http:\\/\\/a0.twimg.com\\/a\\/1345479106\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\\/a\\/1345479106\"]},\"hashed\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\\/c\"],\"http\":[\"http:\\/\\/a0.twimg.com\\/c\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\\/c\"]}},\"inEU\":false,\"globalConfig\":{\"short_url_length\":20,\"short_url_length_https\":21,\"max_media_per_upload\":1,\"characters_reserved_per_media\":21,\"photo_sizes\":{\"large\":{\"h\":2048,\"resize\":\"fit\",\"w\":1024},\"medium\":{\"h\":1200,\"resize\":\"fit\",\"w\":600},\"thumb\":{\"h\":150,\"resize\":\"crop\",\"w\":150},\"small\":{\"h\":480,\"resize\":\"fit\",\"w\":340}},\"non_username_paths\":[\"about\",\"account\",\"accounts\",\"activity\",\"all\",\"announcements\",\"anywhere\",\"api_rules\",\"api_terms\",\"apirules\",\"apps\",\"auth\",\"badges\",\"blog\",\"business\",\"buttons\",\"contacts\",\"devices\",\"direct_messages\",\"download\",\"downloads\",\"edit_announcements\",\"faq\",\"favorites\",\"find_sources\",\"find_users\",\"followers\",\"following\",\"friend_request\",\"friendrequest\",\"friends\",\"goodies\",\"help\",\"home\",\"im_account\",\"inbox\",\"invitations\",\"invite\",\"jobs\",\"list\",\"login\",\"logo\",\"logout\",\"me\",\"mentions\",\"messages\",\"mockview\",\"newtwitter\",\"notifications\",\"nudge\",\"oauth\",\"phoenix_search\",\"positions\",\"privacy\",\"public_timeline\",\"related_tweets\",\"replies\",\"retweeted_of_mine\",\"retweets\",\"retweets_by_others\",\"rules\",\"saved_searches\",\"search\",\"sent\",\"settings\",\"share\",\"signup\",\"signin\",\"similar_to\",\"statistics\",\"terms\",\"tos\",\"translate\",\"trends\",\"tweetbutton\",\"twttr\",\"update_discoverability\",\"users\",\"welcome\",\"who_to_follow\",\"widgets\",\"zendesk_auth\",\"media_signup\"],\"photo_size_limit\":3145728},\"scribeBufferSize\":10,\"isPreflight\":false},\"countries\":[{\"name\":\"Worldwide\",\"code\":\"xx\"},{\"name\":\"Afghanistan\",\"code\":\"af\"},{\"name\":\"Algeria\",\"code\":\"dz\"},{\"name\":\"Argentina\",\"code\":\"ar\"},{\"name\":\"Australia\",\"code\":\"au\"},{\"name\":\"Bangladesh\",\"code\":\"bd\"},{\"name\":\"Brazil\",\"code\":\"br\"},{\"name\":\"Cameroon\",\"code\":\"cm\"},{\"name\":\"Canada\",\"code\":\"ca\"},{\"name\":\"Colombia\",\"code\":\"co\"},{\"name\":\"Denmark\",\"code\":\"dk\"},{\"name\":\"Egypt\",\"code\":\"eg\"},{\"name\":\"Ethiopia\",\"code\":\"et\"},{\"name\":\"France\",\"code\":\"fr\"},{\"name\":\"Germany\",\"code\":\"de\"},{\"name\":\"Ghana\",\"code\":\"gh\"},{\"name\":\"Greece\",\"code\":\"gr\"},{\"name\":\"India\",\"code\":\"in\"},{\"name\":\"Indonesia\",\"code\":\"id\"},{\"name\":\"Iraq\",\"code\":\"iq\"},{\"name\":\"Ireland\",\"code\":\"ie\"},{\"name\":\"Israel\",\"code\":\"il\"},{\"name\":\"Italy\",\"code\":\"it\"},{\"name\":\"Japan\",\"code\":\"jp\"},{\"name\":\"Kenya\",\"code\":\"ke\"},{\"name\":\"Madagascar\",\"code\":\"mg\"},{\"name\":\"Malaysia\",\"code\":\"my\"},{\"name\":\"Mexico\",\"code\":\"mx\"},{\"name\":\"Morocco\",\"code\":\"ma\"},{\"name\":\"Mozambique\",\"code\":\"mz\"},{\"name\":\"Nepal\",\"code\":\"np\"},{\"name\":\"Netherlands\",\"code\":\"nl\"},{\"name\":\"New Zealand\",\"code\":\"nz\"},{\"name\":\"Nigeria\",\"code\":\"ni\"},{\"name\":\"Pakistan\",\"code\":\"pk\"},{\"name\":\"Peru\",\"code\":\"pe\"},{\"name\":\"Philippines\",\"code\":\"ph\"},{\"name\":\"Poland\",\"code\":\"pl\"},{\"name\":\"Republic of Korea\",\"code\":\"kr\"},{\"name\":\"Romania\",\"code\":\"ro\"},{\"name\":\"Russia\",\"code\":\"ru\"},{\"name\":\"Saudi Arabia\",\"code\":\"sa\"},{\"name\":\"Singapore\",\"code\":\"sg\"},{\"name\":\"South Africa\",\"code\":\"za\"},{\"name\":\"Spain\",\"code\":\"es\"},{\"name\":\"Sri Lanka\",\"code\":\"lk\"},{\"name\":\"Sweden\",\"code\":\"se\"},{\"name\":\"Switzerland\",\"code\":\"ch\"},{\"name\":\"Taiwan\",\"code\":\"tw\"},{\"name\":\"Tanzania\",\"code\":\"tz\"},{\"name\":\"Thailand\",\"code\":\"th\"},{\"name\":\"Turkey\",\"code\":\"tr\"},{\"name\":\"Uganda\",\"code\":\"ug\"},{\"name\":\"Ukraine\",\"code\":\"ua\"},{\"name\":\"United Kingdom\",\"code\":\"gb\"},{\"name\":\"United States\",\"code\":\"us\"},{\"name\":\"Uzbekistan\",\"code\":\"uz\"},{\"name\":\"Venezuela\",\"code\":\"ve\"},{\"name\":\"Vietnam\",\"code\":\"vn\"},{\"name\":\"Yemen\",\"code\":\"ye\"}],\"postAuthenticityToken\":\"9e50dac99e40371e3d0f8b00356e40a879e2278d\",\"deciderFeatures\":{\"phoenix_instagram_and_friends\":1,\"escape_ampersands_in_search_highlighter\":1,\"tweet_geo_component\":1,\"phoenix_search_relevance\":1,\"geo_ui_dropdown_available\":1,\"local_trends\":1,\"tweet_stream_following\":1,\"phoenix_apple_itunes_more\":1,\"in_reply_to_component\":1,\"welcome_profile\":1,\"api_per_country_takedown\":1,\"people_stream_fresh\":1,\"welcome_warm_signup\":1,\"phoenix_search_dropdown\":1,\"phoenix_local_plancast\":1,\"newest_list_members_component\":1,\"tweet_stream_home\":1,\"use_scribe_post\":1,\"phoenix_preload_twimgs\":1,\"japanese_new_ad_provider\":1,\"phoenix_pepsi_details\":1,\"linkify_cashtags\":1,\"swift_events\":1,\"tweet_stream_retweets_by_you_polling\":1,\"place_users_stream\":1,\"tweet_stream_favorites_polling\":1,\"whotofollow_similarities\":1,\"tweet_stream_retweets_by_you\":1,\"mobile_download_gallery\":1,\"phoenix_search_relevance_logged_out\":1,\"phoenix_autocomplete\":1,\"tweet_stream_retweets_by_others\":1,\"phoenix_apple_itunes\":1,\"scribe_form_piggyback\":1,\"tweet_streams_polling\":1,\"typeahead_saved_searches\":1,\"phoenix_flickr_details\":1,\"disable_gallery_thumbs\":1,\"media_flagging\":1,\"profile_image_latency\":1,\"phoenix_first_time\":1,\"personalization_preview\":1,\"swift_impression_cookie\":1,\"phoenix_local_meetup\":1,\"dashboard_activity_following\":1,\"turkey\":1,\"list_stream_memberships\":1,\"phoenix_facets_logged_out\":1,\"wtf_signup_suggestions\":1,\"scribe_client_event\":1,\"geo_more_places\":1,\"front_full_signup\":1,\"swift_lists\":1,\"phoenix_url_resolver\":1,\"tweet_streams\":1,\"phoenix_scribe\":1,\"onebox_user_search\":1,\"personalization_settings\":1,\"personalized_trends\":1,\"tweet_stream_mentions_polling\":1,\"place_tweets_component\":1,\"swift_login\":1,\"swift_favorites\":1,\"html5Routing\":1,\"more_lists_component\":1,\"embed_code_dialog\":1,\"disable_gallery_grid\":1,\"people_stream_people_search\":1,\"place_people_component\":1,\"ptw_reinjection\":1,\"advanced_search\":1,\"geo_location\":1,\"typeahead_global_nav\":1,\"i18n_new_translation_center\":1,\"tweet_stream_user_polling\":1,\"swift_events_reroute\":1,\"profile_tweetbox\":1,\"fake_loggedout_decider\":1,\"t1_dm_poll\":1,\"empty_timeline_recommendations\":1,\"user_onebox\":1,\"people_stream_friends\":1,\"tweet_stream_list_polling\":1,\"phoenix_local_foursquare\":1,\"people_stream_follower_requests\":1,\"phoenix_turkey_html5_resize\":1,\"swift_mentions\":1,\"bananaquit_show_opt_out\":1,\"user_shuffler\":1,\"contact_import\":1,\"geo_show_similar_places\":1,\"swift_facebook_token\":1,\"t1d_tweet_img\":1,\"ssl_cdn_akamai_fraction\":1,\"old_webclient_events\":1,\"swift_interactions\":1,\"tweet_stream_home_polling\":1,\"recent_tweets_component\":1,\"promoted_accounts_in_whotofollow_viewall\":1,\"email_device_settings\":1,\"news_onebox\":1,\"activity_status_summary\":1,\"tweet_stream_list\":1,\"tweet_stream_following_polling\":1,\"phoenix_tweetbox_talon\":1,\"activity_read\":1,\"tweet_stream_mentions\":1,\"swift_events_search\":1,\"typeahead_local_queries\":1,\"swift_action_queue\":1,\"tweet_stream_your_tweets_retweeted\":1,\"mobile_download_gallery_logged_out\":1,\"phoenix_facebook_details\":1,\"phoenix_facets\":1,\"people_streams\":1,\"flock\":1,\"tweet_stream_profile_polling\":1,\"t1d_tweet_vid\":1,\"message_stream\":1,\"swift_typeahead\":1,\"suggestion_categories_streams\":1,\"phoenix_pctd\":1,\"photo_copy_paste_inception\":1,\"geo_ui\":1,\"dashboard_activity_followers\":1,\"tweet_stream_favorites\":1,\"whotofollow_random_sample\":1,\"inline_media_component\":1,\"list_stream_subscriptions\":1,\"avatar_upload\":1,\"geo_place_creation\":1,\"phoenix_user_media_gallery\":1,\"logged_out_people_search\":1,\"platform_coerce_native_media_to_cards\":1,\"conversations\":1,\"phoenix_wordpress_details\":1,\"onebox\":1,\"sports_onebox\":1,\"people_stream_list_members\":1,\"phoenix_aol_video\":1,\"list_streams\":1,\"whotofollow_recommendations\":1,\"swift_discover\":1,\"social_context\":1,\"phoenix_whosay_details\":1,\"tweet_stream_your_tweets_retweeted_polling\":1,\"eurl_dwell_time_store\":1,\"swift_permalink\":1,\"t1d_topic_img\":1,\"search_assistance\":1,\"typeahead\":1,\"welcome_ad_track\":1,\"wtf_home_timeline_show_links\":1,\"sports_onebox_polling\":1,\"tweet_stream_profile\":1,\"contact_import_stream\":1,\"phoenix_facets_videos\":1,\"tweet_stream_user\":1,\"scribe_image_failures\":1,\"phoenix_turkey_permalink\":1,\"people_stream_followers\":1,\"phoenix_turkey_flash\":1,\"swift_profile\":1,\"trends_component_polling\":1,\"promo_component\":1,\"activity_modal\":1,\"profile_pane_fresh\":1,\"tweet_stream_retweets_by_others_polling\":1,\"big_photo_permalink\":1,\"tweet_stream_search_polling\":1,\"mt_tweet_backend_bing\":1,\"trends_component\":1,\"blender_search_timeline\":1,\"japanese_ad_component\":1,\"geo_allow_set_location_manually\":1,\"bananaquit_dnt_scribe\":1,\"phoenix_amazon_details\":1,\"phoenix_local_gowalla\":1,\"profile_combined_api\":1,\"infinite_scroll\":1,\"phoenix_facets_images\":1,\"t1d_topic_vid\":1,\"add_authenticity_token_via_js\":1,\"tweet_stream_search\":1,\"people_stream_list_followers\":1,\"promptbird_phoenix\":1,\"list_stream_own_lists\":1},\"abBuckets\":{\"mobile_download_app_header_335\":{\"version\":3,\"bucket_names\":[\"control\",\"download_signin\",\"download_signup\",\"launch_signin\"],\"bucket\":\"download_signup\",\"experiment_key\":\"mobile_download_app_header_335\"},\"signup_mailto_on_welcome_312\":{\"version\":4,\"bucket_names\":[\"control\",\"usual\"],\"bucket\":\"usual\",\"experiment_key\":\"signup_mailto_on_welcome_312\"},\"timeline_copy_317\":{\"version\":3,\"bucket_names\":[\"control\",\"stream\"],\"bucket\":\"control\",\"experiment_key\":\"timeline_copy_317\"},\"tweet_permalink_logged_out_action_330\":{\"version\":3,\"bucket_names\":[\"control\",\"current\"],\"bucket\":\"control\",\"experiment_key\":\"tweet_permalink_logged_out_action_330\"},\"mobile_refresh_captcha_311\":{\"version\":2,\"bucket_names\":[\"control\",\"refresh_captcha\"],\"bucket\":\"refresh_captcha\",\"experiment_key\":\"mobile_refresh_captcha_311\"}}}";
// 1274
f693592812_415.returns.push(o16);
// 1276
o17.value = "";
// undefined
o17 = null;
// 1282
f693592812_415.returns.push(o18);
// 1284
o19.value = "";
// undefined
o19 = null;
// 1290
f693592812_415.returns.push(o20);
// 1292
o21.value = "";
// undefined
o21 = null;
// 1302
f693592812_415.returns.push(o23);
// 1304
o24.value = "";
// undefined
o24 = null;
// 1310
f693592812_415.returns.push(o25);
// 1312
o26.value = "";
// undefined
o26 = null;
// 1357
f693592812_415.returns.push(o16);
// 1365
f693592812_415.returns.push(o18);
// 1373
f693592812_415.returns.push(o20);
// 1385
f693592812_415.returns.push(o23);
// 1393
f693592812_415.returns.push(o25);
// 1440
f693592812_415.returns.push(o16);
// 1448
f693592812_415.returns.push(o18);
// 1456
f693592812_415.returns.push(o20);
// 1468
f693592812_415.returns.push(o23);
// 1476
f693592812_415.returns.push(o25);
// 1514
o17 = {};
// 1515
ow693592812.JSBNG__event = undefined;
// 1516
o17.type = "load";
// undefined
o17 = null;
// 1517
// 1518
o4.userAgent = "Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.1 (KHTML, like Gecko) QtTestBrowser/0.1 Safari/537.1";
// 1519
o0.nodeType = 9;
// 1520
o0.JSBNG__addEventListener = f693592812_487;
// 1522
o17 = {};
// 1523
f693592812_400.returns.push(o17);
// 1524
o0.documentElement = o8;
// 1525
f693592812_495 = function() { return f693592812_495.returns[f693592812_495.inst++]; };
f693592812_495.returns = [];
f693592812_495.inst = 0;
// 1526
o17.setAttribute = f693592812_495;
// 1527
f693592812_495.returns.push(undefined);
// 1528
// 1529
o17.getElementsByTagName = f693592812_415;
// 1530
o19 = {};
// 1531
f693592812_415.returns.push(o19);
// 1533
o21 = {};
// 1534
f693592812_415.returns.push(o21);
// 1535
o24 = {};
// 1536
o21["0"] = o24;
// undefined
o21 = null;
// 1537
o19.length = 4;
// undefined
o19 = null;
// 1539
o19 = {};
// 1540
f693592812_400.returns.push(o19);
// 1541
f693592812_500 = function() { return f693592812_500.returns[f693592812_500.inst++]; };
f693592812_500.returns = [];
f693592812_500.inst = 0;
// 1542
o19.appendChild = f693592812_500;
// 1544
o21 = {};
// 1545
f693592812_400.returns.push(o21);
// 1546
f693592812_500.returns.push(o21);
// 1548
o26 = {};
// 1549
f693592812_415.returns.push(o26);
// 1550
o39 = {};
// 1551
o26["0"] = o39;
// undefined
o26 = null;
// 1552
o26 = {};
// 1553
o17.firstChild = o26;
// 1554
o26.nodeType = 3;
// undefined
o26 = null;
// 1556
o26 = {};
// 1557
f693592812_415.returns.push(o26);
// 1558
o26.length = 0;
// undefined
o26 = null;
// 1560
o26 = {};
// 1561
f693592812_415.returns.push(o26);
// 1562
o26.length = 1;
// undefined
o26 = null;
// 1563
o24.getAttribute = f693592812_474;
// 1564
f693592812_474.returns.push("top:1px;float:left;opacity:.55;");
// 1566
f693592812_474.returns.push("/a");
// 1567
o26 = {};
// 1568
o24.style = o26;
// undefined
o24 = null;
// 1569
o26.opacity = "0.55";
// 1571
o26.cssFloat = "left";
// undefined
o26 = null;
// 1572
o39.value = "on";
// 1573
o21.selected = "true";
// 1574
o17.className = "";
// 1576
o24 = {};
// 1577
f693592812_400.returns.push(o24);
// 1578
o24.enctype = "application/x-www-form-urlencoded";
// undefined
o24 = null;
// 1580
o24 = {};
// 1581
f693592812_400.returns.push(o24);
// 1582
o24.cloneNode = f693592812_478;
// undefined
o24 = null;
// 1583
o24 = {};
// 1584
f693592812_478.returns.push(o24);
// 1585
o24.outerHTML = "<nav></nav>";
// undefined
o24 = null;
// 1586
// 1587
o39.cloneNode = f693592812_478;
// undefined
o39 = null;
// 1588
o24 = {};
// 1589
f693592812_478.returns.push(o24);
// 1590
o24.checked = "true";
// undefined
o24 = null;
// 1591
// undefined
o19 = null;
// 1592
o21.disabled = "false";
// undefined
o21 = null;
// 1593
// 1594
o17.JSBNG__addEventListener = f693592812_487;
// 1596
o19 = {};
// 1597
f693592812_400.returns.push(o19);
// 1598
// 1599
o19.setAttribute = f693592812_495;
// 1600
f693592812_495.returns.push(undefined);
// 1603
f693592812_495.returns.push(undefined);
// 1604
o17.appendChild = f693592812_500;
// 1605
f693592812_500.returns.push(o19);
// 1606
f693592812_513 = function() { return f693592812_513.returns[f693592812_513.inst++]; };
f693592812_513.returns = [];
f693592812_513.inst = 0;
// 1607
o0.createDocumentFragment = f693592812_513;
// 1608
o21 = {};
// 1609
f693592812_513.returns.push(o21);
// 1610
o21.appendChild = f693592812_500;
// 1611
o17.lastChild = o19;
// 1612
f693592812_500.returns.push(o19);
// 1613
o21.cloneNode = f693592812_478;
// 1614
o24 = {};
// 1615
f693592812_478.returns.push(o24);
// 1616
o24.cloneNode = f693592812_478;
// undefined
o24 = null;
// 1617
o24 = {};
// 1618
f693592812_478.returns.push(o24);
// 1619
o26 = {};
// 1620
o24.lastChild = o26;
// undefined
o24 = null;
// 1621
o26.checked = "true";
// undefined
o26 = null;
// 1622
o19.checked = "true";
// 1623
f693592812_518 = function() { return f693592812_518.returns[f693592812_518.inst++]; };
f693592812_518.returns = [];
f693592812_518.inst = 0;
// 1624
o21.removeChild = f693592812_518;
// undefined
o21 = null;
// 1625
f693592812_518.returns.push(o19);
// undefined
o19 = null;
// 1627
f693592812_500.returns.push(o17);
// 1628
// 1630
o19 = {};
// 1631
f693592812_400.returns.push(o19);
// 1632
o21 = {};
// 1633
o19.style = o21;
// 1634
// 1636
// undefined
o21 = null;
// 1637
o21 = {};
// 1638
o17.style = o21;
// 1639
// undefined
o21 = null;
// 1641
f693592812_500.returns.push(o19);
// undefined
o19 = null;
// 1642
o19 = {};
// 1643
f693592812_4.returns.push(o19);
// 1644
o19.marginRight = "";
// undefined
o19 = null;
// 1645
o17.JSBNG__attachEvent = void 0;
// 1647
f693592812_518.returns.push(o17);
// undefined
o17 = null;
// 1648
o0.readyState = "interactive";
// 1651
f693592812_487.returns.push(undefined);
// 1652
f693592812_7.returns.push(undefined);
// 1653
f693592812_393.returns.push(0.9642799841240048);
// 1654
f693592812_523 = function() { return f693592812_523.returns[f693592812_523.inst++]; };
f693592812_523.returns = [];
f693592812_523.inst = 0;
// 1655
o0.JSBNG__removeEventListener = f693592812_523;
// 1656
f693592812_393.returns.push(0.30541597050614655);
// 1658
o17 = {};
// 1659
o8.childNodes = o17;
// 1660
o17.length = 3;
// 1661
o17["0"] = o10;
// 1662
o19 = {};
// 1663
o17["1"] = o19;
// undefined
o19 = null;
// 1664
o17["2"] = o12;
// undefined
o17 = null;
// 1666
f693592812_526 = function() { return f693592812_526.returns[f693592812_526.inst++]; };
f693592812_526.returns = [];
f693592812_526.inst = 0;
// 1667
o8.compareDocumentPosition = f693592812_526;
// 1669
o17 = {};
// 1670
f693592812_400.returns.push(o17);
// 1671
o19 = {};
// 1672
f693592812_0.returns.push(o19);
// 1673
o19.getTime = f693592812_395;
// undefined
o19 = null;
// 1674
f693592812_395.returns.push(1345562151703);
// 1676
// 1677
o8.insertBefore = f693592812_481;
// 1678
o8.firstChild = o10;
// 1679
f693592812_481.returns.push(o17);
// 1681
f693592812_413.returns.push(null);
// 1682
o8.removeChild = f693592812_518;
// 1683
f693592812_518.returns.push(o17);
// undefined
o17 = null;
// 1685
o17 = {};
// 1686
f693592812_400.returns.push(o17);
// 1687
o17.appendChild = f693592812_500;
// 1688
f693592812_530 = function() { return f693592812_530.returns[f693592812_530.inst++]; };
f693592812_530.returns = [];
f693592812_530.inst = 0;
// 1689
o0.createComment = f693592812_530;
// 1690
o19 = {};
// 1691
f693592812_530.returns.push(o19);
// 1692
f693592812_500.returns.push(o19);
// undefined
o19 = null;
// 1693
o17.getElementsByTagName = f693592812_415;
// 1694
o19 = {};
// 1695
f693592812_415.returns.push(o19);
// 1696
o19.length = 0;
// undefined
o19 = null;
// 1697
// 1698
o19 = {};
// 1699
o17.firstChild = o19;
// undefined
o17 = null;
// 1701
o19.getAttribute = f693592812_474;
// undefined
o19 = null;
// 1704
f693592812_474.returns.push("#");
// 1705
f693592812_534 = function() { return f693592812_534.returns[f693592812_534.inst++]; };
f693592812_534.returns = [];
f693592812_534.inst = 0;
// 1706
o0.querySelectorAll = f693592812_534;
// 1708
o17 = {};
// 1709
f693592812_400.returns.push(o17);
// 1710
// 1711
f693592812_536 = function() { return f693592812_536.returns[f693592812_536.inst++]; };
f693592812_536.returns = [];
f693592812_536.inst = 0;
// 1712
o17.querySelectorAll = f693592812_536;
// undefined
o17 = null;
// 1714
o17 = {};
// 1715
f693592812_536.returns.push(o17);
// 1716
o17.length = 1;
// undefined
o17 = null;
// 1718
o8.matchesSelector = void 0;
// 1719
o8.mozMatchesSelector = void 0;
// 1720
f693592812_538 = function() { return f693592812_538.returns[f693592812_538.inst++]; };
f693592812_538.returns = [];
f693592812_538.inst = 0;
// 1721
o8.webkitMatchesSelector = f693592812_538;
// 1723
o17 = {};
// 1724
f693592812_400.returns.push(o17);
// undefined
o17 = null;
// 1725
f693592812_538.returns.push(true);
// 1728
o17 = {};
// 1729
f693592812_400.returns.push(o17);
// 1730
// 1731
f693592812_541 = function() { return f693592812_541.returns[f693592812_541.inst++]; };
f693592812_541.returns = [];
f693592812_541.inst = 0;
// 1732
o17.getElementsByClassName = f693592812_541;
// 1734
o19 = {};
// 1735
f693592812_541.returns.push(o19);
// undefined
fo693592812_542_length = function() { return fo693592812_542_length.returns[fo693592812_542_length.inst++]; };
fo693592812_542_length.returns = [];
fo693592812_542_length.inst = 0;
defineGetter(o19, "length", fo693592812_542_length);
// undefined
fo693592812_542_length.returns.push(1);
// 1737
o21 = {};
// 1738
o17.lastChild = o21;
// undefined
o17 = null;
// 1739
// undefined
o21 = null;
// 1741
f693592812_541.returns.push(o19);
// undefined
o19 = null;
// undefined
fo693592812_542_length.returns.push(2);
// 1744
f693592812_544 = function() { return f693592812_544.returns[f693592812_544.inst++]; };
f693592812_544.returns = [];
f693592812_544.inst = 0;
// 1745
o8.contains = f693592812_544;
// 1747
o17 = {};
// 1748
f693592812_513.returns.push(o17);
// 1749
o17.createElement = void 0;
// undefined
o17 = null;
// 1750
o0.defaultView = ow693592812;
// 1753
o8.currentStyle = void 0;
// 1755
o17 = {};
// 1756
f693592812_0.returns.push(o17);
// 1757
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 1758
f693592812_395.returns.push(1345562151746);
// 1759
o17 = {};
// 1760
f693592812_55.returns.push(o17);
// undefined
o17 = null;
// 1762
o17 = {};
// 1763
f693592812_0.prototype = o17;
// 1764
f693592812_549 = function() { return f693592812_549.returns[f693592812_549.inst++]; };
f693592812_549.returns = [];
f693592812_549.inst = 0;
// 1765
o17.toJSON = f693592812_549;
// undefined
o17 = null;
// 1768
o17 = {};
// 1769
f693592812_0.returns.push(o17);
// undefined
o17 = null;
// 1772
o17 = {};
// 1773
f693592812_400.returns.push(o17);
// 1774
o19 = {};
// 1775
o17.style = o19;
// undefined
o17 = null;
// 1777
o17 = {};
// 1778
f693592812_400.returns.push(o17);
// 1780
o21 = {};
// 1781
f693592812_400.returns.push(o21);
// 1782
f693592812_555 = function() { return f693592812_555.returns[f693592812_555.inst++]; };
f693592812_555.returns = [];
f693592812_555.inst = 0;
// 1783
o21.getContext = f693592812_555;
// undefined
o21 = null;
// 1785
o21 = {};
// 1786
f693592812_400.returns.push(o21);
// 1787
o21.getContext = f693592812_555;
// undefined
o21 = null;
// 1789
o21 = {};
// 1790
f693592812_400.returns.push(o21);
// 1791
o21.getContext = f693592812_555;
// undefined
o21 = null;
// 1792
o21 = {};
// 1793
f693592812_555.returns.push(o21);
// 1794
f693592812_559 = function() { return f693592812_559.returns[f693592812_559.inst++]; };
f693592812_559.returns = [];
f693592812_559.inst = 0;
// 1795
o21.fillText = f693592812_559;
// undefined
o21 = null;
// 1796
o21 = {};
// 1797
f693592812_54.returns.push(o21);
// undefined
o21 = null;
// 1798
o0.documentMode = void 0;
// 1799
f693592812_561 = function() { return f693592812_561.returns[f693592812_561.inst++]; };
f693592812_561.returns = [];
f693592812_561.inst = 0;
// 1800
o5.pushState = f693592812_561;
// undefined
o5 = null;
// 1802
o5 = {};
// 1803
f693592812_400.returns.push(o5);
// 1804
o5.setAttribute = f693592812_495;
// 1806
f693592812_495.returns.push(undefined);
// 1807
f693592812_563 = function() { return f693592812_563.returns[f693592812_563.inst++]; };
f693592812_563.returns = [];
f693592812_563.inst = 0;
// 1808
o5.ondrag = f693592812_563;
// undefined
o5 = null;
// 1810
o5 = {};
// 1811
f693592812_400.returns.push(o5);
// 1812
o5.setAttribute = f693592812_495;
// 1814
f693592812_495.returns.push(undefined);
// 1815
f693592812_565 = function() { return f693592812_565.returns[f693592812_565.inst++]; };
f693592812_565.returns = [];
f693592812_565.inst = 0;
// 1816
o5.ondragstart = f693592812_565;
// undefined
o5 = null;
// 1818
o5 = {};
// 1819
f693592812_400.returns.push(o5);
// 1820
o5.setAttribute = f693592812_495;
// 1822
f693592812_495.returns.push(undefined);
// 1823
f693592812_567 = function() { return f693592812_567.returns[f693592812_567.inst++]; };
f693592812_567.returns = [];
f693592812_567.inst = 0;
// 1824
o5.ondragenter = f693592812_567;
// undefined
o5 = null;
// 1826
o5 = {};
// 1827
f693592812_400.returns.push(o5);
// 1828
o5.setAttribute = f693592812_495;
// 1830
f693592812_495.returns.push(undefined);
// 1831
f693592812_569 = function() { return f693592812_569.returns[f693592812_569.inst++]; };
f693592812_569.returns = [];
f693592812_569.inst = 0;
// 1832
o5.ondragover = f693592812_569;
// undefined
o5 = null;
// 1834
o5 = {};
// 1835
f693592812_400.returns.push(o5);
// 1836
o5.setAttribute = f693592812_495;
// 1838
f693592812_495.returns.push(undefined);
// 1839
f693592812_571 = function() { return f693592812_571.returns[f693592812_571.inst++]; };
f693592812_571.returns = [];
f693592812_571.inst = 0;
// 1840
o5.ondragleave = f693592812_571;
// undefined
o5 = null;
// 1842
o5 = {};
// 1843
f693592812_400.returns.push(o5);
// 1844
o5.setAttribute = f693592812_495;
// 1846
f693592812_495.returns.push(undefined);
// 1847
f693592812_573 = function() { return f693592812_573.returns[f693592812_573.inst++]; };
f693592812_573.returns = [];
f693592812_573.inst = 0;
// 1848
o5.ondragend = f693592812_573;
// undefined
o5 = null;
// 1850
o5 = {};
// 1851
f693592812_400.returns.push(o5);
// 1852
o5.setAttribute = f693592812_495;
// 1854
f693592812_495.returns.push(undefined);
// 1855
f693592812_575 = function() { return f693592812_575.returns[f693592812_575.inst++]; };
f693592812_575.returns = [];
f693592812_575.inst = 0;
// 1856
o5.ondrop = f693592812_575;
// undefined
o5 = null;
// 1857
// undefined
fo693592812_552_backgroundColor = function() { return fo693592812_552_backgroundColor.returns[fo693592812_552_backgroundColor.inst++]; };
fo693592812_552_backgroundColor.returns = [];
fo693592812_552_backgroundColor.inst = 0;
defineGetter(o19, "backgroundColor", fo693592812_552_backgroundColor);
// undefined
fo693592812_552_backgroundColor.returns.push("rgba(150, 255, 150, 0.496094)");
// 1859
// undefined
fo693592812_552_backgroundColor.returns.push("rgba(255, 255, 255, 0.496094)");
// 1861
// 1862
o19.background = "url(http:/), url(http:/), url(http:/) red";
// 1863
o19.backgroundSize = "initial, initial, initial";
// 1864
o19.borderImage = "";
// 1865
o19.borderRadius = "";
// 1866
o19.boxShadow = "";
// 1867
// 1868
o19.opacity = "0.5";
// 1869
o19.animationName = void 0;
// 1870
o19.WebkitAnimationName = "";
// 1871
o19.columnCount = void 0;
// 1872
o19.WebkitColumnCount = "";
// 1873
// 1874
o19.backgroundImage = "-webkit-linear-gradient(left top, rgb(153, 255, 153), white)";
// 1875
o19.boxReflect = void 0;
// 1876
o19.WebkitBoxReflect = "";
// 1877
o19.transformProperty = void 0;
// 1878
o19.WebkitTransform = "";
// 1879
o19.perspectiveProperty = void 0;
// 1880
o19.WebkitPerspective = "";
// 1882
o5 = {};
// 1883
f693592812_400.returns.push(o5);
// 1885
o21 = {};
// 1886
f693592812_400.returns.push(o21);
// 1887
// 1889
o24 = {};
// 1890
f693592812_396.returns.push(o24);
// 1891
o24["0"] = o10;
// undefined
o24 = null;
// 1892
o10.appendChild = f693592812_500;
// 1893
f693592812_500.returns.push(o5);
// 1894
// 1895
o8.appendChild = f693592812_500;
// 1896
f693592812_500.returns.push(o21);
// 1897
o21.offsetHeight = 3;
// 1898
o5.parentNode = o10;
// 1899
o10.removeChild = f693592812_518;
// 1900
f693592812_518.returns.push(o5);
// undefined
o5 = null;
// 1901
o21.parentNode = o8;
// 1903
f693592812_518.returns.push(o21);
// undefined
o21 = null;
// 1904
o19.transitionProperty = void 0;
// 1905
o19.WebkitTransitionProperty = "";
// 1907
o5 = {};
// 1908
f693592812_400.returns.push(o5);
// 1909
o5.canPlayType = void 0;
// undefined
o5 = null;
// 1911
o5 = {};
// 1912
f693592812_400.returns.push(o5);
// 1913
o5.canPlayType = void 0;
// undefined
o5 = null;
// 1914
o3.JSBNG__status = 0;
// undefined
o3 = null;
// 1915
f693592812_581 = function() { return f693592812_581.returns[f693592812_581.inst++]; };
f693592812_581.returns = [];
f693592812_581.inst = 0;
// 1916
o0.createElementNS = f693592812_581;
// 1918
o3 = {};
// 1919
f693592812_581.returns.push(o3);
// 1920
f693592812_583 = function() { return f693592812_583.returns[f693592812_583.inst++]; };
f693592812_583.returns = [];
f693592812_583.inst = 0;
// 1921
o3.createSVGRect = f693592812_583;
// undefined
o3 = null;
// 1924
o3 = {};
// 1925
f693592812_581.returns.push(o3);
// undefined
o3 = null;
// 1928
o3 = {};
// 1929
f693592812_581.returns.push(o3);
// undefined
o3 = null;
// 1930
o17.setAttribute = f693592812_495;
// 1931
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type = function() { return fo693592812_553_type.returns[fo693592812_553_type.inst++]; };
fo693592812_553_type.returns = [];
fo693592812_553_type.inst = 0;
defineGetter(o17, "type", fo693592812_553_type);
// undefined
fo693592812_553_type.returns.push("search");
// undefined
fo693592812_553_type.returns.push("search");
// 1936
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("tel");
// undefined
fo693592812_553_type.returns.push("tel");
// 1941
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("url");
// undefined
fo693592812_553_type.returns.push("url");
// undefined
fo693592812_553_type.returns.push("url");
// 1946
f693592812_586 = function() { return f693592812_586.returns[f693592812_586.inst++]; };
f693592812_586.returns = [];
f693592812_586.inst = 0;
// 1947
o17.checkValidity = f693592812_586;
// 1949
f693592812_586.returns.push(false);
// 1951
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("email");
// undefined
fo693592812_553_type.returns.push("email");
// undefined
fo693592812_553_type.returns.push("email");
// 1958
f693592812_586.returns.push(false);
// 1960
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1963
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1966
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1969
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1972
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1975
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1978
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("number");
// undefined
fo693592812_553_type.returns.push("number");
// undefined
fo693592812_553_type.returns.push("number");
// undefined
fo693592812_553_value = function() { return fo693592812_553_value.returns[fo693592812_553_value.inst++]; };
fo693592812_553_value.returns = [];
fo693592812_553_value.inst = 0;
defineGetter(o17, "value", fo693592812_553_value);
// undefined
o17 = null;
// undefined
fo693592812_553_value.returns.push("");
// 1985
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("range");
// undefined
fo693592812_553_type.returns.push("range");
// undefined
fo693592812_553_type.returns.push("range");
// undefined
fo693592812_553_value.returns.push("50");
// 1992
f693592812_495.returns.push(undefined);
// undefined
fo693592812_553_type.returns.push("text");
// 1994
// undefined
o19 = null;
// 1996
o3 = {};
// 1997
f693592812_400.returns.push(o3);
// 1998
// 1999
o5 = {};
// 2000
o3.childNodes = o5;
// undefined
o3 = null;
// 2001
o5.length = 1;
// undefined
o5 = null;
// undefined
fo693592812_398_className.returns.push(" ");
// 2005
o8.addBehavior = void 0;
// 2006
f693592812_589 = function() { return f693592812_589.returns[f693592812_589.inst++]; };
f693592812_589.returns = [];
f693592812_589.inst = 0;
// 2007
o2.getItem = f693592812_589;
// 2008
f693592812_589.returns.push(null);
// 2010
f693592812_589.returns.push(null);
// 2011
f693592812_13.returns.push(2);
// 2012
o3 = {};
// 2013
f693592812_0.returns.push(o3);
// undefined
o3 = null;
// 2016
o1.getItem = f693592812_589;
// 2017
f693592812_589.returns.push(null);
// 2018
f693592812_7.returns.push(undefined);
// 2022
o0.nodeName = "#document";
// undefined
fo693592812_1_jQuery17109642799841240048 = function() { return fo693592812_1_jQuery17109642799841240048.returns[fo693592812_1_jQuery17109642799841240048.inst++]; };
fo693592812_1_jQuery17109642799841240048.returns = [];
fo693592812_1_jQuery17109642799841240048.inst = 0;
defineGetter(o0, "jQuery17109642799841240048", fo693592812_1_jQuery17109642799841240048);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(void 0);
// 2029
f693592812_487.returns.push(undefined);
// 2030
f693592812_7.returns.push(undefined);
// 2031
o6.host = "twitter.com";
// undefined
o6 = null;
// 2033
f693592812_589.returns.push(null);
// 2035
f693592812_589.returns.push(null);
// 2037
f693592812_589.returns.push(null);
// 2039
f693592812_589.returns.push(null);
// 2041
f693592812_589.returns.push(null);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl");
// 2045
o3 = {};
// 2046
f693592812_0.returns.push(o3);
// 2047
f693592812_592 = function() { return f693592812_592.returns[f693592812_592.inst++]; };
f693592812_592.returns = [];
f693592812_592.inst = 0;
// 2048
o3.setTime = f693592812_592;
// 2049
o3.getTime = f693592812_395;
// 2050
f693592812_395.returns.push(1345562152240);
// 2051
f693592812_592.returns.push(1348154152240);
// 2052
f693592812_593 = function() { return f693592812_593.returns[f693592812_593.inst++]; };
f693592812_593.returns = [];
f693592812_593.inst = 0;
// 2053
o3.toUTCString = f693592812_593;
// undefined
o3 = null;
// 2054
f693592812_593.returns.push("Thu, 20 Sep 2012 15:15:52 GMT");
// 2057
f693592812_7.returns.push(undefined);
// 2059
o3 = {};
// 2060
f693592812_0.returns.push(o3);
// 2061
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 2062
f693592812_395.returns.push(1345562152307);
// 2064
o3 = {};
// 2065
f693592812_400.returns.push(o3);
// 2066
o3.nodeType = 1;
// 2068
o3.nodeName = "DIV";
// 2071
o3.jQuery17109642799841240048 = void 0;
// 2072
// 2073
o3.JSBNG__addEventListener = f693592812_487;
// undefined
o3 = null;
// 2075
f693592812_487.returns.push(undefined);
// 2076
o3 = {};
// 2077
f693592812_0.returns.push(o3);
// 2078
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 2079
f693592812_395.returns.push(1345562152308);
// 2081
o3 = {};
// 2082
f693592812_400.returns.push(o3);
// 2083
o3.nodeType = 1;
// 2085
o3.nodeName = "DIV";
// 2088
o3.jQuery17109642799841240048 = void 0;
// 2089
// 2090
o3.JSBNG__addEventListener = f693592812_487;
// undefined
o3 = null;
// 2092
f693592812_487.returns.push(undefined);
// 2093
o3 = {};
// 2094
f693592812_0.returns.push(o3);
// 2095
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 2096
f693592812_395.returns.push(1345562152332);
// 2098
o3 = {};
// 2099
f693592812_400.returns.push(o3);
// 2100
o3.nodeType = 1;
// 2102
o3.nodeName = "DIV";
// undefined
fo693592812_599_jQuery17109642799841240048 = function() { return fo693592812_599_jQuery17109642799841240048.returns[fo693592812_599_jQuery17109642799841240048.inst++]; };
fo693592812_599_jQuery17109642799841240048.returns = [];
fo693592812_599_jQuery17109642799841240048.inst = 0;
defineGetter(o3, "jQuery17109642799841240048", fo693592812_599_jQuery17109642799841240048);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(void 0);
// 2107
o3.JSBNG__addEventListener = f693592812_487;
// 2109
f693592812_487.returns.push(undefined);
// 2112
o5 = {};
// 2113
f693592812_0.returns.push(o5);
// 2114
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2115
f693592812_395.returns.push(1345562152335);
// 2116
o3.parentNode = null;
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2129
o3.onrouteAdded = void 0;
// 2132
o3.routeAdded = void 0;
// 2135
o5 = {};
// 2136
f693592812_0.returns.push(o5);
// 2137
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2138
f693592812_395.returns.push(1345562152338);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2158
o5 = {};
// 2159
f693592812_0.returns.push(o5);
// 2160
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2161
f693592812_395.returns.push(1345562152342);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2181
o5 = {};
// 2182
f693592812_0.returns.push(o5);
// 2183
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2184
f693592812_395.returns.push(1345562152343);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2204
o5 = {};
// 2205
f693592812_0.returns.push(o5);
// 2206
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2207
f693592812_395.returns.push(1345562152343);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2227
o5 = {};
// 2228
f693592812_0.returns.push(o5);
// 2229
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2230
f693592812_395.returns.push(1345562152344);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2250
o5 = {};
// 2251
f693592812_0.returns.push(o5);
// 2252
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2253
f693592812_395.returns.push(1345562152347);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2273
o5 = {};
// 2274
f693592812_0.returns.push(o5);
// 2275
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2276
f693592812_395.returns.push(1345562152348);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2296
o5 = {};
// 2297
f693592812_0.returns.push(o5);
// 2298
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2299
f693592812_395.returns.push(1345562152349);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2319
o5 = {};
// 2320
f693592812_0.returns.push(o5);
// 2321
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2322
f693592812_395.returns.push(1345562152350);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2342
o5 = {};
// 2343
f693592812_0.returns.push(o5);
// 2344
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2345
f693592812_395.returns.push(1345562152351);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2365
o5 = {};
// 2366
f693592812_0.returns.push(o5);
// 2367
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2368
f693592812_395.returns.push(1345562152354);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2388
o5 = {};
// 2389
f693592812_0.returns.push(o5);
// 2390
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2391
f693592812_395.returns.push(1345562152355);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2411
o5 = {};
// 2412
f693592812_0.returns.push(o5);
// 2413
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2414
f693592812_395.returns.push(1345562152356);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2434
o5 = {};
// 2435
f693592812_0.returns.push(o5);
// 2436
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2437
f693592812_395.returns.push(1345562152357);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2457
o5 = {};
// 2458
f693592812_0.returns.push(o5);
// 2459
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2460
f693592812_395.returns.push(1345562152358);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2480
o5 = {};
// 2481
f693592812_0.returns.push(o5);
// 2482
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2483
f693592812_395.returns.push(1345562152362);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2503
o5 = {};
// 2504
f693592812_0.returns.push(o5);
// 2505
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2506
f693592812_395.returns.push(1345562152363);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2526
o5 = {};
// 2527
f693592812_0.returns.push(o5);
// 2528
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2529
f693592812_395.returns.push(1345562152364);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2549
o5 = {};
// 2550
f693592812_0.returns.push(o5);
// 2551
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2552
f693592812_395.returns.push(1345562152364);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2572
o5 = {};
// 2573
f693592812_0.returns.push(o5);
// 2574
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2575
f693592812_395.returns.push(1345562152365);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2595
o5 = {};
// 2596
f693592812_0.returns.push(o5);
// 2597
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2598
f693592812_395.returns.push(1345562152368);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2618
o5 = {};
// 2619
f693592812_0.returns.push(o5);
// 2620
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2621
f693592812_395.returns.push(1345562152369);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2641
o5 = {};
// 2642
f693592812_0.returns.push(o5);
// 2643
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2644
f693592812_395.returns.push(1345562152393);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2664
o5 = {};
// 2665
f693592812_0.returns.push(o5);
// 2666
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2667
f693592812_395.returns.push(1345562152394);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2687
o5 = {};
// 2688
f693592812_0.returns.push(o5);
// 2689
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2690
f693592812_395.returns.push(1345562152395);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2710
o5 = {};
// 2711
f693592812_0.returns.push(o5);
// 2712
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2713
f693592812_395.returns.push(1345562152399);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2733
o5 = {};
// 2734
f693592812_0.returns.push(o5);
// 2735
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2736
f693592812_395.returns.push(1345562152400);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2756
o5 = {};
// 2757
f693592812_0.returns.push(o5);
// 2758
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2759
f693592812_395.returns.push(1345562152401);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2779
o5 = {};
// 2780
f693592812_0.returns.push(o5);
// 2781
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2782
f693592812_395.returns.push(1345562152402);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2802
o5 = {};
// 2803
f693592812_0.returns.push(o5);
// 2804
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2805
f693592812_395.returns.push(1345562152402);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2825
o5 = {};
// 2826
f693592812_0.returns.push(o5);
// 2827
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2828
f693592812_395.returns.push(1345562152405);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2848
o5 = {};
// 2849
f693592812_0.returns.push(o5);
// 2850
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2851
f693592812_395.returns.push(1345562152406);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2871
o5 = {};
// 2872
f693592812_0.returns.push(o5);
// 2873
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2874
f693592812_395.returns.push(1345562152407);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2894
o5 = {};
// 2895
f693592812_0.returns.push(o5);
// 2896
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2897
f693592812_395.returns.push(1345562152408);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2917
o5 = {};
// 2918
f693592812_0.returns.push(o5);
// 2919
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2920
f693592812_395.returns.push(1345562152409);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2940
o5 = {};
// 2941
f693592812_0.returns.push(o5);
// 2942
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2943
f693592812_395.returns.push(1345562152412);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2963
o5 = {};
// 2964
f693592812_0.returns.push(o5);
// 2965
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2966
f693592812_395.returns.push(1345562152413);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 2986
o5 = {};
// 2987
f693592812_0.returns.push(o5);
// 2988
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 2989
f693592812_395.returns.push(1345562152413);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3009
o5 = {};
// 3010
f693592812_0.returns.push(o5);
// 3011
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3012
f693592812_395.returns.push(1345562152414);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3032
o5 = {};
// 3033
f693592812_0.returns.push(o5);
// 3034
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3035
f693592812_395.returns.push(1345562152425);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3055
o5 = {};
// 3056
f693592812_0.returns.push(o5);
// 3057
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3058
f693592812_395.returns.push(1345562152426);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3078
o5 = {};
// 3079
f693592812_0.returns.push(o5);
// 3080
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3081
f693592812_395.returns.push(1345562152427);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3101
o5 = {};
// 3102
f693592812_0.returns.push(o5);
// 3103
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3104
f693592812_395.returns.push(1345562152427);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3124
o5 = {};
// 3125
f693592812_0.returns.push(o5);
// 3126
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3127
f693592812_395.returns.push(1345562152429);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3147
o5 = {};
// 3148
f693592812_0.returns.push(o5);
// 3149
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3150
f693592812_395.returns.push(1345562152433);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3171
o5 = {};
// 3172
f693592812_0.returns.push(o5);
// 3173
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3174
f693592812_395.returns.push(1345562152434);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3194
o5 = {};
// 3195
f693592812_0.returns.push(o5);
// 3196
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3197
f693592812_395.returns.push(1345562152435);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3218
o5 = {};
// 3219
f693592812_0.returns.push(o5);
// 3220
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3221
f693592812_395.returns.push(1345562152436);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3241
o5 = {};
// 3242
f693592812_0.returns.push(o5);
// 3243
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3244
f693592812_395.returns.push(1345562152437);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3266
o5 = {};
// 3267
f693592812_0.returns.push(o5);
// 3268
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3269
f693592812_395.returns.push(1345562152441);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3291
o5 = {};
// 3292
f693592812_0.returns.push(o5);
// 3293
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3294
f693592812_395.returns.push(1345562152442);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3316
o5 = {};
// 3317
f693592812_0.returns.push(o5);
// 3318
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3319
f693592812_395.returns.push(1345562152442);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3341
o5 = {};
// 3342
f693592812_0.returns.push(o5);
// 3343
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3344
f693592812_395.returns.push(1345562152443);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3364
o5 = {};
// 3365
f693592812_0.returns.push(o5);
// 3366
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3367
f693592812_395.returns.push(1345562152445);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3387
o5 = {};
// 3388
f693592812_0.returns.push(o5);
// 3389
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3390
f693592812_395.returns.push(1345562152448);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3410
o5 = {};
// 3411
f693592812_0.returns.push(o5);
// 3412
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3413
f693592812_395.returns.push(1345562152448);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3433
o5 = {};
// 3434
f693592812_0.returns.push(o5);
// 3435
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3436
f693592812_395.returns.push(1345562152449);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3456
o5 = {};
// 3457
f693592812_0.returns.push(o5);
// 3458
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3459
f693592812_395.returns.push(1345562152450);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3479
o5 = {};
// 3480
f693592812_0.returns.push(o5);
// 3481
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3482
f693592812_395.returns.push(1345562152453);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3502
o5 = {};
// 3503
f693592812_0.returns.push(o5);
// 3504
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3505
f693592812_395.returns.push(1345562152455);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3525
o5 = {};
// 3526
f693592812_0.returns.push(o5);
// 3527
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3528
f693592812_395.returns.push(1345562152455);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3548
o5 = {};
// 3549
f693592812_0.returns.push(o5);
// 3550
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3551
f693592812_395.returns.push(1345562152457);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3571
o5 = {};
// 3572
f693592812_0.returns.push(o5);
// 3573
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3574
f693592812_395.returns.push(1345562152458);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3594
o5 = {};
// 3595
f693592812_0.returns.push(o5);
// 3596
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3597
f693592812_395.returns.push(1345562152461);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3617
o5 = {};
// 3618
f693592812_0.returns.push(o5);
// 3619
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3620
f693592812_395.returns.push(1345562152462);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3640
o5 = {};
// 3641
f693592812_0.returns.push(o5);
// 3642
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3643
f693592812_395.returns.push(1345562152463);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3663
o5 = {};
// 3664
f693592812_0.returns.push(o5);
// 3665
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3666
f693592812_395.returns.push(1345562152466);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3686
o5 = {};
// 3687
f693592812_0.returns.push(o5);
// 3688
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3689
f693592812_395.returns.push(1345562152466);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3709
o5 = {};
// 3710
f693592812_0.returns.push(o5);
// 3711
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3712
f693592812_395.returns.push(1345562152470);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3732
o5 = {};
// 3733
f693592812_0.returns.push(o5);
// 3734
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3735
f693592812_395.returns.push(1345562152470);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3755
o5 = {};
// 3756
f693592812_0.returns.push(o5);
// 3757
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3758
f693592812_395.returns.push(1345562152471);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3778
o5 = {};
// 3779
f693592812_0.returns.push(o5);
// 3780
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3781
f693592812_395.returns.push(1345562152472);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3801
o5 = {};
// 3802
f693592812_0.returns.push(o5);
// 3803
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3804
f693592812_395.returns.push(1345562152473);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3824
o5 = {};
// 3825
f693592812_0.returns.push(o5);
// 3826
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3827
f693592812_395.returns.push(1345562152476);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3847
o5 = {};
// 3848
f693592812_0.returns.push(o5);
// 3849
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3850
f693592812_395.returns.push(1345562152477);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3870
o5 = {};
// 3871
f693592812_0.returns.push(o5);
// 3872
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3873
f693592812_395.returns.push(1345562152477);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3893
o5 = {};
// 3894
f693592812_0.returns.push(o5);
// 3895
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3896
f693592812_395.returns.push(1345562152478);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3916
o5 = {};
// 3917
f693592812_0.returns.push(o5);
// 3918
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3919
f693592812_395.returns.push(1345562152479);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3939
o5 = {};
// 3940
f693592812_0.returns.push(o5);
// 3941
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3942
f693592812_395.returns.push(1345562152483);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3962
o5 = {};
// 3963
f693592812_0.returns.push(o5);
// 3964
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3965
f693592812_395.returns.push(1345562152484);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 3985
o5 = {};
// 3986
f693592812_0.returns.push(o5);
// 3987
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 3988
f693592812_395.returns.push(1345562152485);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4008
o5 = {};
// 4009
f693592812_0.returns.push(o5);
// 4010
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4011
f693592812_395.returns.push(1345562152486);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4031
o5 = {};
// 4032
f693592812_0.returns.push(o5);
// 4033
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4034
f693592812_395.returns.push(1345562152487);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4054
o5 = {};
// 4055
f693592812_0.returns.push(o5);
// 4056
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4057
f693592812_395.returns.push(1345562152489);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4077
o5 = {};
// 4078
f693592812_0.returns.push(o5);
// 4079
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4080
f693592812_395.returns.push(1345562152490);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4100
o5 = {};
// 4101
f693592812_0.returns.push(o5);
// 4102
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4103
f693592812_395.returns.push(1345562152491);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4123
o5 = {};
// 4124
f693592812_0.returns.push(o5);
// 4125
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4126
f693592812_395.returns.push(1345562152492);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4146
o5 = {};
// 4147
f693592812_0.returns.push(o5);
// 4148
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4149
f693592812_395.returns.push(1345562152493);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4169
o5 = {};
// 4170
f693592812_0.returns.push(o5);
// 4171
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4172
f693592812_395.returns.push(1345562152496);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4192
o5 = {};
// 4193
f693592812_0.returns.push(o5);
// 4194
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4195
f693592812_395.returns.push(1345562152497);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4215
o5 = {};
// 4216
f693592812_0.returns.push(o5);
// 4217
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4218
f693592812_395.returns.push(1345562152498);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4238
o5 = {};
// 4239
f693592812_0.returns.push(o5);
// 4240
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4241
f693592812_395.returns.push(1345562152499);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4261
o5 = {};
// 4262
f693592812_0.returns.push(o5);
// 4263
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4264
f693592812_395.returns.push(1345562152501);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4284
o5 = {};
// 4285
f693592812_0.returns.push(o5);
// 4286
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4287
f693592812_395.returns.push(1345562152502);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4309
o5 = {};
// 4310
f693592812_0.returns.push(o5);
// 4311
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4312
f693592812_395.returns.push(1345562152504);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4334
o5 = {};
// 4335
f693592812_0.returns.push(o5);
// 4336
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4337
f693592812_395.returns.push(1345562152504);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4357
o5 = {};
// 4358
f693592812_0.returns.push(o5);
// 4359
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4360
f693592812_395.returns.push(1345562152506);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4382
o5 = {};
// 4383
f693592812_0.returns.push(o5);
// 4384
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4385
f693592812_395.returns.push(1345562152509);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4407
o5 = {};
// 4408
f693592812_0.returns.push(o5);
// 4409
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4410
f693592812_395.returns.push(1345562152510);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4430
o5 = {};
// 4431
f693592812_0.returns.push(o5);
// 4432
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4433
f693592812_395.returns.push(1345562152511);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4453
o5 = {};
// 4454
f693592812_0.returns.push(o5);
// 4455
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4456
f693592812_395.returns.push(1345562152512);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4476
o5 = {};
// 4477
f693592812_0.returns.push(o5);
// 4478
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4479
f693592812_395.returns.push(1345562152513);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4499
o5 = {};
// 4500
f693592812_0.returns.push(o5);
// 4501
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4502
f693592812_395.returns.push(1345562152516);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4522
o5 = {};
// 4523
f693592812_0.returns.push(o5);
// 4524
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4525
f693592812_395.returns.push(1345562152518);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4545
o5 = {};
// 4546
f693592812_0.returns.push(o5);
// 4547
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4548
f693592812_395.returns.push(1345562152519);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4568
o5 = {};
// 4569
f693592812_0.returns.push(o5);
// 4570
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4571
f693592812_395.returns.push(1345562152520);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4591
o5 = {};
// 4592
f693592812_0.returns.push(o5);
// 4593
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4594
f693592812_395.returns.push(1345562152521);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4614
o5 = {};
// 4615
f693592812_0.returns.push(o5);
// 4616
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4617
f693592812_395.returns.push(1345562152526);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4637
o5 = {};
// 4638
f693592812_0.returns.push(o5);
// 4639
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4640
f693592812_395.returns.push(1345562152527);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4660
o5 = {};
// 4661
f693592812_0.returns.push(o5);
// 4662
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4663
f693592812_395.returns.push(1345562152529);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4683
o5 = {};
// 4684
f693592812_0.returns.push(o5);
// 4685
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4686
f693592812_395.returns.push(1345562152530);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4706
o5 = {};
// 4707
f693592812_0.returns.push(o5);
// 4708
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4709
f693592812_395.returns.push(1345562152531);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4729
o5 = {};
// 4730
f693592812_0.returns.push(o5);
// 4731
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4732
f693592812_395.returns.push(1345562152535);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4752
o5 = {};
// 4753
f693592812_0.returns.push(o5);
// 4754
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4755
f693592812_395.returns.push(1345562152536);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4775
o5 = {};
// 4776
f693592812_0.returns.push(o5);
// 4777
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4778
f693592812_395.returns.push(1345562152537);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4798
o5 = {};
// 4799
f693592812_0.returns.push(o5);
// 4800
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4801
f693592812_395.returns.push(1345562152538);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4821
o5 = {};
// 4822
f693592812_0.returns.push(o5);
// 4823
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4824
f693592812_395.returns.push(1345562152542);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4844
o5 = {};
// 4845
f693592812_0.returns.push(o5);
// 4846
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4847
f693592812_395.returns.push(1345562152543);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4867
o5 = {};
// 4868
f693592812_0.returns.push(o5);
// 4869
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4870
f693592812_395.returns.push(1345562152544);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4892
o5 = {};
// 4893
f693592812_0.returns.push(o5);
// 4894
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4895
f693592812_395.returns.push(1345562152545);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4915
o5 = {};
// 4916
f693592812_0.returns.push(o5);
// 4917
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4918
f693592812_395.returns.push(1345562152546);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4938
o5 = {};
// 4939
f693592812_0.returns.push(o5);
// 4940
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4941
f693592812_395.returns.push(1345562152550);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4961
o5 = {};
// 4962
f693592812_0.returns.push(o5);
// 4963
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4964
f693592812_395.returns.push(1345562152551);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 4984
o5 = {};
// 4985
f693592812_0.returns.push(o5);
// 4986
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 4987
f693592812_395.returns.push(1345562152552);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5007
o5 = {};
// 5008
f693592812_0.returns.push(o5);
// 5009
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5010
f693592812_395.returns.push(1345562152552);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5030
o5 = {};
// 5031
f693592812_0.returns.push(o5);
// 5032
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5033
f693592812_395.returns.push(1345562152553);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5053
o5 = {};
// 5054
f693592812_0.returns.push(o5);
// 5055
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5056
f693592812_395.returns.push(1345562152556);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5076
o5 = {};
// 5077
f693592812_0.returns.push(o5);
// 5078
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5079
f693592812_395.returns.push(1345562152557);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5099
o5 = {};
// 5100
f693592812_0.returns.push(o5);
// 5101
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5102
f693592812_395.returns.push(1345562152558);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5122
o5 = {};
// 5123
f693592812_0.returns.push(o5);
// 5124
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5125
f693592812_395.returns.push(1345562152559);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5145
o5 = {};
// 5146
f693592812_0.returns.push(o5);
// 5147
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5148
f693592812_395.returns.push(1345562152560);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5168
o5 = {};
// 5169
f693592812_0.returns.push(o5);
// 5170
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5171
f693592812_395.returns.push(1345562152564);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5191
o5 = {};
// 5192
f693592812_0.returns.push(o5);
// 5193
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5194
f693592812_395.returns.push(1345562152565);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5214
o5 = {};
// 5215
f693592812_0.returns.push(o5);
// 5216
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5217
f693592812_395.returns.push(1345562152566);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5237
o5 = {};
// 5238
f693592812_0.returns.push(o5);
// 5239
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5240
f693592812_395.returns.push(1345562152567);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5260
o5 = {};
// 5261
f693592812_0.returns.push(o5);
// 5262
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5263
f693592812_395.returns.push(1345562152568);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5283
o5 = {};
// 5284
f693592812_0.returns.push(o5);
// 5285
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5286
f693592812_395.returns.push(1345562152571);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5308
o5 = {};
// 5309
f693592812_0.returns.push(o5);
// 5310
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5311
f693592812_395.returns.push(1345562152572);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5333
o5 = {};
// 5334
f693592812_0.returns.push(o5);
// 5335
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5336
f693592812_395.returns.push(1345562152573);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5358
o5 = {};
// 5359
f693592812_0.returns.push(o5);
// 5360
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5361
f693592812_395.returns.push(1345562152575);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5383
o5 = {};
// 5384
f693592812_0.returns.push(o5);
// 5385
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5386
f693592812_395.returns.push(1345562152578);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5406
o5 = {};
// 5407
f693592812_0.returns.push(o5);
// 5408
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5409
f693592812_395.returns.push(1345562152579);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5429
o5 = {};
// 5430
f693592812_0.returns.push(o5);
// 5431
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5432
f693592812_395.returns.push(1345562152580);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5452
o5 = {};
// 5453
f693592812_0.returns.push(o5);
// 5454
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5455
f693592812_395.returns.push(1345562152580);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5475
o5 = {};
// 5476
f693592812_0.returns.push(o5);
// 5477
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5478
f693592812_395.returns.push(1345562152581);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5498
o5 = {};
// 5499
f693592812_0.returns.push(o5);
// 5500
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5501
f693592812_395.returns.push(1345562152586);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5521
o5 = {};
// 5522
f693592812_0.returns.push(o5);
// 5523
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5524
f693592812_395.returns.push(1345562152586);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5544
o5 = {};
// 5545
f693592812_0.returns.push(o5);
// 5546
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5547
f693592812_395.returns.push(1345562152587);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5567
o5 = {};
// 5568
f693592812_0.returns.push(o5);
// 5569
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5570
f693592812_395.returns.push(1345562152588);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5590
o5 = {};
// 5591
f693592812_0.returns.push(o5);
// 5592
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5593
f693592812_395.returns.push(1345562152589);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5613
o5 = {};
// 5614
f693592812_0.returns.push(o5);
// 5615
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5616
f693592812_395.returns.push(1345562152592);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5638
o5 = {};
// 5639
f693592812_0.returns.push(o5);
// 5640
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5641
f693592812_395.returns.push(1345562152593);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5663
o5 = {};
// 5664
f693592812_0.returns.push(o5);
// 5665
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5666
f693592812_395.returns.push(1345562152594);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5688
o5 = {};
// 5689
f693592812_0.returns.push(o5);
// 5690
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5691
f693592812_395.returns.push(1345562152595);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5713
o5 = {};
// 5714
f693592812_0.returns.push(o5);
// 5715
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5716
f693592812_395.returns.push(1345562152596);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5738
o5 = {};
// 5739
f693592812_0.returns.push(o5);
// 5740
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5741
f693592812_395.returns.push(1345562152600);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5763
o5 = {};
// 5764
f693592812_0.returns.push(o5);
// 5765
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5766
f693592812_395.returns.push(1345562152601);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5788
o5 = {};
// 5789
f693592812_0.returns.push(o5);
// 5790
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5791
f693592812_395.returns.push(1345562152602);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5811
o5 = {};
// 5812
f693592812_0.returns.push(o5);
// 5813
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5814
f693592812_395.returns.push(1345562152603);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5834
o5 = {};
// 5835
f693592812_0.returns.push(o5);
// 5836
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5837
f693592812_395.returns.push(1345562152606);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5857
o5 = {};
// 5858
f693592812_0.returns.push(o5);
// 5859
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5860
f693592812_395.returns.push(1345562152607);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5880
o5 = {};
// 5881
f693592812_0.returns.push(o5);
// 5882
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5883
f693592812_395.returns.push(1345562152608);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5903
o5 = {};
// 5904
f693592812_0.returns.push(o5);
// 5905
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5906
f693592812_395.returns.push(1345562152609);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5926
o5 = {};
// 5927
f693592812_0.returns.push(o5);
// 5928
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5929
f693592812_395.returns.push(1345562152630);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5949
o5 = {};
// 5950
f693592812_0.returns.push(o5);
// 5951
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5952
f693592812_395.returns.push(1345562152634);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5972
o5 = {};
// 5973
f693592812_0.returns.push(o5);
// 5974
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5975
f693592812_395.returns.push(1345562152634);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 5995
o5 = {};
// 5996
f693592812_0.returns.push(o5);
// 5997
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 5998
f693592812_395.returns.push(1345562152635);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6018
o5 = {};
// 6019
f693592812_0.returns.push(o5);
// 6020
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6021
f693592812_395.returns.push(1345562152636);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6041
o5 = {};
// 6042
f693592812_0.returns.push(o5);
// 6043
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6044
f693592812_395.returns.push(1345562152637);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6064
o5 = {};
// 6065
f693592812_0.returns.push(o5);
// 6066
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6067
f693592812_395.returns.push(1345562152641);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6087
o5 = {};
// 6088
f693592812_0.returns.push(o5);
// 6089
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6090
f693592812_395.returns.push(1345562152642);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6110
o5 = {};
// 6111
f693592812_0.returns.push(o5);
// 6112
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6113
f693592812_395.returns.push(1345562152643);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6133
o5 = {};
// 6134
f693592812_0.returns.push(o5);
// 6135
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6136
f693592812_395.returns.push(1345562152644);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6156
o5 = {};
// 6157
f693592812_0.returns.push(o5);
// 6158
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6159
f693592812_395.returns.push(1345562152645);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6179
o5 = {};
// 6180
f693592812_0.returns.push(o5);
// 6181
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6182
f693592812_395.returns.push(1345562152649);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6202
o5 = {};
// 6203
f693592812_0.returns.push(o5);
// 6204
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6205
f693592812_395.returns.push(1345562152650);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6227
o5 = {};
// 6228
f693592812_0.returns.push(o5);
// 6229
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6230
f693592812_395.returns.push(1345562152651);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6252
o5 = {};
// 6253
f693592812_0.returns.push(o5);
// 6254
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6255
f693592812_395.returns.push(1345562152652);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6277
o5 = {};
// 6278
f693592812_0.returns.push(o5);
// 6279
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6280
f693592812_395.returns.push(1345562152655);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6302
o5 = {};
// 6303
f693592812_0.returns.push(o5);
// 6304
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6305
f693592812_395.returns.push(1345562152656);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6327
o5 = {};
// 6328
f693592812_0.returns.push(o5);
// 6329
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6330
f693592812_395.returns.push(1345562152657);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6352
o5 = {};
// 6353
f693592812_0.returns.push(o5);
// 6354
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6355
f693592812_395.returns.push(1345562152658);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6377
o5 = {};
// 6378
f693592812_0.returns.push(o5);
// 6379
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6380
f693592812_395.returns.push(1345562152658);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6402
o5 = {};
// 6403
f693592812_0.returns.push(o5);
// 6404
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6405
f693592812_395.returns.push(1345562152662);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6427
o5 = {};
// 6428
f693592812_0.returns.push(o5);
// 6429
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6430
f693592812_395.returns.push(1345562152663);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6452
o5 = {};
// 6453
f693592812_0.returns.push(o5);
// 6454
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6455
f693592812_395.returns.push(1345562152664);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6477
o5 = {};
// 6478
f693592812_0.returns.push(o5);
// 6479
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6480
f693592812_395.returns.push(1345562152665);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6502
o5 = {};
// 6503
f693592812_0.returns.push(o5);
// 6504
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6505
f693592812_395.returns.push(1345562152668);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6525
o5 = {};
// 6526
f693592812_0.returns.push(o5);
// 6527
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6528
f693592812_395.returns.push(1345562152669);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6548
o5 = {};
// 6549
f693592812_0.returns.push(o5);
// 6550
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6551
f693592812_395.returns.push(1345562152669);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6573
o5 = {};
// 6574
f693592812_0.returns.push(o5);
// 6575
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6576
f693592812_395.returns.push(1345562152670);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6598
o5 = {};
// 6599
f693592812_0.returns.push(o5);
// 6600
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6601
f693592812_395.returns.push(1345562152671);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6623
o5 = {};
// 6624
f693592812_0.returns.push(o5);
// 6625
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6626
f693592812_395.returns.push(1345562152675);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6648
o5 = {};
// 6649
f693592812_0.returns.push(o5);
// 6650
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6651
f693592812_395.returns.push(1345562152676);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6671
o5 = {};
// 6672
f693592812_0.returns.push(o5);
// 6673
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6674
f693592812_395.returns.push(1345562152676);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6694
o5 = {};
// 6695
f693592812_0.returns.push(o5);
// 6696
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6697
f693592812_395.returns.push(1345562152677);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6717
o5 = {};
// 6718
f693592812_0.returns.push(o5);
// 6719
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6720
f693592812_395.returns.push(1345562152678);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6740
o5 = {};
// 6741
f693592812_0.returns.push(o5);
// 6742
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 6743
f693592812_395.returns.push(1345562152704);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6752
f693592812_487.returns.push(undefined);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 6759
o0.ownerDocument = null;
// 6761
o8.nodeName = "HTML";
// 6764
o5 = {};
// 6765
f693592812_534.returns.push(o5);
// 6766
o5.length = 2;
// 6768
o5["0"] = o8;
// 6769
o5["1"] = o12;
// undefined
o5 = null;
// 6771
o5 = {};
// 6772
f693592812_0.returns.push(o5);
// undefined
o5 = null;
// 6773
o5 = {};
// 6774
f693592812_0.returns.push(o5);
// undefined
o5 = null;
// 6775
o5 = {};
// 6776
f693592812_0.returns.push(o5);
// undefined
o5 = null;
// 6782
o5 = {};
// 6783
f693592812_534.returns.push(o5);
// 6784
o5.length = 0;
// undefined
o5 = null;
// 6791
o5 = {};
// 6792
f693592812_534.returns.push(o5);
// 6793
o5.length = 4;
// 6795
o6 = {};
// 6796
o5["0"] = o6;
// 6797
o17 = {};
// 6798
o5["1"] = o17;
// 6799
o19 = {};
// 6800
o5["2"] = o19;
// 6801
o21 = {};
// 6802
o5["3"] = o21;
// undefined
o5 = null;
// 6803
o6.nodeType = 1;
// 6805
o6.nodeName = "INPUT";
// 6806
o6.type = "hidden";
// 6807
// 6808
o17.nodeType = 1;
// 6810
o17.nodeName = "INPUT";
// 6811
o17.type = "hidden";
// 6812
// undefined
o17 = null;
// 6813
o19.nodeType = 1;
// 6815
o19.nodeName = "INPUT";
// 6816
o19.type = "hidden";
// 6817
// undefined
o19 = null;
// 6818
o21.nodeType = 1;
// 6820
o21.nodeName = "INPUT";
// 6821
o21.type = "hidden";
// 6822
// undefined
o21 = null;
// 6825
o5 = {};
// 6826
f693592812_396.returns.push(o5);
// 6827
o5["0"] = o12;
// undefined
o5 = null;
// 6829
o5 = {};
// 6830
f693592812_400.returns.push(o5);
// 6831
o17 = {};
// 6832
o5.style = o17;
// 6833
// undefined
o17 = null;
// 6836
f693592812_481.returns.push(o5);
// 6838
o17 = {};
// 6839
f693592812_400.returns.push(o17);
// 6840
o5.appendChild = f693592812_500;
// 6841
f693592812_500.returns.push(o17);
// 6842
// 6843
o17.getElementsByTagName = f693592812_415;
// 6844
o19 = {};
// 6845
f693592812_415.returns.push(o19);
// 6846
o21 = {};
// 6847
o19["0"] = o21;
// 6848
o21.offsetHeight = 0;
// 6850
o24 = {};
// 6851
o21.style = o24;
// undefined
o21 = null;
// 6852
// undefined
o24 = null;
// 6853
o21 = {};
// 6854
o19["1"] = o21;
// undefined
o19 = null;
// 6855
o19 = {};
// 6856
o21.style = o19;
// undefined
o21 = null;
// 6857
// undefined
o19 = null;
// 6860
// 6861
o19 = {};
// 6862
o17.style = o19;
// 6864
// 6865
// undefined
fo693592812_812_offsetWidth = function() { return fo693592812_812_offsetWidth.returns[fo693592812_812_offsetWidth.inst++]; };
fo693592812_812_offsetWidth.returns = [];
fo693592812_812_offsetWidth.inst = 0;
defineGetter(o17, "offsetWidth", fo693592812_812_offsetWidth);
// undefined
fo693592812_812_offsetWidth.returns.push(2);
// 6868
o19.zoom = "";
// 6870
// 6872
// undefined
fo693592812_812_offsetWidth.returns.push(1);
// 6875
// 6876
// undefined
fo693592812_812_offsetWidth.returns.push(2);
// 6879
// undefined
o19 = null;
// 6880
// 6881
o19 = {};
// 6882
o17.firstChild = o19;
// undefined
o17 = null;
// 6883
o17 = {};
// 6884
o19.firstChild = o17;
// 6885
o21 = {};
// 6886
o19.nextSibling = o21;
// 6887
o24 = {};
// 6888
o21.firstChild = o24;
// undefined
o21 = null;
// 6889
o21 = {};
// 6890
o24.firstChild = o21;
// undefined
o24 = null;
// undefined
fo693592812_820_offsetTop = function() { return fo693592812_820_offsetTop.returns[fo693592812_820_offsetTop.inst++]; };
fo693592812_820_offsetTop.returns = [];
fo693592812_820_offsetTop.inst = 0;
defineGetter(o17, "offsetTop", fo693592812_820_offsetTop);
// undefined
fo693592812_820_offsetTop.returns.push(0);
// 6892
o21.offsetTop = 0;
// undefined
o21 = null;
// 6893
o21 = {};
// 6894
o17.style = o21;
// undefined
o17 = null;
// 6895
// 6897
// undefined
fo693592812_820_offsetTop.returns.push(20);
// 6901
// 6902
// undefined
o21 = null;
// 6903
o17 = {};
// 6904
o19.style = o17;
// undefined
o19 = null;
// 6905
// 6907
// undefined
o17 = null;
// undefined
fo693592812_820_offsetTop.returns.push(0);
// 6909
o12.offsetTop = 0;
// 6910
o12.removeChild = f693592812_518;
// 6911
f693592812_518.returns.push(o5);
// undefined
o5 = null;
// 6917
f693592812_826 = function() { return f693592812_826.returns[f693592812_826.inst++]; };
f693592812_826.returns = [];
f693592812_826.inst = 0;
// 6918
o0.getElementsByClassName = f693592812_826;
// 6920
o5 = {};
// 6921
f693592812_826.returns.push(o5);
// 6922
o5.length = 1;
// 6924
o17 = {};
// 6925
o5["0"] = o17;
// undefined
o5 = null;
// 6926
o17.nodeType = 1;
// 6928
o17.nodeName = "LI";
// 6931
o17.jQuery17109642799841240048 = void 0;
// 6932
// 6933
o17.JSBNG__addEventListener = f693592812_487;
// undefined
o17 = null;
// 6935
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 6945
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 6954
f693592812_487.returns.push(undefined);
// 6960
o5 = {};
// 6961
f693592812_534.returns.push(o5);
// 6962
o5.length = 1;
// 6964
o17 = {};
// 6965
o5["0"] = o17;
// undefined
o5 = null;
// 6966
o17.nodeType = 1;
// 6968
o17.nodeName = "LI";
// 6971
o17.jQuery17109642799841240048 = void 0;
// 6972
// 6973
o17.JSBNG__addEventListener = f693592812_487;
// 6975
f693592812_487.returns.push(undefined);
// 6976
o17.ownerDocument = o0;
// 6980
o17.getElementsByClassName = f693592812_541;
// undefined
o17 = null;
// 6982
o5 = {};
// 6983
f693592812_541.returns.push(o5);
// 6984
o5.length = 32;
// 6986
o17 = {};
// 6987
o5["0"] = o17;
// 6988
o19 = {};
// 6989
o5["1"] = o19;
// 6990
o21 = {};
// 6991
o5["2"] = o21;
// 6992
o24 = {};
// 6993
o5["3"] = o24;
// 6994
o26 = {};
// 6995
o5["4"] = o26;
// 6996
o39 = {};
// 6997
o5["5"] = o39;
// 6998
o40 = {};
// 6999
o5["6"] = o40;
// 7000
o41 = {};
// 7001
o5["7"] = o41;
// 7002
o42 = {};
// 7003
o5["8"] = o42;
// 7004
o43 = {};
// 7005
o5["9"] = o43;
// 7006
o44 = {};
// 7007
o5["10"] = o44;
// 7008
o45 = {};
// 7009
o5["11"] = o45;
// 7010
o46 = {};
// 7011
o5["12"] = o46;
// 7012
o47 = {};
// 7013
o5["13"] = o47;
// 7014
o48 = {};
// 7015
o5["14"] = o48;
// 7016
o49 = {};
// 7017
o5["15"] = o49;
// 7018
o50 = {};
// 7019
o5["16"] = o50;
// 7020
o51 = {};
// 7021
o5["17"] = o51;
// 7022
o52 = {};
// 7023
o5["18"] = o52;
// 7024
o53 = {};
// 7025
o5["19"] = o53;
// 7026
o54 = {};
// 7027
o5["20"] = o54;
// 7028
o55 = {};
// 7029
o5["21"] = o55;
// 7030
o56 = {};
// 7031
o5["22"] = o56;
// 7032
o57 = {};
// 7033
o5["23"] = o57;
// 7034
o58 = {};
// 7035
o5["24"] = o58;
// 7036
o59 = {};
// 7037
o5["25"] = o59;
// 7038
o60 = {};
// 7039
o5["26"] = o60;
// 7040
o61 = {};
// 7041
o5["27"] = o61;
// 7042
o62 = {};
// 7043
o5["28"] = o62;
// 7044
o63 = {};
// 7045
o5["29"] = o63;
// 7046
o64 = {};
// 7047
o5["30"] = o64;
// 7048
o65 = {};
// 7049
o5["31"] = o65;
// undefined
o5 = null;
// 7050
o17.nodeType = 1;
// 7052
o17.nodeName = "A";
// 7055
o17.jQuery17109642799841240048 = void 0;
// 7056
// 7057
o17.JSBNG__addEventListener = f693592812_487;
// undefined
o17 = null;
// 7059
f693592812_487.returns.push(undefined);
// 7060
o19.nodeType = 1;
// 7062
o19.nodeName = "A";
// 7065
o19.jQuery17109642799841240048 = void 0;
// 7066
// 7067
o19.JSBNG__addEventListener = f693592812_487;
// undefined
o19 = null;
// 7069
f693592812_487.returns.push(undefined);
// 7070
o21.nodeType = 1;
// 7072
o21.nodeName = "A";
// 7075
o21.jQuery17109642799841240048 = void 0;
// 7076
// 7077
o21.JSBNG__addEventListener = f693592812_487;
// undefined
o21 = null;
// 7079
f693592812_487.returns.push(undefined);
// 7080
o24.nodeType = 1;
// 7082
o24.nodeName = "A";
// 7085
o24.jQuery17109642799841240048 = void 0;
// 7086
// 7087
o24.JSBNG__addEventListener = f693592812_487;
// undefined
o24 = null;
// 7089
f693592812_487.returns.push(undefined);
// 7090
o26.nodeType = 1;
// 7092
o26.nodeName = "A";
// 7095
o26.jQuery17109642799841240048 = void 0;
// 7096
// 7097
o26.JSBNG__addEventListener = f693592812_487;
// undefined
o26 = null;
// 7099
f693592812_487.returns.push(undefined);
// 7100
o39.nodeType = 1;
// 7102
o39.nodeName = "A";
// 7105
o39.jQuery17109642799841240048 = void 0;
// 7106
// 7107
o39.JSBNG__addEventListener = f693592812_487;
// undefined
o39 = null;
// 7109
f693592812_487.returns.push(undefined);
// 7110
o40.nodeType = 1;
// 7112
o40.nodeName = "A";
// 7115
o40.jQuery17109642799841240048 = void 0;
// 7116
// 7117
o40.JSBNG__addEventListener = f693592812_487;
// undefined
o40 = null;
// 7119
f693592812_487.returns.push(undefined);
// 7120
o41.nodeType = 1;
// 7122
o41.nodeName = "A";
// 7125
o41.jQuery17109642799841240048 = void 0;
// 7126
// 7127
o41.JSBNG__addEventListener = f693592812_487;
// undefined
o41 = null;
// 7129
f693592812_487.returns.push(undefined);
// 7130
o42.nodeType = 1;
// 7132
o42.nodeName = "A";
// 7135
o42.jQuery17109642799841240048 = void 0;
// 7136
// 7137
o42.JSBNG__addEventListener = f693592812_487;
// undefined
o42 = null;
// 7139
f693592812_487.returns.push(undefined);
// 7140
o43.nodeType = 1;
// 7142
o43.nodeName = "A";
// 7145
o43.jQuery17109642799841240048 = void 0;
// 7146
// 7147
o43.JSBNG__addEventListener = f693592812_487;
// undefined
o43 = null;
// 7149
f693592812_487.returns.push(undefined);
// 7150
o44.nodeType = 1;
// 7152
o44.nodeName = "A";
// 7155
o44.jQuery17109642799841240048 = void 0;
// 7156
// 7157
o44.JSBNG__addEventListener = f693592812_487;
// undefined
o44 = null;
// 7159
f693592812_487.returns.push(undefined);
// 7160
o45.nodeType = 1;
// 7162
o45.nodeName = "A";
// 7165
o45.jQuery17109642799841240048 = void 0;
// 7166
// 7167
o45.JSBNG__addEventListener = f693592812_487;
// undefined
o45 = null;
// 7169
f693592812_487.returns.push(undefined);
// 7170
o46.nodeType = 1;
// 7172
o46.nodeName = "A";
// 7175
o46.jQuery17109642799841240048 = void 0;
// 7176
// 7177
o46.JSBNG__addEventListener = f693592812_487;
// undefined
o46 = null;
// 7179
f693592812_487.returns.push(undefined);
// 7180
o47.nodeType = 1;
// 7182
o47.nodeName = "A";
// 7185
o47.jQuery17109642799841240048 = void 0;
// 7186
// 7187
o47.JSBNG__addEventListener = f693592812_487;
// undefined
o47 = null;
// 7189
f693592812_487.returns.push(undefined);
// 7190
o48.nodeType = 1;
// 7192
o48.nodeName = "A";
// 7195
o48.jQuery17109642799841240048 = void 0;
// 7196
// 7197
o48.JSBNG__addEventListener = f693592812_487;
// undefined
o48 = null;
// 7199
f693592812_487.returns.push(undefined);
// 7200
o49.nodeType = 1;
// 7202
o49.nodeName = "A";
// 7205
o49.jQuery17109642799841240048 = void 0;
// 7206
// 7207
o49.JSBNG__addEventListener = f693592812_487;
// undefined
o49 = null;
// 7209
f693592812_487.returns.push(undefined);
// 7210
o50.nodeType = 1;
// 7212
o50.nodeName = "A";
// 7215
o50.jQuery17109642799841240048 = void 0;
// 7216
// 7217
o50.JSBNG__addEventListener = f693592812_487;
// undefined
o50 = null;
// 7219
f693592812_487.returns.push(undefined);
// 7220
o51.nodeType = 1;
// 7222
o51.nodeName = "A";
// 7225
o51.jQuery17109642799841240048 = void 0;
// 7226
// 7227
o51.JSBNG__addEventListener = f693592812_487;
// undefined
o51 = null;
// 7229
f693592812_487.returns.push(undefined);
// 7230
o52.nodeType = 1;
// 7232
o52.nodeName = "A";
// 7235
o52.jQuery17109642799841240048 = void 0;
// 7236
// 7237
o52.JSBNG__addEventListener = f693592812_487;
// undefined
o52 = null;
// 7239
f693592812_487.returns.push(undefined);
// 7240
o53.nodeType = 1;
// 7242
o53.nodeName = "A";
// 7245
o53.jQuery17109642799841240048 = void 0;
// 7246
// 7247
o53.JSBNG__addEventListener = f693592812_487;
// undefined
o53 = null;
// 7249
f693592812_487.returns.push(undefined);
// 7250
o54.nodeType = 1;
// 7252
o54.nodeName = "A";
// 7255
o54.jQuery17109642799841240048 = void 0;
// 7256
// 7257
o54.JSBNG__addEventListener = f693592812_487;
// undefined
o54 = null;
// 7259
f693592812_487.returns.push(undefined);
// 7260
o55.nodeType = 1;
// 7262
o55.nodeName = "A";
// 7265
o55.jQuery17109642799841240048 = void 0;
// 7266
// 7267
o55.JSBNG__addEventListener = f693592812_487;
// undefined
o55 = null;
// 7269
f693592812_487.returns.push(undefined);
// 7270
o56.nodeType = 1;
// 7272
o56.nodeName = "A";
// 7275
o56.jQuery17109642799841240048 = void 0;
// 7276
// 7277
o56.JSBNG__addEventListener = f693592812_487;
// undefined
o56 = null;
// 7279
f693592812_487.returns.push(undefined);
// 7280
o57.nodeType = 1;
// 7282
o57.nodeName = "A";
// 7285
o57.jQuery17109642799841240048 = void 0;
// 7286
// 7287
o57.JSBNG__addEventListener = f693592812_487;
// undefined
o57 = null;
// 7289
f693592812_487.returns.push(undefined);
// 7290
o58.nodeType = 1;
// 7292
o58.nodeName = "A";
// 7295
o58.jQuery17109642799841240048 = void 0;
// 7296
// 7297
o58.JSBNG__addEventListener = f693592812_487;
// undefined
o58 = null;
// 7299
f693592812_487.returns.push(undefined);
// 7300
o59.nodeType = 1;
// 7302
o59.nodeName = "A";
// 7305
o59.jQuery17109642799841240048 = void 0;
// 7306
// 7307
o59.JSBNG__addEventListener = f693592812_487;
// undefined
o59 = null;
// 7309
f693592812_487.returns.push(undefined);
// 7310
o60.nodeType = 1;
// 7312
o60.nodeName = "A";
// 7315
o60.jQuery17109642799841240048 = void 0;
// 7316
// 7317
o60.JSBNG__addEventListener = f693592812_487;
// undefined
o60 = null;
// 7319
f693592812_487.returns.push(undefined);
// 7320
o61.nodeType = 1;
// 7322
o61.nodeName = "A";
// 7325
o61.jQuery17109642799841240048 = void 0;
// 7326
// 7327
o61.JSBNG__addEventListener = f693592812_487;
// undefined
o61 = null;
// 7329
f693592812_487.returns.push(undefined);
// 7330
o62.nodeType = 1;
// 7332
o62.nodeName = "A";
// 7335
o62.jQuery17109642799841240048 = void 0;
// 7336
// 7337
o62.JSBNG__addEventListener = f693592812_487;
// undefined
o62 = null;
// 7339
f693592812_487.returns.push(undefined);
// 7340
o63.nodeType = 1;
// 7342
o63.nodeName = "A";
// 7345
o63.jQuery17109642799841240048 = void 0;
// 7346
// 7347
o63.JSBNG__addEventListener = f693592812_487;
// undefined
o63 = null;
// 7349
f693592812_487.returns.push(undefined);
// 7350
o64.nodeType = 1;
// 7352
o64.nodeName = "A";
// 7355
o64.jQuery17109642799841240048 = void 0;
// 7356
// 7357
o64.JSBNG__addEventListener = f693592812_487;
// undefined
o64 = null;
// 7359
f693592812_487.returns.push(undefined);
// 7360
o65.nodeType = 1;
// 7362
o65.nodeName = "A";
// 7365
o65.jQuery17109642799841240048 = void 0;
// 7366
// 7367
o65.JSBNG__addEventListener = f693592812_487;
// undefined
o65 = null;
// 7369
f693592812_487.returns.push(undefined);
// 7375
o5 = {};
// 7376
f693592812_534.returns.push(o5);
// 7377
o5.length = 0;
// undefined
o5 = null;
// 7384
o5 = {};
// 7385
f693592812_534.returns.push(o5);
// 7386
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7406
o5 = {};
// 7407
f693592812_534.returns.push(o5);
// 7408
o5.length = 0;
// undefined
o5 = null;
// 7415
o5 = {};
// 7416
f693592812_534.returns.push(o5);
// 7417
o5.length = 1;
// 7419
o17 = {};
// 7420
o5["0"] = o17;
// undefined
o5 = null;
// 7421
o17.ownerDocument = o0;
// 7424
o17.nodeType = 1;
// 7425
o17.getElementsByTagName = f693592812_415;
// 7426
o5 = {};
// 7427
f693592812_415.returns.push(o5);
// 7428
o5.length = 6;
// 7430
o19 = {};
// 7431
o5["0"] = o19;
// 7432
o21 = {};
// 7433
o5["1"] = o21;
// 7434
o5["2"] = o27;
// 7435
o24 = {};
// 7436
o5["3"] = o24;
// 7437
o26 = {};
// 7438
o5["4"] = o26;
// 7439
o5["5"] = o6;
// 7442
o17.nodeName = "FORM";
// undefined
fo693592812_868_jQuery17109642799841240048 = function() { return fo693592812_868_jQuery17109642799841240048.returns[fo693592812_868_jQuery17109642799841240048.inst++]; };
fo693592812_868_jQuery17109642799841240048.returns = [];
fo693592812_868_jQuery17109642799841240048.inst = 0;
defineGetter(o17, "jQuery17109642799841240048", fo693592812_868_jQuery17109642799841240048);
// undefined
fo693592812_868_jQuery17109642799841240048.returns.push(void 0);
// 7447
o17.JSBNG__addEventListener = f693592812_487;
// 7449
f693592812_487.returns.push(undefined);
// undefined
fo693592812_868_jQuery17109642799841240048.returns.push(39);
// 7458
f693592812_487.returns.push(undefined);
// undefined
fo693592812_868_jQuery17109642799841240048.returns.push(39);
// undefined
fo693592812_868_jQuery17109642799841240048.returns.push(39);
// 7474
f693592812_487.returns.push(undefined);
// 7477
f693592812_487.returns.push(undefined);
// 7484
o17.getAttribute = f693592812_474;
// 7485
f693592812_474.returns.push(null);
// 7486
o39 = {};
// 7487
o17.parentNode = o39;
// undefined
o39 = null;
// 7488
o17.setAttribute = f693592812_495;
// 7489
f693592812_495.returns.push(undefined);
// 7490
o17.querySelectorAll = f693592812_536;
// 7491
o39 = {};
// 7492
f693592812_536.returns.push(o39);
// 7493
o39.length = 0;
// undefined
o39 = null;
// 7495
o17.removeAttribute = f693592812_475;
// undefined
o17 = null;
// 7496
f693592812_475.returns.push(undefined);
// 7504
f693592812_474.returns.push(null);
// 7507
f693592812_495.returns.push(undefined);
// 7510
f693592812_475.returns.push(undefined);
// 7517
f693592812_415.returns.push(o5);
// 7520
o19.ownerDocument = o0;
// 7525
o19.getAttribute = f693592812_474;
// 7526
f693592812_474.returns.push("text");
// 7527
o19.type = "text";
// 7528
o19.nodeName = "INPUT";
// 7530
o21.getAttribute = f693592812_474;
// 7531
f693592812_474.returns.push("password");
// 7532
o21.type = "password";
// 7533
o21.nodeName = "INPUT";
// 7535
o27.getAttribute = f693592812_474;
// 7536
f693592812_474.returns.push("checkbox");
// 7537
o27.type = "checkbox";
// 7538
o27.nodeName = "INPUT";
// 7540
o24.getAttribute = f693592812_474;
// 7541
f693592812_474.returns.push("hidden");
// 7542
o24.type = "hidden";
// 7543
o24.nodeName = "INPUT";
// 7545
o26.getAttribute = f693592812_474;
// 7546
f693592812_474.returns.push("hidden");
// 7547
o26.type = "hidden";
// 7548
o26.nodeName = "INPUT";
// 7550
o6.getAttribute = f693592812_474;
// 7551
f693592812_474.returns.push("hidden");
// 7554
o5["6"] = void 0;
// undefined
o5 = null;
// 7560
o5 = {};
// 7561
f693592812_415.returns.push(o5);
// 7562
o5.length = 0;
// undefined
o5 = null;
// 7564
o19.nodeType = 1;
// undefined
fo693592812_870_jQuery17109642799841240048 = function() { return fo693592812_870_jQuery17109642799841240048.returns[fo693592812_870_jQuery17109642799841240048.inst++]; };
fo693592812_870_jQuery17109642799841240048.returns = [];
fo693592812_870_jQuery17109642799841240048.inst = 0;
defineGetter(o19, "jQuery17109642799841240048", fo693592812_870_jQuery17109642799841240048);
// undefined
fo693592812_870_jQuery17109642799841240048.returns.push(void 0);
// 7571
o19.JSBNG__addEventListener = f693592812_487;
// undefined
o19 = null;
// 7573
f693592812_487.returns.push(undefined);
// 7581
f693592812_474.returns.push(null);
// undefined
fo693592812_870_jQuery17109642799841240048.returns.push(40);
// 7590
f693592812_487.returns.push(undefined);
// 7591
o21.nodeType = 1;
// 7596
o21.jQuery17109642799841240048 = void 0;
// 7597
// 7598
o21.JSBNG__addEventListener = f693592812_487;
// undefined
o21 = null;
// 7600
f693592812_487.returns.push(undefined);
// 7601
o27.nodeType = 1;
// 7606
o27.jQuery17109642799841240048 = void 0;
// 7607
// 7608
o27.JSBNG__addEventListener = f693592812_487;
// undefined
o27 = null;
// 7610
f693592812_487.returns.push(undefined);
// 7611
o24.nodeType = 1;
// 7616
o24.jQuery17109642799841240048 = void 0;
// 7617
// 7618
o24.JSBNG__addEventListener = f693592812_487;
// undefined
o24 = null;
// 7620
f693592812_487.returns.push(undefined);
// 7621
o26.nodeType = 1;
// 7626
o26.jQuery17109642799841240048 = void 0;
// 7627
// 7628
o26.JSBNG__addEventListener = f693592812_487;
// undefined
o26 = null;
// 7630
f693592812_487.returns.push(undefined);
// 7636
o6.jQuery17109642799841240048 = void 0;
// 7637
// 7638
o6.JSBNG__addEventListener = f693592812_487;
// undefined
o6 = null;
// 7640
f693592812_487.returns.push(undefined);
// 7644
o5 = {};
// 7645
f693592812_0.returns.push(o5);
// 7646
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 7647
f693592812_395.returns.push(1345562152851);
// 7648
o0.parentNode = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7653
o0.onready = void 0;
// 7656
o0.ready = void 0;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7665
o12.nodeType = 1;
// 7666
o12.className = "t1  logged-out   front-random-image-city-balcony  ms-windows";
// 7668
// 7676
o5 = {};
// 7677
f693592812_826.returns.push(o5);
// 7678
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7689
f693592812_487.returns.push(undefined);
// 7692
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 7697
f693592812_589.returns.push(null);
// 7698
o5 = {};
// 7699
f693592812_0.returns.push(o5);
// 7700
o5.getTime = f693592812_395;
// undefined
o5 = null;
// 7701
f693592812_395.returns.push(1345562152860);
// 7702
f693592812_880 = function() { return f693592812_880.returns[f693592812_880.inst++]; };
f693592812_880.returns = [];
f693592812_880.inst = 0;
// 7703
o2.setItem = f693592812_880;
// undefined
o2 = null;
// 7704
f693592812_880.returns.push(undefined);
// 7705
o2 = {};
// 7706
f693592812_0.returns.push(o2);
// 7707
o2.getTime = f693592812_395;
// undefined
o2 = null;
// 7708
f693592812_395.returns.push(1345562152860);
// 7709
o2 = {};
// 7710
f693592812_0.returns.push(o2);
// 7711
o2.getTime = f693592812_395;
// undefined
o2 = null;
// 7712
f693592812_395.returns.push(1345562152861);
// 7713
o2 = {};
// 7714
f693592812_0.returns.push(o2);
// 7715
o2.getTime = f693592812_395;
// undefined
o2 = null;
// 7716
f693592812_395.returns.push(1345562152862);
// 7718
o2 = {};
// 7719
f693592812_400.returns.push(o2);
// 7720
o2.nodeType = 1;
// 7722
o2.nodeName = "DIV";
// undefined
fo693592812_884_jQuery17109642799841240048 = function() { return fo693592812_884_jQuery17109642799841240048.returns[fo693592812_884_jQuery17109642799841240048.inst++]; };
fo693592812_884_jQuery17109642799841240048.returns = [];
fo693592812_884_jQuery17109642799841240048.inst = 0;
defineGetter(o2, "jQuery17109642799841240048", fo693592812_884_jQuery17109642799841240048);
// undefined
fo693592812_884_jQuery17109642799841240048.returns.push(void 0);
// 7727
o2.JSBNG__addEventListener = f693592812_487;
// 7729
f693592812_487.returns.push(undefined);
// 7735
o5 = {};
// 7736
f693592812_534.returns.push(o5);
// 7737
o5.length = 0;
// undefined
o5 = null;
// 7743
o12.nodeName = "BODY";
// undefined
fo693592812_412_jQuery17109642799841240048 = function() { return fo693592812_412_jQuery17109642799841240048.returns[fo693592812_412_jQuery17109642799841240048.inst++]; };
fo693592812_412_jQuery17109642799841240048.returns = [];
fo693592812_412_jQuery17109642799841240048.inst = 0;
defineGetter(o12, "jQuery17109642799841240048", fo693592812_412_jQuery17109642799841240048);
// undefined
fo693592812_412_jQuery17109642799841240048.returns.push(void 0);
// 7748
o12.JSBNG__addEventListener = f693592812_487;
// 7750
f693592812_487.returns.push(undefined);
// undefined
fo693592812_412_jQuery17109642799841240048.returns.push(47);
// 7761
f693592812_487.returns.push(undefined);
// undefined
fo693592812_412_jQuery17109642799841240048.returns.push(47);
// 7772
f693592812_487.returns.push(undefined);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 7780
f693592812_413.returns.push(null);
// 7783
f693592812_413.returns.push(o28);
// 7784
o28.parentNode = o13;
// 7785
o28.id = "page-outer";
// 7787
o8.clientHeight = 525;
// 7789
o0.compatMode = "CSS1Compat";
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7802
o5 = {};
// 7803
f693592812_534.returns.push(o5);
// 7804
o5.length = 2;
// 7806
o6 = {};
// 7807
o5["0"] = o6;
// undefined
o6 = null;
// 7808
o6 = {};
// 7809
o5["1"] = o6;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7824
o5 = {};
// 7825
f693592812_826.returns.push(o5);
// 7826
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7840
o5 = {};
// 7841
f693592812_534.returns.push(o5);
// 7842
o5.length = 14;
// 7844
o17 = {};
// 7845
o5["0"] = o17;
// undefined
o17 = null;
// 7846
o17 = {};
// 7847
o5["1"] = o17;
// undefined
o17 = null;
// 7848
o17 = {};
// 7849
o5["2"] = o17;
// undefined
o17 = null;
// 7850
o17 = {};
// 7851
o5["3"] = o17;
// undefined
o17 = null;
// 7852
o17 = {};
// 7853
o5["4"] = o17;
// undefined
o17 = null;
// 7854
o17 = {};
// 7855
o5["5"] = o17;
// undefined
o17 = null;
// 7856
o17 = {};
// 7857
o5["6"] = o17;
// undefined
o17 = null;
// 7858
o17 = {};
// 7859
o5["7"] = o17;
// undefined
o17 = null;
// 7860
o17 = {};
// 7861
o5["8"] = o17;
// undefined
o17 = null;
// 7862
o17 = {};
// 7863
o5["9"] = o17;
// undefined
o17 = null;
// 7864
o17 = {};
// 7865
o5["10"] = o17;
// undefined
o17 = null;
// 7866
o17 = {};
// 7867
o5["11"] = o17;
// undefined
o17 = null;
// 7868
o17 = {};
// 7869
o5["12"] = o17;
// undefined
o17 = null;
// 7870
o17 = {};
// 7871
o5["13"] = o17;
// undefined
o5 = null;
// undefined
o17 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7884
o5 = {};
// 7885
f693592812_534.returns.push(o5);
// 7886
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7907
o5 = {};
// 7908
f693592812_534.returns.push(o5);
// 7909
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7930
o5 = {};
// 7931
f693592812_534.returns.push(o5);
// 7932
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7953
o5 = {};
// 7954
f693592812_534.returns.push(o5);
// 7955
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7966
f693592812_487.returns.push(undefined);
// 7972
o5 = {};
// 7973
f693592812_534.returns.push(o5);
// 7974
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 7988
o5 = {};
// 7989
f693592812_534.returns.push(o5);
// 7990
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8004
o5 = {};
// 8005
f693592812_534.returns.push(o5);
// 8006
o5.length = 0;
// undefined
o5 = null;
// 8009
f693592812_413.returns.push(null);
// 8011
o5 = {};
// 8012
f693592812_400.returns.push(o5);
// 8013
o17 = {};
// 8014
o5.style = o17;
// undefined
o5 = null;
// undefined
o17 = null;
// 8020
o5 = {};
// 8021
f693592812_534.returns.push(o5);
// 8022
o5.length = 1;
// 8024
o5["0"] = o6;
// undefined
o5 = null;
// 8025
o6.nodeType = 1;
// 8027
o6.nodeName = "A";
// undefined
fo693592812_888_jQuery17109642799841240048 = function() { return fo693592812_888_jQuery17109642799841240048.returns[fo693592812_888_jQuery17109642799841240048.inst++]; };
fo693592812_888_jQuery17109642799841240048.returns = [];
fo693592812_888_jQuery17109642799841240048.inst = 0;
defineGetter(o6, "jQuery17109642799841240048", fo693592812_888_jQuery17109642799841240048);
// undefined
fo693592812_888_jQuery17109642799841240048.returns.push(void 0);
// 8032
o6.JSBNG__addEventListener = f693592812_487;
// 8034
f693592812_487.returns.push(undefined);
// undefined
fo693592812_888_jQuery17109642799841240048.returns.push(48);
// 8041
o6.getAttribute = f693592812_474;
// 8042
o6.ownerDocument = o0;
// 8046
f693592812_474.returns.push("Close all open Tweets");
// 8053
f693592812_474.returns.push("Close all open Tweets");
// 8059
o6.setAttribute = f693592812_495;
// 8060
f693592812_495.returns.push(undefined);
// 8068
f693592812_495.returns.push(undefined);
// 8069
o6.removeAttribute = f693592812_475;
// undefined
o6 = null;
// 8070
f693592812_475.returns.push(undefined);
// undefined
fo693592812_888_jQuery17109642799841240048.returns.push(48);
// undefined
fo693592812_888_jQuery17109642799841240048.returns.push(48);
// 8083
f693592812_487.returns.push(undefined);
// undefined
fo693592812_888_jQuery17109642799841240048.returns.push(48);
// 8092
f693592812_487.returns.push(undefined);
// 8098
o5 = {};
// 8099
f693592812_534.returns.push(o5);
// 8100
o5.length = 1;
// 8102
o6 = {};
// 8103
o5["0"] = o6;
// undefined
o5 = null;
// 8104
o6.nodeType = 1;
// 8106
o6.nodeName = "FORM";
// undefined
fo693592812_916_jQuery17109642799841240048 = function() { return fo693592812_916_jQuery17109642799841240048.returns[fo693592812_916_jQuery17109642799841240048.inst++]; };
fo693592812_916_jQuery17109642799841240048.returns = [];
fo693592812_916_jQuery17109642799841240048.inst = 0;
defineGetter(o6, "jQuery17109642799841240048", fo693592812_916_jQuery17109642799841240048);
// undefined
fo693592812_916_jQuery17109642799841240048.returns.push(void 0);
// 8111
o6.JSBNG__addEventListener = f693592812_487;
// 8113
f693592812_487.returns.push(undefined);
// 8115
f693592812_413.returns.push(o29);
// 8116
o29.parentNode = o35;
// 8117
o29.id = "message-drawer";
// 8118
o29.nodeType = 1;
// 8120
o29.nodeName = "DIV";
// undefined
fo693592812_454_jQuery17109642799841240048 = function() { return fo693592812_454_jQuery17109642799841240048.returns[fo693592812_454_jQuery17109642799841240048.inst++]; };
fo693592812_454_jQuery17109642799841240048.returns = [];
fo693592812_454_jQuery17109642799841240048.inst = 0;
defineGetter(o29, "jQuery17109642799841240048", fo693592812_454_jQuery17109642799841240048);
// undefined
fo693592812_454_jQuery17109642799841240048.returns.push(void 0);
// 8125
o29.JSBNG__addEventListener = f693592812_487;
// 8127
f693592812_487.returns.push(undefined);
// 8129
f693592812_413.returns.push(o29);
// undefined
o29 = null;
// undefined
fo693592812_454_jQuery17109642799841240048.returns.push(50);
// 8143
o5 = {};
// 8144
f693592812_534.returns.push(o5);
// 8145
o5.length = 0;
// undefined
o5 = null;
// 8152
o5 = {};
// 8153
f693592812_534.returns.push(o5);
// 8154
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8168
o5 = {};
// 8169
f693592812_534.returns.push(o5);
// 8170
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8184
o5 = {};
// 8185
f693592812_534.returns.push(o5);
// 8186
o5.length = 0;
// undefined
o5 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8196
o5 = {};
// 8197
f693592812_413.returns.push(o5);
// 8198
o5.parentNode = o6;
// 8199
o5.id = "search-query";
// 8200
o5.nodeType = 1;
// 8202
o5.nodeName = "INPUT";
// undefined
fo693592812_921_jQuery17109642799841240048 = function() { return fo693592812_921_jQuery17109642799841240048.returns[fo693592812_921_jQuery17109642799841240048.inst++]; };
fo693592812_921_jQuery17109642799841240048.returns = [];
fo693592812_921_jQuery17109642799841240048.inst = 0;
defineGetter(o5, "jQuery17109642799841240048", fo693592812_921_jQuery17109642799841240048);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(void 0);
// 8207
o5.JSBNG__addEventListener = f693592812_487;
// 8209
f693592812_487.returns.push(undefined);
// 8212
f693592812_487.returns.push(undefined);
// 8215
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 8220
f693592812_13.returns.push(3);
// 8222
f693592812_10.returns.push(undefined);
// 8224
f693592812_413.returns.push(null);
// 8231
f693592812_413.returns.push(o5);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8242
f693592812_487.returns.push(undefined);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8251
f693592812_487.returns.push(undefined);
// 8252
o5.hasFocus = void 0;
// 8255
o17 = {};
// 8256
f693592812_0.returns.push(o17);
// 8257
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8258
f693592812_395.returns.push(1345562152935);
// 8260
o6.parentNode = o30;
// 8261
o30.parentNode = o32;
// 8262
o32.parentNode = o33;
// 8263
o33.parentNode = o34;
// 8264
o34.parentNode = o35;
// 8265
o35.parentNode = o13;
// 8266
o13.parentNode = o12;
// 8267
o12.parentNode = o8;
// 8268
o8.parentNode = o0;
// 8270
o5.ownerDocument = o0;
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8292
o5.getAttribute = f693592812_474;
// 8293
f693592812_474.returns.push(null);
// 8295
o5.type = "text";
// 8296
o5.value = "";
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8312
f693592812_474.returns.push("Search");
// 8317
// 8318
o5.onJSBNG__blur = void 0;
// undefined
fo693592812_916_jQuery17109642799841240048.returns.push(49);
// 8323
o6.onJSBNG__blur = void 0;
// 8324
o30.nodeName = "DIV";
// 8326
o30.nodeType = 1;
// 8327
o30.jQuery17109642799841240048 = void 0;
// 8328
o30.onJSBNG__blur = void 0;
// undefined
o30 = null;
// 8329
o32.nodeName = "DIV";
// 8331
o32.nodeType = 1;
// 8332
o32.jQuery17109642799841240048 = void 0;
// 8333
o32.onJSBNG__blur = void 0;
// undefined
o32 = null;
// 8334
o33.nodeName = "DIV";
// 8336
o33.nodeType = 1;
// 8337
o33.jQuery17109642799841240048 = void 0;
// 8338
o33.onJSBNG__blur = void 0;
// undefined
o33 = null;
// 8339
o34.nodeName = "DIV";
// 8341
o34.nodeType = 1;
// 8342
o34.jQuery17109642799841240048 = void 0;
// 8343
o34.onJSBNG__blur = void 0;
// undefined
o34 = null;
// 8344
o35.nodeName = "DIV";
// 8346
o35.nodeType = 1;
// 8347
o35.jQuery17109642799841240048 = void 0;
// 8348
o35.onJSBNG__blur = void 0;
// undefined
o35 = null;
// 8349
o13.nodeName = "DIV";
// 8351
o13.nodeType = 1;
// 8352
o13.jQuery17109642799841240048 = void 0;
// 8353
o13.onJSBNG__blur = void 0;
// undefined
fo693592812_412_jQuery17109642799841240048.returns.push(47);
// 8358
o12.onJSBNG__blur = void 0;
// 8361
o8.nodeType = 1;
// 8362
o8.jQuery17109642799841240048 = void 0;
// 8363
o8.onJSBNG__blur = void 0;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8368
o0.onJSBNG__blur = void 0;
// 8371
f693592812_923 = function() { return f693592812_923.returns[f693592812_923.inst++]; };
f693592812_923.returns = [];
f693592812_923.inst = 0;
// 8372
o5.JSBNG__blur = f693592812_923;
// 8373
o5.offsetWidth = 202;
// 8376
f693592812_923.returns.push(undefined);
// 8377
o17 = {};
// 8378
f693592812_0.returns.push(o17);
// 8379
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8380
f693592812_395.returns.push(1345562152943);
// undefined
fo693592812_884_jQuery17109642799841240048.returns.push(46);
// 8389
f693592812_487.returns.push(undefined);
// 8395
o17 = {};
// 8396
f693592812_534.returns.push(o17);
// 8397
o17.length = 1;
// 8399
o19 = {};
// 8400
o17["0"] = o19;
// undefined
o17 = null;
// 8401
o19.nodeType = 1;
// 8403
o19.nodeName = "SPAN";
// undefined
fo693592812_926_jQuery17109642799841240048 = function() { return fo693592812_926_jQuery17109642799841240048.returns[fo693592812_926_jQuery17109642799841240048.inst++]; };
fo693592812_926_jQuery17109642799841240048.returns = [];
fo693592812_926_jQuery17109642799841240048.inst = 0;
defineGetter(o19, "jQuery17109642799841240048", fo693592812_926_jQuery17109642799841240048);
// undefined
fo693592812_926_jQuery17109642799841240048.returns.push(void 0);
// 8408
o19.JSBNG__addEventListener = f693592812_487;
// 8410
f693592812_487.returns.push(undefined);
// undefined
fo693592812_926_jQuery17109642799841240048.returns.push(52);
// 8419
f693592812_487.returns.push(undefined);
// undefined
fo693592812_926_jQuery17109642799841240048.returns.push(52);
// 8428
f693592812_487.returns.push(undefined);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8441
o17 = {};
// 8442
f693592812_0.returns.push(o17);
// 8443
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8444
f693592812_395.returns.push(1345562152952);
// 8446
o17 = {};
// 8447
f693592812_400.returns.push(o17);
// 8448
o17.nodeType = 1;
// 8450
o17.nodeName = "DIV";
// undefined
fo693592812_928_jQuery17109642799841240048 = function() { return fo693592812_928_jQuery17109642799841240048.returns[fo693592812_928_jQuery17109642799841240048.inst++]; };
fo693592812_928_jQuery17109642799841240048.returns = [];
fo693592812_928_jQuery17109642799841240048.inst = 0;
defineGetter(o17, "jQuery17109642799841240048", fo693592812_928_jQuery17109642799841240048);
// undefined
fo693592812_928_jQuery17109642799841240048.returns.push(void 0);
// 8455
o17.JSBNG__addEventListener = f693592812_487;
// undefined
o17 = null;
// 8457
f693592812_487.returns.push(undefined);
// 8458
o17 = {};
// 8459
f693592812_0.returns.push(o17);
// 8460
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8461
f693592812_395.returns.push(1345562152953);
// undefined
fo693592812_928_jQuery17109642799841240048.returns.push(53);
// 8470
f693592812_487.returns.push(undefined);
// 8471
o17 = {};
// 8472
f693592812_0.returns.push(o17);
// 8473
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8474
f693592812_395.returns.push(1345562152954);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 8483
f693592812_487.returns.push(undefined);
// 8484
o17 = {};
// 8485
f693592812_0.returns.push(o17);
// 8486
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8487
f693592812_395.returns.push(1345562152954);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 8496
f693592812_487.returns.push(undefined);
// 8497
o17 = {};
// 8498
f693592812_0.returns.push(o17);
// 8499
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8500
f693592812_395.returns.push(1345562152955);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 8509
f693592812_487.returns.push(undefined);
// 8514
o17 = {};
// 8515
f693592812_0.returns.push(o17);
// 8516
o17.getTime = f693592812_395;
// undefined
o17 = null;
// 8517
f693592812_395.returns.push(1345562152976);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// undefined
fo693592812_599_jQuery17109642799841240048.returns.push(4);
// 8533
o1.setItem = f693592812_880;
// undefined
o1 = null;
// 8534
f693592812_880.returns.push(undefined);
// 8536
f693592812_413.returns.push(o13);
// 8538
o13.id = "doc";
// 8540
o13.className = "";
// 8543
// 8544
o3.onrouteFollowed = void 0;
// 8547
o3.routeFollowed = void 0;
// undefined
o3 = null;
// 8551
o1 = {};
// 8552
f693592812_0.returns.push(o1);
// 8553
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 8554
f693592812_395.returns.push(1345562153002);
// 8555
o2.parentNode = null;
// undefined
fo693592812_884_jQuery17109642799841240048.returns.push(46);
// undefined
fo693592812_884_jQuery17109642799841240048.returns.push(46);
// undefined
fo693592812_884_jQuery17109642799841240048.returns.push(46);
// 8573
o5.setAttribute = f693592812_495;
// 8574
f693592812_495.returns.push(undefined);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8587
f693592812_474.returns.push("Search");
// 8592
// 8596
o1 = {};
// 8597
f693592812_0.returns.push(o1);
// 8598
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 8599
f693592812_395.returns.push(1345562153004);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8605
o0.onsearchPlaceholderUpdate = void 0;
// 8608
o0.searchPlaceholderUpdate = void 0;
// 8611
o1 = {};
// 8612
f693592812_0.returns.push(o1);
// 8613
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 8614
f693592812_395.returns.push(1345562153005);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// undefined
fo693592812_921_jQuery17109642799841240048.returns.push(51);
// 8648
o5.className = "search-input";
// 8650
// 8652
o1 = {};
// 8653
o6.firstChild = o1;
// 8654
o1.nodeType = 3;
// 8655
o1.nextSibling = o19;
// undefined
o1 = null;
// 8657
o1 = {};
// 8658
o19.nextSibling = o1;
// 8659
o1.nodeType = 3;
// 8660
o3 = {};
// 8661
o1.nextSibling = o3;
// undefined
o1 = null;
// 8662
o3.nodeType = 1;
// 8663
o1 = {};
// 8664
o3.nextSibling = o1;
// 8665
o1.nodeType = 3;
// 8666
o1.nextSibling = o5;
// undefined
o1 = null;
// 8668
o1 = {};
// 8669
o5.nextSibling = o1;
// undefined
o5 = null;
// 8670
o1.nodeType = 3;
// 8671
o5 = {};
// 8672
o1.nextSibling = o5;
// undefined
o1 = null;
// 8673
o5.nodeType = 1;
// 8674
o1 = {};
// 8675
o5.nextSibling = o1;
// 8676
o1.nodeType = 3;
// 8677
o1.nextSibling = null;
// undefined
o1 = null;
// 8683
o19.ownerDocument = o0;
// 8687
o19.getAttribute = f693592812_474;
// undefined
o19 = null;
// 8688
f693592812_474.returns.push(null);
// 8690
o3.getAttribute = f693592812_474;
// undefined
o3 = null;
// 8691
f693592812_474.returns.push(null);
// 8693
o5.getAttribute = f693592812_474;
// 8694
f693592812_474.returns.push("search-query-hint");
// 8696
o5.className = "search-input search-hinting-input";
// 8698
// undefined
o5 = null;
// 8701
o6.ownerDocument = o0;
// 8704
f693592812_538.returns.push(true);
// 8706
o6.className = "form-search js-search-form ";
// 8708
// undefined
o6 = null;
// undefined
fo693592812_916_jQuery17109642799841240048.returns.push(49);
// undefined
fo693592812_412_jQuery17109642799841240048.returns.push(47);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8766
f693592812_923.returns.push(undefined);
// 8767
o2.onswitchToPage = void 0;
// 8770
o2.switchToPage = void 0;
// undefined
o2 = null;
// 8772
f693592812_413.returns.push(null);
// 8774
o1 = {};
// 8775
f693592812_400.returns.push(o1);
// 8777
f693592812_7.returns.push(undefined);
// 8779
f693592812_7.returns.push(undefined);
// 8780
f693592812_7.returns.push(undefined);
// 8781
f693592812_13.returns.push(4);
// 8782
f693592812_7.returns.push(undefined);
// 8783
o2 = {};
// 8784
f693592812_0.returns.push(o2);
// 8785
o2.getTime = f693592812_395;
// undefined
o2 = null;
// 8786
f693592812_395.returns.push(1345562153030);
// 8787
f693592812_13.returns.push(5);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 8797
f693592812_487.returns.push(undefined);
// 8800
f693592812_487.returns.push(undefined);
// 8803
f693592812_487.returns.push(undefined);
// 8806
f693592812_487.returns.push(undefined);
// 8809
f693592812_487.returns.push(undefined);
// 8810
f693592812_12.returns.push(6);
// 8811
o2 = {};
// 8812
f693592812_0.returns.push(o2);
// 8813
o2.getTime = f693592812_395;
// undefined
o2 = null;
// 8814
f693592812_395.returns.push(1345562153033);
// 8816
o2 = {};
// 8817
f693592812_400.returns.push(o2);
// 8818
o2.nodeType = 1;
// 8820
o2.nodeName = "DIV";
// 8823
o2.jQuery17109642799841240048 = void 0;
// 8824
// 8825
o2.JSBNG__addEventListener = f693592812_487;
// undefined
o2 = null;
// 8827
f693592812_487.returns.push(undefined);
// 8829
f693592812_413.returns.push(null);
// 8830
o2 = {};
// 8831
f693592812_0.returns.push(o2);
// undefined
o2 = null;
// 8833
o2 = {};
// 8834
f693592812_478.returns.push(o2);
// 8835
// 8836
// 8837
// 8838
// 8839
// 8840
// 8841
// 8843
o7.parentNode = o10;
// undefined
o10 = null;
// 8846
f693592812_481.returns.push(o2);
// 8858
f693592812_415.returns.push(o16);
// 8866
f693592812_415.returns.push(o18);
// 8874
f693592812_415.returns.push(o20);
// 8886
f693592812_415.returns.push(o23);
// 8894
f693592812_415.returns.push(o25);
// 8931
o3 = {};
// 8932
f693592812_0.returns.push(o3);
// 8933
o3.getTime = f693592812_395;
// 8934
f693592812_395.returns.push(1345562154036);
// 8945
f693592812_415.returns.push(o16);
// 8953
o5 = {};
// 8961
f693592812_415.returns.push(o16);
// 8969
f693592812_415.returns.push(o18);
// 8977
f693592812_415.returns.push(o20);
// 8989
f693592812_415.returns.push(o23);
// 8997
f693592812_415.returns.push(o25);
// 9034
o3 = {};
// 9035
f693592812_0.returns.push(o3);
// 9036
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 9037
f693592812_395.returns.push(1345562154036);
// 9048
f693592812_415.returns.push(o16);
// 9056
o5.type = "mouseover";
// 9057
o5.jQuery17109642799841240048 = void 0;
// 9061
o5.defaultPrevented = "false";
// 9062
o5.returnValue = "true";
// 9063
o5.getPreventDefault = void 0;
// 9064
o5.timeStamp = 1345562184352;
// 9065
o5.toElement = o15;
// 9066
o5.screenY = 401;
// 9067
o5.screenX = 684;
// 9068
o5.pageY = 175;
// 9069
o5.pageX = 211;
// 9070
o5.offsetY = 175;
// 9071
o5.offsetX = 211;
// 9072
o5.fromElement = null;
// 9073
o5.clientY = 175;
// 9074
o5.clientX = 211;
// 9075
o5.buttons = void 0;
// 9076
o5.button = 0;
// 9077
o5.which = 0;
// 9078
o5.view = ow693592812;
// 9080
o5.target = o15;
// 9081
o5.shiftKey = "false";
// 9082
o5.relatedTarget = null;
// 9083
o5.metaKey = "false";
// 9084
o5.eventPhase = 3;
// 9085
o5.currentTarget = o0;
// 9086
o5.ctrlKey = "false";
// 9087
o5.cancelable = "true";
// 9088
o5.bubbles = "true";
// 9089
o5.altKey = "false";
// 9090
o5.srcElement = o15;
// 9091
o5.relatedNode = void 0;
// 9092
o5.attrName = void 0;
// 9093
o5.attrChange = void 0;
// undefined
o5 = null;
// 9094
o15.nodeType = 1;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9101
o15.disabled = void 0;
// 9104
o3 = {};
// 9105
o15.attributes = o3;
// 9106
o5 = {};
// 9107
o3.class = o5;
// undefined
o3 = null;
// 9108
o5.value = "wrapper";
// undefined
o5 = null;
// 9109
o15.ownerDocument = o0;
// 9112
f693592812_538.returns.push(false);
// 9116
f693592812_538.returns.push(false);
// 9120
f693592812_538.returns.push(false);
// 9121
o15.parentNode = o28;
// 9122
o3 = {};
// 9123
o28.attributes = o3;
// 9124
o5 = {};
// 9125
o3.class = o5;
// undefined
o3 = null;
// 9126
o5.value = "";
// undefined
o5 = null;
// 9127
o28.ownerDocument = o0;
// undefined
o28 = null;
// 9130
f693592812_538.returns.push(false);
// 9134
f693592812_538.returns.push(false);
// 9138
f693592812_538.returns.push(false);
// 9140
o3 = {};
// 9141
o13.attributes = o3;
// 9142
o5 = {};
// 9143
o3.class = o5;
// undefined
o3 = null;
// 9144
o5.value = "route-search";
// undefined
o5 = null;
// 9145
o13.ownerDocument = o0;
// undefined
o13 = null;
// 9148
f693592812_538.returns.push(false);
// 9152
f693592812_538.returns.push(false);
// 9156
f693592812_538.returns.push(false);
// 9158
o3 = {};
// 9159
o12.attributes = o3;
// 9160
o5 = {};
// 9161
o3.class = o5;
// undefined
o3 = null;
// 9162
o5.value = "t1  logged-out   front-random-image-city-balcony  ms-windows webkit";
// undefined
o5 = null;
// 9163
o12.ownerDocument = o0;
// 9166
f693592812_538.returns.push(false);
// 9170
f693592812_538.returns.push(false);
// 9174
f693592812_538.returns.push(false);
// 9176
o3 = {};
// 9177
o8.attributes = o3;
// 9178
o5 = {};
// 9179
o3.class = o5;
// undefined
o3 = null;
// 9180
o5.value = "  js";
// undefined
o5 = null;
// 9181
o8.ownerDocument = o0;
// 9184
f693592812_538.returns.push(false);
// 9188
f693592812_538.returns.push(false);
// 9192
f693592812_538.returns.push(false);
// 9194
o3 = {};
// 9195
o3.type = "mousemove";
// 9196
o3.jQuery17109642799841240048 = void 0;
// 9200
o3.defaultPrevented = "false";
// 9201
o3.returnValue = "true";
// 9202
o3.getPreventDefault = void 0;
// 9203
o3.timeStamp = 1345562199499;
// 9204
o3.toElement = o15;
// 9205
o3.screenY = 401;
// 9206
o3.screenX = 684;
// 9207
o3.pageY = 175;
// 9208
o3.pageX = 211;
// 9209
o3.offsetY = 175;
// 9210
o3.offsetX = 211;
// 9211
o3.fromElement = null;
// 9212
o3.clientY = 175;
// 9213
o3.clientX = 211;
// 9214
o3.buttons = void 0;
// 9215
o3.button = 0;
// 9216
o3.which = 0;
// 9217
o3.view = ow693592812;
// 9219
o3.target = o15;
// 9220
o3.shiftKey = "false";
// 9221
o3.relatedTarget = null;
// 9222
o3.metaKey = "false";
// 9223
o3.eventPhase = 3;
// 9224
o3.currentTarget = o0;
// 9225
o3.ctrlKey = "false";
// 9226
o3.cancelable = "false";
// 9227
o3.bubbles = "true";
// 9228
o3.altKey = "false";
// 9229
o3.srcElement = o15;
// 9230
o3.relatedNode = void 0;
// 9231
o3.attrName = void 0;
// 9232
o3.attrChange = void 0;
// undefined
o3 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9291
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9300
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9309
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9318
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9327
f693592812_523.returns.push(undefined);
// 9328
f693592812_15.returns.push(undefined);
// 9329
o3 = {};
// 9330
f693592812_0.returns.push(o3);
// 9331
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 9332
f693592812_395.returns.push(1345562199580);
// 9333
f693592812_12.returns.push(7);
// 9337
o3 = {};
// 9338
f693592812_0.returns.push(o3);
// 9339
o3.getTime = f693592812_395;
// undefined
o3 = null;
// 9340
f693592812_395.returns.push(1345562199580);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9346
o0.onactive = void 0;
// 9349
o0.active = void 0;
// 9350
o3 = {};
// 9351
o3.type = "keydown";
// 9352
o3.jQuery17109642799841240048 = void 0;
// 9356
o3.defaultPrevented = "false";
// 9357
o3.returnValue = "true";
// 9358
o3.getPreventDefault = void 0;
// 9359
o3.timeStamp = 1345562199619;
// 9360
o3.keyCode = 18;
// 9361
o3.key = void 0;
// 9362
o3.charCode = 0;
// 9363
o3.char = void 0;
// 9364
o3.which = 18;
// 9365
o3.view = ow693592812;
// 9367
o3.target = o12;
// 9368
o3.shiftKey = "false";
// 9369
o3.relatedTarget = void 0;
// 9370
o3.metaKey = "false";
// 9371
o3.eventPhase = 3;
// 9372
o3.currentTarget = o0;
// 9373
o3.ctrlKey = "false";
// 9374
o3.cancelable = "true";
// 9375
o3.bubbles = "true";
// 9376
o3.altKey = "true";
// 9377
o3.srcElement = o12;
// 9378
o3.relatedNode = void 0;
// 9379
o3.attrName = void 0;
// 9380
o3.attrChange = void 0;
// undefined
o3 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9386
o3 = {};
// 9387
f693592812_0.returns.push(o3);
// undefined
o3 = null;
// 9388
o1.ownerDocument = o0;
// 9391
o1.nodeType = 1;
// 9393
o1.nodeName = "DIV";
// 9394
o1.getAttribute = f693592812_474;
// 9395
f693592812_474.returns.push(null);
// 9396
o1.parentNode = null;
// 9397
o1.setAttribute = f693592812_495;
// 9398
f693592812_495.returns.push(undefined);
// 9399
o1.querySelectorAll = f693592812_536;
// 9400
o3 = {};
// 9401
f693592812_536.returns.push(o3);
// 9402
o3.length = 0;
// undefined
o3 = null;
// 9404
o1.removeAttribute = f693592812_475;
// undefined
o1 = null;
// 9405
f693592812_475.returns.push(undefined);
// 9406
o1 = {};
// 9407
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 9408
f693592812_12.returns.push(8);
// 9419
f693592812_415.returns.push(o16);
// 9427
f693592812_415.returns.push(o18);
// 9435
f693592812_415.returns.push(o20);
// 9447
f693592812_415.returns.push(o23);
// 9455
f693592812_415.returns.push(o25);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 9497
o1 = {};
// 9499
o1.type = "load";
// undefined
o1 = null;
// 9500
// undefined
o2 = null;
// 9501
f693592812_393.returns.push(0.2988254274241626);
// 9505
o1 = {};
// 9506
o0.styleSheets = o1;
// undefined
o1 = null;
// 9512
o1 = {};
// 9513
f693592812_534.returns.push(o1);
// 9514
o1.length = 1;
// 9516
o2 = {};
// 9517
o1["0"] = o2;
// undefined
o1 = null;
// undefined
o2 = null;
// 9519
o12.appendChild = f693592812_500;
// 9521
o1 = {};
// 9522
f693592812_400.returns.push(o1);
// 9523
f693592812_500.returns.push(o1);
// 9524
o2 = {};
// 9525
o1.style = o2;
// 9526
o2.minHeight = "";
// 9527
// 9528
o2.height = "";
// 9529
// 9530
o2.padding = "";
// 9531
// 9532
o2.borderWidth = "";
// 9533
// 9534
o1.offsetHeight = 100;
// 9536
f693592812_518.returns.push(o1);
// undefined
o1 = null;
// 9538
// undefined
o2 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9548
f693592812_487.returns.push(undefined);
// 9549
o1 = {};
// 9550
o4.plugins = o1;
// undefined
o4 = null;
// 9551
o1["Shockwave Flash"] = void 0;
// undefined
o1 = null;
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 9556
f693592812_589.returns.push("{\"v1:134556212694094198\":{\"value\":{\"login\":1345562152860,\"store\":{}},\"expire\":{}}}");
// 9557
o1 = {};
// 9558
f693592812_0.returns.push(o1);
// 9559
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9560
f693592812_395.returns.push(1345562200794);
// 9561
o1 = {};
// 9562
f693592812_0.returns.push(o1);
// 9563
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9564
f693592812_395.returns.push(1345562200794);
// 9565
o1 = {};
// 9566
f693592812_0.returns.push(o1);
// 9567
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9568
f693592812_395.returns.push(1345562200794);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9593
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9617
f693592812_487.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9637
o1 = {};
// 9638
f693592812_534.returns.push(o1);
// 9639
o1.length = 0;
// undefined
o1 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9653
o1 = {};
// 9654
f693592812_534.returns.push(o1);
// 9655
o1.length = 0;
// undefined
o1 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9676
o1 = {};
// 9677
f693592812_534.returns.push(o1);
// 9678
o1.length = 2;
// 9680
o1["0"] = o8;
// 9681
o1["1"] = o12;
// undefined
o1 = null;
// 9687
o1 = {};
// 9688
f693592812_534.returns.push(o1);
// 9689
o1.length = 2;
// 9691
o1["0"] = o8;
// 9692
o1["1"] = o12;
// undefined
o1 = null;
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 9704
o1 = {};
// 9705
f693592812_534.returns.push(o1);
// 9706
o1.length = 2;
// 9708
o1["0"] = o8;
// 9709
o1["1"] = o12;
// undefined
o1 = null;
// 9716
o1 = {};
// 9717
f693592812_534.returns.push(o1);
// 9718
o1.length = 2;
// 9720
o1["0"] = o8;
// 9721
o1["1"] = o12;
// undefined
o1 = null;
// 9727
o1 = {};
// 9728
f693592812_534.returns.push(o1);
// 9729
o1.length = 2;
// 9731
o1["0"] = o8;
// 9732
o1["1"] = o12;
// undefined
o1 = null;
// 9733
o1 = {};
// 9734
f693592812_0.returns.push(o1);
// 9735
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9736
f693592812_395.returns.push(1345562201612);
// 9737
f693592812_13.returns.push(9);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 9747
f693592812_487.returns.push(undefined);
// 9750
f693592812_487.returns.push(undefined);
// 9753
f693592812_487.returns.push(undefined);
// 9756
f693592812_487.returns.push(undefined);
// 9759
f693592812_487.returns.push(undefined);
// 9770
f693592812_415.returns.push(o16);
// 9778
f693592812_415.returns.push(o18);
// 9786
f693592812_415.returns.push(o20);
// 9798
f693592812_415.returns.push(o23);
// 9806
f693592812_415.returns.push(o25);
// 9843
o1 = {};
// undefined
o1 = null;
// 9844
o1 = {};
// 9845
o1.type = "popstate";
// 9846
o1.jQuery17109642799841240048 = void 0;
// 9850
o1.defaultPrevented = "false";
// 9851
o1.returnValue = "true";
// 9852
o1.getPreventDefault = void 0;
// 9853
o1.timeStamp = 1345562201618;
// 9854
o1.which = void 0;
// 9855
o1.view = void 0;
// 9857
o1.target = ow693592812;
// 9858
o1.shiftKey = void 0;
// 9859
o1.relatedTarget = void 0;
// 9860
o1.metaKey = void 0;
// 9861
o1.eventPhase = 2;
// 9862
o1.currentTarget = ow693592812;
// 9863
o1.ctrlKey = void 0;
// 9864
o1.cancelable = "true";
// 9865
o1.bubbles = "false";
// 9866
o1.altKey = void 0;
// 9867
o1.srcElement = ow693592812;
// 9868
o1.relatedNode = void 0;
// 9869
o1.attrName = void 0;
// 9870
o1.attrChange = void 0;
// undefined
o1 = null;
// 9871
o1 = {};
// 9872
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 9880
f693592812_474.returns.push(null);
// 9883
f693592812_495.returns.push(undefined);
// 9885
o1 = {};
// 9886
f693592812_536.returns.push(o1);
// 9887
o1.length = 0;
// undefined
o1 = null;
// 9890
f693592812_475.returns.push(undefined);
// 9891
o1 = {};
// 9892
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 9893
f693592812_12.returns.push(10);
// 9894
o1 = {};
// 9895
f693592812_0.returns.push(o1);
// 9896
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9897
f693592812_395.returns.push(1345562202613);
// 9908
f693592812_415.returns.push(o16);
// 9916
f693592812_415.returns.push(o18);
// 9924
f693592812_415.returns.push(o20);
// 9936
f693592812_415.returns.push(o23);
// 9944
f693592812_415.returns.push(o25);
// 9981
o1 = {};
// 9982
f693592812_0.returns.push(o1);
// 9983
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 9984
f693592812_395.returns.push(1345562203613);
// 9985
o1 = {};
// 9986
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 9994
f693592812_474.returns.push(null);
// 9997
f693592812_495.returns.push(undefined);
// 9999
o1 = {};
// 10000
f693592812_536.returns.push(o1);
// 10001
o1.length = 0;
// undefined
o1 = null;
// 10004
f693592812_475.returns.push(undefined);
// 10005
o1 = {};
// 10006
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10007
f693592812_12.returns.push(11);
// 10018
f693592812_415.returns.push(o16);
// 10026
f693592812_415.returns.push(o18);
// 10034
f693592812_415.returns.push(o20);
// 10046
f693592812_415.returns.push(o23);
// 10054
f693592812_415.returns.push(o25);
// 10091
o1 = {};
// 10092
f693592812_0.returns.push(o1);
// 10093
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10094
f693592812_395.returns.push(1345562204613);
// 10105
f693592812_415.returns.push(o16);
// 10113
f693592812_415.returns.push(o18);
// 10121
f693592812_415.returns.push(o20);
// 10133
f693592812_415.returns.push(o23);
// 10141
f693592812_415.returns.push(o25);
// 10178
o1 = {};
// 10179
f693592812_0.returns.push(o1);
// 10180
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10181
f693592812_395.returns.push(1345562205613);
// 10182
o1 = {};
// 10183
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10191
f693592812_474.returns.push(null);
// 10194
f693592812_495.returns.push(undefined);
// 10196
o1 = {};
// 10197
f693592812_536.returns.push(o1);
// 10198
o1.length = 0;
// undefined
o1 = null;
// 10201
f693592812_475.returns.push(undefined);
// 10202
o1 = {};
// 10203
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10204
f693592812_12.returns.push(12);
// 10215
f693592812_415.returns.push(o16);
// 10223
f693592812_415.returns.push(o18);
// 10231
f693592812_415.returns.push(o20);
// 10243
f693592812_415.returns.push(o23);
// 10251
f693592812_415.returns.push(o25);
// 10288
o1 = {};
// 10289
f693592812_0.returns.push(o1);
// 10290
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10291
f693592812_395.returns.push(1345562206613);
// 10302
f693592812_415.returns.push(o16);
// 10310
f693592812_415.returns.push(o18);
// 10318
f693592812_415.returns.push(o20);
// 10330
f693592812_415.returns.push(o23);
// 10338
f693592812_415.returns.push(o25);
// 10375
o1 = {};
// 10376
f693592812_0.returns.push(o1);
// 10377
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10378
f693592812_395.returns.push(1345562207613);
// 10379
o1 = {};
// 10380
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10388
f693592812_474.returns.push(null);
// 10391
f693592812_495.returns.push(undefined);
// 10393
o1 = {};
// 10394
f693592812_536.returns.push(o1);
// 10395
o1.length = 0;
// undefined
o1 = null;
// 10398
f693592812_475.returns.push(undefined);
// 10399
o1 = {};
// 10400
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10401
f693592812_12.returns.push(13);
// 10412
f693592812_415.returns.push(o16);
// 10420
f693592812_415.returns.push(o18);
// 10428
f693592812_415.returns.push(o20);
// 10440
f693592812_415.returns.push(o23);
// 10448
f693592812_415.returns.push(o25);
// 10485
o1 = {};
// 10486
f693592812_0.returns.push(o1);
// 10487
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10488
f693592812_395.returns.push(1345562208613);
// 10499
f693592812_415.returns.push(o16);
// 10507
f693592812_415.returns.push(o18);
// 10515
f693592812_415.returns.push(o20);
// 10527
f693592812_415.returns.push(o23);
// 10535
f693592812_415.returns.push(o25);
// 10572
o1 = {};
// 10573
f693592812_0.returns.push(o1);
// 10574
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10575
f693592812_395.returns.push(1345562209613);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 10580
o1 = {};
// 10581
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10589
f693592812_474.returns.push(null);
// 10592
f693592812_495.returns.push(undefined);
// 10594
o1 = {};
// 10595
f693592812_536.returns.push(o1);
// 10596
o1.length = 0;
// undefined
o1 = null;
// 10599
f693592812_475.returns.push(undefined);
// 10600
o1 = {};
// 10601
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10602
f693592812_12.returns.push(14);
// 10613
f693592812_415.returns.push(o16);
// 10621
f693592812_415.returns.push(o18);
// 10629
f693592812_415.returns.push(o20);
// 10641
f693592812_415.returns.push(o23);
// 10649
f693592812_415.returns.push(o25);
// 10686
o1 = {};
// 10687
f693592812_0.returns.push(o1);
// 10688
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10689
f693592812_395.returns.push(1345562210613);
// 10700
f693592812_415.returns.push(o16);
// 10708
f693592812_415.returns.push(o18);
// 10716
f693592812_415.returns.push(o20);
// 10728
f693592812_415.returns.push(o23);
// 10736
f693592812_415.returns.push(o25);
// 10773
o1 = {};
// 10774
f693592812_0.returns.push(o1);
// 10775
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10776
f693592812_395.returns.push(1345562211623);
// 10777
o1 = {};
// 10778
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10786
f693592812_474.returns.push(null);
// 10789
f693592812_495.returns.push(undefined);
// 10791
o1 = {};
// 10792
f693592812_536.returns.push(o1);
// 10793
o1.length = 0;
// undefined
o1 = null;
// 10796
f693592812_475.returns.push(undefined);
// 10797
o1 = {};
// 10798
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10799
f693592812_12.returns.push(15);
// 10800
o1 = {};
// 10801
f693592812_0.returns.push(o1);
// 10802
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10803
f693592812_395.returns.push(1345562212623);
// 10814
f693592812_415.returns.push(o16);
// 10822
f693592812_415.returns.push(o18);
// 10830
f693592812_415.returns.push(o20);
// 10842
f693592812_415.returns.push(o23);
// 10850
f693592812_415.returns.push(o25);
// 10887
o1 = {};
// 10888
f693592812_0.returns.push(o1);
// 10889
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 10890
f693592812_395.returns.push(1345562213623);
// 10891
o1 = {};
// 10892
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10900
f693592812_474.returns.push(null);
// 10903
f693592812_495.returns.push(undefined);
// 10905
o1 = {};
// 10906
f693592812_536.returns.push(o1);
// 10907
o1.length = 0;
// undefined
o1 = null;
// 10910
f693592812_475.returns.push(undefined);
// 10911
o1 = {};
// 10912
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 10913
f693592812_12.returns.push(16);
// 10924
f693592812_415.returns.push(o16);
// 10932
f693592812_415.returns.push(o18);
// 10940
f693592812_415.returns.push(o20);
// 10952
f693592812_415.returns.push(o23);
// 10960
f693592812_415.returns.push(o25);
// 10997
o1 = {};
// 10998
f693592812_0.returns.push(o1);
// 10999
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11000
f693592812_395.returns.push(1345562214623);
// 11011
f693592812_415.returns.push(o16);
// 11019
f693592812_415.returns.push(o18);
// 11027
f693592812_415.returns.push(o20);
// 11039
f693592812_415.returns.push(o23);
// 11047
f693592812_415.returns.push(o25);
// 11084
o1 = {};
// 11085
f693592812_0.returns.push(o1);
// 11086
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11087
f693592812_395.returns.push(1345562215623);
// 11088
o1 = {};
// 11089
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11097
f693592812_474.returns.push(null);
// 11100
f693592812_495.returns.push(undefined);
// 11102
o1 = {};
// 11103
f693592812_536.returns.push(o1);
// 11104
o1.length = 0;
// undefined
o1 = null;
// 11107
f693592812_475.returns.push(undefined);
// 11108
o1 = {};
// 11109
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11110
f693592812_12.returns.push(17);
// 11121
f693592812_415.returns.push(o16);
// 11129
f693592812_415.returns.push(o18);
// 11137
f693592812_415.returns.push(o20);
// 11149
f693592812_415.returns.push(o23);
// 11157
f693592812_415.returns.push(o25);
// 11194
o1 = {};
// 11195
f693592812_0.returns.push(o1);
// 11196
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11197
f693592812_395.returns.push(1345562216623);
// 11208
f693592812_415.returns.push(o16);
// 11216
f693592812_415.returns.push(o18);
// 11224
f693592812_415.returns.push(o20);
// 11236
f693592812_415.returns.push(o23);
// 11244
f693592812_415.returns.push(o25);
// 11281
o1 = {};
// 11282
f693592812_0.returns.push(o1);
// 11283
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11284
f693592812_395.returns.push(1345562217623);
// 11285
o1 = {};
// 11286
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11294
f693592812_474.returns.push(null);
// 11297
f693592812_495.returns.push(undefined);
// 11299
o1 = {};
// 11300
f693592812_536.returns.push(o1);
// 11301
o1.length = 0;
// undefined
o1 = null;
// 11304
f693592812_475.returns.push(undefined);
// 11305
o1 = {};
// 11306
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11307
f693592812_12.returns.push(18);
// 11318
f693592812_415.returns.push(o16);
// 11326
f693592812_415.returns.push(o18);
// 11334
f693592812_415.returns.push(o20);
// 11346
f693592812_415.returns.push(o23);
// 11354
f693592812_415.returns.push(o25);
// 11391
o1 = {};
// 11392
f693592812_0.returns.push(o1);
// 11393
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11394
f693592812_395.returns.push(1345562218624);
// 11405
f693592812_415.returns.push(o16);
// 11413
f693592812_415.returns.push(o18);
// 11421
f693592812_415.returns.push(o20);
// 11433
f693592812_415.returns.push(o23);
// 11441
f693592812_415.returns.push(o25);
// 11478
o1 = {};
// 11479
f693592812_0.returns.push(o1);
// 11480
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11481
f693592812_395.returns.push(1345562219623);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 11486
o1 = {};
// 11487
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11495
f693592812_474.returns.push(null);
// 11498
f693592812_495.returns.push(undefined);
// 11500
o1 = {};
// 11501
f693592812_536.returns.push(o1);
// 11502
o1.length = 0;
// undefined
o1 = null;
// 11505
f693592812_475.returns.push(undefined);
// 11506
o1 = {};
// 11507
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11508
f693592812_12.returns.push(19);
// 11519
f693592812_415.returns.push(o16);
// 11527
f693592812_415.returns.push(o18);
// 11535
f693592812_415.returns.push(o20);
// 11547
f693592812_415.returns.push(o23);
// 11555
f693592812_415.returns.push(o25);
// 11592
o1 = {};
// 11593
f693592812_0.returns.push(o1);
// 11594
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11595
f693592812_395.returns.push(1345562220623);
// 11606
f693592812_415.returns.push(o16);
// 11614
f693592812_415.returns.push(o18);
// 11622
f693592812_415.returns.push(o20);
// 11634
f693592812_415.returns.push(o23);
// 11642
f693592812_415.returns.push(o25);
// 11679
o1 = {};
// 11680
f693592812_0.returns.push(o1);
// 11681
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11682
f693592812_395.returns.push(1345562221623);
// 11683
o1 = {};
// 11684
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11692
f693592812_474.returns.push(null);
// 11695
f693592812_495.returns.push(undefined);
// 11697
o1 = {};
// 11698
f693592812_536.returns.push(o1);
// 11699
o1.length = 0;
// undefined
o1 = null;
// 11702
f693592812_475.returns.push(undefined);
// 11703
o1 = {};
// 11704
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11705
f693592812_12.returns.push(20);
// 11706
o1 = {};
// 11707
f693592812_0.returns.push(o1);
// 11708
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11709
f693592812_395.returns.push(1345562222623);
// 11720
f693592812_415.returns.push(o16);
// 11728
f693592812_415.returns.push(o18);
// 11736
f693592812_415.returns.push(o20);
// 11748
f693592812_415.returns.push(o23);
// 11756
f693592812_415.returns.push(o25);
// 11793
o1 = {};
// 11794
f693592812_0.returns.push(o1);
// 11795
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11796
f693592812_395.returns.push(1345562223623);
// 11797
o1 = {};
// 11798
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11806
f693592812_474.returns.push(null);
// 11809
f693592812_495.returns.push(undefined);
// 11811
o1 = {};
// 11812
f693592812_536.returns.push(o1);
// 11813
o1.length = 0;
// undefined
o1 = null;
// 11816
f693592812_475.returns.push(undefined);
// 11817
o1 = {};
// 11818
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 11819
f693592812_12.returns.push(21);
// 11830
f693592812_415.returns.push(o16);
// 11838
f693592812_415.returns.push(o18);
// 11846
f693592812_415.returns.push(o20);
// 11858
f693592812_415.returns.push(o23);
// 11866
f693592812_415.returns.push(o25);
// 11903
o1 = {};
// 11904
f693592812_0.returns.push(o1);
// 11905
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11906
f693592812_395.returns.push(1345562224623);
// 11917
f693592812_415.returns.push(o16);
// 11925
f693592812_415.returns.push(o18);
// 11933
f693592812_415.returns.push(o20);
// 11945
f693592812_415.returns.push(o23);
// 11953
f693592812_415.returns.push(o25);
// 11990
o1 = {};
// 11991
f693592812_0.returns.push(o1);
// 11992
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 11993
f693592812_395.returns.push(1345562225623);
// 11994
o1 = {};
// 11995
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12003
f693592812_474.returns.push(null);
// 12006
f693592812_495.returns.push(undefined);
// 12008
o1 = {};
// 12009
f693592812_536.returns.push(o1);
// 12010
o1.length = 0;
// undefined
o1 = null;
// 12013
f693592812_475.returns.push(undefined);
// 12014
o1 = {};
// 12015
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12016
f693592812_12.returns.push(22);
// 12027
f693592812_415.returns.push(o16);
// 12035
f693592812_415.returns.push(o18);
// 12043
f693592812_415.returns.push(o20);
// 12055
f693592812_415.returns.push(o23);
// 12063
f693592812_415.returns.push(o25);
// 12100
o1 = {};
// 12101
f693592812_0.returns.push(o1);
// 12102
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12103
f693592812_395.returns.push(1345562226623);
// 12114
f693592812_415.returns.push(o16);
// 12122
f693592812_415.returns.push(o18);
// 12130
f693592812_415.returns.push(o20);
// 12142
f693592812_415.returns.push(o23);
// 12150
f693592812_415.returns.push(o25);
// 12187
o1 = {};
// 12188
f693592812_0.returns.push(o1);
// 12189
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12190
f693592812_395.returns.push(1345562227623);
// 12191
o1 = {};
// 12192
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12200
f693592812_474.returns.push(null);
// 12203
f693592812_495.returns.push(undefined);
// 12205
o1 = {};
// 12206
f693592812_536.returns.push(o1);
// 12207
o1.length = 0;
// undefined
o1 = null;
// 12210
f693592812_475.returns.push(undefined);
// 12211
o1 = {};
// 12212
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12213
f693592812_12.returns.push(23);
// 12224
f693592812_415.returns.push(o16);
// 12232
f693592812_415.returns.push(o18);
// 12240
f693592812_415.returns.push(o20);
// 12252
f693592812_415.returns.push(o23);
// 12260
f693592812_415.returns.push(o25);
// 12297
o1 = {};
// 12298
f693592812_0.returns.push(o1);
// 12299
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12300
f693592812_395.returns.push(1345562228623);
// 12311
f693592812_415.returns.push(o16);
// 12319
f693592812_415.returns.push(o18);
// 12327
f693592812_415.returns.push(o20);
// 12339
f693592812_415.returns.push(o23);
// 12347
f693592812_415.returns.push(o25);
// 12384
o1 = {};
// 12385
f693592812_0.returns.push(o1);
// 12386
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12387
f693592812_395.returns.push(1345562229623);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 12392
o1 = {};
// 12393
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12401
f693592812_474.returns.push(null);
// 12404
f693592812_495.returns.push(undefined);
// 12406
o1 = {};
// 12407
f693592812_536.returns.push(o1);
// 12408
o1.length = 0;
// undefined
o1 = null;
// 12411
f693592812_475.returns.push(undefined);
// 12412
o1 = {};
// 12413
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12414
f693592812_12.returns.push(24);
// 12425
f693592812_415.returns.push(o16);
// 12433
f693592812_415.returns.push(o18);
// 12441
f693592812_415.returns.push(o20);
// 12453
f693592812_415.returns.push(o23);
// 12461
f693592812_415.returns.push(o25);
// 12498
o1 = {};
// 12499
f693592812_0.returns.push(o1);
// 12500
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12501
f693592812_395.returns.push(1345562230623);
// 12512
f693592812_415.returns.push(o16);
// 12520
f693592812_415.returns.push(o18);
// 12528
f693592812_415.returns.push(o20);
// 12540
f693592812_415.returns.push(o23);
// 12548
f693592812_415.returns.push(o25);
// 12585
o1 = {};
// 12586
f693592812_0.returns.push(o1);
// 12587
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12588
f693592812_395.returns.push(1345562231623);
// 12589
o1 = {};
// 12590
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12598
f693592812_474.returns.push(null);
// 12601
f693592812_495.returns.push(undefined);
// 12603
o1 = {};
// 12604
f693592812_536.returns.push(o1);
// 12605
o1.length = 0;
// undefined
o1 = null;
// 12608
f693592812_475.returns.push(undefined);
// 12609
o1 = {};
// 12610
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12611
f693592812_12.returns.push(25);
// 12612
o1 = {};
// 12613
f693592812_0.returns.push(o1);
// 12614
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12615
f693592812_395.returns.push(1345562232624);
// 12626
f693592812_415.returns.push(o16);
// 12634
f693592812_415.returns.push(o18);
// 12642
f693592812_415.returns.push(o20);
// 12654
f693592812_415.returns.push(o23);
// 12662
f693592812_415.returns.push(o25);
// 12699
o1 = {};
// 12700
f693592812_0.returns.push(o1);
// 12701
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12702
f693592812_395.returns.push(1345562233623);
// 12703
o1 = {};
// 12704
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12712
f693592812_474.returns.push(null);
// 12715
f693592812_495.returns.push(undefined);
// 12717
o1 = {};
// 12718
f693592812_536.returns.push(o1);
// 12719
o1.length = 0;
// undefined
o1 = null;
// 12722
f693592812_475.returns.push(undefined);
// 12723
o1 = {};
// 12724
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12725
f693592812_12.returns.push(26);
// 12736
f693592812_415.returns.push(o16);
// 12744
f693592812_415.returns.push(o18);
// 12752
f693592812_415.returns.push(o20);
// 12764
f693592812_415.returns.push(o23);
// 12772
f693592812_415.returns.push(o25);
// 12809
o1 = {};
// 12810
f693592812_0.returns.push(o1);
// 12811
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12812
f693592812_395.returns.push(1345562234623);
// 12823
f693592812_415.returns.push(o16);
// 12831
f693592812_415.returns.push(o18);
// 12839
f693592812_415.returns.push(o20);
// 12851
f693592812_415.returns.push(o23);
// 12859
f693592812_415.returns.push(o25);
// 12896
o1 = {};
// 12897
f693592812_0.returns.push(o1);
// 12898
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 12899
f693592812_395.returns.push(1345562235623);
// 12900
o1 = {};
// 12901
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12909
f693592812_474.returns.push(null);
// 12912
f693592812_495.returns.push(undefined);
// 12914
o1 = {};
// 12915
f693592812_536.returns.push(o1);
// 12916
o1.length = 0;
// undefined
o1 = null;
// 12919
f693592812_475.returns.push(undefined);
// 12920
o1 = {};
// 12921
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 12922
f693592812_12.returns.push(27);
// 12933
f693592812_415.returns.push(o16);
// 12941
f693592812_415.returns.push(o18);
// 12949
f693592812_415.returns.push(o20);
// 12961
f693592812_415.returns.push(o23);
// 12969
f693592812_415.returns.push(o25);
// 13006
o1 = {};
// 13007
f693592812_0.returns.push(o1);
// 13008
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13009
f693592812_395.returns.push(1345562236623);
// 13020
f693592812_415.returns.push(o16);
// 13028
f693592812_415.returns.push(o18);
// 13036
f693592812_415.returns.push(o20);
// 13048
f693592812_415.returns.push(o23);
// 13056
f693592812_415.returns.push(o25);
// 13093
o1 = {};
// 13094
f693592812_0.returns.push(o1);
// 13095
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13096
f693592812_395.returns.push(1345562237623);
// 13097
o1 = {};
// 13098
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13106
f693592812_474.returns.push(null);
// 13109
f693592812_495.returns.push(undefined);
// 13111
o1 = {};
// 13112
f693592812_536.returns.push(o1);
// 13113
o1.length = 0;
// undefined
o1 = null;
// 13116
f693592812_475.returns.push(undefined);
// 13117
o1 = {};
// 13118
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13119
f693592812_12.returns.push(28);
// 13130
f693592812_415.returns.push(o16);
// 13138
f693592812_415.returns.push(o18);
// 13146
f693592812_415.returns.push(o20);
// 13158
f693592812_415.returns.push(o23);
// 13166
f693592812_415.returns.push(o25);
// 13203
o1 = {};
// 13204
f693592812_0.returns.push(o1);
// 13205
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13206
f693592812_395.returns.push(1345562238623);
// 13217
f693592812_415.returns.push(o16);
// 13225
f693592812_415.returns.push(o18);
// 13233
f693592812_415.returns.push(o20);
// 13245
f693592812_415.returns.push(o23);
// 13253
f693592812_415.returns.push(o25);
// 13290
o1 = {};
// 13291
f693592812_0.returns.push(o1);
// 13292
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13293
f693592812_395.returns.push(1345562239623);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 13298
o1 = {};
// 13299
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13307
f693592812_474.returns.push(null);
// 13310
f693592812_495.returns.push(undefined);
// 13312
o1 = {};
// 13313
f693592812_536.returns.push(o1);
// 13314
o1.length = 0;
// undefined
o1 = null;
// 13317
f693592812_475.returns.push(undefined);
// 13318
o1 = {};
// 13319
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13320
f693592812_12.returns.push(29);
// 13331
f693592812_415.returns.push(o16);
// 13339
f693592812_415.returns.push(o18);
// 13347
f693592812_415.returns.push(o20);
// 13359
f693592812_415.returns.push(o23);
// 13367
f693592812_415.returns.push(o25);
// 13404
o1 = {};
// 13405
f693592812_0.returns.push(o1);
// 13406
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13407
f693592812_395.returns.push(1345562240623);
// 13418
f693592812_415.returns.push(o16);
// 13426
f693592812_415.returns.push(o18);
// 13434
f693592812_415.returns.push(o20);
// 13446
f693592812_415.returns.push(o23);
// 13454
f693592812_415.returns.push(o25);
// 13491
o1 = {};
// 13492
f693592812_0.returns.push(o1);
// 13493
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13494
f693592812_395.returns.push(1345562241623);
// 13495
o1 = {};
// 13496
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13504
f693592812_474.returns.push(null);
// 13507
f693592812_495.returns.push(undefined);
// 13509
o1 = {};
// 13510
f693592812_536.returns.push(o1);
// 13511
o1.length = 0;
// undefined
o1 = null;
// 13514
f693592812_475.returns.push(undefined);
// 13515
o1 = {};
// 13516
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13517
f693592812_12.returns.push(30);
// 13518
o1 = {};
// 13519
f693592812_0.returns.push(o1);
// 13520
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13521
f693592812_395.returns.push(1345562242628);
// 13532
f693592812_415.returns.push(o16);
// 13540
f693592812_415.returns.push(o18);
// 13548
f693592812_415.returns.push(o20);
// 13560
f693592812_415.returns.push(o23);
// 13568
f693592812_415.returns.push(o25);
// 13605
o1 = {};
// 13606
f693592812_0.returns.push(o1);
// 13607
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13608
f693592812_395.returns.push(1345562243623);
// 13609
o1 = {};
// 13610
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13618
f693592812_474.returns.push(null);
// 13621
f693592812_495.returns.push(undefined);
// 13623
o1 = {};
// 13624
f693592812_536.returns.push(o1);
// 13625
o1.length = 0;
// undefined
o1 = null;
// 13628
f693592812_475.returns.push(undefined);
// 13629
o1 = {};
// 13630
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13631
f693592812_12.returns.push(31);
// 13642
f693592812_415.returns.push(o16);
// 13650
f693592812_415.returns.push(o18);
// 13658
f693592812_415.returns.push(o20);
// 13670
f693592812_415.returns.push(o23);
// 13678
f693592812_415.returns.push(o25);
// 13715
o1 = {};
// 13716
f693592812_0.returns.push(o1);
// 13717
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13718
f693592812_395.returns.push(1345562244623);
// 13729
f693592812_415.returns.push(o16);
// 13737
f693592812_415.returns.push(o18);
// 13745
f693592812_415.returns.push(o20);
// 13757
f693592812_415.returns.push(o23);
// 13765
f693592812_415.returns.push(o25);
// 13802
o1 = {};
// 13803
f693592812_0.returns.push(o1);
// 13804
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13805
f693592812_395.returns.push(1345562245623);
// 13806
o1 = {};
// 13807
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13815
f693592812_474.returns.push(null);
// 13818
f693592812_495.returns.push(undefined);
// 13820
o1 = {};
// 13821
f693592812_536.returns.push(o1);
// 13822
o1.length = 0;
// undefined
o1 = null;
// 13825
f693592812_475.returns.push(undefined);
// 13826
o1 = {};
// 13827
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 13828
f693592812_12.returns.push(32);
// 13839
f693592812_415.returns.push(o16);
// 13847
f693592812_415.returns.push(o18);
// 13855
f693592812_415.returns.push(o20);
// 13867
f693592812_415.returns.push(o23);
// 13875
f693592812_415.returns.push(o25);
// 13912
o1 = {};
// 13913
f693592812_0.returns.push(o1);
// 13914
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 13915
f693592812_395.returns.push(1345562246623);
// 13926
f693592812_415.returns.push(o16);
// 13934
f693592812_415.returns.push(o18);
// 13942
f693592812_415.returns.push(o20);
// 13954
f693592812_415.returns.push(o23);
// 13962
f693592812_415.returns.push(o25);
// 13999
o1 = {};
// 14000
f693592812_0.returns.push(o1);
// 14001
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14002
f693592812_395.returns.push(1345562247623);
// 14003
o1 = {};
// 14004
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14012
f693592812_474.returns.push(null);
// 14015
f693592812_495.returns.push(undefined);
// 14017
o1 = {};
// 14018
f693592812_536.returns.push(o1);
// 14019
o1.length = 0;
// undefined
o1 = null;
// 14022
f693592812_475.returns.push(undefined);
// 14023
o1 = {};
// 14024
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14025
f693592812_12.returns.push(33);
// 14036
f693592812_415.returns.push(o16);
// 14044
f693592812_415.returns.push(o18);
// 14052
f693592812_415.returns.push(o20);
// 14064
f693592812_415.returns.push(o23);
// 14072
f693592812_415.returns.push(o25);
// 14109
o1 = {};
// 14110
f693592812_0.returns.push(o1);
// 14111
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14112
f693592812_395.returns.push(1345562248623);
// 14123
f693592812_415.returns.push(o16);
// 14131
f693592812_415.returns.push(o18);
// 14139
f693592812_415.returns.push(o20);
// 14151
f693592812_415.returns.push(o23);
// 14159
f693592812_415.returns.push(o25);
// 14196
o1 = {};
// 14197
f693592812_0.returns.push(o1);
// 14198
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14199
f693592812_395.returns.push(1345562249624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 14204
o1 = {};
// 14205
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14213
f693592812_474.returns.push(null);
// 14216
f693592812_495.returns.push(undefined);
// 14218
o1 = {};
// 14219
f693592812_536.returns.push(o1);
// 14220
o1.length = 0;
// undefined
o1 = null;
// 14223
f693592812_475.returns.push(undefined);
// 14224
o1 = {};
// 14225
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14226
f693592812_12.returns.push(34);
// 14237
f693592812_415.returns.push(o16);
// 14245
f693592812_415.returns.push(o18);
// 14253
f693592812_415.returns.push(o20);
// 14265
f693592812_415.returns.push(o23);
// 14273
f693592812_415.returns.push(o25);
// 14310
o1 = {};
// 14311
f693592812_0.returns.push(o1);
// 14312
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14313
f693592812_395.returns.push(1345562250623);
// 14324
f693592812_415.returns.push(o16);
// 14332
f693592812_415.returns.push(o18);
// 14340
f693592812_415.returns.push(o20);
// 14352
f693592812_415.returns.push(o23);
// 14360
f693592812_415.returns.push(o25);
// 14397
o1 = {};
// 14398
f693592812_0.returns.push(o1);
// 14399
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14400
f693592812_395.returns.push(1345562251624);
// 14401
o1 = {};
// 14402
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14410
f693592812_474.returns.push(null);
// 14413
f693592812_495.returns.push(undefined);
// 14415
o1 = {};
// 14416
f693592812_536.returns.push(o1);
// 14417
o1.length = 0;
// undefined
o1 = null;
// 14420
f693592812_475.returns.push(undefined);
// 14421
o1 = {};
// 14422
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14423
f693592812_12.returns.push(35);
// 14424
o1 = {};
// 14425
f693592812_0.returns.push(o1);
// 14426
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14427
f693592812_395.returns.push(1345562252628);
// 14438
f693592812_415.returns.push(o16);
// 14446
f693592812_415.returns.push(o18);
// 14454
f693592812_415.returns.push(o20);
// 14466
f693592812_415.returns.push(o23);
// 14474
f693592812_415.returns.push(o25);
// 14511
o1 = {};
// 14512
f693592812_0.returns.push(o1);
// 14513
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14514
f693592812_395.returns.push(1345562253624);
// 14515
o1 = {};
// 14516
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14524
f693592812_474.returns.push(null);
// 14527
f693592812_495.returns.push(undefined);
// 14529
o1 = {};
// 14530
f693592812_536.returns.push(o1);
// 14531
o1.length = 0;
// undefined
o1 = null;
// 14534
f693592812_475.returns.push(undefined);
// 14535
o1 = {};
// 14536
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14537
f693592812_12.returns.push(36);
// 14548
f693592812_415.returns.push(o16);
// 14556
f693592812_415.returns.push(o18);
// 14564
f693592812_415.returns.push(o20);
// 14576
f693592812_415.returns.push(o23);
// 14584
f693592812_415.returns.push(o25);
// 14621
o1 = {};
// 14622
f693592812_0.returns.push(o1);
// 14623
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14624
f693592812_395.returns.push(1345562254624);
// 14635
f693592812_415.returns.push(o16);
// 14643
f693592812_415.returns.push(o18);
// 14651
f693592812_415.returns.push(o20);
// 14663
f693592812_415.returns.push(o23);
// 14671
f693592812_415.returns.push(o25);
// 14708
o1 = {};
// 14709
f693592812_0.returns.push(o1);
// 14710
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14711
f693592812_395.returns.push(1345562255624);
// 14712
o1 = {};
// 14713
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14721
f693592812_474.returns.push(null);
// 14724
f693592812_495.returns.push(undefined);
// 14726
o1 = {};
// 14727
f693592812_536.returns.push(o1);
// 14728
o1.length = 0;
// undefined
o1 = null;
// 14731
f693592812_475.returns.push(undefined);
// 14732
o1 = {};
// 14733
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14734
f693592812_12.returns.push(37);
// 14745
f693592812_415.returns.push(o16);
// 14753
f693592812_415.returns.push(o18);
// 14761
f693592812_415.returns.push(o20);
// 14773
f693592812_415.returns.push(o23);
// 14781
f693592812_415.returns.push(o25);
// 14818
o1 = {};
// 14819
f693592812_0.returns.push(o1);
// 14820
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14821
f693592812_395.returns.push(1345562256624);
// 14832
f693592812_415.returns.push(o16);
// 14840
f693592812_415.returns.push(o18);
// 14848
f693592812_415.returns.push(o20);
// 14860
f693592812_415.returns.push(o23);
// 14868
f693592812_415.returns.push(o25);
// 14905
o1 = {};
// 14906
f693592812_0.returns.push(o1);
// 14907
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 14908
f693592812_395.returns.push(1345562257624);
// 14909
o1 = {};
// 14910
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14918
f693592812_474.returns.push(null);
// 14921
f693592812_495.returns.push(undefined);
// 14923
o1 = {};
// 14924
f693592812_536.returns.push(o1);
// 14925
o1.length = 0;
// undefined
o1 = null;
// 14928
f693592812_475.returns.push(undefined);
// 14929
o1 = {};
// 14930
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 14931
f693592812_12.returns.push(38);
// 14942
f693592812_415.returns.push(o16);
// 14950
f693592812_415.returns.push(o18);
// 14958
f693592812_415.returns.push(o20);
// 14970
f693592812_415.returns.push(o23);
// 14978
f693592812_415.returns.push(o25);
// 15015
o1 = {};
// 15016
f693592812_0.returns.push(o1);
// 15017
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15018
f693592812_395.returns.push(1345562258624);
// 15029
f693592812_415.returns.push(o16);
// 15037
f693592812_415.returns.push(o18);
// 15045
f693592812_415.returns.push(o20);
// 15057
f693592812_415.returns.push(o23);
// 15065
f693592812_415.returns.push(o25);
// 15102
o1 = {};
// 15103
f693592812_0.returns.push(o1);
// 15104
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15105
f693592812_395.returns.push(1345562259624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 15110
o1 = {};
// 15111
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15119
f693592812_474.returns.push(null);
// 15122
f693592812_495.returns.push(undefined);
// 15124
o1 = {};
// 15125
f693592812_536.returns.push(o1);
// 15126
o1.length = 0;
// undefined
o1 = null;
// 15129
f693592812_475.returns.push(undefined);
// 15130
o1 = {};
// 15131
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15132
f693592812_12.returns.push(39);
// 15143
f693592812_415.returns.push(o16);
// 15151
f693592812_415.returns.push(o18);
// 15159
f693592812_415.returns.push(o20);
// 15171
f693592812_415.returns.push(o23);
// 15179
f693592812_415.returns.push(o25);
// 15216
o1 = {};
// 15217
f693592812_0.returns.push(o1);
// 15218
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15219
f693592812_395.returns.push(1345562260624);
// 15230
f693592812_415.returns.push(o16);
// 15238
f693592812_415.returns.push(o18);
// 15246
f693592812_415.returns.push(o20);
// 15258
f693592812_415.returns.push(o23);
// 15266
f693592812_415.returns.push(o25);
// 15303
o1 = {};
// 15304
f693592812_0.returns.push(o1);
// 15305
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15306
f693592812_395.returns.push(1345562261624);
// 15307
o1 = {};
// 15308
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15316
f693592812_474.returns.push(null);
// 15319
f693592812_495.returns.push(undefined);
// 15321
o1 = {};
// 15322
f693592812_536.returns.push(o1);
// 15323
o1.length = 0;
// undefined
o1 = null;
// 15326
f693592812_475.returns.push(undefined);
// 15327
o1 = {};
// 15328
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15329
f693592812_12.returns.push(40);
// 15330
o1 = {};
// 15331
f693592812_0.returns.push(o1);
// 15332
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15333
f693592812_395.returns.push(1345562262624);
// 15344
f693592812_415.returns.push(o16);
// 15352
f693592812_415.returns.push(o18);
// 15360
f693592812_415.returns.push(o20);
// 15372
f693592812_415.returns.push(o23);
// 15380
f693592812_415.returns.push(o25);
// 15417
o1 = {};
// 15418
f693592812_0.returns.push(o1);
// 15419
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15420
f693592812_395.returns.push(1345562263624);
// 15431
f693592812_415.returns.push(o16);
// 15439
f693592812_415.returns.push(o18);
// 15447
f693592812_415.returns.push(o20);
// 15459
f693592812_415.returns.push(o23);
// 15467
f693592812_415.returns.push(o25);
// 15504
o1 = {};
// 15505
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15513
f693592812_474.returns.push(null);
// 15516
f693592812_495.returns.push(undefined);
// 15518
o1 = {};
// 15519
f693592812_536.returns.push(o1);
// 15520
o1.length = 0;
// undefined
o1 = null;
// 15523
f693592812_475.returns.push(undefined);
// 15524
o1 = {};
// 15525
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15526
f693592812_12.returns.push(41);
// 15527
o1 = {};
// 15528
f693592812_0.returns.push(o1);
// 15529
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15530
f693592812_395.returns.push(1345562264624);
// 15541
f693592812_415.returns.push(o16);
// 15549
f693592812_415.returns.push(o18);
// 15557
f693592812_415.returns.push(o20);
// 15569
f693592812_415.returns.push(o23);
// 15577
f693592812_415.returns.push(o25);
// 15614
o1 = {};
// 15615
f693592812_0.returns.push(o1);
// 15616
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15617
f693592812_395.returns.push(1345562265624);
// 15618
o1 = {};
// 15619
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15627
f693592812_474.returns.push(null);
// 15630
f693592812_495.returns.push(undefined);
// 15632
o1 = {};
// 15633
f693592812_536.returns.push(o1);
// 15634
o1.length = 0;
// undefined
o1 = null;
// 15637
f693592812_475.returns.push(undefined);
// 15638
o1 = {};
// 15639
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15640
f693592812_12.returns.push(42);
// 15651
f693592812_415.returns.push(o16);
// 15659
f693592812_415.returns.push(o18);
// 15667
f693592812_415.returns.push(o20);
// 15679
f693592812_415.returns.push(o23);
// 15687
f693592812_415.returns.push(o25);
// 15724
o1 = {};
// 15725
f693592812_0.returns.push(o1);
// 15726
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15727
f693592812_395.returns.push(1345562266624);
// 15738
f693592812_415.returns.push(o16);
// 15746
f693592812_415.returns.push(o18);
// 15754
f693592812_415.returns.push(o20);
// 15766
f693592812_415.returns.push(o23);
// 15774
f693592812_415.returns.push(o25);
// 15811
o1 = {};
// 15812
f693592812_0.returns.push(o1);
// 15813
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15814
f693592812_395.returns.push(1345562267624);
// 15815
o1 = {};
// 15816
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15824
f693592812_474.returns.push(null);
// 15827
f693592812_495.returns.push(undefined);
// 15829
o1 = {};
// 15830
f693592812_536.returns.push(o1);
// 15831
o1.length = 0;
// undefined
o1 = null;
// 15834
f693592812_475.returns.push(undefined);
// 15835
o1 = {};
// 15836
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 15837
f693592812_12.returns.push(43);
// 15848
f693592812_415.returns.push(o16);
// 15856
f693592812_415.returns.push(o18);
// 15864
f693592812_415.returns.push(o20);
// 15876
f693592812_415.returns.push(o23);
// 15884
f693592812_415.returns.push(o25);
// 15921
o1 = {};
// 15922
f693592812_0.returns.push(o1);
// 15923
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 15924
f693592812_395.returns.push(1345562268624);
// 15935
f693592812_415.returns.push(o16);
// 15943
f693592812_415.returns.push(o18);
// 15951
f693592812_415.returns.push(o20);
// 15963
f693592812_415.returns.push(o23);
// 15971
f693592812_415.returns.push(o25);
// 16008
o1 = {};
// 16009
f693592812_0.returns.push(o1);
// 16010
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16011
f693592812_395.returns.push(1345562269624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 16016
o1 = {};
// 16017
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16025
f693592812_474.returns.push(null);
// 16028
f693592812_495.returns.push(undefined);
// 16030
o1 = {};
// 16031
f693592812_536.returns.push(o1);
// 16032
o1.length = 0;
// undefined
o1 = null;
// 16035
f693592812_475.returns.push(undefined);
// 16036
o1 = {};
// 16037
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16038
f693592812_12.returns.push(44);
// 16049
f693592812_415.returns.push(o16);
// 16057
f693592812_415.returns.push(o18);
// 16065
f693592812_415.returns.push(o20);
// 16077
f693592812_415.returns.push(o23);
// 16085
f693592812_415.returns.push(o25);
// 16122
o1 = {};
// 16123
f693592812_0.returns.push(o1);
// 16124
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16125
f693592812_395.returns.push(1345562270624);
// 16136
f693592812_415.returns.push(o16);
// 16144
f693592812_415.returns.push(o18);
// 16152
f693592812_415.returns.push(o20);
// 16164
f693592812_415.returns.push(o23);
// 16172
f693592812_415.returns.push(o25);
// 16209
o1 = {};
// 16210
f693592812_0.returns.push(o1);
// 16211
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16212
f693592812_395.returns.push(1345562271624);
// 16213
o1 = {};
// 16214
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16222
f693592812_474.returns.push(null);
// 16225
f693592812_495.returns.push(undefined);
// 16227
o1 = {};
// 16228
f693592812_536.returns.push(o1);
// 16229
o1.length = 0;
// undefined
o1 = null;
// 16232
f693592812_475.returns.push(undefined);
// 16233
o1 = {};
// 16234
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16235
f693592812_12.returns.push(45);
// 16236
o1 = {};
// 16237
f693592812_0.returns.push(o1);
// 16238
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16239
f693592812_395.returns.push(1345562272624);
// 16250
f693592812_415.returns.push(o16);
// 16258
f693592812_415.returns.push(o18);
// 16266
f693592812_415.returns.push(o20);
// 16278
f693592812_415.returns.push(o23);
// 16286
f693592812_415.returns.push(o25);
// 16323
o1 = {};
// 16324
f693592812_0.returns.push(o1);
// 16325
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16326
f693592812_395.returns.push(1345562273624);
// 16337
f693592812_415.returns.push(o16);
// 16345
f693592812_415.returns.push(o18);
// 16353
f693592812_415.returns.push(o20);
// 16365
f693592812_415.returns.push(o23);
// 16373
f693592812_415.returns.push(o25);
// 16410
o1 = {};
// 16411
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16419
f693592812_474.returns.push(null);
// 16422
f693592812_495.returns.push(undefined);
// 16424
o1 = {};
// 16425
f693592812_536.returns.push(o1);
// 16426
o1.length = 0;
// undefined
o1 = null;
// 16429
f693592812_475.returns.push(undefined);
// 16430
o1 = {};
// 16431
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16432
f693592812_12.returns.push(46);
// 16433
o1 = {};
// 16434
f693592812_0.returns.push(o1);
// 16435
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16436
f693592812_395.returns.push(1345562274624);
// 16447
f693592812_415.returns.push(o16);
// 16455
f693592812_415.returns.push(o18);
// 16463
f693592812_415.returns.push(o20);
// 16475
f693592812_415.returns.push(o23);
// 16483
f693592812_415.returns.push(o25);
// 16520
o1 = {};
// 16521
f693592812_0.returns.push(o1);
// 16522
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16523
f693592812_395.returns.push(1345562275624);
// 16524
o1 = {};
// 16525
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16533
f693592812_474.returns.push(null);
// 16536
f693592812_495.returns.push(undefined);
// 16538
o1 = {};
// 16539
f693592812_536.returns.push(o1);
// 16540
o1.length = 0;
// undefined
o1 = null;
// 16543
f693592812_475.returns.push(undefined);
// 16544
o1 = {};
// 16545
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16546
f693592812_12.returns.push(47);
// 16557
f693592812_415.returns.push(o16);
// 16565
f693592812_415.returns.push(o18);
// 16573
f693592812_415.returns.push(o20);
// 16585
f693592812_415.returns.push(o23);
// 16593
f693592812_415.returns.push(o25);
// 16630
o1 = {};
// 16631
f693592812_0.returns.push(o1);
// 16632
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16633
f693592812_395.returns.push(1345562276624);
// 16644
f693592812_415.returns.push(o16);
// 16652
f693592812_415.returns.push(o18);
// 16660
f693592812_415.returns.push(o20);
// 16672
f693592812_415.returns.push(o23);
// 16680
f693592812_415.returns.push(o25);
// 16717
o1 = {};
// 16718
f693592812_0.returns.push(o1);
// 16719
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16720
f693592812_395.returns.push(1345562277624);
// 16721
o1 = {};
// 16722
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16730
f693592812_474.returns.push(null);
// 16733
f693592812_495.returns.push(undefined);
// 16735
o1 = {};
// 16736
f693592812_536.returns.push(o1);
// 16737
o1.length = 0;
// undefined
o1 = null;
// 16740
f693592812_475.returns.push(undefined);
// 16741
o1 = {};
// 16742
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16743
f693592812_12.returns.push(48);
// 16754
f693592812_415.returns.push(o16);
// 16762
f693592812_415.returns.push(o18);
// 16770
f693592812_415.returns.push(o20);
// 16782
f693592812_415.returns.push(o23);
// 16790
f693592812_415.returns.push(o25);
// 16827
o1 = {};
// 16828
f693592812_0.returns.push(o1);
// 16829
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16830
f693592812_395.returns.push(1345562278624);
// 16841
f693592812_415.returns.push(o16);
// 16849
f693592812_415.returns.push(o18);
// 16857
f693592812_415.returns.push(o20);
// 16869
f693592812_415.returns.push(o23);
// 16877
f693592812_415.returns.push(o25);
// 16914
o1 = {};
// 16915
f693592812_0.returns.push(o1);
// 16916
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 16917
f693592812_395.returns.push(1345562279624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 16922
o1 = {};
// 16923
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16931
f693592812_474.returns.push(null);
// 16934
f693592812_495.returns.push(undefined);
// 16936
o1 = {};
// 16937
f693592812_536.returns.push(o1);
// 16938
o1.length = 0;
// undefined
o1 = null;
// 16941
f693592812_475.returns.push(undefined);
// 16942
o1 = {};
// 16943
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 16944
f693592812_12.returns.push(49);
// 16955
f693592812_415.returns.push(o16);
// 16963
f693592812_415.returns.push(o18);
// 16971
f693592812_415.returns.push(o20);
// 16983
f693592812_415.returns.push(o23);
// 16991
f693592812_415.returns.push(o25);
// 17028
o1 = {};
// 17029
f693592812_0.returns.push(o1);
// 17030
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17031
f693592812_395.returns.push(1345562280624);
// 17042
f693592812_415.returns.push(o16);
// 17050
f693592812_415.returns.push(o18);
// 17058
f693592812_415.returns.push(o20);
// 17070
f693592812_415.returns.push(o23);
// 17078
f693592812_415.returns.push(o25);
// 17115
o1 = {};
// 17116
f693592812_0.returns.push(o1);
// 17117
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17118
f693592812_395.returns.push(1345562281624);
// 17119
o1 = {};
// 17120
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17128
f693592812_474.returns.push(null);
// 17131
f693592812_495.returns.push(undefined);
// 17133
o1 = {};
// 17134
f693592812_536.returns.push(o1);
// 17135
o1.length = 0;
// undefined
o1 = null;
// 17138
f693592812_475.returns.push(undefined);
// 17139
o1 = {};
// 17140
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17141
f693592812_12.returns.push(50);
// 17142
o1 = {};
// 17143
f693592812_0.returns.push(o1);
// 17144
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17145
f693592812_395.returns.push(1345562282624);
// 17156
f693592812_415.returns.push(o16);
// 17164
f693592812_415.returns.push(o18);
// 17172
f693592812_415.returns.push(o20);
// 17184
f693592812_415.returns.push(o23);
// 17192
f693592812_415.returns.push(o25);
// 17229
o1 = {};
// 17230
f693592812_0.returns.push(o1);
// 17231
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17232
f693592812_395.returns.push(1345562283624);
// 17243
f693592812_415.returns.push(o16);
// 17251
f693592812_415.returns.push(o18);
// 17259
f693592812_415.returns.push(o20);
// 17271
f693592812_415.returns.push(o23);
// 17279
f693592812_415.returns.push(o25);
// 17316
o1 = {};
// 17317
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17325
f693592812_474.returns.push(null);
// 17328
f693592812_495.returns.push(undefined);
// 17330
o1 = {};
// 17331
f693592812_536.returns.push(o1);
// 17332
o1.length = 0;
// undefined
o1 = null;
// 17335
f693592812_475.returns.push(undefined);
// 17336
o1 = {};
// 17337
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17338
f693592812_12.returns.push(51);
// 17339
o1 = {};
// 17340
f693592812_0.returns.push(o1);
// 17341
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17342
f693592812_395.returns.push(1345562284629);
// 17353
f693592812_415.returns.push(o16);
// 17361
f693592812_415.returns.push(o18);
// 17369
f693592812_415.returns.push(o20);
// 17381
f693592812_415.returns.push(o23);
// 17389
f693592812_415.returns.push(o25);
// 17426
o1 = {};
// 17427
f693592812_0.returns.push(o1);
// 17428
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17429
f693592812_395.returns.push(1345562285624);
// 17430
o1 = {};
// 17431
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17439
f693592812_474.returns.push(null);
// 17442
f693592812_495.returns.push(undefined);
// 17444
o1 = {};
// 17445
f693592812_536.returns.push(o1);
// 17446
o1.length = 0;
// undefined
o1 = null;
// 17449
f693592812_475.returns.push(undefined);
// 17450
o1 = {};
// 17451
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17452
f693592812_12.returns.push(52);
// 17463
f693592812_415.returns.push(o16);
// 17471
f693592812_415.returns.push(o18);
// 17479
f693592812_415.returns.push(o20);
// 17491
f693592812_415.returns.push(o23);
// 17499
f693592812_415.returns.push(o25);
// 17536
o1 = {};
// 17537
f693592812_0.returns.push(o1);
// 17538
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17539
f693592812_395.returns.push(1345562286624);
// 17550
f693592812_415.returns.push(o16);
// 17558
f693592812_415.returns.push(o18);
// 17566
f693592812_415.returns.push(o20);
// 17578
f693592812_415.returns.push(o23);
// 17586
f693592812_415.returns.push(o25);
// 17623
o1 = {};
// 17624
f693592812_0.returns.push(o1);
// 17625
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17626
f693592812_395.returns.push(1345562287624);
// 17627
o1 = {};
// 17628
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17636
f693592812_474.returns.push(null);
// 17639
f693592812_495.returns.push(undefined);
// 17641
o1 = {};
// 17642
f693592812_536.returns.push(o1);
// 17643
o1.length = 0;
// undefined
o1 = null;
// 17646
f693592812_475.returns.push(undefined);
// 17647
o1 = {};
// 17648
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17649
f693592812_12.returns.push(53);
// 17660
f693592812_415.returns.push(o16);
// 17668
f693592812_415.returns.push(o18);
// 17676
f693592812_415.returns.push(o20);
// 17688
f693592812_415.returns.push(o23);
// 17696
f693592812_415.returns.push(o25);
// 17733
o1 = {};
// 17734
f693592812_0.returns.push(o1);
// 17735
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17736
f693592812_395.returns.push(1345562288624);
// 17747
f693592812_415.returns.push(o16);
// 17755
f693592812_415.returns.push(o18);
// 17763
f693592812_415.returns.push(o20);
// 17775
f693592812_415.returns.push(o23);
// 17783
f693592812_415.returns.push(o25);
// 17820
o1 = {};
// 17821
f693592812_0.returns.push(o1);
// 17822
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17823
f693592812_395.returns.push(1345562289624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 17828
o1 = {};
// 17829
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17837
f693592812_474.returns.push(null);
// 17840
f693592812_495.returns.push(undefined);
// 17842
o1 = {};
// 17843
f693592812_536.returns.push(o1);
// 17844
o1.length = 0;
// undefined
o1 = null;
// 17847
f693592812_475.returns.push(undefined);
// 17848
o1 = {};
// 17849
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 17850
f693592812_12.returns.push(54);
// 17861
f693592812_415.returns.push(o16);
// 17869
f693592812_415.returns.push(o18);
// 17877
f693592812_415.returns.push(o20);
// 17889
f693592812_415.returns.push(o23);
// 17897
f693592812_415.returns.push(o25);
// 17934
o1 = {};
// 17935
f693592812_0.returns.push(o1);
// 17936
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 17937
f693592812_395.returns.push(1345562290624);
// 17948
f693592812_415.returns.push(o16);
// 17956
f693592812_415.returns.push(o18);
// 17964
f693592812_415.returns.push(o20);
// 17976
f693592812_415.returns.push(o23);
// 17984
f693592812_415.returns.push(o25);
// 18021
o1 = {};
// 18022
f693592812_0.returns.push(o1);
// 18023
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18024
f693592812_395.returns.push(1345562291624);
// 18025
o1 = {};
// 18026
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18034
f693592812_474.returns.push(null);
// 18037
f693592812_495.returns.push(undefined);
// 18039
o1 = {};
// 18040
f693592812_536.returns.push(o1);
// 18041
o1.length = 0;
// undefined
o1 = null;
// 18044
f693592812_475.returns.push(undefined);
// 18045
o1 = {};
// 18046
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18047
f693592812_12.returns.push(55);
// 18048
o1 = {};
// 18049
f693592812_0.returns.push(o1);
// 18050
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18051
f693592812_395.returns.push(1345562292624);
// 18062
f693592812_415.returns.push(o16);
// 18070
f693592812_415.returns.push(o18);
// 18078
f693592812_415.returns.push(o20);
// 18090
f693592812_415.returns.push(o23);
// 18098
f693592812_415.returns.push(o25);
// 18135
o1 = {};
// 18136
f693592812_0.returns.push(o1);
// 18137
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18138
f693592812_395.returns.push(1345562293624);
// 18149
f693592812_415.returns.push(o16);
// 18157
f693592812_415.returns.push(o18);
// 18165
f693592812_415.returns.push(o20);
// 18177
f693592812_415.returns.push(o23);
// 18185
f693592812_415.returns.push(o25);
// 18222
o1 = {};
// 18223
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18231
f693592812_474.returns.push(null);
// 18234
f693592812_495.returns.push(undefined);
// 18236
o1 = {};
// 18237
f693592812_536.returns.push(o1);
// 18238
o1.length = 0;
// undefined
o1 = null;
// 18241
f693592812_475.returns.push(undefined);
// 18242
o1 = {};
// 18243
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18244
f693592812_12.returns.push(56);
// 18245
o1 = {};
// 18246
f693592812_0.returns.push(o1);
// 18247
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18248
f693592812_395.returns.push(1345562294629);
// 18259
f693592812_415.returns.push(o16);
// 18267
f693592812_415.returns.push(o18);
// 18275
f693592812_415.returns.push(o20);
// 18287
f693592812_415.returns.push(o23);
// 18295
f693592812_415.returns.push(o25);
// 18332
o1 = {};
// 18333
f693592812_0.returns.push(o1);
// 18334
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18335
f693592812_395.returns.push(1345562295624);
// 18336
o1 = {};
// 18337
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18345
f693592812_474.returns.push(null);
// 18348
f693592812_495.returns.push(undefined);
// 18350
o1 = {};
// 18351
f693592812_536.returns.push(o1);
// 18352
o1.length = 0;
// undefined
o1 = null;
// 18355
f693592812_475.returns.push(undefined);
// 18356
o1 = {};
// 18357
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18358
f693592812_12.returns.push(57);
// 18369
f693592812_415.returns.push(o16);
// 18377
f693592812_415.returns.push(o18);
// 18385
f693592812_415.returns.push(o20);
// 18397
f693592812_415.returns.push(o23);
// 18405
f693592812_415.returns.push(o25);
// 18442
o1 = {};
// 18443
f693592812_0.returns.push(o1);
// 18444
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18445
f693592812_395.returns.push(1345562296624);
// 18456
f693592812_415.returns.push(o16);
// 18464
f693592812_415.returns.push(o18);
// 18472
f693592812_415.returns.push(o20);
// 18484
f693592812_415.returns.push(o23);
// 18492
f693592812_415.returns.push(o25);
// 18529
o1 = {};
// 18530
f693592812_0.returns.push(o1);
// 18531
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18532
f693592812_395.returns.push(1345562297624);
// 18533
o1 = {};
// 18534
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18542
f693592812_474.returns.push(null);
// 18545
f693592812_495.returns.push(undefined);
// 18547
o1 = {};
// 18548
f693592812_536.returns.push(o1);
// 18549
o1.length = 0;
// undefined
o1 = null;
// 18552
f693592812_475.returns.push(undefined);
// 18553
o1 = {};
// 18554
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18555
f693592812_12.returns.push(58);
// 18566
f693592812_415.returns.push(o16);
// 18574
f693592812_415.returns.push(o18);
// 18582
f693592812_415.returns.push(o20);
// 18594
f693592812_415.returns.push(o23);
// 18602
f693592812_415.returns.push(o25);
// 18639
o1 = {};
// 18640
f693592812_0.returns.push(o1);
// 18641
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18642
f693592812_395.returns.push(1345562298624);
// 18653
f693592812_415.returns.push(o16);
// 18661
f693592812_415.returns.push(o18);
// 18669
f693592812_415.returns.push(o20);
// 18681
f693592812_415.returns.push(o23);
// 18689
f693592812_415.returns.push(o25);
// 18726
o1 = {};
// 18727
f693592812_0.returns.push(o1);
// 18728
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18729
f693592812_395.returns.push(1345562299624);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 18734
o1 = {};
// 18735
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18743
f693592812_474.returns.push(null);
// 18746
f693592812_495.returns.push(undefined);
// 18748
o1 = {};
// 18749
f693592812_536.returns.push(o1);
// 18750
o1.length = 0;
// undefined
o1 = null;
// 18753
f693592812_475.returns.push(undefined);
// 18754
o1 = {};
// 18755
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18756
f693592812_12.returns.push(59);
// 18767
f693592812_415.returns.push(o16);
// 18775
f693592812_415.returns.push(o18);
// 18783
f693592812_415.returns.push(o20);
// 18795
f693592812_415.returns.push(o23);
// 18803
f693592812_415.returns.push(o25);
// 18840
o1 = {};
// 18841
f693592812_0.returns.push(o1);
// 18842
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18843
f693592812_395.returns.push(1345562300624);
// 18854
f693592812_415.returns.push(o16);
// 18862
f693592812_415.returns.push(o18);
// 18870
f693592812_415.returns.push(o20);
// 18882
f693592812_415.returns.push(o23);
// 18890
f693592812_415.returns.push(o25);
// 18927
o1 = {};
// 18928
f693592812_0.returns.push(o1);
// 18929
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18930
f693592812_395.returns.push(1345562301624);
// 18931
o1 = {};
// 18932
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18940
f693592812_474.returns.push(null);
// 18943
f693592812_495.returns.push(undefined);
// 18945
o1 = {};
// 18946
f693592812_536.returns.push(o1);
// 18947
o1.length = 0;
// undefined
o1 = null;
// 18950
f693592812_475.returns.push(undefined);
// 18951
o1 = {};
// 18952
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 18953
f693592812_12.returns.push(60);
// 18954
o1 = {};
// 18955
f693592812_0.returns.push(o1);
// 18956
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 18957
f693592812_395.returns.push(1345562302624);
// 18968
f693592812_415.returns.push(o16);
// 18976
f693592812_415.returns.push(o18);
// 18984
f693592812_415.returns.push(o20);
// 18996
f693592812_415.returns.push(o23);
// 19004
f693592812_415.returns.push(o25);
// 19041
o1 = {};
// 19042
f693592812_0.returns.push(o1);
// 19043
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19044
f693592812_395.returns.push(1345562303624);
// 19055
f693592812_415.returns.push(o16);
// 19063
f693592812_415.returns.push(o18);
// 19071
f693592812_415.returns.push(o20);
// 19083
f693592812_415.returns.push(o23);
// 19091
f693592812_415.returns.push(o25);
// 19128
o1 = {};
// 19129
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19137
f693592812_474.returns.push(null);
// 19140
f693592812_495.returns.push(undefined);
// 19142
o1 = {};
// 19143
f693592812_536.returns.push(o1);
// 19144
o1.length = 0;
// undefined
o1 = null;
// 19147
f693592812_475.returns.push(undefined);
// 19148
o1 = {};
// 19149
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19150
f693592812_12.returns.push(61);
// 19151
o1 = {};
// 19152
f693592812_0.returns.push(o1);
// 19153
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19154
f693592812_395.returns.push(1345562304624);
// 19165
f693592812_415.returns.push(o16);
// 19173
f693592812_415.returns.push(o18);
// 19181
f693592812_415.returns.push(o20);
// 19193
f693592812_415.returns.push(o23);
// 19201
f693592812_415.returns.push(o25);
// 19238
o1 = {};
// 19239
f693592812_0.returns.push(o1);
// 19240
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19241
f693592812_395.returns.push(1345562305625);
// 19242
o1 = {};
// 19243
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19251
f693592812_474.returns.push(null);
// 19254
f693592812_495.returns.push(undefined);
// 19256
o1 = {};
// 19257
f693592812_536.returns.push(o1);
// 19258
o1.length = 0;
// undefined
o1 = null;
// 19261
f693592812_475.returns.push(undefined);
// 19262
o1 = {};
// 19263
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19264
f693592812_12.returns.push(62);
// 19275
f693592812_415.returns.push(o16);
// 19283
f693592812_415.returns.push(o18);
// 19291
f693592812_415.returns.push(o20);
// 19303
f693592812_415.returns.push(o23);
// 19311
f693592812_415.returns.push(o25);
// 19348
o1 = {};
// 19349
f693592812_0.returns.push(o1);
// 19350
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19351
f693592812_395.returns.push(1345562306624);
// 19362
f693592812_415.returns.push(o16);
// 19370
f693592812_415.returns.push(o18);
// 19378
f693592812_415.returns.push(o20);
// 19390
f693592812_415.returns.push(o23);
// 19398
f693592812_415.returns.push(o25);
// 19435
o1 = {};
// 19436
f693592812_0.returns.push(o1);
// 19437
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19438
f693592812_395.returns.push(1345562307624);
// 19439
o1 = {};
// 19440
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19448
f693592812_474.returns.push(null);
// 19451
f693592812_495.returns.push(undefined);
// 19453
o1 = {};
// 19454
f693592812_536.returns.push(o1);
// 19455
o1.length = 0;
// undefined
o1 = null;
// 19458
f693592812_475.returns.push(undefined);
// 19459
o1 = {};
// 19460
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19461
f693592812_12.returns.push(63);
// 19472
f693592812_415.returns.push(o16);
// 19480
f693592812_415.returns.push(o18);
// 19488
f693592812_415.returns.push(o20);
// 19500
f693592812_415.returns.push(o23);
// 19508
f693592812_415.returns.push(o25);
// 19545
o1 = {};
// 19546
f693592812_0.returns.push(o1);
// 19547
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19548
f693592812_395.returns.push(1345562308625);
// 19559
f693592812_415.returns.push(o16);
// 19567
f693592812_415.returns.push(o18);
// 19575
f693592812_415.returns.push(o20);
// 19587
f693592812_415.returns.push(o23);
// 19595
f693592812_415.returns.push(o25);
// 19632
o1 = {};
// 19633
f693592812_0.returns.push(o1);
// 19634
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19635
f693592812_395.returns.push(1345562309625);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 19640
o1 = {};
// 19641
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19649
f693592812_474.returns.push(null);
// 19652
f693592812_495.returns.push(undefined);
// 19654
o1 = {};
// 19655
f693592812_536.returns.push(o1);
// 19656
o1.length = 0;
// undefined
o1 = null;
// 19659
f693592812_475.returns.push(undefined);
// 19660
o1 = {};
// 19661
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19662
f693592812_12.returns.push(64);
// 19673
f693592812_415.returns.push(o16);
// 19681
f693592812_415.returns.push(o18);
// 19689
f693592812_415.returns.push(o20);
// 19701
f693592812_415.returns.push(o23);
// 19709
f693592812_415.returns.push(o25);
// 19746
o1 = {};
// 19747
f693592812_0.returns.push(o1);
// 19748
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19749
f693592812_395.returns.push(1345562310624);
// 19760
f693592812_415.returns.push(o16);
// 19768
f693592812_415.returns.push(o18);
// 19776
f693592812_415.returns.push(o20);
// 19788
f693592812_415.returns.push(o23);
// 19796
f693592812_415.returns.push(o25);
// 19833
o1 = {};
// 19834
f693592812_0.returns.push(o1);
// 19835
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19836
f693592812_395.returns.push(1345562311625);
// 19837
o1 = {};
// 19838
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19846
f693592812_474.returns.push(null);
// 19849
f693592812_495.returns.push(undefined);
// 19851
o1 = {};
// 19852
f693592812_536.returns.push(o1);
// 19853
o1.length = 0;
// undefined
o1 = null;
// 19856
f693592812_475.returns.push(undefined);
// 19857
o1 = {};
// 19858
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 19859
f693592812_12.returns.push(65);
// 19860
o1 = {};
// 19861
f693592812_0.returns.push(o1);
// 19862
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19863
f693592812_395.returns.push(1345562312625);
// 19874
f693592812_415.returns.push(o16);
// 19882
f693592812_415.returns.push(o18);
// 19890
f693592812_415.returns.push(o20);
// 19902
f693592812_415.returns.push(o23);
// 19910
f693592812_415.returns.push(o25);
// 19947
o1 = {};
// 19948
f693592812_0.returns.push(o1);
// 19949
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 19950
f693592812_395.returns.push(1345562313625);
// 19961
f693592812_415.returns.push(o16);
// 19969
f693592812_415.returns.push(o18);
// 19977
f693592812_415.returns.push(o20);
// 19989
f693592812_415.returns.push(o23);
// 19997
f693592812_415.returns.push(o25);
// 20034
o1 = {};
// 20035
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20043
f693592812_474.returns.push(null);
// 20046
f693592812_495.returns.push(undefined);
// 20048
o1 = {};
// 20049
f693592812_536.returns.push(o1);
// 20050
o1.length = 0;
// undefined
o1 = null;
// 20053
f693592812_475.returns.push(undefined);
// 20054
o1 = {};
// 20055
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20056
f693592812_12.returns.push(66);
// 20057
o1 = {};
// 20058
f693592812_0.returns.push(o1);
// 20059
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20060
f693592812_395.returns.push(1345562314625);
// 20071
f693592812_415.returns.push(o16);
// 20079
f693592812_415.returns.push(o18);
// 20087
f693592812_415.returns.push(o20);
// 20099
f693592812_415.returns.push(o23);
// 20107
f693592812_415.returns.push(o25);
// 20144
o1 = {};
// 20145
f693592812_0.returns.push(o1);
// 20146
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20147
f693592812_395.returns.push(1345562315625);
// 20148
o1 = {};
// 20149
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20157
f693592812_474.returns.push(null);
// 20160
f693592812_495.returns.push(undefined);
// 20162
o1 = {};
// 20163
f693592812_536.returns.push(o1);
// 20164
o1.length = 0;
// undefined
o1 = null;
// 20167
f693592812_475.returns.push(undefined);
// 20168
o1 = {};
// 20169
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20170
f693592812_12.returns.push(67);
// 20181
f693592812_415.returns.push(o16);
// 20189
f693592812_415.returns.push(o18);
// 20197
f693592812_415.returns.push(o20);
// 20209
f693592812_415.returns.push(o23);
// 20217
f693592812_415.returns.push(o25);
// 20254
o1 = {};
// 20255
f693592812_0.returns.push(o1);
// 20256
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20257
f693592812_395.returns.push(1345562316629);
// 20268
f693592812_415.returns.push(o16);
// 20276
f693592812_415.returns.push(o18);
// 20284
f693592812_415.returns.push(o20);
// 20296
f693592812_415.returns.push(o23);
// 20304
f693592812_415.returns.push(o25);
// 20341
o1 = {};
// 20342
f693592812_0.returns.push(o1);
// 20343
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20344
f693592812_395.returns.push(1345562317625);
// 20345
o1 = {};
// 20346
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20354
f693592812_474.returns.push(null);
// 20357
f693592812_495.returns.push(undefined);
// 20359
o1 = {};
// 20360
f693592812_536.returns.push(o1);
// 20361
o1.length = 0;
// undefined
o1 = null;
// 20364
f693592812_475.returns.push(undefined);
// 20365
o1 = {};
// 20366
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20367
f693592812_12.returns.push(68);
// 20378
f693592812_415.returns.push(o16);
// 20386
f693592812_415.returns.push(o18);
// 20394
f693592812_415.returns.push(o20);
// 20406
f693592812_415.returns.push(o23);
// 20414
f693592812_415.returns.push(o25);
// 20451
o1 = {};
// 20452
f693592812_0.returns.push(o1);
// 20453
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20454
f693592812_395.returns.push(1345562318625);
// 20465
f693592812_415.returns.push(o16);
// 20473
f693592812_415.returns.push(o18);
// 20481
f693592812_415.returns.push(o20);
// 20493
f693592812_415.returns.push(o23);
// 20501
f693592812_415.returns.push(o25);
// 20538
o1 = {};
// 20539
f693592812_0.returns.push(o1);
// 20540
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20541
f693592812_395.returns.push(1345562319625);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 20546
o1 = {};
// 20547
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20555
f693592812_474.returns.push(null);
// 20558
f693592812_495.returns.push(undefined);
// 20560
o1 = {};
// 20561
f693592812_536.returns.push(o1);
// 20562
o1.length = 0;
// undefined
o1 = null;
// 20565
f693592812_475.returns.push(undefined);
// 20566
o1 = {};
// 20567
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20568
f693592812_12.returns.push(69);
// 20579
f693592812_415.returns.push(o16);
// 20587
f693592812_415.returns.push(o18);
// 20595
f693592812_415.returns.push(o20);
// 20607
f693592812_415.returns.push(o23);
// 20615
f693592812_415.returns.push(o25);
// 20652
o1 = {};
// 20653
f693592812_0.returns.push(o1);
// 20654
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20655
f693592812_395.returns.push(1345562320625);
// 20666
f693592812_415.returns.push(o16);
// 20674
f693592812_415.returns.push(o18);
// 20682
f693592812_415.returns.push(o20);
// 20694
f693592812_415.returns.push(o23);
// 20702
f693592812_415.returns.push(o25);
// 20739
o1 = {};
// 20740
f693592812_0.returns.push(o1);
// 20741
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20742
f693592812_395.returns.push(1345562321625);
// 20743
o1 = {};
// 20744
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20752
f693592812_474.returns.push(null);
// 20755
f693592812_495.returns.push(undefined);
// 20757
o1 = {};
// 20758
f693592812_536.returns.push(o1);
// 20759
o1.length = 0;
// undefined
o1 = null;
// 20762
f693592812_475.returns.push(undefined);
// 20763
o1 = {};
// 20764
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20765
f693592812_12.returns.push(70);
// 20766
o1 = {};
// 20767
f693592812_0.returns.push(o1);
// 20768
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20769
f693592812_395.returns.push(1345562322625);
// 20780
f693592812_415.returns.push(o16);
// 20788
f693592812_415.returns.push(o18);
// 20796
f693592812_415.returns.push(o20);
// 20808
f693592812_415.returns.push(o23);
// 20816
f693592812_415.returns.push(o25);
// 20853
o1 = {};
// 20854
f693592812_0.returns.push(o1);
// 20855
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20856
f693592812_395.returns.push(1345562323632);
// 20867
f693592812_415.returns.push(o16);
// 20875
f693592812_415.returns.push(o18);
// 20883
f693592812_415.returns.push(o20);
// 20895
f693592812_415.returns.push(o23);
// 20903
f693592812_415.returns.push(o25);
// 20940
o1 = {};
// 20941
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20949
f693592812_474.returns.push(null);
// 20952
f693592812_495.returns.push(undefined);
// 20954
o1 = {};
// 20955
f693592812_536.returns.push(o1);
// 20956
o1.length = 0;
// undefined
o1 = null;
// 20959
f693592812_475.returns.push(undefined);
// 20960
o1 = {};
// 20961
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 20962
f693592812_12.returns.push(71);
// 20963
o1 = {};
// 20964
f693592812_0.returns.push(o1);
// 20965
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 20966
f693592812_395.returns.push(1345562324625);
// 20977
f693592812_415.returns.push(o16);
// 20985
f693592812_415.returns.push(o18);
// 20993
f693592812_415.returns.push(o20);
// 21005
f693592812_415.returns.push(o23);
// 21013
f693592812_415.returns.push(o25);
// 21050
o1 = {};
// 21051
f693592812_0.returns.push(o1);
// 21052
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21053
f693592812_395.returns.push(1345562325625);
// 21054
o1 = {};
// 21055
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21063
f693592812_474.returns.push(null);
// 21066
f693592812_495.returns.push(undefined);
// 21068
o1 = {};
// 21069
f693592812_536.returns.push(o1);
// 21070
o1.length = 0;
// undefined
o1 = null;
// 21073
f693592812_475.returns.push(undefined);
// 21074
o1 = {};
// 21075
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21076
f693592812_12.returns.push(72);
// 21087
f693592812_415.returns.push(o16);
// 21095
f693592812_415.returns.push(o18);
// 21103
f693592812_415.returns.push(o20);
// 21115
f693592812_415.returns.push(o23);
// 21123
f693592812_415.returns.push(o25);
// 21160
o1 = {};
// 21161
f693592812_0.returns.push(o1);
// 21162
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21163
f693592812_395.returns.push(1345562326625);
// 21174
f693592812_415.returns.push(o16);
// 21182
f693592812_415.returns.push(o18);
// 21190
f693592812_415.returns.push(o20);
// 21202
f693592812_415.returns.push(o23);
// 21210
f693592812_415.returns.push(o25);
// 21247
o1 = {};
// 21248
f693592812_0.returns.push(o1);
// 21249
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21250
f693592812_395.returns.push(1345562327625);
// 21251
o1 = {};
// 21252
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21260
f693592812_474.returns.push(null);
// 21263
f693592812_495.returns.push(undefined);
// 21265
o1 = {};
// 21266
f693592812_536.returns.push(o1);
// 21267
o1.length = 0;
// undefined
o1 = null;
// 21270
f693592812_475.returns.push(undefined);
// 21271
o1 = {};
// 21272
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21273
f693592812_12.returns.push(73);
// 21284
f693592812_415.returns.push(o16);
// 21292
f693592812_415.returns.push(o18);
// 21300
f693592812_415.returns.push(o20);
// 21312
f693592812_415.returns.push(o23);
// 21320
f693592812_415.returns.push(o25);
// 21357
o1 = {};
// 21358
f693592812_0.returns.push(o1);
// 21359
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21360
f693592812_395.returns.push(1345562328625);
// 21371
f693592812_415.returns.push(o16);
// 21379
f693592812_415.returns.push(o18);
// 21387
f693592812_415.returns.push(o20);
// 21399
f693592812_415.returns.push(o23);
// 21407
f693592812_415.returns.push(o25);
// 21444
o1 = {};
// 21445
f693592812_0.returns.push(o1);
// 21446
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21447
f693592812_395.returns.push(1345562329625);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 21452
o1 = {};
// 21453
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21461
f693592812_474.returns.push(null);
// 21464
f693592812_495.returns.push(undefined);
// 21466
o1 = {};
// 21467
f693592812_536.returns.push(o1);
// 21468
o1.length = 0;
// undefined
o1 = null;
// 21471
f693592812_475.returns.push(undefined);
// 21472
o1 = {};
// 21473
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21474
f693592812_12.returns.push(74);
// 21485
f693592812_415.returns.push(o16);
// 21493
f693592812_415.returns.push(o18);
// 21501
f693592812_415.returns.push(o20);
// 21513
f693592812_415.returns.push(o23);
// 21521
f693592812_415.returns.push(o25);
// 21558
o1 = {};
// 21559
f693592812_0.returns.push(o1);
// 21560
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21561
f693592812_395.returns.push(1345562330629);
// 21572
f693592812_415.returns.push(o16);
// 21580
f693592812_415.returns.push(o18);
// 21588
f693592812_415.returns.push(o20);
// 21600
f693592812_415.returns.push(o23);
// 21608
f693592812_415.returns.push(o25);
// 21645
o1 = {};
// 21646
f693592812_0.returns.push(o1);
// 21647
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21648
f693592812_395.returns.push(1345562331643);
// 21649
o1 = {};
// 21650
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21658
f693592812_474.returns.push(null);
// 21661
f693592812_495.returns.push(undefined);
// 21663
o1 = {};
// 21664
f693592812_536.returns.push(o1);
// 21665
o1.length = 0;
// undefined
o1 = null;
// 21668
f693592812_475.returns.push(undefined);
// 21669
o1 = {};
// 21670
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21671
f693592812_12.returns.push(75);
// 21673
o1 = {};
// 21674
f693592812_55.returns.push(o1);
// 21675
o1.open = f693592812_483;
// 21676
f693592812_483.returns.push(undefined);
// 21677
f693592812_1318 = function() { return f693592812_1318.returns[f693592812_1318.inst++]; };
f693592812_1318.returns = [];
f693592812_1318.inst = 0;
// 21678
o1.setRequestHeader = f693592812_1318;
// 21679
f693592812_1318.returns.push(undefined);
// 21681
f693592812_1318.returns.push(undefined);
// 21682
o1.send = f693592812_484;
// 21683
f693592812_484.returns.push(undefined);
// undefined
fo693592812_1317_readyState = function() { return fo693592812_1317_readyState.returns[fo693592812_1317_readyState.inst++]; };
fo693592812_1317_readyState.returns = [];
fo693592812_1317_readyState.inst = 0;
defineGetter(o1, "readyState", fo693592812_1317_readyState);
// undefined
fo693592812_1317_readyState.returns.push(1);
// 21685
// 21686
o2 = {};
// undefined
o2 = null;
// undefined
fo693592812_1317_readyState.returns.push(2);
// 21688
o2 = {};
// undefined
o2 = null;
// undefined
fo693592812_1317_readyState.returns.push(3);
// 21690
o2 = {};
// undefined
o2 = null;
// undefined
fo693592812_1317_readyState.returns.push(4);
// 21692
// 21693
o1.JSBNG__status = 200;
// 21694
f693592812_1322 = function() { return f693592812_1322.returns[f693592812_1322.inst++]; };
f693592812_1322.returns = [];
f693592812_1322.inst = 0;
// 21695
o1.getAllResponseHeaders = f693592812_1322;
// 21696
f693592812_1322.returns.push("date: Tue, 21 Aug 2012 15:18:52 GMT\r\nx-mid: d2befec3ddd1d7fa506664a89c41bf467694dc1d\r\nstatus: 200 OK\r\nConnection: keep-alive\r\ncontent-length: 4806\r\nx-xss-protection: 1; mode=block\r\nx-runtime: 0.02439\r\nlast-modified: Tue, 21 Aug 2012 15:18:52 GMT\r\nserver: tfe\r\netag: \"8c79b6ccdb31dc23e15b0c1b2849c426\"\r\nx-frame-options: SAMEORIGIN\r\ncontent-type: text/javascript; charset=utf-8\r\npragma: no-cache\r\ncache-control: no-cache, no-store, must-revalidate, pre-check=0, post-check=0\r\nx-transaction: 741f260536f93e7d\r\nexpires: Tue, 31 Mar 1981 05:00:00 GMT\r\n");
// 21697
o1.responseXML = null;
// 21698
o1.responseText = "{\"phoenix_search_dropdown\":1,\"japanese_new_ad_provider\":1,\"phoenix_flickr_details\":1,\"news_onebox\":1,\"more_lists_component\":1,\"profile_pane_fresh\":1,\"tweet_stream_profile\":1,\"promptbird_phoenix\":1,\"welcome_warm_signup\":1,\"email_device_settings\":1,\"people_stream_friends\":1,\"geo_location\":1,\"swift_typeahead\":1,\"phoenix_local_gowalla\":1,\"tweet_streams\":1,\"eurl_dwell_time_store\":1,\"t1_dm_poll\":1,\"contact_import\":1,\"activity_read\":1,\"sports_onebox_polling\":1,\"typeahead_global_nav\":1,\"geo_ui\":1,\"geo_place_creation\":1,\"in_reply_to_component\":1,\"tweet_stream_user\":1,\"logged_out_people_search\":1,\"swift_profile\":1,\"embed_code_dialog\":1,\"mobile_download_gallery\":1,\"user_onebox\":1,\"welcome_ad_track\":1,\"promo_component\":1,\"wtf_home_timeline_show_links\":1,\"tweet_stream_following_polling\":1,\"tweet_stream_your_tweets_retweeted\":1,\"tweet_stream_search_polling\":1,\"escape_ampersands_in_search_highlighter\":1,\"phoenix_aol_video\":1,\"place_tweets_component\":1,\"empty_timeline_recommendations\":1,\"use_scribe_post\":1,\"disable_gallery_thumbs\":1,\"tweet_stream_profile_polling\":1,\"i18n_new_translation_center\":1,\"tweet_stream_retweets_by_you\":1,\"swift_impression_cookie\":1,\"list_stream_memberships\":1,\"swift_interactions\":1,\"people_streams\":1,\"phoenix_turkey_permalink\":1,\"t1d_tweet_vid\":1,\"phoenix_apple_itunes_more\":1,\"whotofollow_recommendations\":1,\"phoenix_scribe\":1,\"tweet_stream_user_polling\":1,\"phoenix_facets_images\":1,\"trends_component_polling\":1,\"people_stream_fresh\":1,\"advanced_search\":1,\"front_full_signup\":1,\"swift_facebook_token\":1,\"phoenix_wordpress_details\":1,\"newest_list_members_component\":1,\"people_stream_list_followers\":1,\"geo_show_similar_places\":1,\"profile_image_latency\":1,\"geo_ui_dropdown_available\":1,\"recent_tweets_component\":1,\"swift_lists\":1,\"tweet_stream_retweets_by_others\":1,\"profile_combined_api\":1,\"blender_search_timeline\":1,\"typeahead_local_queries\":1,\"phoenix_autocomplete\":1,\"swift_discover\":1,\"swift_events\":1,\"tweet_stream_mentions\":1,\"tweet_stream_following\":1,\"scribe_form_piggyback\":1,\"place_people_component\":1,\"sports_onebox\":1,\"people_stream_follower_requests\":1,\"people_stream_people_search\":1,\"profile_tweetbox\":1,\"infinite_scroll\":1,\"geo_more_places\":1,\"whotofollow_similarities\":1,\"scribe_image_failures\":1,\"big_photo_permalink\":1,\"people_stream_list_members\":1,\"phoenix_search_relevance\":1,\"swift_action_queue\":1,\"swift_events_reroute\":1,\"swift_events_search\":1,\"whotofollow_random_sample\":1,\"phoenix_user_media_gallery\":1,\"mobile_download_gallery_logged_out\":1,\"social_context\":1,\"phoenix_turkey_html5_resize\":1,\"phoenix_tweetbox_talon\":1,\"japanese_ad_component\":1,\"flock\":1,\"phoenix_facebook_details\":1,\"t1d_tweet_img\":1,\"user_shuffler\":1,\"tweet_stream_list_polling\":1,\"onebox\":1,\"tweet_stream_home\":1,\"tweet_stream_favorites\":1,\"turkey\":1,\"local_trends\":1,\"contact_import_stream\":1,\"phoenix_turkey_flash\":1,\"ptw_reinjection\":1,\"inline_media_component\":1,\"scribe_client_event\":1,\"tweet_stream_home_polling\":1,\"welcome_profile\":1,\"mt_tweet_backend_bing\":1,\"suggestion_categories_streams\":1,\"message_stream\":1,\"phoenix_pepsi_details\":1,\"tweet_stream_list\":1,\"tweet_stream_retweets_by_others_polling\":1,\"photo_copy_paste_inception\":1,\"activity_status_summary\":1,\"trends_component\":1,\"promoted_accounts_in_whotofollow_viewall\":1,\"geo_allow_set_location_manually\":1,\"phoenix_local_plancast\":1,\"platform_coerce_native_media_to_cards\":1,\"tweet_geo_component\":1,\"phoenix_facets\":1,\"phoenix_facets_logged_out\":1,\"swift_favorites\":1,\"people_stream_followers\":1,\"conversations\":1,\"phoenix_facets_videos\":1,\"phoenix_apple_itunes\":1,\"personalized_trends\":1,\"disable_gallery_grid\":1,\"ssl_cdn_akamai_fraction\":1,\"add_authenticity_token_via_js\":1,\"old_webclient_events\":1,\"phoenix_first_time\":1,\"phoenix_url_resolver\":1,\"phoenix_preload_twimgs\":1,\"t1d_topic_img\":1,\"wtf_signup_suggestions\":1,\"personalization_preview\":1,\"tweet_stream_search\":1,\"personalization_settings\":1,\"swift_permalink\":1,\"bananaquit_show_opt_out\":1,\"media_flagging\":1,\"phoenix_pctd\":1,\"onebox_user_search\":1,\"list_stream_own_lists\":1,\"list_streams\":1,\"tweet_stream_favorites_polling\":1,\"list_stream_subscriptions\":1,\"phoenix_whosay_details\":1,\"t1d_topic_vid\":1,\"html5Routing\":1,\"api_per_country_takedown\":1,\"fake_loggedout_decider\":1,\"bananaquit_dnt_scribe\":1,\"phoenix_instagram_and_friends\":1,\"swift_mentions\":1,\"swift_login\":1,\"tweet_stream_retweets_by_you_polling\":1,\"linkify_cashtags\":1,\"tweet_stream_mentions_polling\":1,\"avatar_upload\":1,\"phoenix_search_relevance_logged_out\":1,\"typeahead\":1,\"phoenix_local_meetup\":1,\"place_users_stream\":1,\"tweet_stream_your_tweets_retweeted_polling\":1,\"phoenix_local_foursquare\":1,\"dashboard_activity_following\":1,\"phoenix_amazon_details\":1,\"typeahead_saved_searches\":1,\"search_assistance\":1,\"dashboard_activity_followers\":1,\"tweet_streams_polling\":1,\"activity_modal\":1}";
// 21699
o1.statusText = "OK";
// undefined
o1 = null;
// 21700
o1 = {};
// 21701
f693592812_0.returns.push(o1);
// 21702
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21703
f693592812_395.returns.push(1345562332643);
// 21714
f693592812_415.returns.push(o16);
// 21722
f693592812_415.returns.push(o18);
// 21730
f693592812_415.returns.push(o20);
// 21742
f693592812_415.returns.push(o23);
// 21750
f693592812_415.returns.push(o25);
// 21787
o1 = {};
// 21788
f693592812_0.returns.push(o1);
// 21789
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21790
f693592812_395.returns.push(1345562333643);
// 21801
f693592812_415.returns.push(o16);
// 21809
f693592812_415.returns.push(o18);
// 21817
f693592812_415.returns.push(o20);
// 21829
f693592812_415.returns.push(o23);
// 21837
f693592812_415.returns.push(o25);
// 21874
o1 = {};
// 21875
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21883
f693592812_474.returns.push(null);
// 21886
f693592812_495.returns.push(undefined);
// 21888
o1 = {};
// 21889
f693592812_536.returns.push(o1);
// 21890
o1.length = 0;
// undefined
o1 = null;
// 21893
f693592812_475.returns.push(undefined);
// 21894
o1 = {};
// 21895
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 21896
f693592812_12.returns.push(76);
// 21897
o1 = {};
// 21898
f693592812_0.returns.push(o1);
// 21899
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21900
f693592812_395.returns.push(1345562334643);
// 21911
f693592812_415.returns.push(o16);
// 21919
f693592812_415.returns.push(o18);
// 21927
f693592812_415.returns.push(o20);
// 21939
f693592812_415.returns.push(o23);
// 21947
f693592812_415.returns.push(o25);
// 21984
o1 = {};
// 21985
f693592812_0.returns.push(o1);
// 21986
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 21987
f693592812_395.returns.push(1345562335643);
// 21998
f693592812_415.returns.push(o16);
// 22006
f693592812_415.returns.push(o18);
// 22014
f693592812_415.returns.push(o20);
// 22026
f693592812_415.returns.push(o23);
// 22034
f693592812_415.returns.push(o25);
// 22071
o1 = {};
// 22072
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22080
f693592812_474.returns.push(null);
// 22083
f693592812_495.returns.push(undefined);
// 22085
o1 = {};
// 22086
f693592812_536.returns.push(o1);
// 22087
o1.length = 0;
// undefined
o1 = null;
// 22090
f693592812_475.returns.push(undefined);
// 22091
o1 = {};
// 22092
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22093
f693592812_12.returns.push(77);
// 22094
o1 = {};
// 22095
f693592812_0.returns.push(o1);
// 22096
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22097
f693592812_395.returns.push(1345562336643);
// 22108
f693592812_415.returns.push(o16);
// 22116
f693592812_415.returns.push(o18);
// 22124
f693592812_415.returns.push(o20);
// 22136
f693592812_415.returns.push(o23);
// 22144
f693592812_415.returns.push(o25);
// 22181
o1 = {};
// 22182
f693592812_0.returns.push(o1);
// 22183
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22184
f693592812_395.returns.push(1345562337643);
// 22185
o1 = {};
// 22186
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22194
f693592812_474.returns.push(null);
// 22197
f693592812_495.returns.push(undefined);
// 22199
o1 = {};
// 22200
f693592812_536.returns.push(o1);
// 22201
o1.length = 0;
// undefined
o1 = null;
// 22204
f693592812_475.returns.push(undefined);
// 22205
o1 = {};
// 22206
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22207
f693592812_12.returns.push(78);
// 22218
f693592812_415.returns.push(o16);
// 22226
f693592812_415.returns.push(o18);
// 22234
f693592812_415.returns.push(o20);
// 22246
f693592812_415.returns.push(o23);
// 22254
f693592812_415.returns.push(o25);
// 22291
o1 = {};
// 22292
f693592812_0.returns.push(o1);
// 22293
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22294
f693592812_395.returns.push(1345562338643);
// 22305
f693592812_415.returns.push(o16);
// 22313
f693592812_415.returns.push(o18);
// 22321
f693592812_415.returns.push(o20);
// 22333
f693592812_415.returns.push(o23);
// 22341
f693592812_415.returns.push(o25);
// 22378
o1 = {};
// 22379
f693592812_0.returns.push(o1);
// 22380
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22381
f693592812_395.returns.push(1345562339643);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 22386
o1 = {};
// 22387
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22395
f693592812_474.returns.push(null);
// 22398
f693592812_495.returns.push(undefined);
// 22400
o1 = {};
// 22401
f693592812_536.returns.push(o1);
// 22402
o1.length = 0;
// undefined
o1 = null;
// 22405
f693592812_475.returns.push(undefined);
// 22406
o1 = {};
// 22407
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22408
f693592812_12.returns.push(79);
// 22419
f693592812_415.returns.push(o16);
// 22427
f693592812_415.returns.push(o18);
// 22435
f693592812_415.returns.push(o20);
// 22447
f693592812_415.returns.push(o23);
// 22455
f693592812_415.returns.push(o25);
// 22492
o1 = {};
// 22493
f693592812_0.returns.push(o1);
// 22494
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22495
f693592812_395.returns.push(1345562340643);
// 22506
f693592812_415.returns.push(o16);
// 22514
f693592812_415.returns.push(o18);
// 22522
f693592812_415.returns.push(o20);
// 22534
f693592812_415.returns.push(o23);
// 22542
f693592812_415.returns.push(o25);
// 22579
o1 = {};
// 22580
f693592812_0.returns.push(o1);
// 22581
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22582
f693592812_395.returns.push(1345562341643);
// 22583
o1 = {};
// 22584
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22592
f693592812_474.returns.push(null);
// 22595
f693592812_495.returns.push(undefined);
// 22597
o1 = {};
// 22598
f693592812_536.returns.push(o1);
// 22599
o1.length = 0;
// undefined
o1 = null;
// 22602
f693592812_475.returns.push(undefined);
// 22603
o1 = {};
// 22604
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22605
f693592812_12.returns.push(80);
// 22606
o1 = {};
// 22607
f693592812_0.returns.push(o1);
// 22608
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22609
f693592812_395.returns.push(1345562342643);
// 22620
f693592812_415.returns.push(o16);
// 22628
f693592812_415.returns.push(o18);
// 22636
f693592812_415.returns.push(o20);
// 22648
f693592812_415.returns.push(o23);
// 22656
f693592812_415.returns.push(o25);
// 22693
o1 = {};
// 22694
f693592812_0.returns.push(o1);
// 22695
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22696
f693592812_395.returns.push(1345562343643);
// 22707
f693592812_415.returns.push(o16);
// 22715
f693592812_415.returns.push(o18);
// 22723
f693592812_415.returns.push(o20);
// 22735
f693592812_415.returns.push(o23);
// 22743
f693592812_415.returns.push(o25);
// 22780
o1 = {};
// 22781
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22789
f693592812_474.returns.push(null);
// 22792
f693592812_495.returns.push(undefined);
// 22794
o1 = {};
// 22795
f693592812_536.returns.push(o1);
// 22796
o1.length = 0;
// undefined
o1 = null;
// 22799
f693592812_475.returns.push(undefined);
// 22800
o1 = {};
// 22801
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22802
f693592812_12.returns.push(81);
// 22803
o1 = {};
// 22804
f693592812_0.returns.push(o1);
// 22805
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22806
f693592812_395.returns.push(1345562344643);
// 22817
f693592812_415.returns.push(o16);
// 22825
f693592812_415.returns.push(o18);
// 22833
f693592812_415.returns.push(o20);
// 22845
f693592812_415.returns.push(o23);
// 22853
f693592812_415.returns.push(o25);
// 22890
o1 = {};
// 22891
f693592812_0.returns.push(o1);
// 22892
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 22893
f693592812_395.returns.push(1345562345643);
// 22904
f693592812_415.returns.push(o16);
// 22912
f693592812_415.returns.push(o18);
// 22920
f693592812_415.returns.push(o20);
// 22932
f693592812_415.returns.push(o23);
// 22940
f693592812_415.returns.push(o25);
// 22977
o1 = {};
// 22978
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22986
f693592812_474.returns.push(null);
// 22989
f693592812_495.returns.push(undefined);
// 22991
o1 = {};
// 22992
f693592812_536.returns.push(o1);
// 22993
o1.length = 0;
// undefined
o1 = null;
// 22996
f693592812_475.returns.push(undefined);
// 22997
o1 = {};
// 22998
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 22999
f693592812_12.returns.push(82);
// 23000
o1 = {};
// 23001
f693592812_0.returns.push(o1);
// 23002
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23003
f693592812_395.returns.push(1345562346643);
// 23014
f693592812_415.returns.push(o16);
// 23022
f693592812_415.returns.push(o18);
// 23030
f693592812_415.returns.push(o20);
// 23042
f693592812_415.returns.push(o23);
// 23050
f693592812_415.returns.push(o25);
// 23087
o1 = {};
// 23088
f693592812_0.returns.push(o1);
// 23089
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23090
f693592812_395.returns.push(1345562347643);
// 23091
o1 = {};
// 23092
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23100
f693592812_474.returns.push(null);
// 23103
f693592812_495.returns.push(undefined);
// 23105
o1 = {};
// 23106
f693592812_536.returns.push(o1);
// 23107
o1.length = 0;
// undefined
o1 = null;
// 23110
f693592812_475.returns.push(undefined);
// 23111
o1 = {};
// 23112
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23113
f693592812_12.returns.push(83);
// 23124
f693592812_415.returns.push(o16);
// 23132
f693592812_415.returns.push(o18);
// 23140
f693592812_415.returns.push(o20);
// 23152
f693592812_415.returns.push(o23);
// 23160
f693592812_415.returns.push(o25);
// 23197
o1 = {};
// 23198
f693592812_0.returns.push(o1);
// 23199
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23200
f693592812_395.returns.push(1345562348643);
// 23211
f693592812_415.returns.push(o16);
// 23219
f693592812_415.returns.push(o18);
// 23227
f693592812_415.returns.push(o20);
// 23239
f693592812_415.returns.push(o23);
// 23247
f693592812_415.returns.push(o25);
// 23284
o1 = {};
// 23285
f693592812_0.returns.push(o1);
// 23286
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23287
f693592812_395.returns.push(1345562349643);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 23292
o1 = {};
// 23293
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23301
f693592812_474.returns.push(null);
// 23304
f693592812_495.returns.push(undefined);
// 23306
o1 = {};
// 23307
f693592812_536.returns.push(o1);
// 23308
o1.length = 0;
// undefined
o1 = null;
// 23311
f693592812_475.returns.push(undefined);
// 23312
o1 = {};
// 23313
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23314
f693592812_12.returns.push(84);
// 23325
f693592812_415.returns.push(o16);
// 23333
f693592812_415.returns.push(o18);
// 23341
f693592812_415.returns.push(o20);
// 23353
f693592812_415.returns.push(o23);
// 23361
f693592812_415.returns.push(o25);
// 23398
o1 = {};
// 23399
f693592812_0.returns.push(o1);
// 23400
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23401
f693592812_395.returns.push(1345562350643);
// 23412
f693592812_415.returns.push(o16);
// 23420
f693592812_415.returns.push(o18);
// 23428
f693592812_415.returns.push(o20);
// 23440
f693592812_415.returns.push(o23);
// 23448
f693592812_415.returns.push(o25);
// 23485
o1 = {};
// 23486
f693592812_0.returns.push(o1);
// 23487
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23488
f693592812_395.returns.push(1345562351643);
// 23489
o1 = {};
// 23490
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23498
f693592812_474.returns.push(null);
// 23501
f693592812_495.returns.push(undefined);
// 23503
o1 = {};
// 23504
f693592812_536.returns.push(o1);
// 23505
o1.length = 0;
// undefined
o1 = null;
// 23508
f693592812_475.returns.push(undefined);
// 23509
o1 = {};
// 23510
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23511
f693592812_12.returns.push(85);
// 23512
o1 = {};
// 23513
f693592812_0.returns.push(o1);
// 23514
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23515
f693592812_395.returns.push(1345562352643);
// 23526
f693592812_415.returns.push(o16);
// 23534
f693592812_415.returns.push(o18);
// 23542
f693592812_415.returns.push(o20);
// 23554
f693592812_415.returns.push(o23);
// 23562
f693592812_415.returns.push(o25);
// 23599
o1 = {};
// 23600
f693592812_0.returns.push(o1);
// 23601
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23602
f693592812_395.returns.push(1345562353643);
// 23613
f693592812_415.returns.push(o16);
// 23621
f693592812_415.returns.push(o18);
// 23629
f693592812_415.returns.push(o20);
// 23641
f693592812_415.returns.push(o23);
// 23649
f693592812_415.returns.push(o25);
// 23686
o1 = {};
// 23687
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23695
f693592812_474.returns.push(null);
// 23698
f693592812_495.returns.push(undefined);
// 23700
o1 = {};
// 23701
f693592812_536.returns.push(o1);
// 23702
o1.length = 0;
// undefined
o1 = null;
// 23705
f693592812_475.returns.push(undefined);
// 23706
o1 = {};
// 23707
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23708
f693592812_12.returns.push(86);
// 23709
o1 = {};
// 23710
f693592812_0.returns.push(o1);
// 23711
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23712
f693592812_395.returns.push(1345562354643);
// 23723
f693592812_415.returns.push(o16);
// 23731
f693592812_415.returns.push(o18);
// 23739
f693592812_415.returns.push(o20);
// 23751
f693592812_415.returns.push(o23);
// 23759
f693592812_415.returns.push(o25);
// 23796
o1 = {};
// 23797
f693592812_0.returns.push(o1);
// 23798
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23799
f693592812_395.returns.push(1345562355643);
// 23810
f693592812_415.returns.push(o16);
// 23818
f693592812_415.returns.push(o18);
// 23826
f693592812_415.returns.push(o20);
// 23838
f693592812_415.returns.push(o23);
// 23846
f693592812_415.returns.push(o25);
// 23883
o1 = {};
// 23884
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23892
f693592812_474.returns.push(null);
// 23895
f693592812_495.returns.push(undefined);
// 23897
o1 = {};
// 23898
f693592812_536.returns.push(o1);
// 23899
o1.length = 0;
// undefined
o1 = null;
// 23902
f693592812_475.returns.push(undefined);
// 23903
o1 = {};
// 23904
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 23905
f693592812_12.returns.push(87);
// 23906
o1 = {};
// 23907
f693592812_0.returns.push(o1);
// 23908
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23909
f693592812_395.returns.push(1345562356643);
// 23920
f693592812_415.returns.push(o16);
// 23928
f693592812_415.returns.push(o18);
// 23936
f693592812_415.returns.push(o20);
// 23948
f693592812_415.returns.push(o23);
// 23956
f693592812_415.returns.push(o25);
// 23993
o1 = {};
// 23994
f693592812_0.returns.push(o1);
// 23995
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 23996
f693592812_395.returns.push(1345562357643);
// 23997
o1 = {};
// 23998
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24006
f693592812_474.returns.push(null);
// 24009
f693592812_495.returns.push(undefined);
// 24011
o1 = {};
// 24012
f693592812_536.returns.push(o1);
// 24013
o1.length = 0;
// undefined
o1 = null;
// 24016
f693592812_475.returns.push(undefined);
// 24017
o1 = {};
// 24018
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24019
f693592812_12.returns.push(88);
// 24030
f693592812_415.returns.push(o16);
// 24038
f693592812_415.returns.push(o18);
// 24046
f693592812_415.returns.push(o20);
// 24058
f693592812_415.returns.push(o23);
// 24066
f693592812_415.returns.push(o25);
// 24103
o1 = {};
// 24104
f693592812_0.returns.push(o1);
// 24105
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24106
f693592812_395.returns.push(1345562358643);
// 24117
f693592812_415.returns.push(o16);
// 24125
f693592812_415.returns.push(o18);
// 24133
f693592812_415.returns.push(o20);
// 24145
f693592812_415.returns.push(o23);
// 24153
f693592812_415.returns.push(o25);
// 24190
o1 = {};
// 24191
f693592812_0.returns.push(o1);
// 24192
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24193
f693592812_395.returns.push(1345562359643);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 24198
o1 = {};
// 24199
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24207
f693592812_474.returns.push(null);
// 24210
f693592812_495.returns.push(undefined);
// 24212
o1 = {};
// 24213
f693592812_536.returns.push(o1);
// 24214
o1.length = 0;
// undefined
o1 = null;
// 24217
f693592812_475.returns.push(undefined);
// 24218
o1 = {};
// 24219
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24220
f693592812_12.returns.push(89);
// 24231
f693592812_415.returns.push(o16);
// 24239
f693592812_415.returns.push(o18);
// 24247
f693592812_415.returns.push(o20);
// 24259
f693592812_415.returns.push(o23);
// 24267
f693592812_415.returns.push(o25);
// 24304
o1 = {};
// 24305
f693592812_0.returns.push(o1);
// 24306
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24307
f693592812_395.returns.push(1345562360643);
// 24318
f693592812_415.returns.push(o16);
// 24326
f693592812_415.returns.push(o18);
// 24334
f693592812_415.returns.push(o20);
// 24346
f693592812_415.returns.push(o23);
// 24354
f693592812_415.returns.push(o25);
// 24391
o1 = {};
// 24392
f693592812_0.returns.push(o1);
// 24393
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24394
f693592812_395.returns.push(1345562361643);
// 24395
o1 = {};
// 24396
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24404
f693592812_474.returns.push(null);
// 24407
f693592812_495.returns.push(undefined);
// 24409
o1 = {};
// 24410
f693592812_536.returns.push(o1);
// 24411
o1.length = 0;
// undefined
o1 = null;
// 24414
f693592812_475.returns.push(undefined);
// 24415
o1 = {};
// 24416
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24417
f693592812_12.returns.push(90);
// 24418
o1 = {};
// 24419
f693592812_0.returns.push(o1);
// 24420
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24421
f693592812_395.returns.push(1345562362643);
// 24432
f693592812_415.returns.push(o16);
// 24440
f693592812_415.returns.push(o18);
// 24448
f693592812_415.returns.push(o20);
// 24460
f693592812_415.returns.push(o23);
// 24468
f693592812_415.returns.push(o25);
// 24505
o1 = {};
// 24506
f693592812_0.returns.push(o1);
// 24507
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24508
f693592812_395.returns.push(1345562363643);
// 24519
f693592812_415.returns.push(o16);
// 24527
f693592812_415.returns.push(o18);
// 24535
f693592812_415.returns.push(o20);
// 24547
f693592812_415.returns.push(o23);
// 24555
f693592812_415.returns.push(o25);
// 24592
o1 = {};
// 24593
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24601
f693592812_474.returns.push(null);
// 24604
f693592812_495.returns.push(undefined);
// 24606
o1 = {};
// 24607
f693592812_536.returns.push(o1);
// 24608
o1.length = 0;
// undefined
o1 = null;
// 24611
f693592812_475.returns.push(undefined);
// 24612
o1 = {};
// 24613
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24614
f693592812_12.returns.push(91);
// 24615
o1 = {};
// 24616
f693592812_0.returns.push(o1);
// 24617
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24618
f693592812_395.returns.push(1345562364643);
// 24629
f693592812_415.returns.push(o16);
// 24637
f693592812_415.returns.push(o18);
// 24645
f693592812_415.returns.push(o20);
// 24657
f693592812_415.returns.push(o23);
// 24665
f693592812_415.returns.push(o25);
// 24702
o1 = {};
// 24703
f693592812_0.returns.push(o1);
// 24704
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24705
f693592812_395.returns.push(1345562365643);
// 24716
f693592812_415.returns.push(o16);
// 24724
f693592812_415.returns.push(o18);
// 24732
f693592812_415.returns.push(o20);
// 24744
f693592812_415.returns.push(o23);
// 24752
f693592812_415.returns.push(o25);
// 24789
o1 = {};
// 24790
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24798
f693592812_474.returns.push(null);
// 24801
f693592812_495.returns.push(undefined);
// 24803
o1 = {};
// 24804
f693592812_536.returns.push(o1);
// 24805
o1.length = 0;
// undefined
o1 = null;
// 24808
f693592812_475.returns.push(undefined);
// 24809
o1 = {};
// 24810
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24811
f693592812_12.returns.push(92);
// 24812
o1 = {};
// 24813
f693592812_0.returns.push(o1);
// 24814
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24815
f693592812_395.returns.push(1345562366643);
// 24826
f693592812_415.returns.push(o16);
// 24834
f693592812_415.returns.push(o18);
// 24842
f693592812_415.returns.push(o20);
// 24854
f693592812_415.returns.push(o23);
// 24862
f693592812_415.returns.push(o25);
// 24899
o1 = {};
// 24900
f693592812_0.returns.push(o1);
// 24901
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 24902
f693592812_395.returns.push(1345562367643);
// 24903
o1 = {};
// 24904
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24912
f693592812_474.returns.push(null);
// 24915
f693592812_495.returns.push(undefined);
// 24917
o1 = {};
// 24918
f693592812_536.returns.push(o1);
// 24919
o1.length = 0;
// undefined
o1 = null;
// 24922
f693592812_475.returns.push(undefined);
// 24923
o1 = {};
// 24924
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 24925
f693592812_12.returns.push(93);
// 24936
f693592812_415.returns.push(o16);
// 24944
f693592812_415.returns.push(o18);
// 24952
f693592812_415.returns.push(o20);
// 24964
f693592812_415.returns.push(o23);
// 24972
f693592812_415.returns.push(o25);
// 25009
o1 = {};
// 25010
f693592812_0.returns.push(o1);
// 25011
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25012
f693592812_395.returns.push(1345562368643);
// 25023
f693592812_415.returns.push(o16);
// 25031
f693592812_415.returns.push(o18);
// 25039
f693592812_415.returns.push(o20);
// 25051
f693592812_415.returns.push(o23);
// 25059
f693592812_415.returns.push(o25);
// 25096
o1 = {};
// 25097
f693592812_0.returns.push(o1);
// 25098
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25099
f693592812_395.returns.push(1345562369643);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 25104
o1 = {};
// 25105
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25113
f693592812_474.returns.push(null);
// 25116
f693592812_495.returns.push(undefined);
// 25118
o1 = {};
// 25119
f693592812_536.returns.push(o1);
// 25120
o1.length = 0;
// undefined
o1 = null;
// 25123
f693592812_475.returns.push(undefined);
// 25124
o1 = {};
// 25125
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25126
f693592812_12.returns.push(94);
// 25137
f693592812_415.returns.push(o16);
// 25145
f693592812_415.returns.push(o18);
// 25153
f693592812_415.returns.push(o20);
// 25165
f693592812_415.returns.push(o23);
// 25173
f693592812_415.returns.push(o25);
// 25210
o1 = {};
// 25211
f693592812_0.returns.push(o1);
// 25212
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25213
f693592812_395.returns.push(1345562370643);
// 25224
f693592812_415.returns.push(o16);
// 25232
f693592812_415.returns.push(o18);
// 25240
f693592812_415.returns.push(o20);
// 25252
f693592812_415.returns.push(o23);
// 25260
f693592812_415.returns.push(o25);
// 25297
o1 = {};
// 25298
f693592812_0.returns.push(o1);
// 25299
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25300
f693592812_395.returns.push(1345562371643);
// 25301
o1 = {};
// 25302
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25310
f693592812_474.returns.push(null);
// 25313
f693592812_495.returns.push(undefined);
// 25315
o1 = {};
// 25316
f693592812_536.returns.push(o1);
// 25317
o1.length = 0;
// undefined
o1 = null;
// 25320
f693592812_475.returns.push(undefined);
// 25321
o1 = {};
// 25322
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25323
f693592812_12.returns.push(95);
// 25324
o1 = {};
// 25325
f693592812_0.returns.push(o1);
// 25326
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25327
f693592812_395.returns.push(1345562372644);
// 25338
f693592812_415.returns.push(o16);
// 25346
f693592812_415.returns.push(o18);
// 25354
f693592812_415.returns.push(o20);
// 25366
f693592812_415.returns.push(o23);
// 25374
f693592812_415.returns.push(o25);
// 25411
o1 = {};
// 25412
f693592812_0.returns.push(o1);
// 25413
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25414
f693592812_395.returns.push(1345562373643);
// 25425
f693592812_415.returns.push(o16);
// 25433
f693592812_415.returns.push(o18);
// 25441
f693592812_415.returns.push(o20);
// 25453
f693592812_415.returns.push(o23);
// 25461
f693592812_415.returns.push(o25);
// 25498
o1 = {};
// 25499
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25507
f693592812_474.returns.push(null);
// 25510
f693592812_495.returns.push(undefined);
// 25512
o1 = {};
// 25513
f693592812_536.returns.push(o1);
// 25514
o1.length = 0;
// undefined
o1 = null;
// 25517
f693592812_475.returns.push(undefined);
// 25518
o1 = {};
// 25519
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25520
f693592812_12.returns.push(96);
// 25521
o1 = {};
// 25522
f693592812_0.returns.push(o1);
// 25523
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25524
f693592812_395.returns.push(1345562374643);
// 25535
f693592812_415.returns.push(o16);
// 25543
f693592812_415.returns.push(o18);
// 25551
f693592812_415.returns.push(o20);
// 25563
f693592812_415.returns.push(o23);
// 25571
f693592812_415.returns.push(o25);
// 25608
o1 = {};
// 25609
f693592812_0.returns.push(o1);
// 25610
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25611
f693592812_395.returns.push(1345562375643);
// 25622
f693592812_415.returns.push(o16);
// 25630
f693592812_415.returns.push(o18);
// 25638
f693592812_415.returns.push(o20);
// 25650
f693592812_415.returns.push(o23);
// 25658
f693592812_415.returns.push(o25);
// 25695
o1 = {};
// 25696
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25704
f693592812_474.returns.push(null);
// 25707
f693592812_495.returns.push(undefined);
// 25709
o1 = {};
// 25710
f693592812_536.returns.push(o1);
// 25711
o1.length = 0;
// undefined
o1 = null;
// 25714
f693592812_475.returns.push(undefined);
// 25715
o1 = {};
// 25716
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25717
f693592812_12.returns.push(97);
// 25718
o1 = {};
// 25719
f693592812_0.returns.push(o1);
// 25720
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25721
f693592812_395.returns.push(1345562376643);
// 25732
f693592812_415.returns.push(o16);
// 25740
f693592812_415.returns.push(o18);
// 25748
f693592812_415.returns.push(o20);
// 25760
f693592812_415.returns.push(o23);
// 25768
f693592812_415.returns.push(o25);
// 25805
o1 = {};
// 25806
f693592812_0.returns.push(o1);
// 25807
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25808
f693592812_395.returns.push(1345562377643);
// 25809
o1 = {};
// 25810
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25818
f693592812_474.returns.push(null);
// 25821
f693592812_495.returns.push(undefined);
// 25823
o1 = {};
// 25824
f693592812_536.returns.push(o1);
// 25825
o1.length = 0;
// undefined
o1 = null;
// 25828
f693592812_475.returns.push(undefined);
// 25829
o1 = {};
// 25830
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 25831
f693592812_12.returns.push(98);
// 25842
f693592812_415.returns.push(o16);
// 25850
f693592812_415.returns.push(o18);
// 25858
f693592812_415.returns.push(o20);
// 25870
f693592812_415.returns.push(o23);
// 25878
f693592812_415.returns.push(o25);
// 25915
o1 = {};
// 25916
f693592812_0.returns.push(o1);
// 25917
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 25918
f693592812_395.returns.push(1345562378643);
// 25929
f693592812_415.returns.push(o16);
// 25937
f693592812_415.returns.push(o18);
// 25945
f693592812_415.returns.push(o20);
// 25957
f693592812_415.returns.push(o23);
// 25965
f693592812_415.returns.push(o25);
// 26002
o1 = {};
// 26003
f693592812_0.returns.push(o1);
// 26004
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26005
f693592812_395.returns.push(1345562379643);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 26010
o1 = {};
// 26011
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26019
f693592812_474.returns.push(null);
// 26022
f693592812_495.returns.push(undefined);
// 26024
o1 = {};
// 26025
f693592812_536.returns.push(o1);
// 26026
o1.length = 0;
// undefined
o1 = null;
// 26029
f693592812_475.returns.push(undefined);
// 26030
o1 = {};
// 26031
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26032
f693592812_12.returns.push(99);
// 26043
f693592812_415.returns.push(o16);
// 26051
f693592812_415.returns.push(o18);
// 26059
f693592812_415.returns.push(o20);
// 26071
f693592812_415.returns.push(o23);
// 26079
f693592812_415.returns.push(o25);
// 26116
o1 = {};
// 26117
f693592812_0.returns.push(o1);
// 26118
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26119
f693592812_395.returns.push(1345562380643);
// 26130
f693592812_415.returns.push(o16);
// 26138
f693592812_415.returns.push(o18);
// 26146
f693592812_415.returns.push(o20);
// 26158
f693592812_415.returns.push(o23);
// 26166
f693592812_415.returns.push(o25);
// 26203
o1 = {};
// 26204
f693592812_0.returns.push(o1);
// 26205
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26206
f693592812_395.returns.push(1345562381643);
// 26207
o1 = {};
// 26208
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26216
f693592812_474.returns.push(null);
// 26219
f693592812_495.returns.push(undefined);
// 26221
o1 = {};
// 26222
f693592812_536.returns.push(o1);
// 26223
o1.length = 0;
// undefined
o1 = null;
// 26226
f693592812_475.returns.push(undefined);
// 26227
o1 = {};
// 26228
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26229
f693592812_12.returns.push(100);
// 26230
o1 = {};
// 26231
f693592812_0.returns.push(o1);
// 26232
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26233
f693592812_395.returns.push(1345562382644);
// 26244
f693592812_415.returns.push(o16);
// 26252
f693592812_415.returns.push(o18);
// 26260
f693592812_415.returns.push(o20);
// 26272
f693592812_415.returns.push(o23);
// 26280
f693592812_415.returns.push(o25);
// 26317
o1 = {};
// 26318
f693592812_0.returns.push(o1);
// 26319
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26320
f693592812_395.returns.push(1345562383644);
// 26331
f693592812_415.returns.push(o16);
// 26339
f693592812_415.returns.push(o18);
// 26347
f693592812_415.returns.push(o20);
// 26359
f693592812_415.returns.push(o23);
// 26367
f693592812_415.returns.push(o25);
// 26404
o1 = {};
// 26405
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26413
f693592812_474.returns.push(null);
// 26416
f693592812_495.returns.push(undefined);
// 26418
o1 = {};
// 26419
f693592812_536.returns.push(o1);
// 26420
o1.length = 0;
// undefined
o1 = null;
// 26423
f693592812_475.returns.push(undefined);
// 26424
o1 = {};
// 26425
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26426
f693592812_12.returns.push(101);
// 26427
o1 = {};
// 26428
f693592812_0.returns.push(o1);
// 26429
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26430
f693592812_395.returns.push(1345562384644);
// 26441
f693592812_415.returns.push(o16);
// 26449
f693592812_415.returns.push(o18);
// 26457
f693592812_415.returns.push(o20);
// 26469
f693592812_415.returns.push(o23);
// 26477
f693592812_415.returns.push(o25);
// 26514
o1 = {};
// 26515
f693592812_0.returns.push(o1);
// 26516
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26517
f693592812_395.returns.push(1345562385644);
// 26528
f693592812_415.returns.push(o16);
// 26536
f693592812_415.returns.push(o18);
// 26544
f693592812_415.returns.push(o20);
// 26556
f693592812_415.returns.push(o23);
// 26564
f693592812_415.returns.push(o25);
// 26601
o1 = {};
// 26602
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26610
f693592812_474.returns.push(null);
// 26613
f693592812_495.returns.push(undefined);
// 26615
o1 = {};
// 26616
f693592812_536.returns.push(o1);
// 26617
o1.length = 0;
// undefined
o1 = null;
// 26620
f693592812_475.returns.push(undefined);
// 26621
o1 = {};
// 26622
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26623
f693592812_12.returns.push(102);
// 26624
o1 = {};
// 26625
f693592812_0.returns.push(o1);
// 26626
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26627
f693592812_395.returns.push(1345562386644);
// 26638
f693592812_415.returns.push(o16);
// 26646
f693592812_415.returns.push(o18);
// 26654
f693592812_415.returns.push(o20);
// 26666
f693592812_415.returns.push(o23);
// 26674
f693592812_415.returns.push(o25);
// 26711
o1 = {};
// 26712
f693592812_0.returns.push(o1);
// 26713
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26714
f693592812_395.returns.push(1345562387644);
// 26715
o1 = {};
// 26716
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26724
f693592812_474.returns.push(null);
// 26727
f693592812_495.returns.push(undefined);
// 26729
o1 = {};
// 26730
f693592812_536.returns.push(o1);
// 26731
o1.length = 0;
// undefined
o1 = null;
// 26734
f693592812_475.returns.push(undefined);
// 26735
o1 = {};
// 26736
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26737
f693592812_12.returns.push(103);
// 26748
f693592812_415.returns.push(o16);
// 26756
f693592812_415.returns.push(o18);
// 26764
f693592812_415.returns.push(o20);
// 26776
f693592812_415.returns.push(o23);
// 26784
f693592812_415.returns.push(o25);
// 26821
o1 = {};
// 26822
f693592812_0.returns.push(o1);
// 26823
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26824
f693592812_395.returns.push(1345562388644);
// 26835
f693592812_415.returns.push(o16);
// 26843
f693592812_415.returns.push(o18);
// 26851
f693592812_415.returns.push(o20);
// 26863
f693592812_415.returns.push(o23);
// 26871
f693592812_415.returns.push(o25);
// 26908
o1 = {};
// 26909
f693592812_0.returns.push(o1);
// 26910
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 26911
f693592812_395.returns.push(1345562389644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 26916
o1 = {};
// 26917
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26925
f693592812_474.returns.push(null);
// 26928
f693592812_495.returns.push(undefined);
// 26930
o1 = {};
// 26931
f693592812_536.returns.push(o1);
// 26932
o1.length = 0;
// undefined
o1 = null;
// 26935
f693592812_475.returns.push(undefined);
// 26936
o1 = {};
// 26937
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 26938
f693592812_12.returns.push(104);
// 26949
f693592812_415.returns.push(o16);
// 26957
f693592812_415.returns.push(o18);
// 26965
f693592812_415.returns.push(o20);
// 26977
f693592812_415.returns.push(o23);
// 26985
f693592812_415.returns.push(o25);
// 27022
o1 = {};
// 27023
f693592812_0.returns.push(o1);
// 27024
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27025
f693592812_395.returns.push(1345562390644);
// 27036
f693592812_415.returns.push(o16);
// 27044
f693592812_415.returns.push(o18);
// 27052
f693592812_415.returns.push(o20);
// 27064
f693592812_415.returns.push(o23);
// 27072
f693592812_415.returns.push(o25);
// 27109
o1 = {};
// 27110
f693592812_0.returns.push(o1);
// 27111
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27112
f693592812_395.returns.push(1345562391644);
// 27113
o1 = {};
// 27114
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27122
f693592812_474.returns.push(null);
// 27125
f693592812_495.returns.push(undefined);
// 27127
o1 = {};
// 27128
f693592812_536.returns.push(o1);
// 27129
o1.length = 0;
// undefined
o1 = null;
// 27132
f693592812_475.returns.push(undefined);
// 27133
o1 = {};
// 27134
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27135
f693592812_12.returns.push(105);
// 27136
o1 = {};
// 27137
f693592812_0.returns.push(o1);
// 27138
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27139
f693592812_395.returns.push(1345562392644);
// 27150
f693592812_415.returns.push(o16);
// 27158
f693592812_415.returns.push(o18);
// 27166
f693592812_415.returns.push(o20);
// 27178
f693592812_415.returns.push(o23);
// 27186
f693592812_415.returns.push(o25);
// 27223
o1 = {};
// 27224
f693592812_0.returns.push(o1);
// 27225
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27226
f693592812_395.returns.push(1345562393644);
// 27237
f693592812_415.returns.push(o16);
// 27245
f693592812_415.returns.push(o18);
// 27253
f693592812_415.returns.push(o20);
// 27265
f693592812_415.returns.push(o23);
// 27273
f693592812_415.returns.push(o25);
// 27310
o1 = {};
// 27311
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27319
f693592812_474.returns.push(null);
// 27322
f693592812_495.returns.push(undefined);
// 27324
o1 = {};
// 27325
f693592812_536.returns.push(o1);
// 27326
o1.length = 0;
// undefined
o1 = null;
// 27329
f693592812_475.returns.push(undefined);
// 27330
o1 = {};
// 27331
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27332
f693592812_12.returns.push(106);
// 27333
o1 = {};
// 27334
f693592812_0.returns.push(o1);
// 27335
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27336
f693592812_395.returns.push(1345562394644);
// 27347
f693592812_415.returns.push(o16);
// 27355
f693592812_415.returns.push(o18);
// 27363
f693592812_415.returns.push(o20);
// 27375
f693592812_415.returns.push(o23);
// 27383
f693592812_415.returns.push(o25);
// 27420
o1 = {};
// 27421
f693592812_0.returns.push(o1);
// 27422
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27423
f693592812_395.returns.push(1345562395644);
// 27434
f693592812_415.returns.push(o16);
// 27442
f693592812_415.returns.push(o18);
// 27450
f693592812_415.returns.push(o20);
// 27462
f693592812_415.returns.push(o23);
// 27470
f693592812_415.returns.push(o25);
// 27507
o1 = {};
// 27508
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27516
f693592812_474.returns.push(null);
// 27519
f693592812_495.returns.push(undefined);
// 27521
o1 = {};
// 27522
f693592812_536.returns.push(o1);
// 27523
o1.length = 0;
// undefined
o1 = null;
// 27526
f693592812_475.returns.push(undefined);
// 27527
o1 = {};
// 27528
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27529
f693592812_12.returns.push(107);
// 27530
o1 = {};
// 27531
f693592812_0.returns.push(o1);
// 27532
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27533
f693592812_395.returns.push(1345562396644);
// 27544
f693592812_415.returns.push(o16);
// 27552
f693592812_415.returns.push(o18);
// 27560
f693592812_415.returns.push(o20);
// 27572
f693592812_415.returns.push(o23);
// 27580
f693592812_415.returns.push(o25);
// 27617
o1 = {};
// 27618
f693592812_0.returns.push(o1);
// 27619
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27620
f693592812_395.returns.push(1345562397644);
// 27621
o1 = {};
// 27622
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27630
f693592812_474.returns.push(null);
// 27633
f693592812_495.returns.push(undefined);
// 27635
o1 = {};
// 27636
f693592812_536.returns.push(o1);
// 27637
o1.length = 0;
// undefined
o1 = null;
// 27640
f693592812_475.returns.push(undefined);
// 27641
o1 = {};
// 27642
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27643
f693592812_12.returns.push(108);
// 27654
f693592812_415.returns.push(o16);
// 27662
f693592812_415.returns.push(o18);
// 27670
f693592812_415.returns.push(o20);
// 27682
f693592812_415.returns.push(o23);
// 27690
f693592812_415.returns.push(o25);
// 27727
o1 = {};
// 27728
f693592812_0.returns.push(o1);
// 27729
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27730
f693592812_395.returns.push(1345562398644);
// 27741
f693592812_415.returns.push(o16);
// 27749
f693592812_415.returns.push(o18);
// 27757
f693592812_415.returns.push(o20);
// 27769
f693592812_415.returns.push(o23);
// 27777
f693592812_415.returns.push(o25);
// 27814
o1 = {};
// 27815
f693592812_0.returns.push(o1);
// 27816
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27817
f693592812_395.returns.push(1345562399644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 27822
o1 = {};
// 27823
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27831
f693592812_474.returns.push(null);
// 27834
f693592812_495.returns.push(undefined);
// 27836
o1 = {};
// 27837
f693592812_536.returns.push(o1);
// 27838
o1.length = 0;
// undefined
o1 = null;
// 27841
f693592812_475.returns.push(undefined);
// 27842
o1 = {};
// 27843
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 27844
f693592812_12.returns.push(109);
// 27855
f693592812_415.returns.push(o16);
// 27863
f693592812_415.returns.push(o18);
// 27871
f693592812_415.returns.push(o20);
// 27883
f693592812_415.returns.push(o23);
// 27891
f693592812_415.returns.push(o25);
// 27928
o1 = {};
// 27929
f693592812_0.returns.push(o1);
// 27930
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 27931
f693592812_395.returns.push(1345562400644);
// 27942
f693592812_415.returns.push(o16);
// 27950
f693592812_415.returns.push(o18);
// 27958
f693592812_415.returns.push(o20);
// 27970
f693592812_415.returns.push(o23);
// 27978
f693592812_415.returns.push(o25);
// 28015
o1 = {};
// 28016
f693592812_0.returns.push(o1);
// 28017
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28018
f693592812_395.returns.push(1345562401644);
// 28019
o1 = {};
// 28020
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28028
f693592812_474.returns.push(null);
// 28031
f693592812_495.returns.push(undefined);
// 28033
o1 = {};
// 28034
f693592812_536.returns.push(o1);
// 28035
o1.length = 0;
// undefined
o1 = null;
// 28038
f693592812_475.returns.push(undefined);
// 28039
o1 = {};
// 28040
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28041
f693592812_12.returns.push(110);
// 28042
o1 = {};
// 28043
f693592812_0.returns.push(o1);
// 28044
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28045
f693592812_395.returns.push(1345562402644);
// 28056
f693592812_415.returns.push(o16);
// 28064
f693592812_415.returns.push(o18);
// 28072
f693592812_415.returns.push(o20);
// 28084
f693592812_415.returns.push(o23);
// 28092
f693592812_415.returns.push(o25);
// 28129
o1 = {};
// 28130
f693592812_0.returns.push(o1);
// 28131
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28132
f693592812_395.returns.push(1345562403644);
// 28143
f693592812_415.returns.push(o16);
// 28151
f693592812_415.returns.push(o18);
// 28159
f693592812_415.returns.push(o20);
// 28171
f693592812_415.returns.push(o23);
// 28179
f693592812_415.returns.push(o25);
// 28216
o1 = {};
// 28217
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28225
f693592812_474.returns.push(null);
// 28228
f693592812_495.returns.push(undefined);
// 28230
o1 = {};
// 28231
f693592812_536.returns.push(o1);
// 28232
o1.length = 0;
// undefined
o1 = null;
// 28235
f693592812_475.returns.push(undefined);
// 28236
o1 = {};
// 28237
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28238
f693592812_12.returns.push(111);
// 28239
o1 = {};
// 28240
f693592812_0.returns.push(o1);
// 28241
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28242
f693592812_395.returns.push(1345562404644);
// 28253
f693592812_415.returns.push(o16);
// 28261
f693592812_415.returns.push(o18);
// 28269
f693592812_415.returns.push(o20);
// 28281
f693592812_415.returns.push(o23);
// 28289
f693592812_415.returns.push(o25);
// 28326
o1 = {};
// 28327
f693592812_0.returns.push(o1);
// 28328
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28329
f693592812_395.returns.push(1345562405644);
// 28340
f693592812_415.returns.push(o16);
// 28348
f693592812_415.returns.push(o18);
// 28356
f693592812_415.returns.push(o20);
// 28368
f693592812_415.returns.push(o23);
// 28376
f693592812_415.returns.push(o25);
// 28413
o1 = {};
// 28414
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28422
f693592812_474.returns.push(null);
// 28425
f693592812_495.returns.push(undefined);
// 28427
o1 = {};
// 28428
f693592812_536.returns.push(o1);
// 28429
o1.length = 0;
// undefined
o1 = null;
// 28432
f693592812_475.returns.push(undefined);
// 28433
o1 = {};
// 28434
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28435
f693592812_12.returns.push(112);
// 28436
o1 = {};
// 28437
f693592812_0.returns.push(o1);
// 28438
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28439
f693592812_395.returns.push(1345562406680);
// 28450
f693592812_415.returns.push(o16);
// 28458
f693592812_415.returns.push(o18);
// 28466
f693592812_415.returns.push(o20);
// 28478
f693592812_415.returns.push(o23);
// 28486
f693592812_415.returns.push(o25);
// 28523
o1 = {};
// 28524
f693592812_0.returns.push(o1);
// 28525
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28526
f693592812_395.returns.push(1345562407644);
// 28527
o1 = {};
// 28528
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28536
f693592812_474.returns.push(null);
// 28539
f693592812_495.returns.push(undefined);
// 28541
o1 = {};
// 28542
f693592812_536.returns.push(o1);
// 28543
o1.length = 0;
// undefined
o1 = null;
// 28546
f693592812_475.returns.push(undefined);
// 28547
o1 = {};
// 28548
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28549
f693592812_12.returns.push(113);
// 28560
f693592812_415.returns.push(o16);
// 28568
f693592812_415.returns.push(o18);
// 28576
f693592812_415.returns.push(o20);
// 28588
f693592812_415.returns.push(o23);
// 28596
f693592812_415.returns.push(o25);
// 28633
o1 = {};
// 28634
f693592812_0.returns.push(o1);
// 28635
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28636
f693592812_395.returns.push(1345562408644);
// 28647
f693592812_415.returns.push(o16);
// 28655
f693592812_415.returns.push(o18);
// 28663
f693592812_415.returns.push(o20);
// 28675
f693592812_415.returns.push(o23);
// 28683
f693592812_415.returns.push(o25);
// 28720
o1 = {};
// 28721
f693592812_0.returns.push(o1);
// 28722
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28723
f693592812_395.returns.push(1345562409644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 28728
o1 = {};
// 28729
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28737
f693592812_474.returns.push(null);
// 28740
f693592812_495.returns.push(undefined);
// 28742
o1 = {};
// 28743
f693592812_536.returns.push(o1);
// 28744
o1.length = 0;
// undefined
o1 = null;
// 28747
f693592812_475.returns.push(undefined);
// 28748
o1 = {};
// 28749
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28750
f693592812_12.returns.push(114);
// 28761
f693592812_415.returns.push(o16);
// 28769
f693592812_415.returns.push(o18);
// 28777
f693592812_415.returns.push(o20);
// 28789
f693592812_415.returns.push(o23);
// 28797
f693592812_415.returns.push(o25);
// 28834
o1 = {};
// 28835
f693592812_0.returns.push(o1);
// 28836
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28837
f693592812_395.returns.push(1345562410644);
// 28848
f693592812_415.returns.push(o16);
// 28856
f693592812_415.returns.push(o18);
// 28864
f693592812_415.returns.push(o20);
// 28876
f693592812_415.returns.push(o23);
// 28884
f693592812_415.returns.push(o25);
// 28921
o1 = {};
// 28922
f693592812_0.returns.push(o1);
// 28923
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28924
f693592812_395.returns.push(1345562411644);
// 28925
o1 = {};
// 28926
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28934
f693592812_474.returns.push(null);
// 28937
f693592812_495.returns.push(undefined);
// 28939
o1 = {};
// 28940
f693592812_536.returns.push(o1);
// 28941
o1.length = 0;
// undefined
o1 = null;
// 28944
f693592812_475.returns.push(undefined);
// 28945
o1 = {};
// 28946
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 28947
f693592812_12.returns.push(115);
// 28948
o1 = {};
// 28949
f693592812_0.returns.push(o1);
// 28950
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 28951
f693592812_395.returns.push(1345562412644);
// 28962
f693592812_415.returns.push(o16);
// 28970
f693592812_415.returns.push(o18);
// 28978
f693592812_415.returns.push(o20);
// 28990
f693592812_415.returns.push(o23);
// 28998
f693592812_415.returns.push(o25);
// 29035
o1 = {};
// 29036
f693592812_0.returns.push(o1);
// 29037
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29038
f693592812_395.returns.push(1345562413644);
// 29049
f693592812_415.returns.push(o16);
// 29057
f693592812_415.returns.push(o18);
// 29065
f693592812_415.returns.push(o20);
// 29077
f693592812_415.returns.push(o23);
// 29085
f693592812_415.returns.push(o25);
// 29122
o1 = {};
// 29123
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29131
f693592812_474.returns.push(null);
// 29134
f693592812_495.returns.push(undefined);
// 29136
o1 = {};
// 29137
f693592812_536.returns.push(o1);
// 29138
o1.length = 0;
// undefined
o1 = null;
// 29141
f693592812_475.returns.push(undefined);
// 29142
o1 = {};
// 29143
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29144
f693592812_12.returns.push(116);
// 29145
o1 = {};
// 29146
f693592812_0.returns.push(o1);
// 29147
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29148
f693592812_395.returns.push(1345562414644);
// 29159
f693592812_415.returns.push(o16);
// 29167
f693592812_415.returns.push(o18);
// 29175
f693592812_415.returns.push(o20);
// 29187
f693592812_415.returns.push(o23);
// 29195
f693592812_415.returns.push(o25);
// 29232
o1 = {};
// 29233
f693592812_0.returns.push(o1);
// 29234
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29235
f693592812_395.returns.push(1345562415644);
// 29246
f693592812_415.returns.push(o16);
// 29254
f693592812_415.returns.push(o18);
// 29262
f693592812_415.returns.push(o20);
// 29274
f693592812_415.returns.push(o23);
// 29282
f693592812_415.returns.push(o25);
// 29319
o1 = {};
// 29320
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29328
f693592812_474.returns.push(null);
// 29331
f693592812_495.returns.push(undefined);
// 29333
o1 = {};
// 29334
f693592812_536.returns.push(o1);
// 29335
o1.length = 0;
// undefined
o1 = null;
// 29338
f693592812_475.returns.push(undefined);
// 29339
o1 = {};
// 29340
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29341
f693592812_12.returns.push(117);
// 29342
o1 = {};
// 29343
f693592812_0.returns.push(o1);
// 29344
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29345
f693592812_395.returns.push(1345562416644);
// 29356
f693592812_415.returns.push(o16);
// 29364
f693592812_415.returns.push(o18);
// 29372
f693592812_415.returns.push(o20);
// 29384
f693592812_415.returns.push(o23);
// 29392
f693592812_415.returns.push(o25);
// 29429
o1 = {};
// 29430
f693592812_0.returns.push(o1);
// 29431
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29432
f693592812_395.returns.push(1345562417644);
// 29443
f693592812_415.returns.push(o16);
// 29451
f693592812_415.returns.push(o18);
// 29459
f693592812_415.returns.push(o20);
// 29471
f693592812_415.returns.push(o23);
// 29479
f693592812_415.returns.push(o25);
// 29516
o1 = {};
// 29517
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29525
f693592812_474.returns.push(null);
// 29528
f693592812_495.returns.push(undefined);
// 29530
o1 = {};
// 29531
f693592812_536.returns.push(o1);
// 29532
o1.length = 0;
// undefined
o1 = null;
// 29535
f693592812_475.returns.push(undefined);
// 29536
o1 = {};
// 29537
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29538
f693592812_12.returns.push(118);
// 29539
o1 = {};
// 29540
f693592812_0.returns.push(o1);
// 29541
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29542
f693592812_395.returns.push(1345562418644);
// 29553
f693592812_415.returns.push(o16);
// 29561
f693592812_415.returns.push(o18);
// 29569
f693592812_415.returns.push(o20);
// 29581
f693592812_415.returns.push(o23);
// 29589
f693592812_415.returns.push(o25);
// 29626
o1 = {};
// 29627
f693592812_0.returns.push(o1);
// 29628
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29629
f693592812_395.returns.push(1345562419644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 29634
o1 = {};
// 29635
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29643
f693592812_474.returns.push(null);
// 29646
f693592812_495.returns.push(undefined);
// 29648
o1 = {};
// 29649
f693592812_536.returns.push(o1);
// 29650
o1.length = 0;
// undefined
o1 = null;
// 29653
f693592812_475.returns.push(undefined);
// 29654
o1 = {};
// 29655
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29656
f693592812_12.returns.push(119);
// 29667
f693592812_415.returns.push(o16);
// 29675
f693592812_415.returns.push(o18);
// 29683
f693592812_415.returns.push(o20);
// 29695
f693592812_415.returns.push(o23);
// 29703
f693592812_415.returns.push(o25);
// 29740
o1 = {};
// 29741
f693592812_0.returns.push(o1);
// 29742
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29743
f693592812_395.returns.push(1345562420644);
// 29754
f693592812_415.returns.push(o16);
// 29762
f693592812_415.returns.push(o18);
// 29770
f693592812_415.returns.push(o20);
// 29782
f693592812_415.returns.push(o23);
// 29790
f693592812_415.returns.push(o25);
// 29827
o1 = {};
// 29828
f693592812_0.returns.push(o1);
// 29829
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29830
f693592812_395.returns.push(1345562421644);
// 29831
o1 = {};
// 29832
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29840
f693592812_474.returns.push(null);
// 29843
f693592812_495.returns.push(undefined);
// 29845
o1 = {};
// 29846
f693592812_536.returns.push(o1);
// 29847
o1.length = 0;
// undefined
o1 = null;
// 29850
f693592812_475.returns.push(undefined);
// 29851
o1 = {};
// 29852
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 29853
f693592812_12.returns.push(120);
// 29854
o1 = {};
// 29855
f693592812_0.returns.push(o1);
// 29856
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29857
f693592812_395.returns.push(1345562422644);
// 29868
f693592812_415.returns.push(o16);
// 29876
f693592812_415.returns.push(o18);
// 29884
f693592812_415.returns.push(o20);
// 29896
f693592812_415.returns.push(o23);
// 29904
f693592812_415.returns.push(o25);
// 29941
o1 = {};
// 29942
f693592812_0.returns.push(o1);
// 29943
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 29944
f693592812_395.returns.push(1345562423644);
// 29955
f693592812_415.returns.push(o16);
// 29963
f693592812_415.returns.push(o18);
// 29971
f693592812_415.returns.push(o20);
// 29983
f693592812_415.returns.push(o23);
// 29991
f693592812_415.returns.push(o25);
// 30028
o1 = {};
// 30029
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30037
f693592812_474.returns.push(null);
// 30040
f693592812_495.returns.push(undefined);
// 30042
o1 = {};
// 30043
f693592812_536.returns.push(o1);
// 30044
o1.length = 0;
// undefined
o1 = null;
// 30047
f693592812_475.returns.push(undefined);
// 30048
o1 = {};
// 30049
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30050
f693592812_12.returns.push(121);
// 30051
o1 = {};
// 30052
f693592812_0.returns.push(o1);
// 30053
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30054
f693592812_395.returns.push(1345562424648);
// 30065
f693592812_415.returns.push(o16);
// 30073
f693592812_415.returns.push(o18);
// 30081
f693592812_415.returns.push(o20);
// 30093
f693592812_415.returns.push(o23);
// 30101
f693592812_415.returns.push(o25);
// 30138
o1 = {};
// 30139
f693592812_0.returns.push(o1);
// 30140
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30141
f693592812_395.returns.push(1345562425644);
// 30152
f693592812_415.returns.push(o16);
// 30160
f693592812_415.returns.push(o18);
// 30168
f693592812_415.returns.push(o20);
// 30180
f693592812_415.returns.push(o23);
// 30188
f693592812_415.returns.push(o25);
// 30225
o1 = {};
// 30226
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30234
f693592812_474.returns.push(null);
// 30237
f693592812_495.returns.push(undefined);
// 30239
o1 = {};
// 30240
f693592812_536.returns.push(o1);
// 30241
o1.length = 0;
// undefined
o1 = null;
// 30244
f693592812_475.returns.push(undefined);
// 30245
o1 = {};
// 30246
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30247
f693592812_12.returns.push(122);
// 30248
o1 = {};
// 30249
f693592812_0.returns.push(o1);
// 30250
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30251
f693592812_395.returns.push(1345562426644);
// 30262
f693592812_415.returns.push(o16);
// 30270
f693592812_415.returns.push(o18);
// 30278
f693592812_415.returns.push(o20);
// 30290
f693592812_415.returns.push(o23);
// 30298
f693592812_415.returns.push(o25);
// 30335
o1 = {};
// 30336
f693592812_0.returns.push(o1);
// 30337
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30338
f693592812_395.returns.push(1345562427644);
// 30349
f693592812_415.returns.push(o16);
// 30357
f693592812_415.returns.push(o18);
// 30365
f693592812_415.returns.push(o20);
// 30377
f693592812_415.returns.push(o23);
// 30385
f693592812_415.returns.push(o25);
// 30422
o1 = {};
// 30423
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30431
f693592812_474.returns.push(null);
// 30434
f693592812_495.returns.push(undefined);
// 30436
o1 = {};
// 30437
f693592812_536.returns.push(o1);
// 30438
o1.length = 0;
// undefined
o1 = null;
// 30441
f693592812_475.returns.push(undefined);
// 30442
o1 = {};
// 30443
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30444
f693592812_12.returns.push(123);
// 30445
o1 = {};
// 30446
f693592812_0.returns.push(o1);
// 30447
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30448
f693592812_395.returns.push(1345562428644);
// 30459
f693592812_415.returns.push(o16);
// 30467
f693592812_415.returns.push(o18);
// 30475
f693592812_415.returns.push(o20);
// 30487
f693592812_415.returns.push(o23);
// 30495
f693592812_415.returns.push(o25);
// 30532
o1 = {};
// 30533
f693592812_0.returns.push(o1);
// 30534
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30535
f693592812_395.returns.push(1345562429644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 30540
o1 = {};
// 30541
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30549
f693592812_474.returns.push(null);
// 30552
f693592812_495.returns.push(undefined);
// 30554
o1 = {};
// 30555
f693592812_536.returns.push(o1);
// 30556
o1.length = 0;
// undefined
o1 = null;
// 30559
f693592812_475.returns.push(undefined);
// 30560
o1 = {};
// 30561
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30562
f693592812_12.returns.push(124);
// 30573
f693592812_415.returns.push(o16);
// 30581
f693592812_415.returns.push(o18);
// 30589
f693592812_415.returns.push(o20);
// 30601
f693592812_415.returns.push(o23);
// 30609
f693592812_415.returns.push(o25);
// 30646
o1 = {};
// 30647
f693592812_0.returns.push(o1);
// 30648
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30649
f693592812_395.returns.push(1345562430644);
// 30660
f693592812_415.returns.push(o16);
// 30668
f693592812_415.returns.push(o18);
// 30676
f693592812_415.returns.push(o20);
// 30688
f693592812_415.returns.push(o23);
// 30696
f693592812_415.returns.push(o25);
// 30733
o1 = {};
// 30734
f693592812_0.returns.push(o1);
// 30735
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30736
f693592812_395.returns.push(1345562431644);
// 30737
o1 = {};
// 30738
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30746
f693592812_474.returns.push(null);
// 30749
f693592812_495.returns.push(undefined);
// 30751
o1 = {};
// 30752
f693592812_536.returns.push(o1);
// 30753
o1.length = 0;
// undefined
o1 = null;
// 30756
f693592812_475.returns.push(undefined);
// 30757
o1 = {};
// 30758
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30759
f693592812_12.returns.push(125);
// 30760
o1 = {};
// 30761
f693592812_0.returns.push(o1);
// 30762
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30763
f693592812_395.returns.push(1345562432644);
// 30774
f693592812_415.returns.push(o16);
// 30782
f693592812_415.returns.push(o18);
// 30790
f693592812_415.returns.push(o20);
// 30802
f693592812_415.returns.push(o23);
// 30810
f693592812_415.returns.push(o25);
// 30847
o1 = {};
// 30848
f693592812_0.returns.push(o1);
// 30849
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30850
f693592812_395.returns.push(1345562433644);
// 30861
f693592812_415.returns.push(o16);
// 30869
f693592812_415.returns.push(o18);
// 30877
f693592812_415.returns.push(o20);
// 30889
f693592812_415.returns.push(o23);
// 30897
f693592812_415.returns.push(o25);
// 30934
o1 = {};
// 30935
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30943
f693592812_474.returns.push(null);
// 30946
f693592812_495.returns.push(undefined);
// 30948
o1 = {};
// 30949
f693592812_536.returns.push(o1);
// 30950
o1.length = 0;
// undefined
o1 = null;
// 30953
f693592812_475.returns.push(undefined);
// 30954
o1 = {};
// 30955
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 30956
f693592812_12.returns.push(126);
// 30957
o1 = {};
// 30958
f693592812_0.returns.push(o1);
// 30959
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 30960
f693592812_395.returns.push(1345562434644);
// 30971
f693592812_415.returns.push(o16);
// 30979
f693592812_415.returns.push(o18);
// 30987
f693592812_415.returns.push(o20);
// 30999
f693592812_415.returns.push(o23);
// 31007
f693592812_415.returns.push(o25);
// 31044
o1 = {};
// 31045
f693592812_0.returns.push(o1);
// 31046
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31047
f693592812_395.returns.push(1345562435644);
// 31058
f693592812_415.returns.push(o16);
// 31066
f693592812_415.returns.push(o18);
// 31074
f693592812_415.returns.push(o20);
// 31086
f693592812_415.returns.push(o23);
// 31094
f693592812_415.returns.push(o25);
// 31131
o1 = {};
// 31132
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31140
f693592812_474.returns.push(null);
// 31143
f693592812_495.returns.push(undefined);
// 31145
o1 = {};
// 31146
f693592812_536.returns.push(o1);
// 31147
o1.length = 0;
// undefined
o1 = null;
// 31150
f693592812_475.returns.push(undefined);
// 31151
o1 = {};
// 31152
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31153
f693592812_12.returns.push(127);
// 31154
o1 = {};
// 31155
f693592812_0.returns.push(o1);
// 31156
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31157
f693592812_395.returns.push(1345562436644);
// 31168
f693592812_415.returns.push(o16);
// 31176
f693592812_415.returns.push(o18);
// 31184
f693592812_415.returns.push(o20);
// 31196
f693592812_415.returns.push(o23);
// 31204
f693592812_415.returns.push(o25);
// 31241
o1 = {};
// 31242
f693592812_0.returns.push(o1);
// 31243
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31244
f693592812_395.returns.push(1345562437644);
// 31255
f693592812_415.returns.push(o16);
// 31263
f693592812_415.returns.push(o18);
// 31271
f693592812_415.returns.push(o20);
// 31283
f693592812_415.returns.push(o23);
// 31291
f693592812_415.returns.push(o25);
// 31328
o1 = {};
// 31329
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31337
f693592812_474.returns.push(null);
// 31340
f693592812_495.returns.push(undefined);
// 31342
o1 = {};
// 31343
f693592812_536.returns.push(o1);
// 31344
o1.length = 0;
// undefined
o1 = null;
// 31347
f693592812_475.returns.push(undefined);
// 31348
o1 = {};
// 31349
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31350
f693592812_12.returns.push(128);
// 31351
o1 = {};
// 31352
f693592812_0.returns.push(o1);
// 31353
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31354
f693592812_395.returns.push(1345562438644);
// 31365
f693592812_415.returns.push(o16);
// 31373
f693592812_415.returns.push(o18);
// 31381
f693592812_415.returns.push(o20);
// 31393
f693592812_415.returns.push(o23);
// 31401
f693592812_415.returns.push(o25);
// 31438
o1 = {};
// 31439
f693592812_0.returns.push(o1);
// 31440
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31441
f693592812_395.returns.push(1345562439644);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 31446
o1 = {};
// 31447
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31455
f693592812_474.returns.push(null);
// 31458
f693592812_495.returns.push(undefined);
// 31460
o1 = {};
// 31461
f693592812_536.returns.push(o1);
// 31462
o1.length = 0;
// undefined
o1 = null;
// 31465
f693592812_475.returns.push(undefined);
// 31466
o1 = {};
// 31467
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31468
f693592812_12.returns.push(129);
// 31479
f693592812_415.returns.push(o16);
// 31487
f693592812_415.returns.push(o18);
// 31495
f693592812_415.returns.push(o20);
// 31507
f693592812_415.returns.push(o23);
// 31515
f693592812_415.returns.push(o25);
// 31552
o1 = {};
// 31553
f693592812_0.returns.push(o1);
// 31554
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31555
f693592812_395.returns.push(1345562440644);
// 31566
f693592812_415.returns.push(o16);
// 31574
f693592812_415.returns.push(o18);
// 31582
f693592812_415.returns.push(o20);
// 31594
f693592812_415.returns.push(o23);
// 31602
f693592812_415.returns.push(o25);
// 31639
o1 = {};
// 31640
f693592812_0.returns.push(o1);
// 31641
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31642
f693592812_395.returns.push(1345562441644);
// 31643
o1 = {};
// 31644
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31652
f693592812_474.returns.push(null);
// 31655
f693592812_495.returns.push(undefined);
// 31657
o1 = {};
// 31658
f693592812_536.returns.push(o1);
// 31659
o1.length = 0;
// undefined
o1 = null;
// 31662
f693592812_475.returns.push(undefined);
// 31663
o1 = {};
// 31664
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31665
f693592812_12.returns.push(130);
// 31666
o1 = {};
// 31667
f693592812_0.returns.push(o1);
// 31668
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31669
f693592812_395.returns.push(1345562442644);
// 31680
f693592812_415.returns.push(o16);
// 31688
f693592812_415.returns.push(o18);
// 31696
f693592812_415.returns.push(o20);
// 31708
f693592812_415.returns.push(o23);
// 31716
f693592812_415.returns.push(o25);
// 31753
o1 = {};
// 31754
f693592812_0.returns.push(o1);
// 31755
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31756
f693592812_395.returns.push(1345562443644);
// 31767
f693592812_415.returns.push(o16);
// 31775
f693592812_415.returns.push(o18);
// 31783
f693592812_415.returns.push(o20);
// 31795
f693592812_415.returns.push(o23);
// 31803
f693592812_415.returns.push(o25);
// 31840
o1 = {};
// 31841
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31849
f693592812_474.returns.push(null);
// 31852
f693592812_495.returns.push(undefined);
// 31854
o1 = {};
// 31855
f693592812_536.returns.push(o1);
// 31856
o1.length = 0;
// undefined
o1 = null;
// 31859
f693592812_475.returns.push(undefined);
// 31860
o1 = {};
// 31861
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 31862
f693592812_12.returns.push(131);
// 31863
o1 = {};
// 31864
f693592812_0.returns.push(o1);
// 31865
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31866
f693592812_395.returns.push(1345562444644);
// 31877
f693592812_415.returns.push(o16);
// 31885
f693592812_415.returns.push(o18);
// 31893
f693592812_415.returns.push(o20);
// 31905
f693592812_415.returns.push(o23);
// 31913
f693592812_415.returns.push(o25);
// 31950
o1 = {};
// 31951
f693592812_0.returns.push(o1);
// 31952
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 31953
f693592812_395.returns.push(1345562445645);
// 31964
f693592812_415.returns.push(o16);
// 31972
f693592812_415.returns.push(o18);
// 31980
f693592812_415.returns.push(o20);
// 31992
f693592812_415.returns.push(o23);
// 32000
f693592812_415.returns.push(o25);
// 32037
o1 = {};
// 32038
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32046
f693592812_474.returns.push(null);
// 32049
f693592812_495.returns.push(undefined);
// 32051
o1 = {};
// 32052
f693592812_536.returns.push(o1);
// 32053
o1.length = 0;
// undefined
o1 = null;
// 32056
f693592812_475.returns.push(undefined);
// 32057
o1 = {};
// 32058
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32059
f693592812_12.returns.push(132);
// 32060
o1 = {};
// 32061
f693592812_0.returns.push(o1);
// 32062
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32063
f693592812_395.returns.push(1345562446644);
// 32074
f693592812_415.returns.push(o16);
// 32082
f693592812_415.returns.push(o18);
// 32090
f693592812_415.returns.push(o20);
// 32102
f693592812_415.returns.push(o23);
// 32110
f693592812_415.returns.push(o25);
// 32147
o1 = {};
// 32148
f693592812_0.returns.push(o1);
// 32149
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32150
f693592812_395.returns.push(1345562447645);
// 32161
f693592812_415.returns.push(o16);
// 32169
f693592812_415.returns.push(o18);
// 32177
f693592812_415.returns.push(o20);
// 32189
f693592812_415.returns.push(o23);
// 32197
f693592812_415.returns.push(o25);
// 32234
o1 = {};
// 32235
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32243
f693592812_474.returns.push(null);
// 32246
f693592812_495.returns.push(undefined);
// 32248
o1 = {};
// 32249
f693592812_536.returns.push(o1);
// 32250
o1.length = 0;
// undefined
o1 = null;
// 32253
f693592812_475.returns.push(undefined);
// 32254
o1 = {};
// 32255
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32256
f693592812_12.returns.push(133);
// 32257
o1 = {};
// 32258
f693592812_0.returns.push(o1);
// 32259
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32260
f693592812_395.returns.push(1345562448645);
// 32271
f693592812_415.returns.push(o16);
// 32279
f693592812_415.returns.push(o18);
// 32287
f693592812_415.returns.push(o20);
// 32299
f693592812_415.returns.push(o23);
// 32307
f693592812_415.returns.push(o25);
// 32344
o1 = {};
// 32345
f693592812_0.returns.push(o1);
// 32346
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32347
f693592812_395.returns.push(1345562449645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 32352
o1 = {};
// 32353
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32361
f693592812_474.returns.push(null);
// 32364
f693592812_495.returns.push(undefined);
// 32366
o1 = {};
// 32367
f693592812_536.returns.push(o1);
// 32368
o1.length = 0;
// undefined
o1 = null;
// 32371
f693592812_475.returns.push(undefined);
// 32372
o1 = {};
// 32373
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32374
f693592812_12.returns.push(134);
// 32385
f693592812_415.returns.push(o16);
// 32393
f693592812_415.returns.push(o18);
// 32401
f693592812_415.returns.push(o20);
// 32413
f693592812_415.returns.push(o23);
// 32421
f693592812_415.returns.push(o25);
// 32458
o1 = {};
// 32459
f693592812_0.returns.push(o1);
// 32460
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32461
f693592812_395.returns.push(1345562450645);
// 32472
f693592812_415.returns.push(o16);
// 32480
f693592812_415.returns.push(o18);
// 32488
f693592812_415.returns.push(o20);
// 32500
f693592812_415.returns.push(o23);
// 32508
f693592812_415.returns.push(o25);
// 32545
o1 = {};
// 32546
f693592812_0.returns.push(o1);
// 32547
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32548
f693592812_395.returns.push(1345562451644);
// 32549
o1 = {};
// 32550
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32558
f693592812_474.returns.push(null);
// 32561
f693592812_495.returns.push(undefined);
// 32563
o1 = {};
// 32564
f693592812_536.returns.push(o1);
// 32565
o1.length = 0;
// undefined
o1 = null;
// 32568
f693592812_475.returns.push(undefined);
// 32569
o1 = {};
// 32570
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32571
f693592812_12.returns.push(135);
// 32572
o1 = {};
// 32573
f693592812_0.returns.push(o1);
// 32574
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32575
f693592812_395.returns.push(1345562452645);
// 32586
f693592812_415.returns.push(o16);
// 32594
f693592812_415.returns.push(o18);
// 32602
f693592812_415.returns.push(o20);
// 32614
f693592812_415.returns.push(o23);
// 32622
f693592812_415.returns.push(o25);
// 32659
o1 = {};
// 32660
f693592812_0.returns.push(o1);
// 32661
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32662
f693592812_395.returns.push(1345562453645);
// 32673
f693592812_415.returns.push(o16);
// 32681
f693592812_415.returns.push(o18);
// 32689
f693592812_415.returns.push(o20);
// 32701
f693592812_415.returns.push(o23);
// 32709
f693592812_415.returns.push(o25);
// 32746
o1 = {};
// 32747
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32755
f693592812_474.returns.push(null);
// 32758
f693592812_495.returns.push(undefined);
// 32760
o1 = {};
// 32761
f693592812_536.returns.push(o1);
// 32762
o1.length = 0;
// undefined
o1 = null;
// 32765
f693592812_475.returns.push(undefined);
// 32766
o1 = {};
// 32767
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32768
f693592812_12.returns.push(136);
// 32769
o1 = {};
// 32770
f693592812_0.returns.push(o1);
// 32771
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32772
f693592812_395.returns.push(1345562454645);
// 32783
f693592812_415.returns.push(o16);
// 32791
f693592812_415.returns.push(o18);
// 32799
f693592812_415.returns.push(o20);
// 32811
f693592812_415.returns.push(o23);
// 32819
f693592812_415.returns.push(o25);
// 32856
o1 = {};
// 32857
f693592812_0.returns.push(o1);
// 32858
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32859
f693592812_395.returns.push(1345562455645);
// 32870
f693592812_415.returns.push(o16);
// 32878
f693592812_415.returns.push(o18);
// 32886
f693592812_415.returns.push(o20);
// 32898
f693592812_415.returns.push(o23);
// 32906
f693592812_415.returns.push(o25);
// 32943
o1 = {};
// 32944
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32952
f693592812_474.returns.push(null);
// 32955
f693592812_495.returns.push(undefined);
// 32957
o1 = {};
// 32958
f693592812_536.returns.push(o1);
// 32959
o1.length = 0;
// undefined
o1 = null;
// 32962
f693592812_475.returns.push(undefined);
// 32963
o1 = {};
// 32964
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 32965
f693592812_12.returns.push(137);
// 32966
o1 = {};
// 32967
f693592812_0.returns.push(o1);
// 32968
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 32969
f693592812_395.returns.push(1345562456645);
// 32980
f693592812_415.returns.push(o16);
// 32988
f693592812_415.returns.push(o18);
// 32996
f693592812_415.returns.push(o20);
// 33008
f693592812_415.returns.push(o23);
// 33016
f693592812_415.returns.push(o25);
// 33053
o1 = {};
// 33054
f693592812_0.returns.push(o1);
// 33055
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33056
f693592812_395.returns.push(1345562457645);
// 33067
f693592812_415.returns.push(o16);
// 33075
f693592812_415.returns.push(o18);
// 33083
f693592812_415.returns.push(o20);
// 33095
f693592812_415.returns.push(o23);
// 33103
f693592812_415.returns.push(o25);
// 33140
o1 = {};
// 33141
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33149
f693592812_474.returns.push(null);
// 33152
f693592812_495.returns.push(undefined);
// 33154
o1 = {};
// 33155
f693592812_536.returns.push(o1);
// 33156
o1.length = 0;
// undefined
o1 = null;
// 33159
f693592812_475.returns.push(undefined);
// 33160
o1 = {};
// 33161
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33162
f693592812_12.returns.push(138);
// 33163
o1 = {};
// 33164
f693592812_0.returns.push(o1);
// 33165
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33166
f693592812_395.returns.push(1345562458645);
// 33177
f693592812_415.returns.push(o16);
// 33185
f693592812_415.returns.push(o18);
// 33193
f693592812_415.returns.push(o20);
// 33205
f693592812_415.returns.push(o23);
// 33213
f693592812_415.returns.push(o25);
// 33250
o1 = {};
// 33251
f693592812_0.returns.push(o1);
// 33252
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33253
f693592812_395.returns.push(1345562459645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 33258
o1 = {};
// 33259
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33267
f693592812_474.returns.push(null);
// 33270
f693592812_495.returns.push(undefined);
// 33272
o1 = {};
// 33273
f693592812_536.returns.push(o1);
// 33274
o1.length = 0;
// undefined
o1 = null;
// 33277
f693592812_475.returns.push(undefined);
// 33278
o1 = {};
// 33279
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33280
f693592812_12.returns.push(139);
// 33291
f693592812_415.returns.push(o16);
// 33299
f693592812_415.returns.push(o18);
// 33307
f693592812_415.returns.push(o20);
// 33319
f693592812_415.returns.push(o23);
// 33327
f693592812_415.returns.push(o25);
// 33364
o1 = {};
// 33365
f693592812_0.returns.push(o1);
// 33366
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33367
f693592812_395.returns.push(1345562460645);
// 33378
f693592812_415.returns.push(o16);
// 33386
f693592812_415.returns.push(o18);
// 33394
f693592812_415.returns.push(o20);
// 33406
f693592812_415.returns.push(o23);
// 33414
f693592812_415.returns.push(o25);
// 33451
o1 = {};
// 33452
f693592812_0.returns.push(o1);
// 33453
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33454
f693592812_395.returns.push(1345562461645);
// 33455
o1 = {};
// 33456
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33464
f693592812_474.returns.push(null);
// 33467
f693592812_495.returns.push(undefined);
// 33469
o1 = {};
// 33470
f693592812_536.returns.push(o1);
// 33471
o1.length = 0;
// undefined
o1 = null;
// 33474
f693592812_475.returns.push(undefined);
// 33475
o1 = {};
// 33476
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33477
f693592812_12.returns.push(140);
// 33478
o1 = {};
// 33479
f693592812_0.returns.push(o1);
// 33480
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33481
f693592812_395.returns.push(1345562462645);
// 33492
f693592812_415.returns.push(o16);
// 33500
f693592812_415.returns.push(o18);
// 33508
f693592812_415.returns.push(o20);
// 33520
f693592812_415.returns.push(o23);
// 33528
f693592812_415.returns.push(o25);
// 33565
o1 = {};
// 33566
f693592812_0.returns.push(o1);
// 33567
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33568
f693592812_395.returns.push(1345562463645);
// 33579
f693592812_415.returns.push(o16);
// 33587
f693592812_415.returns.push(o18);
// 33595
f693592812_415.returns.push(o20);
// 33607
f693592812_415.returns.push(o23);
// 33615
f693592812_415.returns.push(o25);
// 33652
o1 = {};
// 33653
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33661
f693592812_474.returns.push(null);
// 33664
f693592812_495.returns.push(undefined);
// 33666
o1 = {};
// 33667
f693592812_536.returns.push(o1);
// 33668
o1.length = 0;
// undefined
o1 = null;
// 33671
f693592812_475.returns.push(undefined);
// 33672
o1 = {};
// 33673
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33674
f693592812_12.returns.push(141);
// 33675
o1 = {};
// 33676
f693592812_0.returns.push(o1);
// 33677
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33678
f693592812_395.returns.push(1345562464645);
// 33689
f693592812_415.returns.push(o16);
// 33697
f693592812_415.returns.push(o18);
// 33705
f693592812_415.returns.push(o20);
// 33717
f693592812_415.returns.push(o23);
// 33725
f693592812_415.returns.push(o25);
// 33762
o1 = {};
// 33763
f693592812_0.returns.push(o1);
// 33764
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33765
f693592812_395.returns.push(1345562465645);
// 33776
f693592812_415.returns.push(o16);
// 33784
f693592812_415.returns.push(o18);
// 33792
f693592812_415.returns.push(o20);
// 33804
f693592812_415.returns.push(o23);
// 33812
f693592812_415.returns.push(o25);
// 33849
o1 = {};
// 33850
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33858
f693592812_474.returns.push(null);
// 33861
f693592812_495.returns.push(undefined);
// 33863
o1 = {};
// 33864
f693592812_536.returns.push(o1);
// 33865
o1.length = 0;
// undefined
o1 = null;
// 33868
f693592812_475.returns.push(undefined);
// 33869
o1 = {};
// 33870
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 33871
f693592812_12.returns.push(142);
// 33872
o1 = {};
// 33873
f693592812_0.returns.push(o1);
// 33874
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33875
f693592812_395.returns.push(1345562466645);
// 33886
f693592812_415.returns.push(o16);
// 33894
f693592812_415.returns.push(o18);
// 33902
f693592812_415.returns.push(o20);
// 33914
f693592812_415.returns.push(o23);
// 33922
f693592812_415.returns.push(o25);
// 33959
o1 = {};
// 33960
f693592812_0.returns.push(o1);
// 33961
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 33962
f693592812_395.returns.push(1345562467645);
// 33973
f693592812_415.returns.push(o16);
// 33981
f693592812_415.returns.push(o18);
// 33989
f693592812_415.returns.push(o20);
// 34001
f693592812_415.returns.push(o23);
// 34009
f693592812_415.returns.push(o25);
// 34046
o1 = {};
// 34047
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34055
f693592812_474.returns.push(null);
// 34058
f693592812_495.returns.push(undefined);
// 34060
o1 = {};
// 34061
f693592812_536.returns.push(o1);
// 34062
o1.length = 0;
// undefined
o1 = null;
// 34065
f693592812_475.returns.push(undefined);
// 34066
o1 = {};
// 34067
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34068
f693592812_12.returns.push(143);
// 34069
o1 = {};
// 34070
f693592812_0.returns.push(o1);
// 34071
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34072
f693592812_395.returns.push(1345562468645);
// 34083
f693592812_415.returns.push(o16);
// 34091
f693592812_415.returns.push(o18);
// 34099
f693592812_415.returns.push(o20);
// 34111
f693592812_415.returns.push(o23);
// 34119
f693592812_415.returns.push(o25);
// 34156
o1 = {};
// 34157
f693592812_0.returns.push(o1);
// 34158
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34159
f693592812_395.returns.push(1345562469645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 34164
o1 = {};
// 34165
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34173
f693592812_474.returns.push(null);
// 34176
f693592812_495.returns.push(undefined);
// 34178
o1 = {};
// 34179
f693592812_536.returns.push(o1);
// 34180
o1.length = 0;
// undefined
o1 = null;
// 34183
f693592812_475.returns.push(undefined);
// 34184
o1 = {};
// 34185
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34186
f693592812_12.returns.push(144);
// 34197
f693592812_415.returns.push(o16);
// 34205
f693592812_415.returns.push(o18);
// 34213
f693592812_415.returns.push(o20);
// 34225
f693592812_415.returns.push(o23);
// 34233
f693592812_415.returns.push(o25);
// 34270
o1 = {};
// 34271
f693592812_0.returns.push(o1);
// 34272
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34273
f693592812_395.returns.push(1345562470645);
// 34284
f693592812_415.returns.push(o16);
// 34292
f693592812_415.returns.push(o18);
// 34300
f693592812_415.returns.push(o20);
// 34312
f693592812_415.returns.push(o23);
// 34320
f693592812_415.returns.push(o25);
// 34357
o1 = {};
// 34358
f693592812_0.returns.push(o1);
// 34359
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34360
f693592812_395.returns.push(1345562471645);
// 34361
o1 = {};
// 34362
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34370
f693592812_474.returns.push(null);
// 34373
f693592812_495.returns.push(undefined);
// 34375
o1 = {};
// 34376
f693592812_536.returns.push(o1);
// 34377
o1.length = 0;
// undefined
o1 = null;
// 34380
f693592812_475.returns.push(undefined);
// 34381
o1 = {};
// 34382
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34383
f693592812_12.returns.push(145);
// 34384
o1 = {};
// 34385
f693592812_0.returns.push(o1);
// 34386
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34387
f693592812_395.returns.push(1345562472645);
// 34398
f693592812_415.returns.push(o16);
// 34406
f693592812_415.returns.push(o18);
// 34414
f693592812_415.returns.push(o20);
// 34426
f693592812_415.returns.push(o23);
// 34434
f693592812_415.returns.push(o25);
// 34471
o1 = {};
// 34472
f693592812_0.returns.push(o1);
// 34473
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34474
f693592812_395.returns.push(1345562473645);
// 34485
f693592812_415.returns.push(o16);
// 34493
f693592812_415.returns.push(o18);
// 34501
f693592812_415.returns.push(o20);
// 34513
f693592812_415.returns.push(o23);
// 34521
f693592812_415.returns.push(o25);
// 34558
o1 = {};
// 34559
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34567
f693592812_474.returns.push(null);
// 34570
f693592812_495.returns.push(undefined);
// 34572
o1 = {};
// 34573
f693592812_536.returns.push(o1);
// 34574
o1.length = 0;
// undefined
o1 = null;
// 34577
f693592812_475.returns.push(undefined);
// 34578
o1 = {};
// 34579
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34580
f693592812_12.returns.push(146);
// 34581
o1 = {};
// 34582
f693592812_0.returns.push(o1);
// 34583
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34584
f693592812_395.returns.push(1345562474645);
// 34595
f693592812_415.returns.push(o16);
// 34603
f693592812_415.returns.push(o18);
// 34611
f693592812_415.returns.push(o20);
// 34623
f693592812_415.returns.push(o23);
// 34631
f693592812_415.returns.push(o25);
// 34668
o1 = {};
// 34669
f693592812_0.returns.push(o1);
// 34670
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34671
f693592812_395.returns.push(1345562475645);
// 34682
f693592812_415.returns.push(o16);
// 34690
f693592812_415.returns.push(o18);
// 34698
f693592812_415.returns.push(o20);
// 34710
f693592812_415.returns.push(o23);
// 34718
f693592812_415.returns.push(o25);
// 34755
o1 = {};
// 34756
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34764
f693592812_474.returns.push(null);
// 34767
f693592812_495.returns.push(undefined);
// 34769
o1 = {};
// 34770
f693592812_536.returns.push(o1);
// 34771
o1.length = 0;
// undefined
o1 = null;
// 34774
f693592812_475.returns.push(undefined);
// 34775
o1 = {};
// 34776
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34777
f693592812_12.returns.push(147);
// 34778
o1 = {};
// 34779
f693592812_0.returns.push(o1);
// 34780
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34781
f693592812_395.returns.push(1345562476645);
// 34792
f693592812_415.returns.push(o16);
// 34800
f693592812_415.returns.push(o18);
// 34808
f693592812_415.returns.push(o20);
// 34820
f693592812_415.returns.push(o23);
// 34828
f693592812_415.returns.push(o25);
// 34865
o1 = {};
// 34866
f693592812_0.returns.push(o1);
// 34867
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34868
f693592812_395.returns.push(1345562477645);
// 34879
f693592812_415.returns.push(o16);
// 34887
f693592812_415.returns.push(o18);
// 34895
f693592812_415.returns.push(o20);
// 34907
f693592812_415.returns.push(o23);
// 34915
f693592812_415.returns.push(o25);
// 34952
o1 = {};
// 34953
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34961
f693592812_474.returns.push(null);
// 34964
f693592812_495.returns.push(undefined);
// 34966
o1 = {};
// 34967
f693592812_536.returns.push(o1);
// 34968
o1.length = 0;
// undefined
o1 = null;
// 34971
f693592812_475.returns.push(undefined);
// 34972
o1 = {};
// 34973
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 34974
f693592812_12.returns.push(148);
// 34975
o1 = {};
// 34976
f693592812_0.returns.push(o1);
// 34977
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 34978
f693592812_395.returns.push(1345562478645);
// 34989
f693592812_415.returns.push(o16);
// 34997
f693592812_415.returns.push(o18);
// 35005
f693592812_415.returns.push(o20);
// 35017
f693592812_415.returns.push(o23);
// 35025
f693592812_415.returns.push(o25);
// 35062
o1 = {};
// 35063
f693592812_0.returns.push(o1);
// 35064
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35065
f693592812_395.returns.push(1345562479645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 35070
o1 = {};
// 35071
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35079
f693592812_474.returns.push(null);
// 35082
f693592812_495.returns.push(undefined);
// 35084
o1 = {};
// 35085
f693592812_536.returns.push(o1);
// 35086
o1.length = 0;
// undefined
o1 = null;
// 35089
f693592812_475.returns.push(undefined);
// 35090
o1 = {};
// 35091
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35092
f693592812_12.returns.push(149);
// 35103
f693592812_415.returns.push(o16);
// 35111
f693592812_415.returns.push(o18);
// 35119
f693592812_415.returns.push(o20);
// 35131
f693592812_415.returns.push(o23);
// 35139
f693592812_415.returns.push(o25);
// 35176
o1 = {};
// 35177
f693592812_0.returns.push(o1);
// 35178
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35179
f693592812_395.returns.push(1345562480645);
// 35190
f693592812_415.returns.push(o16);
// 35198
f693592812_415.returns.push(o18);
// 35206
f693592812_415.returns.push(o20);
// 35218
f693592812_415.returns.push(o23);
// 35226
f693592812_415.returns.push(o25);
// 35263
o1 = {};
// 35264
f693592812_0.returns.push(o1);
// 35265
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35266
f693592812_395.returns.push(1345562481645);
// 35267
o1 = {};
// 35268
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35276
f693592812_474.returns.push(null);
// 35279
f693592812_495.returns.push(undefined);
// 35281
o1 = {};
// 35282
f693592812_536.returns.push(o1);
// 35283
o1.length = 0;
// undefined
o1 = null;
// 35286
f693592812_475.returns.push(undefined);
// 35287
o1 = {};
// 35288
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35289
f693592812_12.returns.push(150);
// 35290
o1 = {};
// 35291
f693592812_0.returns.push(o1);
// 35292
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35293
f693592812_395.returns.push(1345562482645);
// 35304
f693592812_415.returns.push(o16);
// 35312
f693592812_415.returns.push(o18);
// 35320
f693592812_415.returns.push(o20);
// 35332
f693592812_415.returns.push(o23);
// 35340
f693592812_415.returns.push(o25);
// 35377
o1 = {};
// 35378
f693592812_0.returns.push(o1);
// 35379
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35380
f693592812_395.returns.push(1345562483645);
// 35391
f693592812_415.returns.push(o16);
// 35399
f693592812_415.returns.push(o18);
// 35407
f693592812_415.returns.push(o20);
// 35419
f693592812_415.returns.push(o23);
// 35427
f693592812_415.returns.push(o25);
// 35464
o1 = {};
// 35465
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35473
f693592812_474.returns.push(null);
// 35476
f693592812_495.returns.push(undefined);
// 35478
o1 = {};
// 35479
f693592812_536.returns.push(o1);
// 35480
o1.length = 0;
// undefined
o1 = null;
// 35483
f693592812_475.returns.push(undefined);
// 35484
o1 = {};
// 35485
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35486
f693592812_12.returns.push(151);
// 35487
o1 = {};
// 35488
f693592812_0.returns.push(o1);
// 35489
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35490
f693592812_395.returns.push(1345562484645);
// 35501
f693592812_415.returns.push(o16);
// 35509
f693592812_415.returns.push(o18);
// 35517
f693592812_415.returns.push(o20);
// 35529
f693592812_415.returns.push(o23);
// 35537
f693592812_415.returns.push(o25);
// 35574
o1 = {};
// 35575
f693592812_0.returns.push(o1);
// 35576
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35577
f693592812_395.returns.push(1345562485645);
// 35588
f693592812_415.returns.push(o16);
// 35596
f693592812_415.returns.push(o18);
// 35604
f693592812_415.returns.push(o20);
// 35616
f693592812_415.returns.push(o23);
// 35624
f693592812_415.returns.push(o25);
// 35661
o1 = {};
// 35662
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35670
f693592812_474.returns.push(null);
// 35673
f693592812_495.returns.push(undefined);
// 35675
o1 = {};
// 35676
f693592812_536.returns.push(o1);
// 35677
o1.length = 0;
// undefined
o1 = null;
// 35680
f693592812_475.returns.push(undefined);
// 35681
o1 = {};
// 35682
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35683
f693592812_12.returns.push(152);
// 35684
o1 = {};
// 35685
f693592812_0.returns.push(o1);
// 35686
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35687
f693592812_395.returns.push(1345562486645);
// 35698
f693592812_415.returns.push(o16);
// 35706
f693592812_415.returns.push(o18);
// 35714
f693592812_415.returns.push(o20);
// 35726
f693592812_415.returns.push(o23);
// 35734
f693592812_415.returns.push(o25);
// 35771
o1 = {};
// 35772
f693592812_0.returns.push(o1);
// 35773
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35774
f693592812_395.returns.push(1345562487645);
// 35785
f693592812_415.returns.push(o16);
// 35793
f693592812_415.returns.push(o18);
// 35801
f693592812_415.returns.push(o20);
// 35813
f693592812_415.returns.push(o23);
// 35821
f693592812_415.returns.push(o25);
// 35858
o1 = {};
// 35859
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35867
f693592812_474.returns.push(null);
// 35870
f693592812_495.returns.push(undefined);
// 35872
o1 = {};
// 35873
f693592812_536.returns.push(o1);
// 35874
o1.length = 0;
// undefined
o1 = null;
// 35877
f693592812_475.returns.push(undefined);
// 35878
o1 = {};
// 35879
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35880
f693592812_12.returns.push(153);
// 35881
o1 = {};
// 35882
f693592812_0.returns.push(o1);
// 35883
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35884
f693592812_395.returns.push(1345562488645);
// 35895
f693592812_415.returns.push(o16);
// 35903
f693592812_415.returns.push(o18);
// 35911
f693592812_415.returns.push(o20);
// 35923
f693592812_415.returns.push(o23);
// 35931
f693592812_415.returns.push(o25);
// 35968
o1 = {};
// 35969
f693592812_0.returns.push(o1);
// 35970
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 35971
f693592812_395.returns.push(1345562489645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 35976
o1 = {};
// 35977
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35985
f693592812_474.returns.push(null);
// 35988
f693592812_495.returns.push(undefined);
// 35990
o1 = {};
// 35991
f693592812_536.returns.push(o1);
// 35992
o1.length = 0;
// undefined
o1 = null;
// 35995
f693592812_475.returns.push(undefined);
// 35996
o1 = {};
// 35997
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 35998
f693592812_12.returns.push(154);
// 36009
f693592812_415.returns.push(o16);
// 36017
f693592812_415.returns.push(o18);
// 36025
f693592812_415.returns.push(o20);
// 36037
f693592812_415.returns.push(o23);
// 36045
f693592812_415.returns.push(o25);
// 36082
o1 = {};
// 36083
f693592812_0.returns.push(o1);
// 36084
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36085
f693592812_395.returns.push(1345562490645);
// 36096
f693592812_415.returns.push(o16);
// 36104
f693592812_415.returns.push(o18);
// 36112
f693592812_415.returns.push(o20);
// 36124
f693592812_415.returns.push(o23);
// 36132
f693592812_415.returns.push(o25);
// 36169
o1 = {};
// 36170
f693592812_0.returns.push(o1);
// 36171
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36172
f693592812_395.returns.push(1345562491645);
// 36173
o1 = {};
// 36174
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36182
f693592812_474.returns.push(null);
// 36185
f693592812_495.returns.push(undefined);
// 36187
o1 = {};
// 36188
f693592812_536.returns.push(o1);
// 36189
o1.length = 0;
// undefined
o1 = null;
// 36192
f693592812_475.returns.push(undefined);
// 36193
o1 = {};
// 36194
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36195
f693592812_12.returns.push(155);
// 36196
o1 = {};
// 36197
f693592812_0.returns.push(o1);
// 36198
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36199
f693592812_395.returns.push(1345562492645);
// 36210
f693592812_415.returns.push(o16);
// 36218
f693592812_415.returns.push(o18);
// 36226
f693592812_415.returns.push(o20);
// 36238
f693592812_415.returns.push(o23);
// 36246
f693592812_415.returns.push(o25);
// 36283
o1 = {};
// 36284
f693592812_0.returns.push(o1);
// 36285
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36286
f693592812_395.returns.push(1345562493645);
// 36297
f693592812_415.returns.push(o16);
// 36305
f693592812_415.returns.push(o18);
// 36313
f693592812_415.returns.push(o20);
// 36325
f693592812_415.returns.push(o23);
// 36333
f693592812_415.returns.push(o25);
// 36370
o1 = {};
// 36371
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36379
f693592812_474.returns.push(null);
// 36382
f693592812_495.returns.push(undefined);
// 36384
o1 = {};
// 36385
f693592812_536.returns.push(o1);
// 36386
o1.length = 0;
// undefined
o1 = null;
// 36389
f693592812_475.returns.push(undefined);
// 36390
o1 = {};
// 36391
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36392
f693592812_12.returns.push(156);
// 36393
o1 = {};
// 36394
f693592812_0.returns.push(o1);
// 36395
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36396
f693592812_395.returns.push(1345562494645);
// 36407
f693592812_415.returns.push(o16);
// 36415
f693592812_415.returns.push(o18);
// 36423
f693592812_415.returns.push(o20);
// 36435
f693592812_415.returns.push(o23);
// 36443
f693592812_415.returns.push(o25);
// 36480
o1 = {};
// 36481
f693592812_0.returns.push(o1);
// 36482
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36483
f693592812_395.returns.push(1345562495645);
// 36494
f693592812_415.returns.push(o16);
// 36502
f693592812_415.returns.push(o18);
// 36510
f693592812_415.returns.push(o20);
// 36522
f693592812_415.returns.push(o23);
// 36530
f693592812_415.returns.push(o25);
// 36567
o1 = {};
// 36568
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36576
f693592812_474.returns.push(null);
// 36579
f693592812_495.returns.push(undefined);
// 36581
o1 = {};
// 36582
f693592812_536.returns.push(o1);
// 36583
o1.length = 0;
// undefined
o1 = null;
// 36586
f693592812_475.returns.push(undefined);
// 36587
o1 = {};
// 36588
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36589
f693592812_12.returns.push(157);
// 36590
o1 = {};
// 36591
f693592812_0.returns.push(o1);
// 36592
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36593
f693592812_395.returns.push(1345562496645);
// 36604
f693592812_415.returns.push(o16);
// 36612
f693592812_415.returns.push(o18);
// 36620
f693592812_415.returns.push(o20);
// 36632
f693592812_415.returns.push(o23);
// 36640
f693592812_415.returns.push(o25);
// 36677
o1 = {};
// 36678
f693592812_0.returns.push(o1);
// 36679
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36680
f693592812_395.returns.push(1345562497645);
// 36691
f693592812_415.returns.push(o16);
// 36699
f693592812_415.returns.push(o18);
// 36707
f693592812_415.returns.push(o20);
// 36719
f693592812_415.returns.push(o23);
// 36727
f693592812_415.returns.push(o25);
// 36764
o1 = {};
// 36765
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36773
f693592812_474.returns.push(null);
// 36776
f693592812_495.returns.push(undefined);
// 36778
o1 = {};
// 36779
f693592812_536.returns.push(o1);
// 36780
o1.length = 0;
// undefined
o1 = null;
// 36783
f693592812_475.returns.push(undefined);
// 36784
o1 = {};
// 36785
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36786
f693592812_12.returns.push(158);
// 36787
o1 = {};
// 36788
f693592812_0.returns.push(o1);
// 36789
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36790
f693592812_395.returns.push(1345562498645);
// 36801
f693592812_415.returns.push(o16);
// 36809
f693592812_415.returns.push(o18);
// 36817
f693592812_415.returns.push(o20);
// 36829
f693592812_415.returns.push(o23);
// 36837
f693592812_415.returns.push(o25);
// 36874
o1 = {};
// 36875
f693592812_0.returns.push(o1);
// 36876
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36877
f693592812_395.returns.push(1345562499645);
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// undefined
fo693592812_1_cookie.returns.push("k=10.36.33.117.1345562126928519; guest_id=v1%3A134556212694094198; original_referer=4bfz%2B%2BmebEkRkMWFCXm%2FCUOsvDoVeFTl; js=1");
// 36882
o1 = {};
// 36883
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36891
f693592812_474.returns.push(null);
// 36894
f693592812_495.returns.push(undefined);
// 36896
o1 = {};
// 36897
f693592812_536.returns.push(o1);
// 36898
o1.length = 0;
// undefined
o1 = null;
// 36901
f693592812_475.returns.push(undefined);
// 36902
o1 = {};
// 36903
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 36904
f693592812_12.returns.push(159);
// 36915
f693592812_415.returns.push(o16);
// 36923
f693592812_415.returns.push(o18);
// 36931
f693592812_415.returns.push(o20);
// 36943
f693592812_415.returns.push(o23);
// 36951
f693592812_415.returns.push(o25);
// 36988
o1 = {};
// 36989
f693592812_0.returns.push(o1);
// 36990
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 36991
f693592812_395.returns.push(1345562500645);
// 36992
o1 = {};
// 36993
o1.type = "mousemove";
// 36994
o1.jQuery17109642799841240048 = void 0;
// 36998
o1.defaultPrevented = "false";
// 36999
o1.returnValue = "true";
// 37000
o1.getPreventDefault = void 0;
// 37001
o1.timeStamp = 1345562500824;
// 37002
o1.toElement = o15;
// 37003
o1.screenY = 325;
// 37004
o1.screenX = 482;
// 37005
o1.pageY = 99;
// 37006
o1.pageX = 9;
// 37007
o1.offsetY = 99;
// 37008
o1.offsetX = 9;
// 37009
o1.fromElement = null;
// 37010
o1.clientY = 99;
// 37011
o1.clientX = 9;
// 37012
o1.buttons = void 0;
// 37013
o1.button = 0;
// 37014
o1.which = 0;
// 37015
o1.view = ow693592812;
// 37017
o1.target = o15;
// 37018
o1.shiftKey = "false";
// 37019
o1.relatedTarget = null;
// 37020
o1.metaKey = "false";
// 37021
o1.eventPhase = 3;
// 37022
o1.currentTarget = o0;
// 37023
o1.ctrlKey = "false";
// 37024
o1.cancelable = "false";
// 37025
o1.bubbles = "true";
// 37026
o1.altKey = "false";
// 37027
o1.srcElement = o15;
// 37028
o1.relatedNode = void 0;
// 37029
o1.attrName = void 0;
// 37030
o1.attrChange = void 0;
// undefined
o1 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37107
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37116
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37125
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37134
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37143
f693592812_523.returns.push(undefined);
// 37144
f693592812_15.returns.push(undefined);
// 37145
o1 = {};
// 37146
f693592812_0.returns.push(o1);
// 37147
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 37148
f693592812_395.returns.push(1345562500846);
// 37149
f693592812_12.returns.push(160);
// 37150
o1 = {};
// 37151
o1.type = "scroll";
// 37152
o1.jQuery17109642799841240048 = void 0;
// 37156
o1.defaultPrevented = "false";
// 37157
o1.returnValue = "true";
// 37158
o1.getPreventDefault = void 0;
// 37159
o1.timeStamp = 1345562501335;
// 37160
o1.which = void 0;
// 37161
o1.view = void 0;
// 37163
o1.target = o0;
// 37164
o1.shiftKey = void 0;
// 37165
o1.relatedTarget = void 0;
// 37166
o1.metaKey = void 0;
// 37167
o1.eventPhase = 3;
// 37168
o1.currentTarget = ow693592812;
// 37169
o1.ctrlKey = void 0;
// 37170
o1.cancelable = "false";
// 37171
o1.bubbles = "true";
// 37172
o1.altKey = void 0;
// 37173
o1.srcElement = o0;
// 37174
o1.relatedNode = void 0;
// 37175
o1.attrName = void 0;
// 37176
o1.attrChange = void 0;
// undefined
o1 = null;
// 37188
f693592812_415.returns.push(o16);
// 37196
f693592812_415.returns.push(o18);
// 37204
f693592812_415.returns.push(o20);
// 37216
f693592812_415.returns.push(o23);
// 37224
f693592812_415.returns.push(o25);
// 37269
o12.scrollHeight = 579;
// 37271
o8.scrollHeight = 579;
// 37273
o12.offsetHeight = 525;
// 37275
o8.offsetHeight = 525;
// undefined
o8 = null;
// 37276
o1 = {};
// 37277
f693592812_0.returns.push(o1);
// 37278
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 37279
f693592812_395.returns.push(1345562501846);
// 37280
f693592812_13.returns.push(161);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37290
f693592812_487.returns.push(undefined);
// 37293
f693592812_487.returns.push(undefined);
// 37296
f693592812_487.returns.push(undefined);
// 37299
f693592812_487.returns.push(undefined);
// 37302
f693592812_487.returns.push(undefined);
// 37303
o1 = {};
// 37304
o1.type = "mousewheel";
// 37305
o1.jQuery17109642799841240048 = void 0;
// 37309
o1.defaultPrevented = "false";
// 37310
o1.returnValue = "true";
// 37311
o1.getPreventDefault = void 0;
// 37312
o1.timeStamp = 1345562502284;
// 37313
o1.which = 0;
// 37314
o1.view = ow693592812;
// 37316
o1.target = o15;
// 37317
o1.shiftKey = "false";
// 37318
o1.relatedTarget = void 0;
// 37319
o1.metaKey = "false";
// 37320
o1.eventPhase = 3;
// 37321
o1.currentTarget = o0;
// 37322
o1.ctrlKey = "false";
// 37323
o1.cancelable = "true";
// 37324
o1.bubbles = "true";
// 37325
o1.altKey = "false";
// 37326
o1.srcElement = o15;
// undefined
o15 = null;
// 37327
o1.relatedNode = void 0;
// 37328
o1.attrName = void 0;
// 37329
o1.attrChange = void 0;
// undefined
o1 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37404
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37413
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37422
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37431
f693592812_523.returns.push(undefined);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37440
f693592812_523.returns.push(undefined);
// 37441
f693592812_15.returns.push(undefined);
// 37442
o1 = {};
// 37443
f693592812_0.returns.push(o1);
// 37444
o1.getTime = f693592812_395;
// undefined
o1 = null;
// 37445
f693592812_395.returns.push(1345562502309);
// 37446
f693592812_12.returns.push(162);
// 37447
o1 = {};
// 37448
o1.type = "scroll";
// 37449
o1.jQuery17109642799841240048 = void 0;
// 37453
o1.defaultPrevented = "false";
// 37454
o1.returnValue = "true";
// 37455
o1.getPreventDefault = void 0;
// 37456
o1.timeStamp = 1345562502311;
// 37457
o1.which = void 0;
// 37458
o1.view = void 0;
// 37460
o1.target = o0;
// 37461
o1.shiftKey = void 0;
// 37462
o1.relatedTarget = void 0;
// 37463
o1.metaKey = void 0;
// 37464
o1.eventPhase = 3;
// 37465
o1.currentTarget = ow693592812;
// 37466
o1.ctrlKey = void 0;
// 37467
o1.cancelable = "false";
// 37468
o1.bubbles = "true";
// 37469
o1.altKey = void 0;
// 37470
o1.srcElement = o0;
// 37471
o1.relatedNode = void 0;
// 37472
o1.attrName = void 0;
// 37473
o1.attrChange = void 0;
// undefined
o1 = null;
// 37475
o1 = {};
// 37476
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 37484
f693592812_474.returns.push(null);
// 37487
f693592812_495.returns.push(undefined);
// 37489
o1 = {};
// 37490
f693592812_536.returns.push(o1);
// 37491
o1.length = 0;
// undefined
o1 = null;
// 37494
f693592812_475.returns.push(undefined);
// 37495
o1 = {};
// 37496
f693592812_0.returns.push(o1);
// undefined
o1 = null;
// 37497
f693592812_12.returns.push(163);
// 37523
f693592812_415.returns.push(o16);
// undefined
o16 = null;
// 37531
f693592812_415.returns.push(o18);
// undefined
o18 = null;
// 37539
f693592812_415.returns.push(o20);
// undefined
o20 = null;
// 37551
f693592812_415.returns.push(o23);
// undefined
o23 = null;
// 37559
f693592812_415.returns.push(o25);
// undefined
o25 = null;
// 37596
o1 = {};
// 37597
o1.type = "keydown";
// 37598
o1.jQuery17109642799841240048 = void 0;
// 37602
o1.defaultPrevented = "false";
// 37603
o1.returnValue = "true";
// 37604
o1.getPreventDefault = void 0;
// 37605
o1.timeStamp = 1345562502795;
// 37606
o1.keyCode = 17;
// 37607
o1.key = void 0;
// 37608
o1.charCode = 0;
// 37609
o1.char = void 0;
// 37610
o1.which = 17;
// 37611
o1.view = ow693592812;
// 37613
o1.target = o12;
// 37614
o1.shiftKey = "false";
// 37615
o1.relatedTarget = void 0;
// 37616
o1.metaKey = "false";
// 37617
o1.eventPhase = 3;
// 37618
o1.currentTarget = o0;
// undefined
o0 = null;
// 37619
o1.ctrlKey = "true";
// 37620
o1.cancelable = "true";
// 37621
o1.bubbles = "true";
// 37622
o1.altKey = "false";
// 37623
o1.srcElement = o12;
// 37624
o1.relatedNode = void 0;
// 37625
o1.attrName = void 0;
// 37626
o1.attrChange = void 0;
// undefined
o1 = null;
// undefined
fo693592812_1_jQuery17109642799841240048.returns.push(1);
// 37632
// 0
JSBNG_Replay$ = function(real, cb) { if (!real) return;
// 819
geval("JSBNG__document.domain = \"twitter.com\";\nJSBNG__document.startTime = new JSBNG__Date().getTime();\nvar twttr = {\n};\ntwttr.versionName = \"phoenix\";\ntwttr.isT1 = true;\ntwttr.didPingKeynote = false;\ntwttr.keynoteTTFTPing = function() {\n    if (((!twttr.didPingKeynote && ((window.JSBNG__location.href.indexOf(\"keynoteTest\") > 0))))) {\n        var image = JSBNG__document.createElement(\"img\");\n        image.src = \"/images/keynote.gif\";\n        twttr.didPingKeynote = true;\n    }\n;\n;\n};\n((window.JSBNG__console || function() {\n    var a = [\"log\",\"debug\",\"info\",\"warn\",\"error\",\"assert\",\"dir\",\"dirxml\",\"group\",\"groupEnd\",\"time\",\"timeEnd\",\"count\",\"trace\",\"profile\",\"profileEnd\",];\n    window.JSBNG__console = {\n    };\n    for (var b = 0; ((b < a.length)); ++b) {\n        window.JSBNG__console[a[b]] = function() {\n        \n        };\n    ;\n    };\n;\n}()));\ntwttr.griffin = {\n    current: [\"olympics\",\"nascar\",\"euro2012\",]\n};\ntwttr.griffin.euroTerms = [];\n((twttr.griffin || (twttr.griffin = {\n    current: []\n}))), twttr.griffin.isEvent = function(a) {\n    if (!a) {\n        return !1;\n    }\n;\n;\n    a = a.replace(/^#|\\/$/g, \"\").toLowerCase();\n    for (var b = 0; ((b < twttr.griffin.current.length)); b++) {\n        if (((a == twttr.griffin.current[b]))) {\n            return a;\n        }\n    ;\n    ;\n    };\n;\n    return !1;\n}, twttr.griffin.redirectIfEvent = function(a, b) {\n    var a = twttr.griffin.isEvent(a);\n    if (a) {\n        var c = ((JSBNG__document.referrer || \"none\")), d = [\"ev_\",b,\"_\",a,\"=\",c,\"; path=/\",].join(\"\");\n        return JSBNG__document.cookie = d, window.JSBNG__location.replace(((\"/hashtag/\" + a))), !0;\n    }\n;\n;\n    return !1;\n}, twttr.griffin.isEuroSearchTakeover = function(a) {\n    if (((!twttr.griffin.euroTerms || !a))) {\n        return !1;\n    }\n;\n;\n    ((((a && ((a.substr(0, 1) == \"#\")))) && (a = a.substr(1)))), a = a.toLowerCase();\n    for (var b = 0; ((b < twttr.griffin.euroTerms.length)); b++) {\n        if (((a == twttr.griffin.euroTerms[b]))) {\n            return !0;\n        }\n    ;\n    ;\n    };\n;\n    return !1;\n}, twttr.griffin.redirectOnSearch = function(a) {\n    return (($.cookie(((\"noReroute_\" + a))) ? !1 : twttr.griffin.redirectIfEvent(a, \"takeover\")));\n}, twttr.griffin.setNoRedirectOnSearch = function(a, b) {\n    if (!twttr.griffin.isEvent(a)) {\n        return;\n    }\n;\n;\n    var c = ((b ? !0 : null));\n    $.cookie(((\"noReroute_\" + a)), c);\n};\nif (((((window.JSBNG__location.pathname == \"/\")) && ((window.JSBNG__location.hash != \"\"))))) {\n    var hash = window.JSBNG__location.hash.substr(1).toLowerCase();\n    twttr.griffin.redirectIfEvent(hash, \"redir\");\n}\n;\n;\n;");
// 830
geval("(function() {\n    window.JSBNG__setTimeout = window.JSBNG__setTimeout, window.JSBNG__setInterval = window.JSBNG__setInterval, window.WATCH = function(a, b) {\n        ((((typeof b == \"undefined\")) && (b = a, a = undefined))), ((((typeof a == \"string\")) && (WATCH._didExecute[a] = !0))), WATCH._attempt(this, b);\n    }, WATCH._didExecute = {\n    }, WATCH._reportCount = 0, WATCH._reportLimit = 25, WATCH._reportInterval = 60000, WATCH._active = !1, WATCH.activate = function(a) {\n        ((((typeof a == \"undefined\")) && (a = !0))), WATCH._active = a, extend(WATCH, ((WATCH._active ? WATCH.actives : WATCH.inactives)));\n    }, WATCH.actives = {\n    }, WATCH.inactives = {\n    };\n    var extend = function(a, b) {\n        for (var c in b) {\n            a[c] = b[c];\n        ;\n        };\n    ;\n    }, noop = function() {\n    \n    };\n    WATCH._attempt = function(a, b) {\n        ((((arguments.length < 2)) && (b = a, a = window)));\n        if (WATCH._active) {\n            try {\n                b.apply(a);\n            } catch (c) {\n                WATCH._triggerError(c);\n            };\n        }\n         else {\n            b.apply(a);\n        }\n    ;\n    ;\n    }, WATCH.inactives.end = noop, WATCH.actives.end = function(a) {\n        if (((typeof a == \"undefined\"))) {\n            throw new Error(\"WATCH.end() requires a label\");\n        }\n    ;\n    ;\n        ((WATCH._didExecute[a] ? WATCH._didExecute[a] = !1 : ((WATCH._active && WATCH._triggerError(new Error(((((((((\"WATCH.end(\\\"\" + a)) + \"\\\") called without successful call to WATCH(\\\"\")) + a)) + \"\\\", fn(){...}) - a SyntaxError probably just happened\")))))))), WATCH._didExecute[a] = !1;\n    }, WATCH.inactives.callback = function(a, b) {\n        return ((((typeof b == \"undefined\")) ? a : b));\n    }, WATCH.actives.callback = function(that, callback) {\n        ((((arguments.length === 1)) && (callback = that, that = this))), ((((typeof callback == \"string\")) && (callback = function(stringVersion) {\n            return function() {\n                eval(stringVersion);\n            };\n        }(callback))));\n        var watchedCallback = function() {\n            var a = this, b = arguments, c;\n            return WATCH._attempt(function() {\n                c = callback.apply(a, b);\n            }), c;\n        };\n        return watchedCallback.isWatched = !0, watchedCallback;\n    }, WATCH._onErrorCallbacks = {\n    }, WATCH.inactives._addOnError = noop, WATCH.actives._addOnError = function(a) {\n        var b = WATCH._unique();\n        return WATCH._onErrorCallbacks[b] = a, b;\n    }, WATCH.inactives._removeOnError = noop, WATCH.actives._removeOnError = function(a) {\n        delete WATCH._onErrorCallbacks[a];\n    }, WATCH._lastUnique = -1, WATCH._unique = function() {\n        return ++WATCH._lastUnique;\n    }, WATCH.inactives.jQuery = noop, WATCH.actives.jQuery = function() {\n        WATCH._originalJQueryEventAdd = ((WATCH._originalJQueryEventAdd || jQuery.JSBNG__event.add)), jQuery.JSBNG__event.add = function() {\n            var a = Array.prototype.slice.call(arguments);\n            return ((((typeof a[2] == \"function\")) ? a[2] = WATCH.callback(a[2]) : ((((((a && ((typeof a[2] == \"object\")))) && a[2].handler)) && (a[2].handler = WATCH.callback(a[2].handler)))))), WATCH._originalJQueryEventAdd.apply(this, a);\n        }, WATCH._originalJQueryAjax = ((WATCH._originalJQueryAjax || jQuery.ajax)), jQuery.ajax = function(a) {\n            return jQuery.each([\"complete\",\"error\",\"success\",], function(b, c) {\n                if (!a[c]) {\n                    return;\n                }\n            ;\n            ;\n                a[c] = WATCH.callback(a[c]);\n            }), WATCH._originalJQueryAjax.apply(this, arguments);\n        };\n    }, WATCH.inactives.undoJQuery = noop, WATCH.actives.undoJQuery = function() {\n        jQuery.JSBNG__event.add = WATCH._originalJQueryEventAdd, jQuery.ajax = WATCH._originalJQueryAjax;\n    }, WATCH._previousErrors = {\n    };\n    var escapeDoubleQuotes = function(a) {\n        return a.toString().replace(\"\\\"\", \"\\\\\\\"\");\n    }, stringifyLite = function(a) {\n        var b = \"{\", c = !1;\n        for (var d in a) {\n            if (((((typeof a[d] == \"undefined\")) || ((a[d] === null))))) {\n                continue;\n            }\n        ;\n        ;\n            b += ((((((((((c ? \",\\\"\" : \"\\\"\")) + escapeDoubleQuotes(d))) + \"\\\":\\\"\")) + escapeDoubleQuotes(a[d]))) + \"\\\"\")), c = !0;\n        };\n    ;\n        return ((b + \"}\"));\n    };\n    WATCH._scribeError = function(a) {\n        if (((WATCH._previousErrors[a.error] && ((((new JSBNG__Date - WATCH._previousErrors[a.error])) < WATCH._reportInterval))))) {\n            return !1;\n        }\n    ;\n    ;\n        if (((WATCH.reportLimit <= WATCH.reportCount))) {\n            return;\n        }\n    ;\n    ;\n        WATCH.reportCount++;\n        if (!JSBNG__document.JSBNG__location.hostname.match(/(^(www|api)\\.)?twitter\\.com$/)) {\n            return;\n        }\n    ;\n    ;\n        WATCH._previousErrors[a.error] = new JSBNG__Date, a.product_name = \"webclient\", a.type = \"js_error\", a.url = window.JSBNG__location.href, a.event_name = \"test\";\n        var b = ((JSBNG__document.JSBNG__location.hostname.match(/(^(www|api|staging\\d+.local)\\.)twitter\\.com$/) != null)), c = ((b ? \"scribe.twitter.com\" : window.JSBNG__location.host)), d = ((((((window.JSBNG__location.protocol.match(/s\\:$/) ? \"https\" : \"http\")) + \"://\")) + c));\n        d += ((b ? \"/\" : \"/scribe\")), d += ((((((\"?category=client_watch_error&log=\" + encodeURIComponent(stringifyLite(a)))) + \"&ts=\")) + (new JSBNG__Date).getTime())), (new JSBNG__Image).src = d;\n    }, WATCH._triggerError = function(a) {\n        var b = !0, c = {\n            error: a\n        };\n        for (var d in WATCH._onErrorCallbacks) {\n            try {\n                ((((WATCH._onErrorCallbacks[d](c) === !1)) && (b = !1)));\n            } catch (e) {\n                c.callbackFailure = !0;\n            };\n        ;\n        };\n    ;\n        WATCH._scribeError(c);\n        if (b) {\n            throw a;\n        }\n    ;\n    ;\n    }, WATCH.inactives.natives = noop, WATCH.actives.natives = function() {\n        window.JSBNG__setInterval = WATCH._watchedSetInterval, window.JSBNG__setTimeout = WATCH._watchedSetTimeout;\n    }, WATCH.inactives.undoNatives = noop, WATCH.actives.undoNatives = function() {\n        window.JSBNG__setInterval = WATCH._originalSetInterval, window.JSBNG__setTimeout = WATCH._originalSetTimeout;\n    }, WATCH._originalSetInterval = window.JSBNG__setInterval, WATCH._originalSetTimeout = window.JSBNG__setTimeout, WATCH._watchedSetInterval = function(a, b) {\n        var c = WATCH._originalSetInterval;\n        return c(WATCH.callback(a), b);\n    }, WATCH._watchedSetTimeout = function(a, b) {\n        var c = WATCH._originalSetTimeout;\n        return c(WATCH.callback(a), b);\n    }, WATCH.activate(!1);\n})();");
// 831
geval("");
// 832
geval("function bust() {\n    JSBNG__document.write = \"\";\n    window.JSBNG__top.JSBNG__location = window.JSBNG__self.JSBNG__location;\n    JSBNG__setTimeout(function() {\n        JSBNG__document.body.innerHTML = \"\";\n    }, 0);\n    window.JSBNG__self.JSBNG__onload = function(evt) {\n        JSBNG__document.body.innerHTML = \"\";\n    };\n};\n;\nif (((window.JSBNG__top !== window.JSBNG__self))) {\n    try {\n        if (window.JSBNG__top.JSBNG__location.host) {\n        \n        }\n         else {\n            bust();\n        }\n    ;\n    ;\n    } catch (ex) {\n        bust();\n    };\n;\n}\n;\n;");
// 833
geval("(function() {\n    var a = JSBNG__document.getElementsByTagName(\"html\")[0], b = window.JSBNG__location.hash.split(\"?\")[0], c = ((b.match(/#/) && ((b.replace(/#[!]?[\\/]?/, \"\") !== \"\"))));\n    ((c ? a.className += \" remove-prerendered-content\" : (a.className += \" use-prerendered-content\", ((a.getAttribute(\"data-nav-highlight-class-name\") && (a.className += ((\" \" + a.getAttribute(\"data-nav-highlight-class-name\")))))))));\n})();");
// 843
geval("var _gaq = ((_gaq || []));\n_gaq.push([\"_setAccount\",\"UA-30775-6\",], [\"_trackPageview\",], [\"_setDomainName\",\"twitter.com\",]), twttr.didInsertGA = !1, twttr.insertGAScriptElement = function() {\n    if (!twttr.didInsertGA) {\n        var a = JSBNG__document.getElementsByTagName(\"script\")[0], b = JSBNG__document.createElement(\"script\");\n        b.async = !0, b.src = ((((((JSBNG__document.JSBNG__location.protocol == \"https:\")) ? \"http://jsbngssl.ssl\" : \"http://www\")) + \".google-analytics.com/ga.js\")), a.parentNode.insertBefore(b, a), twttr.didInsertGA = !0;\n    }\n;\n;\n}, twttr.trackPageView = function(a) {\n    var b = [\"_trackPageview\",];\n    ((a && b.push(a))), _gaq.push(b);\n};");
// 844
geval("WATCH(\"loadrunner\", function() {\n    (function(a, b) {\n        function u(a) {\n            for (var b = 1, c; c = arguments[b]; b++) {\n                for (var d in c) {\n                    a[d] = c[d];\n                ;\n                };\n            ;\n            };\n        ;\n            return a;\n        };\n    ;\n        function v(a) {\n            return Array.prototype.slice.call(a);\n        };\n    ;\n        function x(a, b) {\n            for (var c = 0, d; d = a[c]; c++) {\n                if (((b == d))) {\n                    return c;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        };\n    ;\n        function y() {\n            var a = v(arguments), b = [];\n            for (var c = 0, d = a.length; ((c < d)); c++) {\n                ((((a[c].length > 0)) && b.push(a[c].replace(/\\/$/, \"\"))));\n            ;\n            };\n        ;\n            return b.join(\"/\");\n        };\n    ;\n        function z(a, b, c) {\n            var d = b.split(\"/\"), e = a;\n            while (((d.length > 1))) {\n                var f = d.shift();\n                e = e[f] = ((e[f] || {\n                }));\n            };\n        ;\n            e[d[0]] = c;\n        };\n    ;\n        function A() {\n        \n        };\n    ;\n        function B(a, b) {\n            ((a && (this.id = this.path = this.resolvePath(a)))), this.force = !!b;\n        };\n    ;\n        function C(a, b) {\n            this.id = a, this.body = b, ((((typeof b == \"undefined\")) && (this.path = this.resolvePath(a))));\n        };\n    ;\n        function D(a) {\n            var b = [];\n            for (var c = 0, d; d = a[c]; c++) {\n                ((((d instanceof F)) ? b = b.concat(D(d.deps)) : ((((d instanceof C)) && b.push(d)))));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function E(a) {\n            this.deps = a, ((((this.deps.length == 0)) && this.complete()));\n        };\n    ;\n        function F(a) {\n            this.deps = a;\n        };\n    ;\n        function G() {\n            for (var a in d) {\n                if (((d[a].readyState == \"interactive\"))) {\n                    return m[d[a].id];\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function H(a, b) {\n            var d;\n            return ((((!a && c)) && (d = ((l || G()))))), ((d ? (delete m[d.scriptId], d.body = b, d.execute()) : (k = d = new C(a, b), j[d.id] = d))), d;\n        };\n    ;\n        function I() {\n            var a = v(arguments), b, c;\n            return ((((typeof a[0] == \"string\")) && (b = a.shift()))), c = a.shift(), H(b, c);\n        };\n    ;\n        function J(a, b) {\n            var c = ((b.id || \"\")), d = c.split(\"/\");\n            d.pop();\n            var e = d.join(\"/\");\n            return a.replace(/^\\./, e);\n        };\n    ;\n        function K(a, b) {\n            function d(a) {\n                return C.exports[J(a, b)];\n            };\n        ;\n            var c = [];\n            for (var e = 0, f = a.length; ((e < f)); e++) {\n                if (((a[e] == \"require\"))) {\n                    c.push(d);\n                    continue;\n                }\n            ;\n            ;\n                if (((a[e] == \"exports\"))) {\n                    b.exports = ((b.exports || {\n                    })), c.push(b.exports);\n                    continue;\n                }\n            ;\n            ;\n                c.push(d(a[e]));\n            };\n        ;\n            return c;\n        };\n    ;\n        function L() {\n            var a = v(arguments), b = [], c, d;\n            ((((typeof a[0] == \"string\")) && (c = a.shift()))), ((w(a[0]) && (b = a.shift()))), d = a.shift();\n            var e = H(c, function(a) {\n                function f() {\n                    var c = K(v(b), e), f;\n                    ((((typeof d == \"function\")) ? f = d.apply(e, c) : f = d)), ((((typeof f == \"undefined\")) && (f = e.exports))), a(f);\n                };\n            ;\n                var c = [];\n                for (var g = 0, i = b.length; ((g < i)); g++) {\n                    var j = b[g];\n                    ((((x([\"require\",\"exports\",], j) == -1)) && c.push(J(j, e))));\n                };\n            ;\n                ((((c.length > 0)) ? M.apply(this, c.concat(f)) : f()));\n            });\n            return e;\n        };\n    ;\n        function M() {\n            var a = v(arguments), b;\n            ((((typeof a[((a.length - 1))] == \"function\")) && (b = a.pop())));\n            var c = new E(N(a));\n            return ((b && c.then(b))), c;\n        };\n    ;\n        function N(a) {\n            var b = [];\n            for (var c = 0, d; d = a[c]; c++) {\n                ((((typeof d == \"string\")) && (d = O(d)))), ((w(d) && (d = new F(N(d))))), b.push(d);\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function O(a) {\n            var b, c;\n            for (var d = 0, e; e = M.matchers[d]; d++) {\n                var f = e[0], g = e[1];\n                if (b = a.match(f)) {\n                    return g(a);\n                }\n            ;\n            ;\n            };\n        ;\n            throw new Error(((a + \" was not recognised by loader\")));\n        };\n    ;\n        function Q() {\n            return a.using = n, a.provide = o, a.define = p, a.loadrunner = q, P;\n        };\n    ;\n        function S(a) {\n            if (((typeof R[a] != \"undefined\"))) {\n                return R[a];\n            }\n        ;\n        ;\n            for (var b = 0; ((b < M.bundles.length)); b++) {\n                for (var c in M.bundles[b]) {\n                    if (((((c != a)) && ((x(M.bundles[b][c], a) > -1))))) {\n                        return R[a] = c, c;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            return R[a] = a, a;\n        };\n    ;\n        var c = ((a.JSBNG__attachEvent && !a.JSBNG__opera)), d = b.getElementsByTagName(\"script\"), e = 0, f, g = b.createElement(\"script\"), i = {\n        }, j = {\n        }, k, l, m = {\n        }, n = a.using, o = a.provide, p = a.define, q = a.loadrunner, r = {\n        };\n        for (var s = 0, t; t = d[s]; s++) {\n            if (t.src.match(/loadrunner\\.js(\\?|#|$)/)) {\n                f = t;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        var w = ((Array.isArray || function(a) {\n            return ((a.constructor == Array));\n        }));\n        A.prototype.then = function(b) {\n            var c = this;\n            return ((this.started || (this.started = !0, this.start()))), ((this.completed ? b.apply(a, this.results) : (this.callbacks = ((this.callbacks || [])), this.callbacks.push(b)))), this;\n        }, A.prototype.start = function() {\n        \n        }, A.prototype.complete = function() {\n            if (!this.completed) {\n                this.results = v(arguments), this.completed = !0;\n                if (this.callbacks) {\n                    for (var b = 0, c; c = this.callbacks[b]; b++) {\n                        c.apply(a, this.results);\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }, B.loaded = [], B.times = {\n        }, B.prototype = new A, B.prototype.resolvePath = function(a) {\n            return S(a);\n        }, B.prototype.start = function() {\n            var a = this, b, c;\n            return (((c = j[this.id]) ? (c.then(function() {\n                a.complete();\n            }), this) : ((((b = i[this.id]) ? b.then(function() {\n                a.loaded();\n            }) : ((((!this.force && ((x(B.loaded, this.id) > -1)))) ? this.loaded() : this.load())))), this)));\n        }, B.prototype.createScriptTag = function() {\n            var b = this, c;\n            i[this.id] = b, (((c = r[this.path]) && b.then(function() {\n                for (var a = 0, b; b = c[a]; a++) {\n                    b.complete.apply(b, arguments);\n                ;\n                };\n            ;\n            }))), this.times = {\n                start: new JSBNG__Date\n            };\n            var f = g.cloneNode(!1);\n            this.scriptId = f.id = ((\"LR\" + ++e)), f.type = \"text/javascript\", f.async = !0, f.JSBNG__onerror = function() {\n                throw new Error(((b.path + \" not loaded\")));\n            }, f.JSBNG__onreadystatechange = f.JSBNG__onload = function(c) {\n                c = ((a.JSBNG__event || c));\n                if (((((c.type == \"load\")) || ((x([\"loaded\",\"complete\",], this.readyState) > -1))))) {\n                    this.JSBNG__onreadystatechange = null, b.loaded();\n                }\n            ;\n            ;\n            }, f.src = this.path, l = this, d[0].parentNode.insertBefore(f, d[0]), l = null, m[f.id] = this;\n        }, B.prototype.queueScript = function() {\n            r[this.path] = ((r[this.path] || [])), r[this.path].push(this);\n        }, B.prototype.load = function(a) {\n            return ((((M.autoLoad || a)) ? this.createScriptTag() : this.queueScript())), this;\n        }, B.prototype.loaded = function() {\n            this.complete();\n        }, B.prototype.complete = function() {\n            ((((x(B.loaded, this.id) == -1)) && B.loaded.push(this.id))), ((this.times && (B.times[this.id] = u(this.times, {\n                end: new JSBNG__Date\n            })))), delete i[this.id], A.prototype.complete.apply(this, arguments);\n        }, C.exports = {\n        }, C.prototype = new B, C.prototype.resolvePath = function(a) {\n            return ((((S(a) != a)) ? S(a) : y(M.path, ((a + \".js\")))));\n        }, C.prototype.start = function() {\n            var a, b, c = this, d;\n            ((this.body ? this.execute() : (((a = C.exports[this.id]) ? this.exp(a) : (((b = j[this.id]) ? b.then(function(a) {\n                c.exp(a);\n            }) : (j[this.id] = this, this.load())))))));\n        }, C.prototype.loaded = function() {\n            var a, b, d = this;\n            ((c ? (((b = C.exports[this.id]) ? this.exp(b) : (((a = j[this.id]) && a.then(function(a) {\n                d.exp(a);\n            }))))) : (a = k, k = null, a.id = ((a.id || this.id)), a.then(function(a) {\n                d.exp(a);\n            }))));\n        }, C.prototype.complete = function() {\n            delete j[this.id], B.prototype.complete.apply(this, arguments);\n        }, C.prototype.execute = function() {\n            var a = this;\n            ((((typeof this.body == \"object\")) ? this.exp(this.body) : ((((typeof this.body == \"function\")) && this.body.apply(window, [function(b) {\n                a.exp(b);\n            },])))));\n        }, C.prototype.exp = function(a) {\n            ((this.times && u(this.times, {\n                eval: new JSBNG__Date\n            }))), this.complete(this.exports = C.exports[this.id] = ((a || {\n            })));\n        }, E.prototype = new A, E.prototype.start = function() {\n            function b() {\n                var b = [];\n                for (var c = 0, d; d = a.deps[c]; c++) {\n                    if (!d.completed) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((d.results.length > 0)) && (b = b.concat(d.results))));\n                };\n            ;\n                a.complete.apply(a, b);\n            };\n        ;\n            var a = this;\n            for (var c = 0, d; d = this.deps[c]; c++) {\n                d.then(b);\n            ;\n            };\n        ;\n            return this;\n        }, E.prototype.load = function() {\n            for (var a = 0, b; b = this.deps[a]; a++) {\n                ((b.load && b.load(!0)));\n            ;\n            };\n        ;\n            return this;\n        }, E.prototype.as = function(a) {\n            var b = this;\n            return this.then(function() {\n                var c = D(b.deps), d = {\n                };\n                for (var e = 0, f; f = c[e]; e++) {\n                    z(d, f.id, arguments[e]);\n                ;\n                };\n            ;\n                a.apply(this, [d,].concat(v(arguments)));\n            });\n        }, F.prototype = new A, F.prototype.start = function() {\n            var a = this, b = 0, c = [];\n            return function d() {\n                var e = a.deps[b++];\n                ((e ? e.then(function(a) {\n                    ((((e.results.length > 0)) && (c = c.concat(e.results)))), d();\n                }) : a.complete.apply(a, c)));\n            }(), this;\n        }, F.prototype.load = function() {\n            var a = this, b = 0;\n            return function c() {\n                var d = a.deps[b++];\n                ((((d && d.load)) && d.load(!0).then(function() {\n                    c();\n                })));\n            }(), this;\n        }, L.amd = {\n        };\n        var P = function(a) {\n            return a(M, I, P, L);\n        };\n        P.Script = B, P.Module = C, P.Collection = E, P.Sequence = F, P.Dependency = A, P.noConflict = Q, a.loadrunner = P, a.using = M, a.provide = I, a.define = L, M.path = \"\", M.autoLoad = !0, M.bundles = [];\n        var R = {\n        };\n        M.matchers = [], M.matchers.add = function(a, b) {\n            this.unshift([a,b,]);\n        }, M.matchers.add(/(^script!|\\.js$)/, function(a) {\n            var b = new B(a.replace(/^\\$/, ((M.path.replace(/\\/$/, \"\") + \"/\"))).replace(/^script!/, \"\"), !1);\n            return b.id = a, b;\n        }), M.matchers.add(/^[a-zA-Z0-9_\\-\\/]+$/, function(a) {\n            return new C(a);\n        }), ((f && (M.path = ((((f.getAttribute(\"data-path\") || f.src.split(/loadrunner\\.js/)[0])) || \"\")), (((main = f.getAttribute(\"data-main\")) && M.apply(a, main.split(/\\s*,\\s*/)).then(function() {\n        \n        }))))));\n    })(this, JSBNG__document);\n    loadrunner(function(a, b, c, d) {\n        function e(a) {\n            this.id = this.path = a;\n        };\n    ;\n        e.inProgress = [], e.done = [], e.prototype = new c.Dependency, e.prototype.start = function() {\n            var a = this, b;\n            (((b = e.done[this.id]) ? this.complete(b.result) : (((b = e.inProgress[this.id]) ? b.then(function() {\n                a.complete(b.result);\n            }) : (e.inProgress[this.id] = this, this.load())))));\n        }, e.prototype.load = function() {\n            var a, b = this;\n            if (window.JSBNG__XMLHttpRequest) {\n                a = new window.JSBNG__XMLHttpRequest;\n            }\n             else {\n                try {\n                    a = new window.ActiveXObject(\"Microsoft.XMLHTTP\");\n                } catch (c) {\n                    return new Error(\"XHR not found.\");\n                };\n            }\n        ;\n        ;\n            a.JSBNG__onreadystatechange = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74), function() {\n                ((((a.readyState == 4)) && (b.result = a.responseText, e.done[b.id] = b, delete e.inProgress[b.id], b.complete(b.result))));\n            })), a.open(\"GET\", this.path, !0), a.send(null);\n        }, a.matchers.add(/^json!/, function(a) {\n            return new e(a.substring(5));\n        });\n    });\n    loadrunner(function(a, b, c, d) {\n        function e(a) {\n            this.id = this.path = a;\n        };\n    ;\n        e.inProgress = [], e.done = [], e.prototype = new c.Dependency, e.prototype.start = function() {\n            var a = this, b;\n            (((b = e.done[this.id]) ? this.complete(b.result) : (((b = e.inProgress[this.id]) ? b.then(function() {\n                a.complete(b.result);\n            }) : (e.inProgress[this.id] = this, this.load())))));\n        }, e.prototype.load = function() {\n            var b = this;\n            a(\"lib/lazyload\", function(a) {\n                function c() {\n                    e.done[b.id] = b, delete e.inProgress[b.id], b.complete();\n                };\n            ;\n                (((($(((((\"link[href='\" + b.path)) + \"']\"))).length > 0)) ? c() : a.css(b.path, c)));\n            });\n        }, a.matchers.add(/^css!/, function(b) {\n            var c;\n            return b = b.replace(/^css!/, \"\"), c = /^(https?:)?\\/\\//.test(b), new e(b.replace(/^\\//, ((((((!c && a.cssPath)) || \"\")).replace(/\\/$/, \"\") + \"/\"))));\n        });\n    });\n    loadrunner(function(a, b, c, d) {\n        function e(a, b) {\n            for (var c = 0, d; d = a[c]; c++) {\n                if (((b == d))) {\n                    return c;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        };\n    ;\n        function f(a) {\n            var b;\n            ((((a.charAt(0) == \"\\u003E\")) && (a = a.substring(1))));\n            if (b = g.inProgress[a]) {\n                b.complete(), delete g.inProgress[a];\n            }\n        ;\n        ;\n            g.done.push(a);\n        };\n    ;\n        var g = function(a) {\n            this.id = a;\n        };\n        g.inProgress = [], g.done = [], g.prototype = new c.Dependency, g.prototype.start = function() {\n            var a, b = this;\n            ((((e(g.done, this.id) != -1)) ? this.complete() : (((a = g.inProgress[this.id]) ? a.then(function() {\n                b.complete();\n            }) : g.inProgress[this.id] = this))));\n        }, a.matchers.add(/^>/, function(a) {\n            return new g(a.substring(1));\n        }), window.signal = f;\n    });\n});");
// 884
geval("WATCH.end(\"loadrunner\");");
// 885
geval("WATCH(\"javascript_logged_out\", function() {\n    function miniScribe(eName, more, cat) {\n        var log = [], cat = ((cat || \"client_event\")), more = ((more || {\n        }));\n        more.event_name = eName;\n        for (var k in more) {\n            log.push(((((((((\"\\\"\" + k)) + \"\\\":\\\"\")) + more[k])) + \"\\\"\")));\n        };\n    ;\n    ;\n        (new JSBNG__Image()).src = ((((((((((\"//scribe.twitter.com/scribe?category=\" + encodeURIComponent(cat))) + \"&log=\")) + encodeURIComponent(((((\"{\" + log.join(\",\"))) + \"}\"))))) + \"&ts=\")) + (+new JSBNG__Date)));\n    };\n;\n    (function() {\n        function a(a, b) {\n            var c = ((a.tagName ? a : JSBNG__document.getElementById(a)));\n            return ((b ? c.getElementsByTagName(b) : c));\n        };\n    ;\n        function b(a, b, c) {\n            for (var d = ((a.length - 1)); ((d >= 0)); d--) {\n                var e = a[d].className, f = ((e && e.match(b)));\n                ((f && c.call(a[d], f[1])));\n            };\n        ;\n        };\n    ;\n        function c(a, b) {\n            return a.className = a.className.replace(((\" \" + b)), \"\");\n        };\n    ;\n        function d(a, b) {\n            return a.className = ((((c(a, b) + \" \")) + b));\n        };\n    ;\n        function l() {\n            var a = !!JSBNG__navigator.cookieEnabled;\n            if (((((typeof JSBNG__navigator.cookieEnabled == \"undefined\")) || ((JSBNG__navigator.appName == \"Microsoft Internet Explorer\"))))) {\n                JSBNG__document.cookie = \"cookies_enabled\", a = ((JSBNG__document.cookie.indexOf(\"cookies_enabled\") != -1));\n            }\n        ;\n        ;\n            return a;\n        };\n    ;\n        function m(a) {\n            var b, c, d, e = JSBNG__document.cookie.split(\";\");\n            for (b = 0; ((b < e.length)); b++) {\n                c = e[b].substr(0, e[b].indexOf(\"=\")), d = e[b].substr(((e[b].indexOf(\"=\") + 1))), c = c.replace(/^\\s+|\\s+$/g, \"\");\n                if (((c == a))) {\n                    return unescape(d);\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        };\n    ;\n        var e = JSBNG__document.body, f = JSBNG__document.getElementById(\"doc\"), g;\n        ((JSBNG__location.href.match(/#!\\/./) ? (((g = JSBNG__location.href.match(/#!?\\/(login|download)(\\/|$)/)) && d(f, ((\"route-\" + g[1]))))) : (c(e, \"user-style-twttr loading-body\"), d(e, \"front-page\"), ((JSBNG__document.body.className.match(/front-image-nascar/) ? miniScribe(\"web:front:::impression\", {\n            context: \"olympics\"\n        }) : miniScribe(\"web:front:::impression\", {\n            context: \"front\"\n        }))), window._scribedFrontImpression = !0)));\n        var i = a(f, \"div\"), j = \"hasome\";\n        b(i, /holding/, function() {\n            var b = this, e = a(b, \"input\")[0], f = a(b, \"span\")[0];\n            ((((e && f)) && (f.JSBNG__onclick = function() {\n                e.JSBNG__focus();\n            }, e.JSBNG__onblur = function() {\n                ((e.value.length || c(b, j)));\n            }, e.JSBNG__onkeydown = function(a) {\n                JSBNG__setTimeout(function() {\n                    ((((((a && ((a.keyCode === 8)))) || e.value.length)) ? d(b, j) : c(b, j)));\n                }, 0);\n            })));\n        }), window.JSBNG__setInterval(function() {\n            b(i, /holding/, function() {\n                var b = a(this, \"input\")[0];\n                ((((b && b.value.length)) && d(this, j)));\n            });\n        }, 1111);\n        var k = {\n            signin: \"web:front:login_callout:form:login_click\",\n            signup: \"web:front:signup_callout:form:signup_click\",\n            search: \"web:front:main:search_field:search\",\n            language: \"web:front:footer:language_selector:select\"\n        };\n        b(i, /js-front-(signin|signup|search|language)/, function(b) {\n            var c = a(this, \"form\"), d = k[b];\n            ((((c && c[0])) && (c[0].JSBNG__onsubmit = function() {\n                ((a(f).className.match(\"route-front\") || miniScribe(d)));\n            })));\n        }), ((l() || (JSBNG__document.getElementById(\"front-no-cookies-warn\").style.display = \"block\")));\n        var n = !!JSBNG__document.getElementById(\"remember_default_checked\"), o = m(\"remember_checked\"), p = ((((o == \"1\")) || ((((o == null)) && n)))), q, r = JSBNG__document.getElementsByName(\"remember_me\");\n        for (q = 0; ((q < r.length)); q++) {\n            r[q].checked = p;\n        ;\n        };\n    ;\n    })();\n});");
// 1163
geval("WATCH.end(\"javascript_logged_out\");");
// 1164
geval("WATCH(\"boot\", function() {\n    using.cssPath = \"http://a0.twimg.com/a/1345479106/\";\n    using.path = \"http://a0.twimg.com/a/1345479106/phoenix/js\";\n    using.autoLoad = false;\n    provide(\"boot/init\", function(a) {\n        function c(a) {\n            for (var b in a) {\n                ((a.hasOwnProperty(b) && (twttr[b] = a[b])));\n            ;\n            };\n        ;\n        };\n    ;\n        function d(a) {\n            ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data process start\"))), c(a.twttr), signal(\"\\u003Epayload\"), ((a.boomr && using(a.boomr.js).load().then(function() {\n                delete BOOMR.plugins.RT, BOOMR.init({\n                    allow_ssl: !0,\n                    autorun: !1,\n                    user_ip: twttr.remoteIP,\n                    BW: {\n                        base_url: a.boomr.base_url\n                    }\n                }), using(\"\\u003EsetupComplete\", \"util\").as(function(b) {\n                    JSBNG__setTimeout(BOOMR.page_ready, 10000), BOOMR.subscribe(\"before_beacon\", function(c) {\n                        if (!c.bw) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = parseInt(((c.bw / 1024)), 10), e = parseInt(((((c.bw_err * 100)) / c.bw)), 10), f = parseInt(((((c.lat_err * 100)) / c.lat)), 10);\n                        scribble(\"measurement\", {\n                            load_time_ms: c.t_done,\n                            bandwidth_kbytes: d,\n                            bandwidth_error_percent: e,\n                            latency_ms: c.lat,\n                            latency_error_percent: f,\n                            product: \"webclient\",\n                            base_url: a.boomr.base_url\n                        }, \"boomerang\"), ((b.util.params().boomr && twttr.showMessage(((((((((((((((\"Bandwidth: \" + b.util.addCommas(d))) + \" KB/s &plusmn; \")) + e)) + \"%\\u003Cbr /\\u003ELatency: \")) + c.lat)) + \" ms &plusmn; \")) + c.lat_err)), !0)));\n                    });\n                });\n            }))), ((a.countryCode && (twttr.countryCode = a.countryCode)));\n            if (a.countries) {\n                twttr.countries = a.countries;\n                if (twttr.countryCode) {\n                    for (var b = 0, d = twttr.countries.length; ((b < d)); b++) {\n                        ((((twttr.countries[b].code == twttr.countryCode)) && (twttr.countries[b].selected = !0)));\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((a.pageLocaleJS ? (((twttr.bootTimings && twttr.bootTimings.add(\"i18n fetch start\"))), using(a.pageLocaleJS).load().then(function() {\n                ((twttr.bootTimings && twttr.bootTimings.add(\"i18n fetch finish\"))), signal(\"\\u003ElanguageData\");\n            })) : signal(\"\\u003ElanguageData\"))), using(\"\\u003EdefaultViews\", twttr.bundleMore, function() {\n                ((a.showWelcomeBanner && (new twttr.views.WelcomeToPhoenixBanner).render($(\"#banners\"), \"append\"))), ((a.flashNotice && twttr.showMessage(a.flashNotice, !0)));\n            }), using(\"\\u003Edecider\", function() {\n                twttr.decider._updateFeatures(a.deciderFeatures, !0), signal(\"\\u003EdeciderFeaturesFromBootstrap\");\n            }), using(\"\\u003Eab_decider\", function() {\n                twttr.abdecider._updateExperiments(a.abBuckets, !0);\n            }), using(\"\\u003Eapi_ready\", function() {\n                twttr.API.setConfig({\n                    postAuthenticityToken: a.postAuthenticityToken\n                }), $(\"input.authenticity_token\").val(a.postAuthenticityToken), ((twttr.decider.isAvailable(\"add_authenticity_token_via_js\") && $(\"input[name=authenticity_token]\").val(a.postAuthenticityToken)));\n                var b = a.requestCacheSeedData;\n                for (var c = 0, d = b.length; ((c < d)); ++c) {\n                    var e = b[c];\n                    twttr.API._requestCache.inject(e.api_request_name, e.options, e.json, 1);\n                };\n            ;\n                signal(\"\\u003Erequest_cache_seeded\"), ((a.homeTimelineFetchSize && (twttr.API.homeTimelineFetchSize = a.homeTimelineFetchSize)));\n            }), ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data process finish\")));\n        };\n    ;\n        function e() {\n            ((twttr.loggedIn ? (((twttr.bootTimings && twttr.bootTimings.add(\"initCurrentUser start\"))), using(\"boot/bootstrap_data\", \"\\u003Erequest_cache_seeded\", function(a) {\n                twttr.API.User.current({\n                    error: function() {\n                        window.JSBNG__location.reload(!0);\n                    },\n                    success: function(b) {\n                        twttr.currentUser = b;\n                        for (var c in a.userProperties) {\n                            twttr.currentUser.sync(c, ((a.userProperties[c] || !1)));\n                        ;\n                        };\n                    ;\n                        twttr.API.User.bind(\"update\", function(a, b) {\n                            if (((twttr.currentUser.id == b.id))) {\n                                var c = [\"JSBNG__name\",\"url\",\"JSBNG__location\",\"description\",];\n                                for (var d = 0; ((d < c.length)); ++d) {\n                                    twttr.currentUser.sync(c[d], b[c[d]]);\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                        }), ((twttr.bootTimings && twttr.bootTimings.add(\"initCurrentUser finish\"))), signal(\"\\u003EallCurrentUserDataLoaded\");\n                    }\n                });\n            })) : signal(\"\\u003EallCurrentUserDataLoaded\")));\n        };\n    ;\n        function f(a) {\n            var b = new JSBNG__Date;\n            using(a).load().then(function() {\n                var a = new JSBNG__Date;\n                using(\"boot/bootstrap_data\", function() {\n                    twttr.Profiler.logPreviousEvent(\"twttr.bundles fetched\", b, a);\n                });\n            });\n        };\n    ;\n        function g(a) {\n            function c() {\n                ((b || JSBNG__setTimeout(function() {\n                    twttr.keynoteTTFTPing(), b = !0, a();\n                }, 0)));\n            };\n        ;\n            function d() {\n                JSBNG__setTimeout(c, 0);\n            };\n        ;\n            function f() {\n                e.JSBNG__onresize = null, d();\n            };\n        ;\n            var b = !1, e = JSBNG__document.getElementById(\"stream-items-id\");\n            if (!e) {\n                a();\n                return;\n            }\n        ;\n        ;\n            if (((e.clientHeight > 0))) {\n                d();\n                return;\n            }\n        ;\n        ;\n            e.JSBNG__onresize = f;\n        };\n    ;\n        function i(a) {\n            for (var b in a) {\n                return !1;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function j(a) {\n            function d() {\n                JSBNG__clearTimeout(c), $(b).remove(), twttr.app.recalculatePadding();\n            };\n        ;\n            function e() {\n                b.style.display = \"block\", JSBNG__setTimeout(function() {\n                    b.style.height = \"46px\";\n                });\n            };\n        ;\n            if (!a) {\n                return;\n            }\n        ;\n        ;\n            var b = JSBNG__document.getElementById(\"slow-load-banner\");\n            if (!b) {\n                return;\n            }\n        ;\n        ;\n            var c;\n            c = JSBNG__setTimeout(e, a), ((twttr.bundleCore && using(twttr.bundleCore, d)));\n        };\n    ;\n        var b = {\n            add: function(a, b) {\n                ((b || (b = new JSBNG__Date))), twttr.bootTimings.data.push({\n                    JSBNG__name: a,\n                    timestamp: b\n                });\n            },\n            data: [],\n            done: function() {\n                twttr.bootTimings.add = twttr.bootTimings.done = $.noop, $.each(loadrunner.Script.times, function(a, b) {\n                    $.each(b, function(b, c) {\n                        twttr.bootTimings.data.push({\n                            JSBNG__name: [\"bundle\",a,b,].join(\" \"),\n                            timestamp: c\n                        });\n                    });\n                }), twttr.Profiler.logDataSet(\"Boot\", twttr.appStartTime, twttr.bootTimings.data), twttr.bootTimings = null;\n            }\n        };\n        a({\n            init: function(a) {\n                if (a.renderedOnServer) {\n                    var k = JSBNG__document.getElementsByTagName(\"html\")[0], l = k.className.match(/highlight-global-nav-([a-z]+)/);\n                    if (((a.twttr.loggedIn && l))) {\n                        var m = ((\"global-nav-\" + l[1]));\n                        JSBNG__document.getElementById(m).className += \" active\";\n                    }\n                     else if (k.className.match(/remove-prerendered-content/)) {\n                        JSBNG__document.getElementById(\"page-outer\").className = JSBNG__document.getElementById(\"page-outer\").className.replace(\"flush-to-top\", \"\");\n                        var n = JSBNG__document.getElementById(\"page-container\");\n                        n.className = n.className.replace(\"home-container\", \"\"), n.innerHTML = \"\", signal(\"\\u003EwokeUp\"), a.renderedOnServer = !1;\n                    }\n                    \n                ;\n                ;\n                    k.className = k.className.replace(\"use-prerendered-content\", \"\").replace(\"remove-prerendered-content\", \"\"), ((k.getAttribute(\"data-nav-highlight-class-name\") && (k.className = k.className.replace(k.getAttribute(\"data-nav-highlight-class-name\"), \"\"), k.removeAttribute(\"data-nav-highlight-class-name\"))));\n                }\n            ;\n            ;\n                if (a.disablePhoenix) {\n                    j(a.loadTimeoutInterval);\n                    return;\n                }\n            ;\n            ;\n                c(a.twttr), twttr.appStartTime = JSBNG__document.startTime, twttr.geo = ((twttr.geo || {\n                })), twttr.session = ((twttr.session || {\n                })), twttr.session.impressionId = ((twttr.appStartTime + Math.JSBNG__random())), twttr.isLocalhost = JSBNG__location.hostname.match(/localhost\\.twitter\\.com/);\n                if (twttr.allScribeEvents) {\n                    try {\n                        twttr.allScribeEvents = ((JSON.parse(JSBNG__localStorage.twttrAllScribeEvents) || []));\n                    } catch (o) {\n                        twttr.allScribeEvents = [];\n                    };\n                }\n            ;\n            ;\n                twttr.bootTimings = ((a.profiling ? b : null));\n                for (var p = 0; ((p < a.loadrunnerAssets.length)); p++) {\n                    using.bundles.push(a.loadrunnerAssets[p]);\n                ;\n                };\n            ;\n                ((((((a.loadrunnerAssets.length == 1)) && i(a.loadrunnerAssets[0]))) && (using.autoLoad = !0))), j(a.loadTimeoutInterval), twttr.proto = window.JSBNG__location.protocol.replace(\":\", \"\"), twttr.isSSL = function() {\n                    return ((twttr.proto === \"https\"));\n                }, twttr.createIframe = function(a, b) {\n                    var c = JSBNG__document.createElement(\"div\");\n                    c.innerHTML = ((((\"\\u003Cdiv tabindex=\\\"-1\\\" role=\\\"presentation\\\" style=\\\"position:absolute;top:-9999px;\\\" src=\\\"\" + a)) + \"\\\"\\u003E\\u003C/div\\u003E\"));\n                    var d = c.firstChild, e = function() {\n                        b.apply(d, arguments);\n                    };\n                    return ((d.JSBNG__addEventListener ? d.JSBNG__addEventListener(\"load\", e, !1) : d.JSBNG__attachEvent(\"JSBNG__onload\", e))), JSBNG__document.body.insertBefore(d, JSBNG__document.body.firstChild), d;\n                }, ((a.inline_bootstrap_data || provide(\"boot/bootstrap_data\", function(a) {\n                    var b = [];\n                    b.push(((((((((\"json!/account/bootstrap_data\" + window.JSBNG__location.search)) + ((window.JSBNG__location.search ? \"&\" : \"?\")))) + \"r=\")) + Math.JSBNG__random()))), ((((typeof JSON == \"undefined\")) && b.push(twttr.bundleCore))), ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data fetch start\"))), using(b, function(b) {\n                        ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data fetch finish\")));\n                        var c = JSON.parse(b);\n                        a(c);\n                    });\n                }))), f(a.assets), using(twttr.bundleCore, function() {\n                    twttr.anywhere.remote = {\n                    }, using(\"bluejs/api\", function(a) {\n                        twttr.API = a, twttr.API.setConfig({\n                            cacheObjects: !0,\n                            includeEntities: !0\n                        }), twttr.extendAPI(), signal(\"\\u003Eapi_ready\"), using(\"\\u003Erequest_cache_seeded\", function() {\n                            e();\n                        });\n                    });\n                }), using(a.setupDependencies, function() {\n                    ((twttr.bootTimings && twttr.bootTimings.add(\"setup start\"))), jQuery.ready(), jQuery.fx.interval = 50, twttr.setup(a.renderedOnServer), ((twttr.bootTimings && twttr.bootTimings.add(\"setup finish\"))), signal(\"\\u003EsetupComplete\");\n                    var b = function() {\n                        using(twttr.bundleMore).load();\n                    };\n                    (((($.browser.msie && ((parseInt($.browser.version, 10) <= 8)))) ? g(b) : b()));\n                }), using(twttr.bundleMore, function() {\n                    signal(\"\\u003EallCodeLoaded\");\n                }), using(\"boot/bootstrap_data\", d), twttr.createIframe(a.pReceiverURL, function() {\n                    var a = this;\n                    using(twttr.bundleCore, function() {\n                        twttr.anywhere.remote.server = a, twttr.anywhere.api.util.RemoteRequest.flush();\n                    });\n                });\n            }\n        });\n    });\n    using(\"boot/init\", function(boot) {\n        var data = {\n            assets: [\"bundle/t1-core\",],\n            sandboxes: {\n                jsonp: \"http://a0.twimg.com/a/1345479106/jsonp_sandbox.html\",\n                detailsPaneContent: \"http://a0.twimg.com/a/1345479106/details_pane_content_sandbox.html\"\n            },\n            renderedOnServer: true,\n            loadrunnerAssets: [{\n                \"http://a0.twimg.com/c/phoenix/en/bundle/ie6.d71f8de82c7cddee6a11aa7aa093031396c8e9bf.js\": [\"bundle/ie6\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/sandbox.46298132d415b0168f1b1626bc148c99a6496dcc.js\": [\"bundle/sandbox\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-core.cff52d0363daa50776332252b9ef769a2fbda0a4.js\": [\"bundle/t1-core\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-hogan-more.864d58ff5bd506f67e89f2afc518ea78c42aa0b1.js\": [\"bundle/t1-hogan-more\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-more.7152802a7d535e74c7338f5254308d61bce6e545.js\": [\"bundle/t1-more\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/signup.193171e43f7c3caa12329ea028e723413019576b.js\": [\"bundle/signup\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-hogan-core.da31cb481a235c68052dc0329e13f6a1aef9c31e.js\": [\"bundle/t1-hogan-core\",]\n            },],\n            twttr: {\n                loggedIn: false,\n                expando: false,\n                isT1: true,\n                placeDataPrefix: \"http://geo.l3.twitter.com/places/autocomplete_places-\",\n                hasHoversInCss: true,\n                remoteIP: \"117.213.94.4\",\n                isRTL: false,\n                requestFullCity: \"in,25,madras\",\n                bundleCore: \"bundle/t1-core\",\n                deciderOverrides: {\n                },\n                domains: {\n                    local: \"twitter.com\",\n                    upload: \"upload.twitter.com\",\n                    remote: \"api.twitter.com\"\n                },\n                bundleMore: \"bundle/t1-more\",\n                hosts: {\n                    local: \"http://twitter.com\",\n                    upload: \"http://upload.twitter.com\",\n                    remote: \"http://api.twitter.com\"\n                }\n            },\n            pReceiverURL: \"http://api.twitter.com/receiver.html\",\n            setupDependencies: [\"\\u003EallCurrentUserDataLoaded\",\"\\u003Erequest_cache_seeded\",\"bundle/t1-core\",\"\\u003ElanguageData\",],\n            profiling: false,\n            inline_bootstrap_data: false,\n            disablePhoenix: false,\n            loadTimeoutInterval: 10000\n        };\n        boot.init(data);\n    });\n});");
// 1251
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o11,o22);
// undefined
o22 = null;
// 1253
geval("WATCH.end(\"boot\");");
// 1256
o11.readyState = 2;
// 1255
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o11,o36);
// undefined
o36 = null;
// 1259
o11.readyState = 3;
// 1258
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o11,o37);
// undefined
o37 = null;
// 1262
o11.readyState = 4;
// 1264
o14.length = 26;
// undefined
o14 = null;
// 1261
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o11,o38);
// undefined
o11 = null;
// undefined
o38 = null;
// 6835
o12.firstChild = o31;
// undefined
o12 = null;
// undefined
o31 = null;
// 8842
o9["0"] = o7;
// undefined
o9 = null;
// undefined
o7 = null;
// 1513
geval("provide(\"/account/templates_t1_core.js\", function(exports) {\n    if (!twttr.isMockview) {\n        var __hogan_opts = {\n            sectionTags: [{\n                o: \"_i\",\n                c: \"i\"\n            },],\n            disableLambda: true\n        };\n        twttr.provide(\"twttr.templates\", {\n            activity_modal: \"\\u003Cdiv id='activity-modal' style='display: none'\\u003E\\u000a  \\u003Cdiv class='left-pointer'\\u003E\\u003C/div\\u003E\\u000a  \\u003Ca class='dismiss' title=\\\"Hide\\\"\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Cp class='header'\\u003E\\u003Cspan class='new'\\u003ENew!\\u003C/span\\u003E Activity and @{{current_user_screen_name}}\\u003C/p\\u003E\\u000a  \\u003Cp class='desc'\\u003E\\u000a      View favorites, follows, retweets and more by people you follow in \\u003Cstrong\\u003EActivity\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a  \\u003Cp class='extra-blurb desc'\\u003E\\u000a    View your mentions, tweets that were retweeted and more in \\u003Cstrong\\u003E@{{current_user_screen_name}}\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            bg_img_css: \"\\u000a\\u003Cstyle id=\\\"user-style-{{screen_name}}-bg-img\\\" class=\\\"js-user-style-bg-img\\\"\\u003E\\u000a  body.user-style-{{screen_name}} {\\u000a    {{#is_vit_layout}}\\u000a      {{^is_mobile}}\\u000a      background-color: #3c8fc9;\\u000a      {{/is_mobile}}\\u000a      {{#is_mobile}}\\u000a      background-color: #e2e2e2;\\u000a      {{/is_mobile}}\\u000a    {{/is_vit_layout}}\\u000a    {{^is_vit_layout}}\\u000a      {{#profile_use_background_image}}\\u000a        {{#profile_background_image_url}}\\u000a          background-image: url({{profile_background_image_url}});\\u000a        {{/profile_background_image_url}}\\u000a      {{/profile_use_background_image}}\\u000a    {{/is_vit_layout}}\\u000a  }\\u000a\\u003C/style\\u003E\\u000a\",\n            details_pane: \"\\u003Cdiv class=\\\"inner-pane\\\"\\u003E\\u000a  \\u003Cdiv class='pane-toolbar pane-built-in'\\u003E\\u000a    {{#popable}}\\u000a      \\u003Ca class='pane-back toolbar-control' href='#'\\u003E\\u003Cspan\\u003E&larr;\\u003C/span\\u003E {{back_label}}\\u003C/a\\u003E\\u000a    {{/popable}}\\u000a    {{#closable}}\\u000a      \\u003Ca class='pane-close toolbar-control' href='#'\\u003Eclose \\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a    {{/closable}}\\u000a    \\u003Cbr style='clear: both' /\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"pane-components\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"pane-components-inner\\\"\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            details_pane_container: \"\\u003Cdiv id=\\\"details-pane-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"details-pane-shell\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"details-pane\\\"\\u003E\\u000a      {{{pane}}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            home_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    \\u003Cdiv class=\\\"page-header home-header\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"main-tweet-box\\\"\\u003E\\u000a        {{\\u003Eposting_tweet_box}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-home {{#active_tab_home}}active{{/active_tab_home}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='All you follow' href=\\\"{{index_path}}\\\"\\u003ETimeline\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        {{#decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-your_activity {{#active_tab_your_activity}}active{{/active_tab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='@{{current_user_screen_name}}' href=\\\"{{your_activity_path}}\\\"\\u003E@{{current_user_screen_name}}\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Activity' href=\\\"{{activity_path}}\\\"\\u003EActivity\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        {{^decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-mentions {{#active_tab_mentions}}active{{/active_tab_mentions}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Mentions' href=\\\"{{mentions_path}}\\\"\\u003E@Mentions\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-retweets dropdown-link {{#active_tab_retweets}}active{{/active_tab_retweets}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ERetweets\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-searches dropdown-link {{#active_tab_searches}}active{{/active_tab_searches}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ESearches\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-lists dropdown-link {{#active_tab_lists}}active{{/active_tab_lists}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ELists\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a        {{#decider_network_discovery}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-discovery activity-subtabs {{#active_tab_network_discovery}}active{{/active_tab_network_discovery}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Discover' href=\\\"{{discovery_path}}\\\"\\u003EDiscover\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_network_discovery}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#decider_activity_read}}\\u000a      {{#activity_subtabs}}\\u000a        \\u003Cul class=\\\"stream-subtabs stream-subtabs-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-your_activity {{#active_subtab_your_activity}}active{{/active_subtab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{your_activity_path}}\\\"\\u003Eabout you\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-separator\\\"\\u003E&middot;\\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-activity {{#active_subtab_activity}}active{{/active_subtab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{activity_path}}\\\"\\u003Eby people you follow\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a      {{/activity_subtabs}}\\u000a    {{/decider_activity_read}}\\u000a    {{\\u003Estream_manager}}\\u000a    {{#rendering_on_server}}\\u003Cscript\\u003Etwttr.tweetsVisibleTime = new Date();if (window.ttft) window.ttft.serverRendered('home');twttr.keynoteTTFTPing();\\u003C/script\\u003E{{/rendering_on_server}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#current_user}}\\u000a      {{\\u003Ehome_dashboard}}\\u000a    {{/current_user}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            message_drawer: \"\\u003Cdiv class=\\\"message {{^rendering_on_server}}{{type}}{{/rendering_on_server}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"message-inside\\\"\\u003E\\u000a    \\u003Cspan class=\\\"message-text\\\"\\u003E{{{text}}}\\u003C/span\\u000a    \\u003E{{#close_button}}\\u003Ca class=\\\"dismiss\\\" href=\\\"#\\\"\\u003E&times;\\u003C/a\\u003E{{/close_button}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            message_notification: \"{{#message}}\\u000a\\u003Cdiv data-sender-id='{{sender_screen_name}}' data-message-id=\\\"{{id}}\\\" class='notification'\\u003E\\u000a  \\u003Ca class='dismiss' href='#'\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Ch1\\u003ENew Message from {{{sender_screen_name}}}\\u003C/h1\\u003E\\u000a  \\u003Cdiv class='message-text'\\u003E{{{text}}}\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"message-notification-reply-box\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-editor\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-button button\\\"\\u003ESend\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/message}}\",\n            more_button: \"\\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"more-button-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"more-button btn\\\"\\u003Emore\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            new_tweets_bar: \"\\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"new-tweets-bar js-new-tweets-bar\\\" data-item-count=\\\"{{count}}\\\"\\u003E\\u000a    \\u000a    {{#tweets_count_phrase}}\\u000a      {{tweets_count_phrase}}\\u000a    {{/tweets_count_phrase}}\\u000a    {{^tweets_count_phrase}}\\u000a      {{#is_tweet}}\\u000a        {{#count_one}}{{count}} new Tweet{{/count_one}}{{#count_other}}{{count}} new Tweets{{/count_other}}\\u000a      {{/is_tweet}}\\u000a      {{^is_tweet}}\\u000a        {{#count_one}}{{count}} new Interaction{{/count_one}}{{#count_other}}{{count}} new Interactions{{/count_other}}\\u000a      {{/is_tweet}}\\u000a    {{/tweets_count_phrase}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            pill_css: \"\\u000a.profile-style-{{screen_name}} a {\\u000a  {{#profile_link_color}}\\u000a    color: #{{profile_link_color}} !important;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000aa:hover .geo-pin, body.user-style-{{screen_name}} .stream-item:hover .geo-pin {\\u000a  background-color: #{{profile_link_color}};\\u000a}\",\n            posting_tweet_box: \"\\u003Cform method=\\\"post\\\" action=\\\"/status/update\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-box condensed\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      \\u003Ch2\\u003EWhat\\u2019s happening?\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"text-area\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"text-area-editor twttr-editor\\\"\\u003E\\u000a        \\u003Ctextarea class=\\\"twitter-anywhere-tweet-box-editor\\\" name=\\\"status\\\" style=\\\"width: 482px; height: 36px;\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            stream: \"\\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a  \\u000a  \\u003Cdiv class=\\\"js-stream-items stream-items\\\" id=\\\"stream-items-id\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stream_activity: \"\\u003Cspan class='stream-activity-line'\\u003E\\u003Ci\\u003E\\u003C/i\\u003E{{{sentence}}}\\u003C/span\\u003E\",\n            stream_item: \"\\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"{{item_type}}\\\"{{#rendering_on_server}} id=\\\"stream-item-{{item_type}}-{{item_id}}\\\"{{/rendering_on_server}}\\u003E\\u000a  {{{item_html}}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_loading: \"\\u003Cdiv class=\\\"stream-loading\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Cspan class=\\\"spinner\\\" title=\\\"Loading...\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_manager: \"\\u003Cdiv class=\\\"stream-manager js-stream-manager-container\\\"{{#page_name_underscore}} id=\\\"{{page_name_underscore}}-stream-manager\\\"{{/page_name_underscore}}\\u003E\\u000a  {{#tweets}}\\u000a    \\u003Cdiv class=\\\"stream-title\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"stream-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream {{#page_name_underscore}}{{page_name_underscore}}-stream{{/page_name_underscore}}\\\"\\u003E\\u000a        \\u000a        \\u003Cdiv class=\\\"js-stream-items stream-items\\\" id=\\\"stream-items-id\\\"\\u003E{{{tweets}}}\\u003C/div\\u003E\\u000a        {{#show_empty_home}}\\u000a          \\u003Cdiv class=\\\"component\\\"\\u003E{{\\u003Eempty_home}}\\u003C/div\\u003E\\u000a        {{/show_empty_home}}\\u000a        {{#include_stream_footer}}\\u000a          \\u003Cdiv class=\\\"component\\\"\\u003E{{\\u003Estream_end}}\\u003C/div\\u003E\\u000a        {{/include_stream_footer}}\\u000a\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/tweets}}\\u000a  {{#rendering_on_server}}\\u000a    {{^tweets}}\\u000a      {{#profile_page}}\\u000a        {{^can_view}}\\u000a          {{\\u003Estream}}\\u000a        {{/can_view}}\\u000a      {{/profile_page}}\\u000a    {{/tweets}}\\u000a  {{/rendering_on_server}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_tweet: \"\\u000a\\u000a{{^render_withheld}}\\u000a\\u000a  \\u000a  {{#is_current_user_withheld}}\\u000a    {{\\u003Ewithheld_message}}\\u000a  {{/is_current_user_withheld}}\\u000a\\u000a  \\u003Cdiv class=\\\"tweet original-tweet js-stream-tweet js-actionable-tweet js-hover js-profile-popup-actionable js-original-tweet {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}{{#embedded_by_activity}} js-activity-tweet{{/embedded_by_activity}}{{#spam_threat}} spam-threat-tweet{{/spam_threat}} {{\\u003Ecommon_tweet_classes}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a\\u000a    \\u000a    \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a\\u000a    \\u000a    \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a        {{\\u003Etweet_timestamp}}\\u000a        {{#tweet_spam_experiment_enabled}}\\u000a          {{\\u003Etweet_spam_menu}}\\u000a        {{/tweet_spam_experiment_enabled}}\\u000a        {{\\u003Etweet_user_block}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{#rendering_on_server}}\\u000a        \\u003Cp class=\\\"js-tweet-text{{#is_rtl_tweet}} tweet-text-rtl{{/is_rtl_tweet}}\\\"\\u003E\\u000a          {{\\u003Elinked_tweet}}\\u000a        \\u003C/p\\u003E\\u000a      {{/rendering_on_server}}\\u000a      {{^rendering_on_server}}\\u000a        \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a      {{/rendering_on_server}}\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a        \\u000a        {{\\u003Etweet_context}}\\u000a\\u000a        \\u000a        \\u003Ca class=\\\"details with-icn js-details\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a          \\u003Cspan class=\\\"details-icon js-icon-container\\\"{{#place_name}} data-placename=\\\"{{place_name}}\\\"{{/place_name}}\\u003E\\u000a            {{#is_reply}}\\u000a              \\u003Ci class=\\\"sm-chat\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/is_reply}}\\u000a            {{#rendering_on_server}}\\u000a            {{#has_embedded_photo}}\\u000a              \\u003Ci class=\\\"sm-image\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_photo}}\\u000a            {{#has_embedded_summary}}\\u000a              \\u003Ci class=\\\"sm-embed\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_summary}}\\u000a            {{#has_embedded_player}}\\u000a              \\u003Ci class=\\\"sm-video\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_player}}\\u000a            {{#has_strong_geo}}\\u000a              \\u003Ci class=\\\"sm-geo\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_strong_geo}}\\u000a            {{/rendering_on_server}}\\u000a          \\u003C/span\\u003E\\u000a          \\u003Cb\\u003E\\u000a            \\u003Cspan class=\\\"expand-stream-item js-view-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{expand_callout_text}}\\u000a                {{^expand_callout_text}}\\u000a                  \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                    Expand\\u000a                  \\u003C/span\\u003E\\u000a                {{/expand_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                {{#is_reply}}\\u000a                  View conversation\\u000a                {{/is_reply}}\\u000a                {{^is_reply}}\\u000a                  \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                    Expand\\u000a                  \\u003C/span\\u003E\\u000a                {{/is_reply}}\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a            \\u003Cspan class=\\\"collapse-stream-item js-hide-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{collapse_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                {{#is_reply}}\\u000a                  Hide conversation\\u000a                {{/is_reply}}\\u000a                {{^is_reply}}\\u000a                  \\u003Cspan class=\\\"collapse-action-wrapper\\\"\\u003E\\u000a                    Collapse\\u000a                  \\u003C/span\\u003E\\u000a                {{/is_reply}}\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a          \\u003C/b\\u003E\\u000a        \\u003C/a\\u003E\\u000a\\u000a        \\u000a        {{\\u003Etweet_actions}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{\\u003Estream_tweet_expansion}}\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/render_withheld}}\\u000a\\u000a{{#render_withheld}}\\u000a  {{\\u003Estream_tweet_withheld}}\\u000a{{/render_withheld}}\\u000a\",\n            stream_tweet_withheld: \"\\u003Cdiv class=\\\"tweet original-tweet withheld-tweet js-stream-tweet js-actionable-tweet js-profile-popup-actionable js-original-tweet {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}{{#embedded_by_activity}} js-activity-tweet{{/embedded_by_activity}} {{\\u003Ecommon_tweet_classes}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a  \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"account-group\\\"\\u003E\\u000a        \\u003Cstrong class=\\\"fullname\\\"\\u003ETweet withheld\\u003C/strong\\u003E\\u000a      \\u003C/a\\u003E\\u000a      {{\\u003Etweet_timestamp}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a      {{\\u003Etweet_context}}\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Estream_tweet_expansion}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_actions: \"\\u000a\\u000a\\u000a \\u003Cul class=\\\"tweet-actions js-actions\\\"\\u003E\\u000a  \\u003Cli class=\\\"action-reply-container\\\"\\u003E\\u000a    \\u000a    {{^change_german_verbs}}\\u000a      \\u003Ca class=\\\"with-icn js-action-reply\\\" data-modal=\\\"tweet-reply\\\" href=\\\"#\\\" title=\\\"Reply\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-reply\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cb\\u003EReply\\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/change_german_verbs}}\\u000a    {{#change_german_verbs}}\\u000a      \\u003Ca class=\\\"with-icn js-action-reply\\\" data-modal=\\\"tweet-reply\\\" href=\\\"#\\\" title=\\\"Kommentieren\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-reply\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cb\\u003EKommentieren\\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/change_german_verbs}}\\u000a  \\u003C/li\\u003E\\u000a  {{#allowed_to_retweet}}\\u000a    \\u003Cli class=\\\"action-rt-container\\\"\\u003E\\u000a      \\u003Ca class=\\\"with-icn js-toggle-rt\\\" data-modal=\\\"tweet-retweet\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-rt\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u000a        \\u000a        {{^change_german_verbs}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"undo-retweet\\\" title=\\\"Undo retweet\\\"\\u003ERetweeted\\u003C/span\\u003E\\u003Cspan class=\\\"retweet\\\" title=\\\"Retweet\\\"\\u003ERetweet\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/change_german_verbs}}\\u000a        {{#change_german_verbs}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"undo-retweet\\\" title=\\\"Nicht mehr teilen\\\"\\u003EGeteilt\\u003C/span\\u003E\\u003Cspan class=\\\"retweet\\\" title=\\\"Teilen\\\"\\u003ETeilen\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/change_german_verbs}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/allowed_to_retweet}}\\u000a  \\u003Cli class=\\\"action-del-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"with-icn js-action-del\\\" href=\\\"#\\\" title=\\\"Delete\\\"\\u003E\\u000a      \\u003Ci class=\\\"sm-trash\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003Cb\\u003EDelete\\u003C/b\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"action-fav-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"with-icn js-toggle-fav\\\" href=\\\"#\\\"\\u003E\\u000a      \\u003Ci class=\\\"sm-fav\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u000a      \\u000a      {{^change_german_verbs}}\\u000a        {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo favorite\\\"\\u003EFavorited\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Favorite\\\"\\u003EFavorite\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_like}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo like\\\"\\u003ELiked\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Like\\\"\\u003ELike\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_star}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo star\\\"\\u003EStarred\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Star\\\"\\u003EStar\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_star}}\\u000a      {{/change_german_verbs}}\\u000a      {{#change_german_verbs}}\\u000a        \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Gef\\u00e4llt mir nicht\\\"\\u003EGef\\u00e4llt mir jetzt\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Favorite\\\"\\u003EGef\\u00e4llt mir\\u003C/span\\u003E\\u003C/b\\u003E\\u000a      {{/change_german_verbs}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            tweet_contributor: \"{{#contributor}}\\u000a  \\u003Cspan class=\\\"tweet-contributors\\\"\\u003Eby \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"user-profile-link\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E{{screen_name}}\\u003C/a\\u003E\\u003C/span\\u003E\\u000a{{/contributor}}\",\n            tweet_dogear: \"\\u003Cdiv class=\\\"tweet-dogear\\\"\\u003E\\u003C/div\\u003E\",\n            tweet_labels: \"{{#is_top_tweet}}\\u000a    \\u003Cspan class=\\\"tweet-context icon-link\\\"\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-top\\\"\\u003E\\u003C/i\\u003E{{#retweet_count}}Retweeted {{retweet_count}} times{{/retweet_count}}{{^retweet_count}}Top Tweet{{/retweet_count}}\\u003C/span\\u003E\\u000a{{/is_top_tweet}}\\u000a\\u000a{{#is_sponsored}}\\u000a  \\u003Ca href=\\\"{{#retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}{{^retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}\\\" class=\\\"icon-link promoted-arrow tweet-context user-profile-link js-action-profile-promoted\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\" title=\\\"{{disclosure_text}}\\\"\\u003E\\u003Cspan\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-{{disclosure_type}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003EPromoted by {{advertiser_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u000a  {{#in_home_page}}\\u000a    {{^rendering_on_server}}\\u000a      \\u003Ca class=\\\"icon-link tweet-feedback dismiss-action js-action-dismiss\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cb\\u003EDismiss\\u003C/b\\u003E\\u003C/a\\u003E\\u000a    {{/rendering_on_server}}\\u000a    {{{social_context}}}\\u000a  {{/in_home_page}}\\u000a{{/is_sponsored}}\",\n            tweet_meta: \"\\u003Cdiv class='tweet-meta'\\u003E\\u000a  \\u003Cspan class='icons'\\u003E\\u000a    {{#is_sponsored}}\\u000a      {{#retweet_count}}\\u000a        \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E \\u003Cem\\u003E{{retweet_count_text}}\\u003C/em\\u003E\\u000a      {{/retweet_count}}\\u000a    {{/is_sponsored}}\\u000a\\u000a    {{^decider_activity_read}}\\u000a      {{^is_sponsored}}\\u000a        {{#was_retweeted}}\\u000a          {{#retweeting_status}}\\u000a            \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E {{#user}}\\u003Cem\\u003Eby {{screen_name}}\\u003C/em\\u003E{{/user}}\\u000a          {{/retweeting_status}}\\u000a        {{/was_retweeted}}\\u000a      {{/is_sponsored}}\\u000a    {{/decider_activity_read}}\\u000a\\u000a    \\u003Cdiv class=\\\"extra-icons\\\"\\u003E\\u000a      {{^can_expand}}\\u000a        {{#is_reply}}\\u000a          \\u003Cspan class='reply-icon icon js-reply-notice'\\u003E@\\u003C/span\\u003E\\u000a        {{/is_reply}}\\u000a        \\u003Cspan class=\\\"inlinemedia-icons js-icon-container\\\"\\u003E\\u003C/span\\u003E\\u000a        {{#show_geo_icon}}\\u003Cspan class=\\\"geo-pin\\\"\\u003E\\u003C/span\\u003E{{/show_geo_icon}}\\u000a      {{/can_expand}}\\u000a      {{#can_expand}}\\u000a        {{\\u003Etweet_timestamp}}\\u000a      {{/can_expand}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{#can_expand}}\\u000a  {{\\u003Etweet_actions}}\\u000a{{/can_expand}}\",\n            tweet_source: \"\\u003Cspan class=\\\"tweet-source\\\"\\u003Evia {{{source}}}\\u003C/span\\u003E\",\n            tweet_text: \"\\u003Cdiv class=\\\"tweet-text js-tweet-text\\\"\\u003E\\u000a  {{\\u003Elinked_tweet}}\\u000a\\u003C/div\\u003E\",\n            tweet_timestamp: \"\\u003Csmall class=\\\"time\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{permalink_path}}\\\" class=\\\"tweet-timestamp js-permalink\\\" title=\\\"{{explicit_timestamp}}\\\" {{#impression_cookie}}data-send-impression-cookie{{/impression_cookie}}\\u003E\\u003Cspan class=\\\"_timestamp js-short-timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{short_timestamp}}\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u003C/small\\u003E\\u000a\",\n            tweet_user_image_48: \"{{#user}}\\u000a\\u003Cimg height=\\\"48\\\" width=\\\"48\\\" src='{{profile_image_url}}' alt='{{name}}' class='user-profile-link js-action-profile-avatar' data-user-id='{{id}}'/\\u003E\\u000a{{/user}}\\u000a\",\n            tweet_user_name: \"{{#user}}\\u000a\\u003Cspan class='tweet-user-name'\\u003E\\u000a  \\u003Ca class='tweet-screen-name user-profile-link js-action-profile-name' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a  \\u003Cspan class='tweet-full-name'\\u003E{{name}}\\u003C/span\\u003E\\u000a  {{#show_follow_action}}\\u000a    {{^is_current_user}}\\u000a    \\u003Cspan class=\\\"tweet-user-follow\\\"\\u003E\\u000a    \\u003C/span\\u003E\\u000a    {{/is_current_user}}\\u000a  {{/show_follow_action}}\\u000a\\u003C/span\\u003E\\u000a{{/user}}\",\n            user_css_p1: \"\\u000a\\u003Cstyle id=\\\"user-style-{{screen_name}}\\\"\\u003E\\u000a  body.user-style-{{screen_name}} {\\u000a    {{#profile_use_background_image}}\\u000a      background-position: left 40px;\\u000a      background-attachment: fixed;\\u000a      {{^profile_background_tile}}\\u000a        background-repeat: no-repeat;\\u000a      {{/profile_background_tile}}\\u000a    {{/profile_use_background_image}}\\u000a    {{#profile_background_color}}\\u000a      background-color: #{{profile_background_color}};\\u000a    {{/profile_background_color}}\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} a,\\u000a  body.user-style-{{screen_name}} ul.stream-tabs li,\\u000a  body.user-style-{{screen_name}} .component .promo strong,\\u000a  body.user-style-{{screen_name}} .message-thread-preview:hover .message-count,\\u000a  body.user-style-{{screen_name}} .list-membership-container li.create-a-list {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}};\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-screen-name,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-geo-text,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .user-profile-link,\\u000a  body.user-style-{{screen_name}} span.user-stat-link,\\u000a  body.user-style-{{screen_name}} a.title-link:hover,\\u000a  body.user-style-{{screen_name}} a.user-stats-count:hover span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a,\\u000a  body.user-style-{{screen_name}} .user-detailed-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .tweet-activity:hover a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link b,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-feedback,\\u000a  body.user-style-{{screen_name}} .promoted-tweet:hover .social-context a,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a:hover span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity .user,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-count,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence span.user,\\u000a  body.user-style-{{screen_name}} .JSBNG__onebox-user-screen-name:hover {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-screen-name {\\u000a    color: #333 !important;\\u000a  }\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-timestamp {\\u000a    color: #999 !important;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .hovered-stream-item,\\u000a  body.user-style-{{screen_name}} .stream-item:hover,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:active {\\u000a    {{#rgba_tweet_background_color}}\\u000a      background-color: {{rgba_tweet_background_color}};\\u000a    {{/rgba_tweet_background_color}}\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}};\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover {\\u000a    border-top-color: transparent;\\u000a    border-bottom-color: #EBEBEB;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:hover {\\u000a    {{#rgba_newtweets_background_color}}\\u000a      background-color: {{rgba_newtweets_background_color}};\\u000a    {{/rgba_newtweets_background_color}}\\u000a    {{#rgba_newtweets_border_color}}\\u000a      border-color: {{rgba_newtweets_border_color}};\\u000a    {{/rgba_newtweets_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-screen-name,\\u000a  body.user-style-{{screen_name}} .profile-screenname,\\u000a  body.user-style-{{screen_name}} .title-link,\\u000a  body.user-style-{{screen_name}} div.latest-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} div.truncated-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} a.user-stats-count span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .welcome-steps li .active a strong,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence span.user {\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-full-name,\\u000a  body.user-style-{{screen_name}} span.trend-location,\\u000a  body.user-style-{{screen_name}} .your-activity h3,\\u000a  body.user-style-{{screen_name}} .trends-inner h3,\\u000a  body.user-style-{{screen_name}} .dashboard .user-rec-inner h3,\\u000a  body.user-style-{{screen_name}} .latest-tweet,\\u000a  body.user-style-{{screen_name}} .truncated-tweet,\\u000a  body.user-style-{{screen_name}} .latest-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .truncated-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a s,\\u000a  body.user-style-{{screen_name}} .social-context div,\\u000a  body.user-style-{{screen_name}} .dashboard .dot,\\u000a  body.user-style-{{screen_name}} .component .promo,\\u000a  body.user-style-{{screen_name}} .component .promo a.definition,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .dismiss,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .ellip,\\u000a  body.user-style-{{screen_name}} .facets-media-not-displayed .not-displayed-text,\\u000a  body.user-style-{{screen_name}} .dashboard .copyright,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item a.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence {\\u000a    {{#rgba_text_color}}\\u000a      color: {{rgba_text_color}};\\u000a    {{/rgba_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #page-container,\\u000a  body.user-style-{{screen_name}} .user-sidebar-color,\\u000a  body.user-style-{{screen_name}} .expando-container .dashboard {\\u000a    {{#profile_sidebar_fill_color}}\\u000a      \\u000a      background: #{{profile_sidebar_fill_color}};\\u000a    {{/profile_sidebar_fill_color}}\\u000a    {{#rgba_sidebar_color}}\\u000a      \\u000a      background: {{rgba_sidebar_color}};\\u000a    {{/rgba_sidebar_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .activity:hover .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .hovered-stream-item .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .dashboard .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content  {\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}} !important;\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-atreply:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-hashtag:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-timeline-link:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-timeline-link,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-timeline-link {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} s,\\u000a  body.user-style-{{screen_name}} .pretty-link s {\\u000a    {{#profile_pretty_link_color}}\\u000a      color: #{{profile_pretty_link_color}};\\u000a    {{/profile_pretty_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard s,\\u000a  body.user-style-{{screen_name}} .dashboard .pretty-link s,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a s {\\u000a    {{#profile_pretty_link_sidebar_color}}\\u000a      color: #{{profile_pretty_link_sidebar_color}};\\u000a    {{/profile_pretty_link_sidebar_color}}\\u000a  }\\u000a\\u000a  {{\\u003Epill_css}}\\u000a\\u003C/style\\u003E\",\n            user_link: \"\\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E\",\n            common_tweet_classes: \"\\u000a{{#is_sponsored}} promoted-tweet{{/is_sponsored}}{{#is_my_tweet}} my-tweet{{/is_my_tweet}}{{#favorited}} favorited{{/favorited}}{{#is_retweeted_by_current_user}} retweeted{{/is_retweeted_by_current_user}}{{#preexpanded}} opened-tweet{{/preexpanded}}\\u000a{{#can_delete_user_tweets}}can-delete{{/can_delete_user_tweets}}\\u000a{{#has_visible_cards}} has-cards{{/has_visible_cards}}\\u000a{{#has_native_media}} has-native-media{{/has_native_media}}\\u000a{{#has_retweet_count}} with-social-proof{{/has_retweet_count}}\\u000a{{^has_retweet_count}}{{#tweet_stats}} with-social-proof{{/tweet_stats}}{{/has_retweet_count}}\\u000a{{#has_preloadable_media}} has-preloadable-media{{/has_preloadable_media}}\",\n            JSBNG__content: \"\\u003Cdiv class=\\\"content-main js-content-main breakable\\\"\\u003E\\u000a  \\u003Cdiv id=\\\"js-promptbird-below-black-bar-hook\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv id=\\\"js-empty-timeline-recommendations-module-hook\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-header js-stream-header\\\"\\u003E\\u000a    {{\\u003Estream_header}} \\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream js-stream-manager-container\\\"\\u003E\\u000a    {{#rendering_on_server}}\\u000a      {{\\u003Estream_manager}}\\u000a      \\u003Cscript\\u003Eif (window.ttft) window.ttft.serverRendered('{{page_name}}');twttr.keynoteTTFTPing();\\u003C/script\\u003E\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#rendering_on_server}}\\u000a    {{\\u003Emini_home_profile}}\\u000a  {{/rendering_on_server}}\\u000a\\u003C/div\\u003E\\u000a\",\n            linked_tweet: \"{{#swift}}\\u000a  {{#render_withheld}}\\u000a    {{text}} \\u003Ca href=\\\"{{withheld_help_path}}\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a  {{/render_withheld}}\\u000a  {{^render_withheld}}\\u000a    {{#tweet_parts}}{{#entity}}\\u003Ca href=\\\"{{url}}\\\" {{#attributes}}{{name}}=\\\"{{value}}\\\" {{/attributes}}\\u003E{{#complex_link}}\\u003Cspan class=\\\"invisible\\\"\\u003E{{before_display_url}}\\u003C/span\\u003E\\u003Cspan class=\\\"js-display-url\\\"\\u003E{{display_sans_ellipsis}}\\u003C/span\\u003E\\u003Cspan class=\\\"invisible\\\"\\u003E{{after_display_url}}\\u003C/span\\u003E\\u003Cspan class=\\\"tco-ellipsis\\\"\\u003E\\u003Cspan class=\\\"invisible\\\"\\u003E&nbsp;\\u003C/span\\u003E{{following_ellipsis}}\\u003C/span\\u003E{{/complex_link}}{{^complex_link}}{{#prefix}}\\u003Cs\\u003E{{prefix}}\\u003C/s\\u003E\\u003Cb\\u003E{{text}}\\u003C/b\\u003E{{/prefix}}{{^prefix}}{{text}}{{/prefix}}{{/complex_link}}\\u003C/a\\u003E{{/entity}}{{^entity}}{{text}}{{/entity}}{{/tweet_parts}}\\u000a  {{/render_withheld}}\\u000a{{/swift}}\\u000a{{^swift}}\\u000a  {{{linkified_text}}}\\u000a{{/swift}}\\u000a\",\n            page: \"{{\\u003Edashboard}}\\u000a{{\\u003Econtent}}\",\n            promoted_disclosure: \"\\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003E\\u000a\\u003Ca href=\\\"{{#user}}{{profile_path}}{{/user}}\\\"\\u000a   class=\\\"js-action-profile-promoted js-user-profile-link js-promoted-badge\\\"\\u000a   data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\"\\u000a   {{#user}}{{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}{{/user}}\\u000a\\u003EPromoted by {{advertiser_name}}\\u003C/a\\u003E\",\n            stream_header: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Cspan class=\\\"content-header-buttons js-header-button-container\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u000a    \\u000a    \\u003Cspan class=\\\"js-stream-title\\\"\\u003E{{stream_title}}\\u003C/span\\u003E&nbsp;\\u003Csmall class=\\\"view-toggler js-view-toggler\\\"\\u003E\\u003C/small\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  {{#header_help}}\\u003Cp class=\\\"js-header-help subheader\\\"\\u003E{{{header_help}}}\\u003C/p\\u003E{{/header_help}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_tweet_expansion: \"\\u003Cdiv class=\\\"expanded-content js-tweet-details-dropdown\\\"\\u003E\\u000a  {{^on_permalink}}\\u000a    {{#preexpanded}}{{\\u003Etweet_details}}{{/preexpanded}}\\u000a  {{/on_permalink}}\\u000a\\u003C/div\\u003E\",\n            tweet_context: \"\\u000a\\u000a\\u000a\\u000a\\u003Cdiv class=\\\"context\\\"\\u003E\\u000a  {{#is_sponsored}}\\u000a    \\u003Cspan class=\\\"metadata with-icn js-disclosure js-tooltip\\\" title=\\\"{{disclosure_text}}\\\"\\u003E\\u000a      {{#was_retweeted}}\\u000a        {{#retweeting_status}}\\u000a          {{\\u003Epromoted_disclosure}}\\u000a        {{/retweeting_status}}\\u000a      {{/was_retweeted}}\\u000a      {{^was_retweeted}}\\u000a        {{\\u003Epromoted_disclosure}}\\u000a      {{/was_retweeted}}\\u000a    \\u003C/span\\u003E\\u000a    {{#in_home_page}}\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"btn-link dismiss-promoted js-action-dismiss with-icn\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003E{{^abtest_dismiss_text_180_any_bucket}}Dismiss{{/abtest_dismiss_text_180_any_bucket}}{{#abtest_dismiss_text_180_dismiss_tweet}}Dismiss Tweet{{/abtest_dismiss_text_180_dismiss_tweet}}{{#abtest_dismiss_text_180_remove_tweet}}Remove Tweet{{/abtest_dismiss_text_180_remove_tweet}}{{#abtest_dismiss_text_180_not_interested}}Not interested{{/abtest_dismiss_text_180_not_interested}}\\u003C/b\\u003E\\u003C/button\\u003E\\u000a      {{#rendering_on_server}}\\u000a        \\u003Cspan class=\\\"social-context\\\"\\u003E{{\\u003Emini_social_proof}}\\u003C/span\\u003E\\u000a      {{/rendering_on_server}}\\u000a      {{^rendering_on_server}}\\u000a        {{{social_context}}}\\u000a      {{/rendering_on_server}}\\u000a    {{/in_home_page}}\\u000a  {{/is_sponsored}}\\u000a  {{#is_top_tweet}}\\u000a    \\u003Cspan class=\\\"metadata with-icn\\\"\\u003E\\u000a      \\u003Ci class=\\\"badge-top\\\"\\u003E\\u003C/i\\u003E{{#retweet_count}}Retweeted {{retweet_count}} times{{/retweet_count}}{{^retweet_count}}Top Tweet{{/retweet_count}}\\u000a    \\u003C/span\\u003E\\u000a  {{/is_top_tweet}}\\u000a  {{^is_sponsored}}\\u000a    {{#was_retweeted}}\\u000a      {{#retweeting_status}}\\u000a        {{#user}}\\u000a          \\u000a          {{^change_german_verbs}}\\u000a            \\u003Cspan class=\\\"with-icn\\\"\\u003E\\u003Ci class=\\\"badge-retweeted\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"js-retweet-text\\\"\\u003ERetweeted by \\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u000a          {{/change_german_verbs}}\\u000a          {{#change_german_verbs}}\\u000a            \\u003Cspan class=\\\"with-icn\\\"\\u003E\\u003Ci class=\\\"badge-retweeted\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"js-retweet-text\\\"\\u003EVon \\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E geteilt\\u003C/span\\u003E\\u003C/span\\u003E\\u000a          {{/change_german_verbs}}\\u000a        {{/user}}\\u000a      {{/retweeting_status}}\\u000a    {{/was_retweeted}}\\u000a  {{/is_sponsored}}\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_data: \"\\u000adata-tweet-id=\\\"{{id}}\\\"\\u000a{{{tweet_impression_id}}}\\u000adata-item-id=\\\"{{id}}\\\"\\u000a{{#current_user_retweet}} data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}}\\u000a{{#was_retweeted}}{{#retweeting_status}} data-retweet-id=\\\"{{id}}\\\"{{/retweeting_status}}{{/was_retweeted}}\\u000a{{#user}} data-screen-name=\\\"{{screen_name}}\\\" data-name=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"{{/user}}\\u000a{{#protected}} data-protected=\\\"true\\\"{{/protected}}\\u000a{{#is_sponsored}} data-promoted=\\\"true\\\"{{/is_sponsored}}\\u000a{{#show_geo_icon}} data-geo=\\\"true\\\"{{/show_geo_icon}}\\u000a{{#cards}} data-card-type=\\\"{{#photos}}photo{{/photos}}{{#summaries}}summary{{/summaries}}{{#players}}player{{/players}}\\\"{{/cards}}\\u000adata-is-reply-to=\\\"{{is_reply}}\\\"\\u000a{{#status_data}} data-status=\\\"{{status_data}}\\\"{{/status_data}}\\u000a{{#rendering_on_server}}{{^preexpanded}}data-expanded-footer=\\\"{{{escaped_tweet_details}}}{{#deprecated_escape_html_for_tweet_details}}{{\\u003Etweet_details}}{{/deprecated_escape_html_for_tweet_details}}\\\"{{/preexpanded}}{{/rendering_on_server}}\\u000a{{#possibly_sensitive}} data-possibly-sensitive=\\\"true\\\"{{/possibly_sensitive}}\\u000a{{#impression_cookie}} data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}\\u000a{{#mentioned_screen_names}} data-mentions=\\\"{{mentioned_screen_names}}\\\"{{/mentioned_screen_names}}\\u000a{{#relevance_type}} data-relevance-type=\\\"{{relevance_type}}\\\"{{/relevance_type}}\\u000a\",\n            tweet_geo_text: \"{{#has_geo}}\\u000a  {{^show_geo_map}}\\u000a    \\u003Cdiv\\u003E\\u000a      \\u003Ca class=\\\"js-tweet-geo-text tweet-geo-text\\\" href=\\\"{{place_path}}\\\"\\u003E\\u000a        {{#place_name}}from {{place_name}}{{/place_name}}{{^place_name}}view location{{/place_name}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/show_geo_map}}\\u000a{{/has_geo}}\",\n            tweet_user_block: \"{{#user}}\\u000a  \\u003Ca {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}} class=\\\"account-group js-account-group js-action-profile js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Cimg class=\\\"avatar js-action-profile-avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a    \\u003Cstrong class=\\\"fullname js-action-profile-name show-popup-with-id\\\"\\u003E{{name}}{{#show_verified_badge}}{{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EVerified\\u003C/span\\u003E\\u003C/i\\u003E{{/verified}}{{/show_verified_badge}}\\u003C/strong\\u003E\\u000a    \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a    {{#protected}}\\u000a      \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a    {{/protected}}\\u000a  \\u003C/a\\u003E\\u000a{{/user}}\\u000a\",\n            user_css_t1: \"\\u000a\\u003Cstyle id=\\\"user-style-{{style_namespace}}\\\" class=\\\"js-user-style\\\"\\u003E\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000aa,\\u000a\\u000a\\u000a\\u000a.btn-link,\\u000a\\u000a\\u000a\\u000a\\u000a  \\u000a  \\u000a\\u000a.pretty-link{{colon_hover}} s,\\u000a.pretty-link{{colon_hover}} b,\\u000a/* Account Group */\\u000a.metadata a{{colon_hover}},\\u000a\\u000a.account-group{{colon_hover}} .fullname,\\u000a\\u000a.stats a{{colon_hover}},\\u000a.stats a{{colon_hover}} strong,\\u000a\\u000a.profile-modal-header .fullname a{{colon_hover}},\\u000a.profile-modal-header .username a{{colon_hover}},\\u000a\\u000a.story-article{{colon_hover}} .metadata,\\u000a\\u000a.find-friends-sources li{{colon_hover}} .source,\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a.stream-item a{{colon_hover}} .fullname,\\u000a\\u000a.stream-item .view-all-supplements{{colon_hover}},\\u000a\\u000a.tweet .time a{{colon_hover}},\\u000a.tweet{{colon_hover}} .user-dropdown .mark-as-spam-text,\\u000a.tweet-actions a,\\u000a.tweet .details.with-icn b,\\u000a\\u000a.stream-item{{colon_hover}} .original-tweet .expand-action-wrapper,\\u000a.opened-tweet.original-tweet  .expand-action-wrapper,\\u000a\\u000a.stream-item{{colon_hover}} .original-tweet .details b,\\u000a.stream-item.open .original-tweet .details b,\\u000a\\u000a.simple-tweet{{colon_hover}} .details b,\\u000a.simple-tweet.open .details b,\\u000a.simple-tweet{{colon_hover}} .details .expand-action-wrapper,\\u000a.simple-tweet.open .details .collapse-action-wrapper,\\u000a.simple-tweet{{colon_hover}} .details .simple-details-link,\\u000a\\u000a.client-and-actions a{{colon_hover}},\\u000a\\u000a.dismiss-promoted{{colon_hover}} b,\\u000a\\u000a.tweet .context .pretty-link{{colon_hover}} s,\\u000a.tweet .context .pretty-link{{colon_hover}} b,\\u000a\\u000a.list .username a{{colon_hover}},\\u000a.list-membership-container .create-a-list,\\u000a.list-membership-container .create-a-list{{colon_hover}},\\u000a\\u000a\\u000a\\u000a.story-header{{colon_hover}} .view-tweets,\\u000a.card .list-details a{{colon_hover}},\\u000a.card .card-body{{colon_hover}} .attribution,\\u000a.new-tweets-bar,\\u000a.JSBNG__onebox .soccer ul.ticker a{{colon_hover}},\\u000a\\u000a\\u000a\\u000a.discover-item-actions a,\\u000a\\u000a\\u000a\\u000a.remove-background-btn,\\u000a\\u000a\\u000a\\u000a.stream-item-activity-me .latest-tweet .tweet-row a{{colon_hover}} {\\u000a  {{#profile_link_color}}\\u000a    color: #{{profile_link_color}};\\u000a  {{/profile_link_color}}\\u000a  {{^profile_link_color}}\\u000a    color: #0084B4;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000as,\\u000a.pretty-link{{colon_hover}} s,\\u000a.stream-item-activity-me .latest-tweet .tweet-row a{{colon_hover}} s {\\u000a  {{#profile_pretty_link_color}}\\u000a    color: #{{profile_pretty_link_color}};\\u000a  {{/profile_pretty_link_color}}\\u000a  {{^profile_pretty_link_color}}\\u000a    color: #66B5D2;\\u000a  {{/profile_pretty_link_color}}\\u000a}\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a.tweet .sm-reply,\\u000a.tweet .sm-rt,\\u000a.tweet .sm-fav,\\u000a.tweet .sm-image,\\u000a.tweet .sm-video,\\u000a.tweet .sm-audio,\\u000a.tweet .sm-geo,\\u000a.tweet .sm-in,\\u000a.tweet .sm-trash,\\u000a.tweet .sm-page,\\u000a.tweet .sm-embed,\\u000a.tweet .sm-summary,\\u000a.tweet .sm-chat,\\u000a\\u000a.tweet .mark-as-spam-flag,\\u000a.tweet .mark-as-spam-silhouette,\\u000a\\u000a.timelines-navigation .active .profile-nav-icon,\\u000a.timelines-navigation .profile-nav-icon{{colon_hover}},\\u000a\\u000a.sm-top-tweet,\\u000a\\u000a\\u000a.discover-item .js-action-card-search{{colon_hover}} .sm-search {\\u000a  {{#profile_link_color}}\\u000a    background-color: #{{profile_link_color}};\\u000a  {{/profile_link_color}}\\u000a  {{^profile_link_color}}\\u000a    background-color: #6684B4;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000abody {\\u000a  {{#profile_use_background_image}}\\u000a    background-position: {{#center_background}}center{{/center_background}}{{^center_background}}left{{/center_background}} 40px;\\u000a    background-attachment: fixed;\\u000a    background-repeat: repeat;\\u000a    {{^profile_background_tile}}\\u000a      background-repeat: no-repeat;\\u000a    {{/profile_background_tile}}\\u000a  {{/profile_use_background_image}}\\u000a  {{#profile_background_color}}\\u000a    background-color: #{{profile_background_color}};\\u000a  {{/profile_background_color}}\\u000a  {{^profile_background_color}}\\u000a    background-color: #c0deed;\\u000a  {{/profile_background_color}}\\u000a}\\u000a\\u003C/style\\u003E\\u000a\",\n            withheld_message: \"\\u003Cdiv class=\\\"withheld-message\\\"\\u003E{{text}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/div\\u003E\\u000a\"\n        });\n    }\n;\n;\n    exports();\n});\nprovide(\"$lib/jquery-1.7.1.js\", function(a) {\n    (function(a, b) {\n        function c(a) {\n            var b = M[a] = {\n            }, c, d;\n            a = a.split(/\\s+/);\n            for (c = 0, d = a.length; ((c < d)); c++) {\n                b[a[c]] = !0;\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function d(a, c, d) {\n            if (((((d === b)) && ((a.nodeType === 1))))) {\n                var e = ((\"data-\" + c.replace(P, \"-$1\").toLowerCase()));\n                d = a.getAttribute(e);\n                if (((typeof d == \"string\"))) {\n                    try {\n                        d = ((((d === \"true\")) ? !0 : ((((d === \"false\")) ? !1 : ((((d === \"null\")) ? null : ((L.isNumeric(d) ? parseFloat(d) : ((O.test(d) ? L.parseJSON(d) : d))))))))));\n                    } catch (f) {\n                    \n                    };\n                ;\n                    L.data(a, c, d);\n                }\n                 else d = b;\n            ;\n            ;\n            }\n        ;\n        ;\n            return d;\n        };\n    ;\n        function e(a) {\n            for (var b in a) {\n                if (((((b === \"data\")) && L.isEmptyObject(a[b])))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((b !== \"toJSON\"))) {\n                    return !1;\n                }\n            ;\n            ;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function f(a, b, c) {\n            var d = ((b + \"defer\")), e = ((b + \"queue\")), f = ((b + \"mark\")), g = L._data(a, d);\n            ((((((g && ((((c === \"queue\")) || !L._data(a, e))))) && ((((c === \"mark\")) || !L._data(a, f))))) && JSBNG__setTimeout(function() {\n                ((((!L._data(a, e) && !L._data(a, f))) && (L.removeData(a, d, !0), g.fire())));\n            }, 0)));\n        };\n    ;\n        function g() {\n            return !1;\n        };\n    ;\n        function i() {\n            return !0;\n        };\n    ;\n        function j(a) {\n            return ((((!a || !a.parentNode)) || ((a.parentNode.nodeType === 11))));\n        };\n    ;\n        function k(a, b, c) {\n            b = ((b || 0));\n            if (L.isFunction(b)) {\n                return L.grep(a, function(a, d) {\n                    var e = !!b.call(a, d, a);\n                    return ((e === c));\n                });\n            }\n        ;\n        ;\n            if (b.nodeType) {\n                return L.grep(a, function(a, d) {\n                    return ((((a === b)) === c));\n                });\n            }\n        ;\n        ;\n            if (((typeof b == \"string\"))) {\n                var d = L.grep(a, function(a) {\n                    return ((a.nodeType === 1));\n                });\n                if (ob.test(b)) {\n                    return L.filter(b, d, !c);\n                }\n            ;\n            ;\n                b = L.filter(b, d);\n            }\n        ;\n        ;\n            return L.grep(a, function(a, d) {\n                return ((((L.inArray(a, b) >= 0)) === c));\n            });\n        };\n    ;\n        function l(a) {\n            var b = sb.split(\"|\"), c = a.createDocumentFragment();\n            if (c.createElement) {\n                while (b.length) {\n                    c.createElement(b.pop());\n                ;\n                };\n            }\n        ;\n        ;\n            return c;\n        };\n    ;\n        function m(a, b) {\n            return ((L.nodeName(a, \"table\") ? ((a.getElementsByTagName(\"tbody\")[0] || a.appendChild(a.ownerDocument.createElement(\"tbody\")))) : a));\n        };\n    ;\n        function n(a, b) {\n            if (((((b.nodeType !== 1)) || !L.hasData(a)))) {\n                return;\n            }\n        ;\n        ;\n            var c, d, e, f = L._data(a), g = L._data(b, f), i = f.events;\n            if (i) {\n                delete g.handle, g.events = {\n                };\n                for (c in i) {\n                    for (d = 0, e = i[c].length; ((d < e)); d++) {\n                        L.JSBNG__event.add(b, ((((c + ((i[c][d].namespace ? \".\" : \"\")))) + i[c][d].namespace)), i[c][d], i[c][d].data);\n                    ;\n                    };\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            ((g.data && (g.data = L.extend({\n            }, g.data))));\n        };\n    ;\n        function o(a, b) {\n            var c;\n            if (((b.nodeType !== 1))) {\n                return;\n            }\n        ;\n        ;\n            ((b.clearAttributes && b.clearAttributes())), ((b.mergeAttributes && b.mergeAttributes(a))), c = b.nodeName.toLowerCase();\n            if (((c === \"object\"))) {\n                b.outerHTML = a.outerHTML;\n            }\n             else {\n                if (((((c !== \"input\")) || ((((a.type !== \"checkbox\")) && ((a.type !== \"radio\"))))))) {\n                    if (((c === \"option\"))) {\n                        b.selected = a.defaultSelected;\n                    }\n                     else {\n                        if (((((c === \"input\")) || ((c === \"textarea\"))))) {\n                            b.defaultValue = a.defaultValue;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                }\n                 else ((a.checked && (b.defaultChecked = b.checked = a.checked))), ((((b.value !== a.value)) && (b.value = a.value)));\n            ;\n            }\n        ;\n        ;\n            b.removeAttribute(L.expando);\n        };\n    ;\n        function p(a) {\n            return ((((typeof a.getElementsByTagName != \"undefined\")) ? a.getElementsByTagName(\"*\") : ((((typeof a.querySelectorAll != \"undefined\")) ? a.querySelectorAll(\"*\") : []))));\n        };\n    ;\n        function q(a) {\n            if (((((a.type === \"checkbox\")) || ((a.type === \"radio\"))))) {\n                a.defaultChecked = a.checked;\n            }\n        ;\n        ;\n        };\n    ;\n        function r(a) {\n            var b = ((a.nodeName || \"\")).toLowerCase();\n            ((((b === \"input\")) ? q(a) : ((((((b !== \"script\")) && ((typeof a.getElementsByTagName != \"undefined\")))) && L.grep(a.getElementsByTagName(\"input\"), q)))));\n        };\n    ;\n        function s(a) {\n            var b = I.createElement(\"div\");\n            return Gb.appendChild(b), b.innerHTML = a.outerHTML, b.firstChild;\n        };\n    ;\n        function t(a, b) {\n            ((b.src ? L.ajax({\n                url: b.src,\n                async: !1,\n                dataType: \"script\"\n            }) : L.globalEval(((((((b.text || b.textContent)) || b.innerHTML)) || \"\")).replace(Eb, \"/*$0*/\")))), ((b.parentNode && b.parentNode.removeChild(b)));\n        };\n    ;\n        function u(a, b, c) {\n            var d = ((((b === \"width\")) ? a.offsetWidth : a.offsetHeight)), e = ((((b === \"width\")) ? Ob : Pb)), f = 0, g = e.length;\n            if (((d > 0))) {\n                if (((c !== \"border\"))) {\n                    for (; ((f < g)); f++) {\n                        ((c || (d -= ((parseFloat(L.css(a, ((\"padding\" + e[f])))) || 0))))), ((((c === \"margin\")) ? d += ((parseFloat(L.css(a, ((c + e[f])))) || 0)) : d -= ((parseFloat(L.css(a, ((((\"border\" + e[f])) + \"Width\")))) || 0))));\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((d + \"px\"));\n            }\n        ;\n        ;\n            d = Qb(a, b, b);\n            if (((((d < 0)) || ((d == null))))) {\n                d = ((a.style[b] || 0));\n            }\n        ;\n        ;\n            d = ((parseFloat(d) || 0));\n            if (c) {\n                for (; ((f < g)); f++) {\n                    d += ((parseFloat(L.css(a, ((\"padding\" + e[f])))) || 0)), ((((c !== \"padding\")) && (d += ((parseFloat(L.css(a, ((((\"border\" + e[f])) + \"Width\")))) || 0))))), ((((c === \"margin\")) && (d += ((parseFloat(L.css(a, ((c + e[f])))) || 0)))));\n                ;\n                };\n            }\n        ;\n        ;\n            return ((d + \"px\"));\n        };\n    ;\n        function v(a) {\n            return function(b, c) {\n                ((((typeof b != \"string\")) && (c = b, b = \"*\")));\n                if (L.isFunction(c)) {\n                    var d = b.toLowerCase().split(dc), e = 0, f = d.length, g, i, j;\n                    for (; ((e < f)); e++) {\n                        g = d[e], j = /^\\+/.test(g), ((j && (g = ((g.substr(1) || \"*\"))))), i = a[g] = ((a[g] || [])), i[((j ? \"unshift\" : \"push\"))](c);\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        function w(a, c, d, e, f, g) {\n            f = ((f || c.dataTypes[0])), g = ((g || {\n            })), g[f] = !0;\n            var i = a[f], j = 0, k = ((i ? i.length : 0)), l = ((a === hc)), m;\n            for (; ((((j < k)) && ((l || !m)))); j++) {\n                m = i[j](c, d, e), ((((typeof m == \"string\")) && ((((!l || g[m])) ? m = b : (c.dataTypes.unshift(m), m = w(a, c, d, e, m, g))))));\n            ;\n            };\n        ;\n            return ((((((l || !m)) && !g[\"*\"])) && (m = w(a, c, d, e, \"*\", g)))), m;\n        };\n    ;\n        function x(a, c) {\n            var d, e, f = ((L.ajaxSettings.flatOptions || {\n            }));\n            for (d in c) {\n                ((((c[d] !== b)) && (((f[d] ? a : ((e || (e = {\n                })))))[d] = c[d])));\n            ;\n            };\n        ;\n            ((e && L.extend(!0, a, e)));\n        };\n    ;\n        function y(a, b, c, d) {\n            if (L.isArray(b)) {\n                L.each(b, function(b, e) {\n                    ((((c || Ub.test(a))) ? d(a, e) : y(((((((a + \"[\")) + ((((((typeof e == \"object\")) || L.isArray(e))) ? b : \"\")))) + \"]\")), e, c, d)));\n                });\n            }\n             else {\n                if (((((!c && ((b != null)))) && ((typeof b == \"object\"))))) {\n                    for (var e in b) {\n                        y(((((((a + \"[\")) + e)) + \"]\")), b[e], c, d);\n                    ;\n                    };\n                }\n                 else {\n                    d(a, b);\n                }\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        function z(a, c, d) {\n            var e = a.contents, f = a.dataTypes, g = a.responseFields, i, j, k, l;\n            for (j in g) {\n                ((((j in d)) && (c[g[j]] = d[j])));\n            ;\n            };\n        ;\n            while (((f[0] === \"*\"))) {\n                f.shift(), ((((i === b)) && (i = ((a.mimeType || c.getResponseHeader(\"content-type\"))))));\n            ;\n            };\n        ;\n            if (i) {\n                for (j in e) {\n                    if (((e[j] && e[j].test(i)))) {\n                        f.unshift(j);\n                        break;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            if (((f[0] in d))) k = f[0];\n             else {\n                for (j in d) {\n                    if (((!f[0] || a.converters[((((j + \" \")) + f[0]))]))) {\n                        k = j;\n                        break;\n                    }\n                ;\n                ;\n                    ((l || (l = j)));\n                };\n            ;\n                k = ((k || l));\n            }\n        ;\n        ;\n            if (k) {\n                return ((((k !== f[0])) && f.unshift(k))), d[k];\n            }\n        ;\n        ;\n        };\n    ;\n        function A(a, c) {\n            ((a.dataFilter && (c = a.dataFilter(c, a.dataType))));\n            var d = a.dataTypes, e = {\n            }, f, g, i = d.length, j, k = d[0], l, m, n, o, p;\n            for (f = 1; ((f < i)); f++) {\n                if (((f === 1))) {\n                    for (g in a.converters) {\n                        ((((typeof g == \"string\")) && (e[g.toLowerCase()] = a.converters[g])));\n                    ;\n                    };\n                }\n            ;\n            ;\n                l = k, k = d[f];\n                if (((k === \"*\"))) {\n                    k = l;\n                }\n                 else {\n                    if (((((l !== \"*\")) && ((l !== k))))) {\n                        m = ((((l + \" \")) + k)), n = ((e[m] || e[((\"* \" + k))]));\n                        if (!n) {\n                            p = b;\n                            for (o in e) {\n                                j = o.split(\" \");\n                                if (((((j[0] === l)) || ((j[0] === \"*\"))))) {\n                                    p = e[((((j[1] + \" \")) + k))];\n                                    if (p) {\n                                        o = e[o], ((((o === !0)) ? n = p : ((((p === !0)) && (n = o)))));\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                    ;\n                    ;\n                        ((((!n && !p)) && L.error(((\"No conversion from \" + m.replace(\" \", \" to \")))))), ((((n !== !0)) && (c = ((n ? n(c) : p(o(c)))))));\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return c;\n        };\n    ;\n        function B() {\n            try {\n                return new a.JSBNG__XMLHttpRequest;\n            } catch (b) {\n            \n            };\n        ;\n        };\n    ;\n        function C() {\n            try {\n                return new a.ActiveXObject(\"Microsoft.XMLHTTP\");\n            } catch (b) {\n            \n            };\n        ;\n        };\n    ;\n        function D() {\n            return JSBNG__setTimeout(E, 0), zc = L.now();\n        };\n    ;\n        function E() {\n            zc = b;\n        };\n    ;\n        function F(a, b) {\n            var c = {\n            };\n            return L.each(yc.concat.apply([], yc.slice(0, b)), function() {\n                c[this] = a;\n            }), c;\n        };\n    ;\n        function G(a) {\n            if (!sc[a]) {\n                var b = I.body, c = L(((((\"\\u003C\" + a)) + \"\\u003E\"))).appendTo(b), d = c.css(\"display\");\n                c.remove();\n                if (((((d === \"none\")) || ((d === \"\"))))) {\n                    ((tc || (tc = I.createElement(\"div\"), tc.frameBorder = tc.width = tc.height = 0))), b.appendChild(tc);\n                    if (((!uc || !tc.createElement))) {\n                        uc = ((tc.contentWindow || tc.contentDocument)).JSBNG__document, uc.write(((((((I.compatMode === \"CSS1Compat\")) ? \"\\u003C!doctype html\\u003E\" : \"\")) + \"\\u003Chtml\\u003E\\u003Cbody\\u003E\"))), uc.close();\n                    }\n                ;\n                ;\n                    c = uc.createElement(a), uc.body.appendChild(c), d = L.css(c, \"display\"), b.removeChild(tc);\n                }\n            ;\n            ;\n                sc[a] = d;\n            }\n        ;\n        ;\n            return sc[a];\n        };\n    ;\n        function H(a) {\n            return ((L.isWindow(a) ? a : ((((a.nodeType === 9)) ? ((a.defaultView || a.parentWindow)) : !1))));\n        };\n    ;\n        var I = a.JSBNG__document, J = a.JSBNG__navigator, K = a.JSBNG__location, L = function() {\n            function c() {\n                if (d.isReady) {\n                    return;\n                }\n            ;\n            ;\n                try {\n                    I.documentElement.doScroll(\"left\");\n                } catch (a) {\n                    JSBNG__setTimeout(c, 1);\n                    return;\n                };\n            ;\n                d.ready();\n            };\n        ;\n            var d = function(a, b) {\n                return new d.fn.init(a, b, g);\n            }, e = a.jQuery, f = a.$, g, i = /^(?:[^#<]*(<[\\w\\W]+>)[^>]*$|#([\\w\\-]*)$)/, j = /\\S/, k = /^\\s+/, l = /\\s+$/, m = /^<(\\w+)\\s*\\/?>(?:<\\/\\1>)?$/, n = /^[\\],:{}\\s]*$/, o = /\\\\(?:[\"\\\\\\/bfnrt]|u[0-9a-fA-F]{4})/g, p = /\"[^\"\\\\\\n\\r]*\"|true|false|null|-?\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d+)?/g, q = /(?:^|:|,)(?:\\s*\\[)+/g, r = /(webkit)[ \\/]([\\w.]+)/, s = /(opera)(?:.*version)?[ \\/]([\\w.]+)/, t = /(msie) ([\\w.]+)/, u = /(mozilla)(?:.*? rv:([\\w.]+))?/, v = /-([a-z]|[0-9])/gi, w = /^-ms-/, x = function(a, b) {\n                return ((b + \"\")).toUpperCase();\n            }, y = J.userAgent, z, A, B, C = Object.prototype.toString, D = Object.prototype.hasOwnProperty, E = Array.prototype.push, F = Array.prototype.slice, G = String.prototype.trim, H = Array.prototype.indexOf, K = {\n            };\n            return d.fn = d.prototype = {\n                constructor: d,\n                init: function(a, c, e) {\n                    var f, g, j, k;\n                    if (!a) {\n                        return this;\n                    }\n                ;\n                ;\n                    if (a.nodeType) {\n                        return this.context = this[0] = a, this.length = 1, this;\n                    }\n                ;\n                ;\n                    if (((((((a === \"body\")) && !c)) && I.body))) {\n                        return this.context = I, this[0] = I.body, this.selector = a, this.length = 1, this;\n                    }\n                ;\n                ;\n                    if (((typeof a == \"string\"))) {\n                        ((((((((a.charAt(0) === \"\\u003C\")) && ((a.charAt(((a.length - 1))) === \"\\u003E\")))) && ((a.length >= 3)))) ? f = [null,a,null,] : f = i.exec(a)));\n                        if (((f && ((f[1] || !c))))) {\n                            if (f[1]) {\n                                return c = ((((c instanceof d)) ? c[0] : c)), k = ((c ? ((c.ownerDocument || c)) : I)), j = m.exec(a), ((j ? ((d.isPlainObject(c) ? (a = [I.createElement(j[1]),], d.fn.attr.call(a, c, !0)) : a = [k.createElement(j[1]),])) : (j = d.buildFragment([f[1],], [k,]), a = ((j.cacheable ? d.clone(j.fragment) : j.fragment)).childNodes))), d.merge(this, a);\n                            }\n                        ;\n                        ;\n                            g = I.getElementById(f[2]);\n                            if (((g && g.parentNode))) {\n                                if (((g.id !== f[2]))) {\n                                    return e.JSBNG__find(a);\n                                }\n                            ;\n                            ;\n                                this.length = 1, this[0] = g;\n                            }\n                        ;\n                        ;\n                            return this.context = I, this.selector = a, this;\n                        }\n                    ;\n                    ;\n                        return ((((!c || c.jquery)) ? ((c || e)).JSBNG__find(a) : this.constructor(c).JSBNG__find(a)));\n                    }\n                ;\n                ;\n                    return ((d.isFunction(a) ? e.ready(a) : (((((a.selector !== b)) && (this.selector = a.selector, this.context = a.context))), d.makeArray(a, this))));\n                },\n                selector: \"\",\n                jquery: \"1.7.1\",\n                length: 0,\n                size: function() {\n                    return this.length;\n                },\n                toArray: function() {\n                    return F.call(this, 0);\n                },\n                get: function(a) {\n                    return ((((a == null)) ? this.toArray() : ((((a < 0)) ? this[((this.length + a))] : this[a]))));\n                },\n                pushStack: function(a, b, c) {\n                    var e = this.constructor();\n                    return ((d.isArray(a) ? E.apply(e, a) : d.merge(e, a))), e.prevObject = this, e.context = this.context, ((((b === \"JSBNG__find\")) ? e.selector = ((((this.selector + ((this.selector ? \" \" : \"\")))) + c)) : ((b && (e.selector = ((((((((((this.selector + \".\")) + b)) + \"(\")) + c)) + \")\"))))))), e;\n                },\n                each: function(a, b) {\n                    return d.each(this, a, b);\n                },\n                ready: function(a) {\n                    return d.bindReady(), A.add(a), this;\n                },\n                eq: function(a) {\n                    return a = +a, ((((a === -1)) ? this.slice(a) : this.slice(a, ((a + 1)))));\n                },\n                first: function() {\n                    return this.eq(0);\n                },\n                last: function() {\n                    return this.eq(-1);\n                },\n                slice: function() {\n                    return this.pushStack(F.apply(this, arguments), \"slice\", F.call(arguments).join(\",\"));\n                },\n                map: function(a) {\n                    return this.pushStack(d.map(this, function(b, c) {\n                        return a.call(b, c, b);\n                    }));\n                },\n                end: function() {\n                    return ((this.prevObject || this.constructor(null)));\n                },\n                push: E,\n                sort: [].sort,\n                splice: [].splice\n            }, d.fn.init.prototype = d.fn, d.extend = d.fn.extend = function() {\n                var a, c, e, f, g, i, j = ((arguments[0] || {\n                })), k = 1, l = arguments.length, m = !1;\n                ((((typeof j == \"boolean\")) && (m = j, j = ((arguments[1] || {\n                })), k = 2))), ((((((typeof j != \"object\")) && !d.isFunction(j))) && (j = {\n                }))), ((((l === k)) && (j = this, --k)));\n                for (; ((k < l)); k++) {\n                    if ((((a = arguments[k]) != null))) {\n                        for (c in a) {\n                            e = j[c], f = a[c];\n                            if (((j === f))) {\n                                continue;\n                            }\n                        ;\n                        ;\n                            ((((((m && f)) && ((d.isPlainObject(f) || (g = d.isArray(f)))))) ? (((g ? (g = !1, i = ((((e && d.isArray(e))) ? e : []))) : i = ((((e && d.isPlainObject(e))) ? e : {\n                            })))), j[c] = d.extend(m, i, f)) : ((((f !== b)) && (j[c] = f)))));\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return j;\n            }, d.extend({\n                noConflict: function(b) {\n                    return ((((a.$ === d)) && (a.$ = f))), ((((b && ((a.jQuery === d)))) && (a.jQuery = e))), d;\n                },\n                isReady: !1,\n                readyWait: 1,\n                holdReady: function(a) {\n                    ((a ? d.readyWait++ : d.ready(!0)));\n                },\n                ready: function(a) {\n                    if (((((((a === !0)) && !--d.readyWait)) || ((((a !== !0)) && !d.isReady))))) {\n                        if (!I.body) {\n                            return JSBNG__setTimeout(d.ready, 1);\n                        }\n                    ;\n                    ;\n                        d.isReady = !0;\n                        if (((((a !== !0)) && ((--d.readyWait > 0))))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        A.fireWith(I, [d,]), ((d.fn.trigger && d(I).trigger(\"ready\").off(\"ready\")));\n                    }\n                ;\n                ;\n                },\n                bindReady: function() {\n                    if (A) {\n                        return;\n                    }\n                ;\n                ;\n                    A = d.Callbacks(\"JSBNG__once memory\");\n                    if (((I.readyState === \"complete\"))) {\n                        return JSBNG__setTimeout(d.ready, 1);\n                    }\n                ;\n                ;\n                    if (I.JSBNG__addEventListener) {\n                        I.JSBNG__addEventListener(\"DOMContentLoaded\", B, !1), a.JSBNG__addEventListener(\"load\", d.ready, !1);\n                    }\n                     else {\n                        if (I.JSBNG__attachEvent) {\n                            I.JSBNG__attachEvent(\"JSBNG__onreadystatechange\", B), a.JSBNG__attachEvent(\"JSBNG__onload\", d.ready);\n                            var b = !1;\n                            try {\n                                b = ((a.JSBNG__frameElement == null));\n                            } catch (e) {\n                            \n                            };\n                        ;\n                            ((((I.documentElement.doScroll && b)) && c()));\n                        }\n                    ;\n                    }\n                ;\n                ;\n                },\n                isFunction: function(a) {\n                    return ((d.type(a) === \"function\"));\n                },\n                isArray: ((Array.isArray || function(a) {\n                    return ((d.type(a) === \"array\"));\n                })),\n                isWindow: function(a) {\n                    return ((((a && ((typeof a == \"object\")))) && ((\"JSBNG__setInterval\" in a))));\n                },\n                isNumeric: function(a) {\n                    return ((!isNaN(parseFloat(a)) && isFinite(a)));\n                },\n                type: function(a) {\n                    return ((((a == null)) ? String(a) : ((K[C.call(a)] || \"object\"))));\n                },\n                isPlainObject: function(a) {\n                    if (((((((!a || ((d.type(a) !== \"object\")))) || a.nodeType)) || d.isWindow(a)))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    try {\n                        if (((((a.constructor && !D.call(a, \"constructor\"))) && !D.call(a.constructor.prototype, \"isPrototypeOf\")))) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                    } catch (c) {\n                        return !1;\n                    };\n                ;\n                    var e;\n                    for (e in a) {\n                    ;\n                    };\n                ;\n                    return ((((e === b)) || D.call(a, e)));\n                },\n                isEmptyObject: function(a) {\n                    for (var b in a) {\n                        return !1;\n                    };\n                ;\n                    return !0;\n                },\n                error: function(a) {\n                    throw new Error(a);\n                },\n                parseJSON: function(b) {\n                    if (((((typeof b != \"string\")) || !b))) {\n                        return null;\n                    }\n                ;\n                ;\n                    b = d.trim(b);\n                    if (((a.JSON && a.JSON.parse))) {\n                        return a.JSON.parse(b);\n                    }\n                ;\n                ;\n                    if (n.test(b.replace(o, \"@\").replace(p, \"]\").replace(q, \"\"))) {\n                        return (new Function(((\"return \" + b))))();\n                    }\n                ;\n                ;\n                    d.error(((\"Invalid JSON: \" + b)));\n                },\n                parseXML: function(c) {\n                    var e, f;\n                    try {\n                        ((a.JSBNG__DOMParser ? (f = new JSBNG__DOMParser, e = f.parseFromString(c, \"text/xml\")) : (e = new ActiveXObject(\"Microsoft.XMLDOM\"), e.async = \"false\", e.loadXML(c))));\n                    } catch (g) {\n                        e = b;\n                    };\n                ;\n                    return ((((((!e || !e.documentElement)) || e.getElementsByTagName(\"parsererror\").length)) && d.error(((\"Invalid XML: \" + c))))), e;\n                },\n                noop: function() {\n                \n                },\n                globalEval: function(b) {\n                    ((((b && j.test(b))) && ((a.execScript || function(b) {\n                        a.eval.call(a, b);\n                    }))(b)));\n                },\n                camelCase: function(a) {\n                    return a.replace(w, \"ms-\").replace(v, x);\n                },\n                nodeName: function(a, b) {\n                    return ((a.nodeName && ((a.nodeName.toUpperCase() === b.toUpperCase()))));\n                },\n                each: function(a, c, e) {\n                    var f, g = 0, i = a.length, j = ((((i === b)) || d.isFunction(a)));\n                    if (e) {\n                        if (j) {\n                            for (f in a) {\n                                if (((c.apply(a[f], e) === !1))) {\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                         else for (; ((g < i)); ) {\n                            if (((c.apply(a[g++], e) === !1))) {\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                     else if (j) {\n                        for (f in a) {\n                            if (((c.call(a[f], f, a[f]) === !1))) {\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                     else for (; ((g < i)); ) {\n                        if (((c.call(a[g], g, a[g++]) === !1))) {\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                    \n                ;\n                ;\n                    return a;\n                },\n                trim: ((G ? function(a) {\n                    return ((((a == null)) ? \"\" : G.call(a)));\n                } : function(a) {\n                    return ((((a == null)) ? \"\" : a.toString().replace(k, \"\").replace(l, \"\")));\n                })),\n                makeArray: function(a, b) {\n                    var c = ((b || []));\n                    if (((a != null))) {\n                        var e = d.type(a);\n                        ((((((((((((a.length == null)) || ((e === \"string\")))) || ((e === \"function\")))) || ((e === \"regexp\")))) || d.isWindow(a))) ? E.call(c, a) : d.merge(c, a)));\n                    }\n                ;\n                ;\n                    return c;\n                },\n                inArray: function(a, b, c) {\n                    var d;\n                    if (b) {\n                        if (H) {\n                            return H.call(b, a, c);\n                        }\n                    ;\n                    ;\n                        d = b.length, c = ((c ? ((((c < 0)) ? Math.max(0, ((d + c))) : c)) : 0));\n                        for (; ((c < d)); c++) {\n                            if (((((c in b)) && ((b[c] === a))))) {\n                                return c;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return -1;\n                },\n                merge: function(a, c) {\n                    var d = a.length, e = 0;\n                    if (((typeof c.length == \"number\"))) {\n                        for (var f = c.length; ((e < f)); e++) {\n                            a[d++] = c[e];\n                        ;\n                        };\n                    }\n                     else {\n                        while (((c[e] !== b))) {\n                            a[d++] = c[e++];\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return a.length = d, a;\n                },\n                grep: function(a, b, c) {\n                    var d = [], e;\n                    c = !!c;\n                    for (var f = 0, g = a.length; ((f < g)); f++) {\n                        e = !!b(a[f], f), ((((c !== e)) && d.push(a[f])));\n                    ;\n                    };\n                ;\n                    return d;\n                },\n                map: function(a, c, e) {\n                    var f, g, i = [], j = 0, k = a.length, l = ((((a instanceof d)) || ((((((k !== b)) && ((typeof k == \"number\")))) && ((((((((((k > 0)) && a[0])) && a[((k - 1))])) || ((k === 0)))) || d.isArray(a)))))));\n                    if (l) {\n                        for (; ((j < k)); j++) {\n                            f = c(a[j], j, e), ((((f != null)) && (i[i.length] = f)));\n                        ;\n                        };\n                    }\n                     else {\n                        for (g in a) {\n                            f = c(a[g], g, e), ((((f != null)) && (i[i.length] = f)));\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return i.concat.apply([], i);\n                },\n                guid: 1,\n                proxy: function(a, c) {\n                    if (((typeof c == \"string\"))) {\n                        var e = a[c];\n                        c = a, a = e;\n                    }\n                ;\n                ;\n                    if (!d.isFunction(a)) {\n                        return b;\n                    }\n                ;\n                ;\n                    var f = F.call(arguments, 2), g = function() {\n                        return a.apply(c, f.concat(F.call(arguments)));\n                    };\n                    return g.guid = a.guid = ((((a.guid || g.guid)) || d.guid++)), g;\n                },\n                access: function(a, c, e, f, g, i) {\n                    var j = a.length;\n                    if (((typeof c == \"object\"))) {\n                        for (var k in c) {\n                            d.access(a, k, c[k], f, g, e);\n                        ;\n                        };\n                    ;\n                        return a;\n                    }\n                ;\n                ;\n                    if (((e !== b))) {\n                        f = ((((!i && f)) && d.isFunction(e)));\n                        for (var l = 0; ((l < j)); l++) {\n                            g(a[l], c, ((f ? e.call(a[l], l, g(a[l], c)) : e)), i);\n                        ;\n                        };\n                    ;\n                        return a;\n                    }\n                ;\n                ;\n                    return ((j ? g(a[0], c) : b));\n                },\n                now: function() {\n                    return (new JSBNG__Date).getTime();\n                },\n                uaMatch: function(a) {\n                    a = a.toLowerCase();\n                    var b = ((((((((r.exec(a) || s.exec(a))) || t.exec(a))) || ((((a.indexOf(\"compatible\") < 0)) && u.exec(a))))) || []));\n                    return {\n                        browser: ((b[1] || \"\")),\n                        version: ((b[2] || \"0\"))\n                    };\n                },\n                sub: function() {\n                    function a(b, c) {\n                        return new a.fn.init(b, c);\n                    };\n                ;\n                    d.extend(!0, a, this), a.superclass = this, a.fn = a.prototype = this(), a.fn.constructor = a, a.sub = this.sub, a.fn.init = function(c, e) {\n                        return ((((((e && ((e instanceof d)))) && !((e instanceof a)))) && (e = a(e)))), d.fn.init.call(this, c, e, b);\n                    }, a.fn.init.prototype = a.fn;\n                    var b = a(I);\n                    return a;\n                },\n                browser: {\n                }\n            }), d.each(\"Boolean Number String Function Array Date RegExp Object\".split(\" \"), function(a, b) {\n                K[((((\"[object \" + b)) + \"]\"))] = b.toLowerCase();\n            }), z = d.uaMatch(y), ((z.browser && (d.browser[z.browser] = !0, d.browser.version = z.version))), ((d.browser.webkit && (d.browser.safari = !0))), ((j.test(\"\\u00a0\") && (k = /^[\\s\\xA0]+/, l = /[\\s\\xA0]+$/))), g = d(I), ((I.JSBNG__addEventListener ? B = function() {\n                I.JSBNG__removeEventListener(\"DOMContentLoaded\", B, !1), d.ready();\n            } : ((I.JSBNG__attachEvent && (B = function() {\n                ((((I.readyState === \"complete\")) && (I.JSBNG__detachEvent(\"JSBNG__onreadystatechange\", B), d.ready())));\n            }))))), d;\n        }(), M = {\n        };\n        L.Callbacks = function(a) {\n            a = ((a ? ((M[a] || c(a))) : {\n            }));\n            var d = [], e = [], f, g, i, j, k, l = function(b) {\n                var c, e, f, g, i;\n                for (c = 0, e = b.length; ((c < e)); c++) {\n                    f = b[c], g = L.type(f), ((((g === \"array\")) ? l(f) : ((((((g === \"function\")) && ((!a.unique || !n.has(f))))) && d.push(f)))));\n                ;\n                };\n            ;\n            }, m = function(b, c) {\n                c = ((c || [])), f = ((!a.memory || [b,c,])), g = !0, k = ((i || 0)), i = 0, j = d.length;\n                for (; ((d && ((k < j)))); k++) {\n                    if (((((d[k].apply(b, c) === !1)) && a.stopOnFalse))) {\n                        f = !0;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                g = !1, ((d && ((a.JSBNG__once ? ((((f === !0)) ? n.disable() : d = [])) : ((((e && e.length)) && (f = e.shift(), n.fireWith(f[0], f[1]))))))));\n            }, n = {\n                add: function() {\n                    if (d) {\n                        var a = d.length;\n                        l(arguments), ((g ? j = d.length : ((((f && ((f !== !0)))) && (i = a, m(f[0], f[1]))))));\n                    }\n                ;\n                ;\n                    return this;\n                },\n                remove: function() {\n                    if (d) {\n                        var b = arguments, c = 0, e = b.length;\n                        for (; ((c < e)); c++) {\n                            for (var f = 0; ((f < d.length)); f++) {\n                                if (((b[c] === d[f]))) {\n                                    ((((g && ((f <= j)))) && (j--, ((((f <= k)) && k--))))), d.splice(f--, 1);\n                                    if (a.unique) {\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return this;\n                },\n                has: function(a) {\n                    if (d) {\n                        var b = 0, c = d.length;\n                        for (; ((b < c)); b++) {\n                            if (((a === d[b]))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return !1;\n                },\n                empty: function() {\n                    return d = [], this;\n                },\n                disable: function() {\n                    return d = e = f = b, this;\n                },\n                disabled: function() {\n                    return !d;\n                },\n                lock: function() {\n                    return e = b, ((((!f || ((f === !0)))) && n.disable())), this;\n                },\n                locked: function() {\n                    return !e;\n                },\n                fireWith: function(b, c) {\n                    return ((e && ((g ? ((a.JSBNG__once || e.push([b,c,]))) : ((((!a.JSBNG__once || !f)) && m(b, c))))))), this;\n                },\n                fire: function() {\n                    return n.fireWith(this, arguments), this;\n                },\n                fired: function() {\n                    return !!f;\n                }\n            };\n            return n;\n        };\n        var N = [].slice;\n        L.extend({\n            Deferred: function(a) {\n                var b = L.Callbacks(\"JSBNG__once memory\"), c = L.Callbacks(\"JSBNG__once memory\"), d = L.Callbacks(\"memory\"), e = \"pending\", f = {\n                    resolve: b,\n                    reject: c,\n                    notify: d\n                }, g = {\n                    done: b.add,\n                    fail: c.add,\n                    progress: d.add,\n                    state: function() {\n                        return e;\n                    },\n                    isResolved: b.fired,\n                    isRejected: c.fired,\n                    then: function(a, b, c) {\n                        return i.done(a).fail(b).progress(c), this;\n                    },\n                    always: function() {\n                        return i.done.apply(i, arguments).fail.apply(i, arguments), this;\n                    },\n                    pipe: function(a, b, c) {\n                        return L.Deferred(function(d) {\n                            L.each({\n                                done: [a,\"resolve\",],\n                                fail: [b,\"reject\",],\n                                progress: [c,\"notify\",]\n                            }, function(a, b) {\n                                var c = b[0], e = b[1], f;\n                                ((L.isFunction(c) ? i[a](function() {\n                                    f = c.apply(this, arguments), ((((f && L.isFunction(f.promise))) ? f.promise().then(d.resolve, d.reject, d.notify) : d[((e + \"With\"))](((((this === i)) ? d : this)), [f,])));\n                                }) : i[a](d[e])));\n                            });\n                        }).promise();\n                    },\n                    promise: function(a) {\n                        if (((a == null))) {\n                            a = g;\n                        }\n                         else {\n                            for (var b in g) {\n                                a[b] = g[b];\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        return a;\n                    }\n                }, i = g.promise({\n                }), j;\n                for (j in f) {\n                    i[j] = f[j].fire, i[((j + \"With\"))] = f[j].fireWith;\n                ;\n                };\n            ;\n                return i.done(function() {\n                    e = \"resolved\";\n                }, c.disable, d.lock).fail(function() {\n                    e = \"rejected\";\n                }, b.disable, d.lock), ((a && a.call(i, i))), i;\n            },\n            when: function(a) {\n                function b(a) {\n                    return function(b) {\n                        d[a] = ((((arguments.length > 1)) ? N.call(arguments, 0) : b)), ((--i || k.resolveWith(k, d)));\n                    };\n                };\n            ;\n                function c(a) {\n                    return function(b) {\n                        g[a] = ((((arguments.length > 1)) ? N.call(arguments, 0) : b)), k.notifyWith(l, g);\n                    };\n                };\n            ;\n                var d = N.call(arguments, 0), e = 0, f = d.length, g = new Array(f), i = f, j = f, k = ((((((((f <= 1)) && a)) && L.isFunction(a.promise))) ? a : L.Deferred())), l = k.promise();\n                if (((f > 1))) {\n                    for (; ((e < f)); e++) {\n                        ((((((d[e] && d[e].promise)) && L.isFunction(d[e].promise))) ? d[e].promise().then(b(e), k.reject, c(e)) : --i));\n                    ;\n                    };\n                ;\n                    ((i || k.resolveWith(k, d)));\n                }\n                 else ((((k !== a)) && k.resolveWith(k, ((f ? [a,] : [])))));\n            ;\n            ;\n                return l;\n            }\n        }), L.support = function() {\n            var b, c, d, e, f, g, i, j, k, l, m, n, o, p = I.createElement(\"div\"), q = I.documentElement;\n            p.setAttribute(\"className\", \"t\"), p.innerHTML = \"   \\u003Clink/\\u003E\\u003Ctable\\u003E\\u003C/table\\u003E\\u003Ca href='/a' style='top:1px;float:left;opacity:.55;'\\u003Ea\\u003C/a\\u003E\\u003Cinput type='checkbox'/\\u003E\", c = p.getElementsByTagName(\"*\"), d = p.getElementsByTagName(\"a\")[0];\n            if (((((!c || !c.length)) || !d))) {\n                return {\n                };\n            }\n        ;\n        ;\n            e = I.createElement(\"select\"), f = e.appendChild(I.createElement(\"option\")), g = p.getElementsByTagName(\"input\")[0], b = {\n                leadingWhitespace: ((p.firstChild.nodeType === 3)),\n                tbody: !p.getElementsByTagName(\"tbody\").length,\n                htmlSerialize: !!p.getElementsByTagName(\"link\").length,\n                style: /top/.test(d.getAttribute(\"style\")),\n                hrefNormalized: ((d.getAttribute(\"href\") === \"/a\")),\n                opacity: /^0.55/.test(d.style.opacity),\n                cssFloat: !!d.style.cssFloat,\n                checkOn: ((g.value === \"JSBNG__on\")),\n                optSelected: f.selected,\n                getSetAttribute: ((p.className !== \"t\")),\n                enctype: !!I.createElement(\"form\").enctype,\n                html5Clone: ((I.createElement(\"nav\").cloneNode(!0).outerHTML !== \"\\u003C:nav\\u003E\\u003C/:nav\\u003E\")),\n                submitBubbles: !0,\n                changeBubbles: !0,\n                focusinBubbles: !1,\n                deleteExpando: !0,\n                noCloneEvent: !0,\n                inlineBlockNeedsLayout: !1,\n                shrinkWrapBlocks: !1,\n                reliableMarginRight: !0\n            }, g.checked = !0, b.noCloneChecked = g.cloneNode(!0).checked, e.disabled = !0, b.optDisabled = !f.disabled;\n            try {\n                delete p.test;\n            } catch (r) {\n                b.deleteExpando = !1;\n            };\n        ;\n            ((((((!p.JSBNG__addEventListener && p.JSBNG__attachEvent)) && p.fireEvent)) && (p.JSBNG__attachEvent(\"JSBNG__onclick\", function() {\n                b.noCloneEvent = !1;\n            }), p.cloneNode(!0).fireEvent(\"JSBNG__onclick\")))), g = I.createElement(\"input\"), g.value = \"t\", g.setAttribute(\"type\", \"radio\"), b.radioValue = ((g.value === \"t\")), g.setAttribute(\"checked\", \"checked\"), p.appendChild(g), j = I.createDocumentFragment(), j.appendChild(p.lastChild), b.checkClone = j.cloneNode(!0).cloneNode(!0).lastChild.checked, b.appendChecked = g.checked, j.removeChild(g), j.appendChild(p), p.innerHTML = \"\", ((a.JSBNG__getComputedStyle && (i = I.createElement(\"div\"), i.style.width = \"0\", i.style.marginRight = \"0\", p.style.width = \"2px\", p.appendChild(i), b.reliableMarginRight = ((((parseInt(((a.JSBNG__getComputedStyle(i, null) || {\n                marginRight: 0\n            })).marginRight, 10) || 0)) === 0)))));\n            if (p.JSBNG__attachEvent) {\n                for (n in {\n                    submit: 1,\n                    change: 1,\n                    focusin: 1\n                }) {\n                    m = ((\"JSBNG__on\" + n)), o = ((m in p)), ((o || (p.setAttribute(m, \"return;\"), o = ((typeof p[m] == \"function\"))))), b[((n + \"Bubbles\"))] = o;\n                ;\n                };\n            }\n        ;\n        ;\n            return j.removeChild(p), j = e = f = i = p = g = null, L(function() {\n                var a, c, d, e, f, g, i, j, l, m, n, q = I.getElementsByTagName(\"body\")[0];\n                if (!q) {\n                    return;\n                }\n            ;\n            ;\n                i = 1, j = \"position:absolute;top:0;left:0;width:1px;height:1px;margin:0;\", l = \"visibility:hidden;border:0;\", m = ((((\"style='\" + j)) + \"border:5px solid #000;padding:0;'\")), n = ((((((((((((\"\\u003Cdiv \" + m)) + \"\\u003E\\u003Cdiv\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\")) + \"\\u003Ctable \")) + m)) + \" cellpadding='0' cellspacing='0'\\u003E\")) + \"\\u003Ctr\\u003E\\u003Ctd\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/table\\u003E\")), a = I.createElement(\"div\"), a.style.cssText = ((((((l + \"width:0;height:0;position:static;top:0;margin-top:\")) + i)) + \"px\")), q.insertBefore(a, q.firstChild), p = I.createElement(\"div\"), a.appendChild(p), p.innerHTML = \"\\u003Ctable\\u003E\\u003Ctr\\u003E\\u003Ctd style='padding:0;border:0;display:none'\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Et\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/table\\u003E\", k = p.getElementsByTagName(\"td\"), o = ((k[0].offsetHeight === 0)), k[0].style.display = \"\", k[1].style.display = \"none\", b.reliableHiddenOffsets = ((o && ((k[0].offsetHeight === 0)))), p.innerHTML = \"\", p.style.width = p.style.paddingLeft = \"1px\", L.boxModel = b.boxModel = ((p.offsetWidth === 2)), ((((typeof p.style.zoom != \"undefined\")) && (p.style.display = \"inline\", p.style.zoom = 1, b.inlineBlockNeedsLayout = ((p.offsetWidth === 2)), p.style.display = \"\", p.innerHTML = \"\\u003Cdiv style='width:4px;'\\u003E\\u003C/div\\u003E\", b.shrinkWrapBlocks = ((p.offsetWidth !== 2))))), p.style.cssText = ((j + l)), p.innerHTML = n, c = p.firstChild, d = c.firstChild, f = c.nextSibling.firstChild.firstChild, g = {\n                    doesNotAddBorder: ((d.offsetTop !== 5)),\n                    doesAddBorderForTableAndCells: ((f.offsetTop === 5))\n                }, d.style.position = \"fixed\", d.style.JSBNG__top = \"20px\", g.fixedPosition = ((((d.offsetTop === 20)) || ((d.offsetTop === 15)))), d.style.position = d.style.JSBNG__top = \"\", c.style.overflow = \"hidden\", c.style.position = \"relative\", g.subtractsBorderForOverflowNotVisible = ((d.offsetTop === -5)), g.doesNotIncludeMarginInBodyOffset = ((q.offsetTop !== i)), q.removeChild(a), p = a = null, L.extend(b, g);\n            }), b;\n        }();\n        var O = /^(?:\\{.*\\}|\\[.*\\])$/, P = /([A-Z])/g;\n        L.extend({\n            cache: {\n            },\n            uuid: 0,\n            expando: ((\"jQuery\" + ((L.fn.jquery + Math.JSBNG__random())).replace(/\\D/g, \"\"))),\n            noData: {\n                embed: !0,\n                object: \"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\",\n                applet: !0\n            },\n            hasData: function(a) {\n                return a = ((a.nodeType ? L.cache[a[L.expando]] : a[L.expando])), ((!!a && !e(a)));\n            },\n            data: function(a, c, d, e) {\n                if (!L.acceptData(a)) {\n                    return;\n                }\n            ;\n            ;\n                var f, g, i, j = L.expando, k = ((typeof c == \"string\")), l = a.nodeType, m = ((l ? L.cache : a)), n = ((l ? a[j] : ((a[j] && j)))), o = ((c === \"events\"));\n                if (((((((((!n || !m[n])) || ((((!o && !e)) && !m[n].data)))) && k)) && ((d === b))))) {\n                    return;\n                }\n            ;\n            ;\n                ((n || ((l ? a[j] = n = ++L.uuid : n = j)))), ((m[n] || (m[n] = {\n                }, ((l || (m[n].toJSON = L.noop))))));\n                if (((((typeof c == \"object\")) || ((typeof c == \"function\"))))) {\n                    ((e ? m[n] = L.extend(m[n], c) : m[n].data = L.extend(m[n].data, c)));\n                }\n            ;\n            ;\n                return f = g = m[n], ((e || (((g.data || (g.data = {\n                }))), g = g.data))), ((((d !== b)) && (g[L.camelCase(c)] = d))), ((((o && !g[c])) ? f.events : (((k ? (i = g[c], ((((i == null)) && (i = g[L.camelCase(c)])))) : i = g)), i)));\n            },\n            removeData: function(a, b, c) {\n                if (!L.acceptData(a)) {\n                    return;\n                }\n            ;\n            ;\n                var d, f, g, i = L.expando, j = a.nodeType, k = ((j ? L.cache : a)), l = ((j ? a[i] : i));\n                if (!k[l]) {\n                    return;\n                }\n            ;\n            ;\n                if (b) {\n                    d = ((c ? k[l] : k[l].data));\n                    if (d) {\n                        ((L.isArray(b) || ((((b in d)) ? b = [b,] : (b = L.camelCase(b), ((((b in d)) ? b = [b,] : b = b.split(\" \"))))))));\n                        for (f = 0, g = b.length; ((f < g)); f++) {\n                            delete d[b[f]];\n                        ;\n                        };\n                    ;\n                        if (!((c ? e : L.isEmptyObject))(d)) {\n                            return;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                if (!c) {\n                    delete k[l].data;\n                    if (!e(k[l])) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((((L.support.deleteExpando || !k.JSBNG__setInterval)) ? delete k[l] : k[l] = null)), ((j && ((L.support.deleteExpando ? delete a[i] : ((a.removeAttribute ? a.removeAttribute(i) : a[i] = null))))));\n            },\n            _data: function(a, b, c) {\n                return L.data(a, b, c, !0);\n            },\n            acceptData: function(a) {\n                if (a.nodeName) {\n                    var b = L.noData[a.nodeName.toLowerCase()];\n                    if (b) {\n                        return ((((b !== !0)) && ((a.getAttribute(\"classid\") === b))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return !0;\n            }\n        }), L.fn.extend({\n            data: function(a, c) {\n                var e, f, g, i = null;\n                if (((typeof a == \"undefined\"))) {\n                    if (this.length) {\n                        i = L.data(this[0]);\n                        if (((((this[0].nodeType === 1)) && !L._data(this[0], \"parsedAttrs\")))) {\n                            f = this[0].attributes;\n                            for (var j = 0, k = f.length; ((j < k)); j++) {\n                                g = f[j].JSBNG__name, ((((g.indexOf(\"data-\") === 0)) && (g = L.camelCase(g.substring(5)), d(this[0], g, i[g]))));\n                            ;\n                            };\n                        ;\n                            L._data(this[0], \"parsedAttrs\", !0);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return i;\n                }\n            ;\n            ;\n                return ((((typeof a == \"object\")) ? this.each(function() {\n                    L.data(this, a);\n                }) : (e = a.split(\".\"), e[1] = ((e[1] ? ((\".\" + e[1])) : \"\")), ((((c === b)) ? (i = this.triggerHandler(((((\"getData\" + e[1])) + \"!\")), [e[0],]), ((((((i === b)) && this.length)) && (i = L.data(this[0], a), i = d(this[0], a, i)))), ((((((i === b)) && e[1])) ? this.data(e[0]) : i))) : this.each(function() {\n                    var b = L(this), d = [e[0],c,];\n                    b.triggerHandler(((((\"setData\" + e[1])) + \"!\")), d), L.data(this, a, c), b.triggerHandler(((((\"changeData\" + e[1])) + \"!\")), d);\n                }))))));\n            },\n            removeData: function(a) {\n                return this.each(function() {\n                    L.removeData(this, a);\n                });\n            }\n        }), L.extend({\n            _mark: function(a, b) {\n                ((a && (b = ((((b || \"fx\")) + \"mark\")), L._data(a, b, ((((L._data(a, b) || 0)) + 1))))));\n            },\n            _unmark: function(a, b, c) {\n                ((((a !== !0)) && (c = b, b = a, a = !1)));\n                if (b) {\n                    c = ((c || \"fx\"));\n                    var d = ((c + \"mark\")), e = ((a ? 0 : ((((L._data(b, d) || 1)) - 1))));\n                    ((e ? L._data(b, d, e) : (L.removeData(b, d, !0), f(b, c, \"mark\"))));\n                }\n            ;\n            ;\n            },\n            queue: function(a, b, c) {\n                var d;\n                if (a) {\n                    return b = ((((b || \"fx\")) + \"queue\")), d = L._data(a, b), ((c && ((((!d || L.isArray(c))) ? d = L._data(a, b, L.makeArray(c)) : d.push(c))))), ((d || []));\n                }\n            ;\n            ;\n            },\n            dequeue: function(a, b) {\n                b = ((b || \"fx\"));\n                var c = L.queue(a, b), d = c.shift(), e = {\n                };\n                ((((d === \"inprogress\")) && (d = c.shift()))), ((d && (((((b === \"fx\")) && c.unshift(\"inprogress\"))), L._data(a, ((b + \".run\")), e), d.call(a, function() {\n                    L.dequeue(a, b);\n                }, e)))), ((c.length || (L.removeData(a, ((((((b + \"queue \")) + b)) + \".run\")), !0), f(a, b, \"queue\"))));\n            }\n        }), L.fn.extend({\n            queue: function(a, c) {\n                return ((((typeof a != \"string\")) && (c = a, a = \"fx\"))), ((((c === b)) ? L.queue(this[0], a) : this.each(function() {\n                    var b = L.queue(this, a, c);\n                    ((((((a === \"fx\")) && ((b[0] !== \"inprogress\")))) && L.dequeue(this, a)));\n                })));\n            },\n            dequeue: function(a) {\n                return this.each(function() {\n                    L.dequeue(this, a);\n                });\n            },\n            delay: function(a, b) {\n                return a = ((L.fx ? ((L.fx.speeds[a] || a)) : a)), b = ((b || \"fx\")), this.queue(b, function(b, c) {\n                    var d = JSBNG__setTimeout(b, a);\n                    c.JSBNG__stop = function() {\n                        JSBNG__clearTimeout(d);\n                    };\n                });\n            },\n            clearQueue: function(a) {\n                return this.queue(((a || \"fx\")), []);\n            },\n            promise: function(a, c) {\n                function d() {\n                    ((--i || e.resolveWith(f, [f,])));\n                };\n            ;\n                ((((typeof a != \"string\")) && (c = a, a = b))), a = ((a || \"fx\"));\n                var e = L.Deferred(), f = this, g = f.length, i = 1, j = ((a + \"defer\")), k = ((a + \"queue\")), l = ((a + \"mark\")), m;\n                while (g--) {\n                    if (m = ((L.data(f[g], j, b, !0) || ((((L.data(f[g], k, b, !0) || L.data(f[g], l, b, !0))) && L.data(f[g], j, L.Callbacks(\"JSBNG__once memory\"), !0)))))) {\n                        i++, m.add(d);\n                    }\n                ;\n                ;\n                };\n            ;\n                return d(), e.promise();\n            }\n        });\n        var Q = /[\\n\\t\\r]/g, R = /\\s+/, S = /\\r/g, T = /^(?:button|input)$/i, U = /^(?:button|input|object|select|textarea)$/i, V = /^a(?:rea)?$/i, W = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i, X = L.support.getSetAttribute, Y, Z, ab;\n        L.fn.extend({\n            attr: function(a, b) {\n                return L.access(this, a, b, !0, L.attr);\n            },\n            removeAttr: function(a) {\n                return this.each(function() {\n                    L.removeAttr(this, a);\n                });\n            },\n            prop: function(a, b) {\n                return L.access(this, a, b, !0, L.prop);\n            },\n            removeProp: function(a) {\n                return a = ((L.propFix[a] || a)), this.each(function() {\n                    try {\n                        this[a] = b, delete this[a];\n                    } catch (c) {\n                    \n                    };\n                ;\n                });\n            },\n            addClass: function(a) {\n                var b, c, d, e, f, g, i;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).addClass(a.call(this, b, this.className));\n                    });\n                }\n            ;\n            ;\n                if (((a && ((typeof a == \"string\"))))) {\n                    b = a.split(R);\n                    for (c = 0, d = this.length; ((c < d)); c++) {\n                        e = this[c];\n                        if (((e.nodeType === 1))) {\n                            if (((!e.className && ((b.length === 1))))) e.className = a;\n                             else {\n                                f = ((((\" \" + e.className)) + \" \"));\n                                for (g = 0, i = b.length; ((g < i)); g++) {\n                                    ((~f.indexOf(((((\" \" + b[g])) + \" \"))) || (f += ((b[g] + \" \")))));\n                                ;\n                                };\n                            ;\n                                e.className = L.trim(f);\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return this;\n            },\n            removeClass: function(a) {\n                var c, d, e, f, g, i, j;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).removeClass(a.call(this, b, this.className));\n                    });\n                }\n            ;\n            ;\n                if (((((a && ((typeof a == \"string\")))) || ((a === b))))) {\n                    c = ((a || \"\")).split(R);\n                    for (d = 0, e = this.length; ((d < e)); d++) {\n                        f = this[d];\n                        if (((((f.nodeType === 1)) && f.className))) {\n                            if (a) {\n                                g = ((((\" \" + f.className)) + \" \")).replace(Q, \" \");\n                                for (i = 0, j = c.length; ((i < j)); i++) {\n                                    g = g.replace(((((\" \" + c[i])) + \" \")), \" \");\n                                ;\n                                };\n                            ;\n                                f.className = L.trim(g);\n                            }\n                             else f.className = \"\";\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return this;\n            },\n            toggleClass: function(a, b) {\n                var c = typeof a, d = ((typeof b == \"boolean\"));\n                return ((L.isFunction(a) ? this.each(function(c) {\n                    L(this).toggleClass(a.call(this, c, this.className, b), b);\n                }) : this.each(function() {\n                    if (((c === \"string\"))) {\n                        var e, f = 0, g = L(this), i = b, j = a.split(R);\n                        while (e = j[f++]) {\n                            i = ((d ? i : !g.hasClass(e))), g[((i ? \"addClass\" : \"removeClass\"))](e);\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((((c === \"undefined\")) || ((c === \"boolean\"))))) {\n                        ((this.className && L._data(this, \"__className__\", this.className))), this.className = ((((this.className || ((a === !1)))) ? \"\" : ((L._data(this, \"__className__\") || \"\"))));\n                    }\n                    \n                ;\n                ;\n                })));\n            },\n            hasClass: function(a) {\n                var b = ((((\" \" + a)) + \" \")), c = 0, d = this.length;\n                for (; ((c < d)); c++) {\n                    if (((((this[c].nodeType === 1)) && ((((((\" \" + this[c].className)) + \" \")).replace(Q, \" \").indexOf(b) > -1))))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            val: function(a) {\n                var c, d, e, f = this[0];\n                if (!arguments.length) {\n                    if (f) {\n                        return c = ((L.valHooks[f.nodeName.toLowerCase()] || L.valHooks[f.type])), ((((((c && ((\"get\" in c)))) && (((d = c.get(f, \"value\")) !== b)))) ? d : (d = f.value, ((((typeof d == \"string\")) ? d.replace(S, \"\") : ((((d == null)) ? \"\" : d)))))));\n                    }\n                ;\n                ;\n                    return;\n                }\n            ;\n            ;\n                return e = L.isFunction(a), this.each(function(d) {\n                    var f = L(this), g;\n                    if (((this.nodeType !== 1))) {\n                        return;\n                    }\n                ;\n                ;\n                    ((e ? g = a.call(this, d, f.val()) : g = a)), ((((g == null)) ? g = \"\" : ((((typeof g == \"number\")) ? g += \"\" : ((L.isArray(g) && (g = L.map(g, function(a) {\n                        return ((((a == null)) ? \"\" : ((a + \"\"))));\n                    })))))))), c = ((L.valHooks[this.nodeName.toLowerCase()] || L.valHooks[this.type]));\n                    if (((((!c || !((\"set\" in c)))) || ((c.set(this, g, \"value\") === b))))) {\n                        this.value = g;\n                    }\n                ;\n                ;\n                });\n            }\n        }), L.extend({\n            valHooks: {\n                option: {\n                    get: function(a) {\n                        var b = a.attributes.value;\n                        return ((((!b || b.specified)) ? a.value : a.text));\n                    }\n                },\n                select: {\n                    get: function(a) {\n                        var b, c, d, e, f = a.selectedIndex, g = [], i = a.options, j = ((a.type === \"select-one\"));\n                        if (((f < 0))) {\n                            return null;\n                        }\n                    ;\n                    ;\n                        c = ((j ? f : 0)), d = ((j ? ((f + 1)) : i.length));\n                        for (; ((c < d)); c++) {\n                            e = i[c];\n                            if (((((e.selected && ((L.support.optDisabled ? !e.disabled : ((e.getAttribute(\"disabled\") === null)))))) && ((!e.parentNode.disabled || !L.nodeName(e.parentNode, \"optgroup\")))))) {\n                                b = L(e).val();\n                                if (j) {\n                                    return b;\n                                }\n                            ;\n                            ;\n                                g.push(b);\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        return ((((((j && !g.length)) && i.length)) ? L(i[f]).val() : g));\n                    },\n                    set: function(a, b) {\n                        var c = L.makeArray(b);\n                        return L(a).JSBNG__find(\"option\").each(function() {\n                            this.selected = ((L.inArray(L(this).val(), c) >= 0));\n                        }), ((c.length || (a.selectedIndex = -1))), c;\n                    }\n                }\n            },\n            attrFn: {\n                val: !0,\n                css: !0,\n                html: !0,\n                text: !0,\n                data: !0,\n                width: !0,\n                height: !0,\n                offset: !0\n            },\n            attr: function(a, c, d, e) {\n                var f, g, i, j = a.nodeType;\n                if (((((((!a || ((j === 3)))) || ((j === 8)))) || ((j === 2))))) {\n                    return;\n                }\n            ;\n            ;\n                if (((e && ((c in L.attrFn))))) {\n                    return L(a)[c](d);\n                }\n            ;\n            ;\n                if (((typeof a.getAttribute == \"undefined\"))) {\n                    return L.prop(a, c, d);\n                }\n            ;\n            ;\n                i = ((((j !== 1)) || !L.isXMLDoc(a))), ((i && (c = c.toLowerCase(), g = ((L.attrHooks[c] || ((W.test(c) ? Z : Y)))))));\n                if (((d !== b))) {\n                    if (((d === null))) {\n                        L.removeAttr(a, c);\n                        return;\n                    }\n                ;\n                ;\n                    return ((((((((g && ((\"set\" in g)))) && i)) && (((f = g.set(a, d, c)) !== b)))) ? f : (a.setAttribute(c, ((\"\" + d))), d)));\n                }\n            ;\n            ;\n                return ((((((((g && ((\"get\" in g)))) && i)) && (((f = g.get(a, c)) !== null)))) ? f : (f = a.getAttribute(c), ((((f === null)) ? b : f)))));\n            },\n            removeAttr: function(a, b) {\n                var c, d, e, f, g = 0;\n                if (((b && ((a.nodeType === 1))))) {\n                    d = b.toLowerCase().split(R), f = d.length;\n                    for (; ((g < f)); g++) {\n                        e = d[g], ((e && (c = ((L.propFix[e] || e)), L.attr(a, e, \"\"), a.removeAttribute(((X ? e : c))), ((((W.test(e) && ((c in a)))) && (a[c] = !1))))));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            },\n            attrHooks: {\n                type: {\n                    set: function(a, b) {\n                        if (((T.test(a.nodeName) && a.parentNode))) {\n                            L.error(\"type property can't be changed\");\n                        }\n                         else {\n                            if (((((!L.support.radioValue && ((b === \"radio\")))) && L.nodeName(a, \"input\")))) {\n                                var c = a.value;\n                                return a.setAttribute(\"type\", b), ((c && (a.value = c))), b;\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                },\n                value: {\n                    get: function(a, b) {\n                        return ((((Y && L.nodeName(a, \"button\"))) ? Y.get(a, b) : ((((b in a)) ? a.value : null))));\n                    },\n                    set: function(a, b, c) {\n                        if (((Y && L.nodeName(a, \"button\")))) {\n                            return Y.set(a, b, c);\n                        }\n                    ;\n                    ;\n                        a.value = b;\n                    }\n                }\n            },\n            propFix: {\n                tabindex: \"tabIndex\",\n                readonly: \"readOnly\",\n                \"for\": \"htmlFor\",\n                class: \"className\",\n                maxlength: \"maxLength\",\n                cellspacing: \"cellSpacing\",\n                cellpadding: \"cellPadding\",\n                rowspan: \"rowSpan\",\n                colspan: \"colSpan\",\n                usemap: \"useMap\",\n                frameborder: \"frameBorder\",\n                contenteditable: \"contentEditable\"\n            },\n            prop: function(a, c, d) {\n                var e, f, g, i = a.nodeType;\n                if (((((((!a || ((i === 3)))) || ((i === 8)))) || ((i === 2))))) {\n                    return;\n                }\n            ;\n            ;\n                return g = ((((i !== 1)) || !L.isXMLDoc(a))), ((g && (c = ((L.propFix[c] || c)), f = L.propHooks[c]))), ((((d !== b)) ? ((((((f && ((\"set\" in f)))) && (((e = f.set(a, d, c)) !== b)))) ? e : a[c] = d)) : ((((((f && ((\"get\" in f)))) && (((e = f.get(a, c)) !== null)))) ? e : a[c]))));\n            },\n            propHooks: {\n                tabIndex: {\n                    get: function(a) {\n                        var c = a.getAttributeNode(\"tabindex\");\n                        return ((((c && c.specified)) ? parseInt(c.value, 10) : ((((U.test(a.nodeName) || ((V.test(a.nodeName) && a.href)))) ? 0 : b))));\n                    }\n                }\n            }\n        }), L.attrHooks.tabindex = L.propHooks.tabIndex, Z = {\n            get: function(a, c) {\n                var d, e = L.prop(a, c);\n                return ((((((e === !0)) || ((((((typeof e != \"boolean\")) && (d = a.getAttributeNode(c)))) && ((d.nodeValue !== !1)))))) ? c.toLowerCase() : b));\n            },\n            set: function(a, b, c) {\n                var d;\n                return ((((b === !1)) ? L.removeAttr(a, c) : (d = ((L.propFix[c] || c)), ((((d in a)) && (a[d] = !0))), a.setAttribute(c, c.toLowerCase())))), c;\n            }\n        }, ((X || (ab = {\n            JSBNG__name: !0,\n            id: !0\n        }, Y = L.valHooks.button = {\n            get: function(a, c) {\n                var d;\n                return d = a.getAttributeNode(c), ((((d && ((ab[c] ? ((d.nodeValue !== \"\")) : d.specified)))) ? d.nodeValue : b));\n            },\n            set: function(a, b, c) {\n                var d = a.getAttributeNode(c);\n                return ((d || (d = I.createAttribute(c), a.setAttributeNode(d)))), d.nodeValue = ((b + \"\"));\n            }\n        }, L.attrHooks.tabindex.set = Y.set, L.each([\"width\",\"height\",], function(a, b) {\n            L.attrHooks[b] = L.extend(L.attrHooks[b], {\n                set: function(a, c) {\n                    if (((c === \"\"))) {\n                        return a.setAttribute(b, \"auto\"), c;\n                    }\n                ;\n                ;\n                }\n            });\n        }), L.attrHooks.contenteditable = {\n            get: Y.get,\n            set: function(a, b, c) {\n                ((((b === \"\")) && (b = \"false\"))), Y.set(a, b, c);\n            }\n        }))), ((L.support.hrefNormalized || L.each([\"href\",\"src\",\"width\",\"height\",], function(a, c) {\n            L.attrHooks[c] = L.extend(L.attrHooks[c], {\n                get: function(a) {\n                    var d = a.getAttribute(c, 2);\n                    return ((((d === null)) ? b : d));\n                }\n            });\n        }))), ((L.support.style || (L.attrHooks.style = {\n            get: function(a) {\n                return ((a.style.cssText.toLowerCase() || b));\n            },\n            set: function(a, b) {\n                return a.style.cssText = ((\"\" + b));\n            }\n        }))), ((L.support.optSelected || (L.propHooks.selected = L.extend(L.propHooks.selected, {\n            get: function(a) {\n                var b = a.parentNode;\n                return ((b && (b.selectedIndex, ((b.parentNode && b.parentNode.selectedIndex))))), null;\n            }\n        })))), ((L.support.enctype || (L.propFix.enctype = \"encoding\"))), ((L.support.checkOn || L.each([\"radio\",\"checkbox\",], function() {\n            L.valHooks[this] = {\n                get: function(a) {\n                    return ((((a.getAttribute(\"value\") === null)) ? \"JSBNG__on\" : a.value));\n                }\n            };\n        }))), L.each([\"radio\",\"checkbox\",], function() {\n            L.valHooks[this] = L.extend(L.valHooks[this], {\n                set: function(a, b) {\n                    if (L.isArray(b)) {\n                        return a.checked = ((L.inArray(L(a).val(), b) >= 0));\n                    }\n                ;\n                ;\n                }\n            });\n        });\n        var bb = /^(?:textarea|input|select)$/i, cb = /^([^\\.]*)?(?:\\.(.+))?$/, db = /\\bhover(\\.\\S+)?\\b/, eb = /^key/, fb = /^(?:mouse|contextmenu)|click/, gb = /^(?:focusinfocus|focusoutblur)$/, hb = /^(\\w*)(?:#([\\w\\-]+))?(?:\\.([\\w\\-]+))?$/, ib = function(a) {\n            var b = hb.exec(a);\n            return ((b && (b[1] = ((b[1] || \"\")).toLowerCase(), b[3] = ((b[3] && new RegExp(((((\"(?:^|\\\\s)\" + b[3])) + \"(?:\\\\s|$)\")))))))), b;\n        }, jb = function(a, b) {\n            var c = ((a.attributes || {\n            }));\n            return ((((((!b[1] || ((a.nodeName.toLowerCase() === b[1])))) && ((!b[2] || ((((c.id || {\n            })).value === b[2])))))) && ((!b[3] || b[3].test(((c[\"class\"] || {\n            })).value)))));\n        }, kb = function(a) {\n            return ((L.JSBNG__event.special.hover ? a : a.replace(db, \"mouseenter$1 mouseleave$1\")));\n        };\n        L.JSBNG__event = {\n            add: function(a, c, d, e, f) {\n                var g, i, j, k, l, m, n, o, p, q, r, s;\n                if (((((((((((a.nodeType === 3)) || ((a.nodeType === 8)))) || !c)) || !d)) || !(g = L._data(a))))) {\n                    return;\n                }\n            ;\n            ;\n                ((d.handler && (p = d, d = p.handler))), ((d.guid || (d.guid = L.guid++))), j = g.events, ((j || (g.events = j = {\n                }))), i = g.handle, ((i || (g.handle = i = function(a) {\n                    return ((((((typeof L == \"undefined\")) || ((!!a && ((L.JSBNG__event.triggered === a.type)))))) ? b : L.JSBNG__event.dispatch.apply(i.elem, arguments)));\n                }, i.elem = a))), c = L.trim(kb(c)).split(\" \");\n                for (k = 0; ((k < c.length)); k++) {\n                    l = ((cb.exec(c[k]) || [])), m = l[1], n = ((l[2] || \"\")).split(\".\").sort(), s = ((L.JSBNG__event.special[m] || {\n                    })), m = ((((f ? s.delegateType : s.bindType)) || m)), s = ((L.JSBNG__event.special[m] || {\n                    })), o = L.extend({\n                        type: m,\n                        origType: l[1],\n                        data: e,\n                        handler: d,\n                        guid: d.guid,\n                        selector: f,\n                        quick: ib(f),\n                        namespace: n.join(\".\")\n                    }, p), r = j[m];\n                    if (!r) {\n                        r = j[m] = [], r.delegateCount = 0;\n                        if (((!s.setup || ((s.setup.call(a, e, n, i) === !1))))) {\n                            ((a.JSBNG__addEventListener ? a.JSBNG__addEventListener(m, i, !1) : ((a.JSBNG__attachEvent && a.JSBNG__attachEvent(((\"JSBNG__on\" + m)), i)))));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ((s.add && (s.add.call(a, o), ((o.handler.guid || (o.handler.guid = d.guid)))))), ((f ? r.splice(r.delegateCount++, 0, o) : r.push(o))), L.JSBNG__event.global[m] = !0;\n                };\n            ;\n                a = null;\n            },\n            global: {\n            },\n            remove: function(a, b, c, d, e) {\n                var f = ((L.hasData(a) && L._data(a))), g, i, j, k, l, m, n, o, p, q, r, s;\n                if (((!f || !(o = f.events)))) {\n                    return;\n                }\n            ;\n            ;\n                b = L.trim(kb(((b || \"\")))).split(\" \");\n                for (g = 0; ((g < b.length)); g++) {\n                    i = ((cb.exec(b[g]) || [])), j = k = i[1], l = i[2];\n                    if (!j) {\n                        for (j in o) {\n                            L.JSBNG__event.remove(a, ((j + b[g])), c, d, !0);\n                        ;\n                        };\n                    ;\n                        continue;\n                    }\n                ;\n                ;\n                    p = ((L.JSBNG__event.special[j] || {\n                    })), j = ((((d ? p.delegateType : p.bindType)) || j)), r = ((o[j] || [])), m = r.length, l = ((l ? new RegExp(((((\"(^|\\\\.)\" + l.split(\".\").sort().join(\"\\\\.(?:.*\\\\.)?\"))) + \"(\\\\.|$)\"))) : null));\n                    for (n = 0; ((n < r.length)); n++) {\n                        s = r[n], ((((((((((e || ((k === s.origType)))) && ((!c || ((c.guid === s.guid)))))) && ((!l || l.test(s.namespace))))) && ((((!d || ((d === s.selector)))) || ((((d === \"**\")) && s.selector)))))) && (r.splice(n--, 1), ((s.selector && r.delegateCount--)), ((p.remove && p.remove.call(a, s))))));\n                    ;\n                    };\n                ;\n                    ((((((r.length === 0)) && ((m !== r.length)))) && (((((!p.teardown || ((p.teardown.call(a, l) === !1)))) && L.removeEvent(a, j, f.handle))), delete o[j])));\n                };\n            ;\n                ((L.isEmptyObject(o) && (q = f.handle, ((q && (q.elem = null))), L.removeData(a, [\"events\",\"handle\",], !0))));\n            },\n            customEvent: {\n                getData: !0,\n                setData: !0,\n                changeData: !0\n            },\n            trigger: function(c, d, e, f) {\n                if (((!e || ((((e.nodeType !== 3)) && ((e.nodeType !== 8))))))) {\n                    var g = ((c.type || c)), i = [], j, k, l, m, n, o, p, q, r, s;\n                    if (gb.test(((g + L.JSBNG__event.triggered)))) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((g.indexOf(\"!\") >= 0)) && (g = g.slice(0, -1), k = !0))), ((((g.indexOf(\".\") >= 0)) && (i = g.split(\".\"), g = i.shift(), i.sort())));\n                    if (((((!e || L.JSBNG__event.customEvent[g])) && !L.JSBNG__event.global[g]))) {\n                        return;\n                    }\n                ;\n                ;\n                    c = ((((typeof c == \"object\")) ? ((c[L.expando] ? c : new L.JSBNG__Event(g, c))) : new L.JSBNG__Event(g))), c.type = g, c.isTrigger = !0, c.exclusive = k, c.namespace = i.join(\".\"), c.namespace_re = ((c.namespace ? new RegExp(((((\"(^|\\\\.)\" + i.join(\"\\\\.(?:.*\\\\.)?\"))) + \"(\\\\.|$)\"))) : null)), o = ((((g.indexOf(\":\") < 0)) ? ((\"JSBNG__on\" + g)) : \"\"));\n                    if (!e) {\n                        j = L.cache;\n                        for (l in j) {\n                            ((((j[l].events && j[l].events[g])) && L.JSBNG__event.trigger(c, d, j[l].handle.elem, !0)));\n                        ;\n                        };\n                    ;\n                        return;\n                    }\n                ;\n                ;\n                    c.result = b, ((c.target || (c.target = e))), d = ((((d != null)) ? L.makeArray(d) : [])), d.unshift(c), p = ((L.JSBNG__event.special[g] || {\n                    }));\n                    if (((p.trigger && ((p.trigger.apply(e, d) === !1))))) {\n                        return;\n                    }\n                ;\n                ;\n                    r = [[e,((p.bindType || g)),],];\n                    if (((((!f && !p.noBubble)) && !L.isWindow(e)))) {\n                        s = ((p.delegateType || g)), m = ((gb.test(((s + g))) ? e : e.parentNode)), n = null;\n                        for (; m; m = m.parentNode) {\n                            r.push([m,s,]), n = m;\n                        ;\n                        };\n                    ;\n                        ((((n && ((n === e.ownerDocument)))) && r.push([((((n.defaultView || n.parentWindow)) || a)),s,])));\n                    }\n                ;\n                ;\n                    for (l = 0; ((((l < r.length)) && !c.isPropagationStopped())); l++) {\n                        m = r[l][0], c.type = r[l][1], q = ((((L._data(m, \"events\") || {\n                        }))[c.type] && L._data(m, \"handle\"))), ((q && q.apply(m, d))), q = ((o && m[o])), ((((((q && L.acceptData(m))) && ((q.apply(m, d) === !1)))) && c.preventDefault()));\n                    ;\n                    };\n                ;\n                    return c.type = g, ((((((((((((((((((!f && !c.isDefaultPrevented())) && ((!p._default || ((p._default.apply(e.ownerDocument, d) === !1)))))) && ((((g !== \"click\")) || !L.nodeName(e, \"a\"))))) && L.acceptData(e))) && o)) && e[g])) && ((((((g !== \"JSBNG__focus\")) && ((g !== \"JSBNG__blur\")))) || ((c.target.offsetWidth !== 0)))))) && !L.isWindow(e))) && (n = e[o], ((n && (e[o] = null))), L.JSBNG__event.triggered = g, e[g](), L.JSBNG__event.triggered = b, ((n && (e[o] = n)))))), c.result;\n                }\n            ;\n            ;\n                return;\n            },\n            dispatch: function(c) {\n                c = L.JSBNG__event.fix(((c || a.JSBNG__event)));\n                var d = ((((L._data(this, \"events\") || {\n                }))[c.type] || [])), e = d.delegateCount, f = [].slice.call(arguments, 0), g = ((!c.exclusive && !c.namespace)), i = [], j, k, l, m, n, o, p, q, r, s, t;\n                f[0] = c, c.delegateTarget = this;\n                if (((((e && !c.target.disabled)) && ((!c.button || ((c.type !== \"click\"))))))) {\n                    m = L(this), m.context = ((this.ownerDocument || this));\n                    for (l = c.target; ((l != this)); l = ((l.parentNode || this))) {\n                        o = {\n                        }, q = [], m[0] = l;\n                        for (j = 0; ((j < e)); j++) {\n                            r = d[j], s = r.selector, ((((o[s] === b)) && (o[s] = ((r.quick ? jb(l, r.quick) : m.is(s)))))), ((o[s] && q.push(r)));\n                        ;\n                        };\n                    ;\n                        ((q.length && i.push({\n                            elem: l,\n                            matches: q\n                        })));\n                    };\n                ;\n                }\n            ;\n            ;\n                ((((d.length > e)) && i.push({\n                    elem: this,\n                    matches: d.slice(e)\n                })));\n                for (j = 0; ((((j < i.length)) && !c.isPropagationStopped())); j++) {\n                    p = i[j], c.currentTarget = p.elem;\n                    for (k = 0; ((((k < p.matches.length)) && !c.isImmediatePropagationStopped())); k++) {\n                        r = p.matches[k];\n                        if (((((g || ((!c.namespace && !r.namespace)))) || ((c.namespace_re && c.namespace_re.test(r.namespace)))))) {\n                            c.data = r.data, c.handleObj = r, n = ((((L.JSBNG__event.special[r.origType] || {\n                            })).handle || r.handler)).apply(p.elem, f), ((((n !== b)) && (c.result = n, ((((n === !1)) && (c.preventDefault(), c.stopPropagation()))))));\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                };\n            ;\n                return c.result;\n            },\n            props: \"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which\".split(\" \"),\n            fixHooks: {\n            },\n            keyHooks: {\n                props: \"char charCode key keyCode\".split(\" \"),\n                filter: function(a, b) {\n                    return ((((a.which == null)) && (a.which = ((((b.charCode != null)) ? b.charCode : b.keyCode))))), a;\n                }\n            },\n            mouseHooks: {\n                props: \"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement\".split(\" \"),\n                filter: function(a, c) {\n                    var d, e, f, g = c.button, i = c.fromElement;\n                    return ((((((a.pageX == null)) && ((c.clientX != null)))) && (d = ((a.target.ownerDocument || I)), e = d.documentElement, f = d.body, a.pageX = ((((c.clientX + ((((((e && e.scrollLeft)) || ((f && f.scrollLeft)))) || 0)))) - ((((((e && e.clientLeft)) || ((f && f.clientLeft)))) || 0)))), a.pageY = ((((c.clientY + ((((((e && e.scrollTop)) || ((f && f.scrollTop)))) || 0)))) - ((((((e && e.clientTop)) || ((f && f.clientTop)))) || 0))))))), ((((!a.relatedTarget && i)) && (a.relatedTarget = ((((i === a.target)) ? c.toElement : i))))), ((((!a.which && ((g !== b)))) && (a.which = ((((g & 1)) ? 1 : ((((g & 2)) ? 3 : ((((g & 4)) ? 2 : 0))))))))), a;\n                }\n            },\n            fix: function(a) {\n                if (a[L.expando]) {\n                    return a;\n                }\n            ;\n            ;\n                var c, d, e = a, f = ((L.JSBNG__event.fixHooks[a.type] || {\n                })), g = ((f.props ? this.props.concat(f.props) : this.props));\n                a = L.JSBNG__Event(e);\n                for (c = g.length; c; ) {\n                    d = g[--c], a[d] = e[d];\n                ;\n                };\n            ;\n                return ((a.target || (a.target = ((e.srcElement || I))))), ((((a.target.nodeType === 3)) && (a.target = a.target.parentNode))), ((((a.metaKey === b)) && (a.metaKey = a.ctrlKey))), ((f.filter ? f.filter(a, e) : a));\n            },\n            special: {\n                ready: {\n                    setup: L.bindReady\n                },\n                load: {\n                    noBubble: !0\n                },\n                JSBNG__focus: {\n                    delegateType: \"focusin\"\n                },\n                JSBNG__blur: {\n                    delegateType: \"focusout\"\n                },\n                beforeunload: {\n                    setup: function(a, b, c) {\n                        ((L.isWindow(this) && (this.JSBNG__onbeforeunload = c)));\n                    },\n                    teardown: function(a, b) {\n                        ((((this.JSBNG__onbeforeunload === b)) && (this.JSBNG__onbeforeunload = null)));\n                    }\n                }\n            },\n            simulate: function(a, b, c, d) {\n                var e = L.extend(new L.JSBNG__Event, c, {\n                    type: a,\n                    isSimulated: !0,\n                    originalEvent: {\n                    }\n                });\n                ((d ? L.JSBNG__event.trigger(e, null, b) : L.JSBNG__event.dispatch.call(b, e))), ((e.isDefaultPrevented() && c.preventDefault()));\n            }\n        }, L.JSBNG__event.handle = L.JSBNG__event.dispatch, L.removeEvent = ((I.JSBNG__removeEventListener ? function(a, b, c) {\n            ((a.JSBNG__removeEventListener && a.JSBNG__removeEventListener(b, c, !1)));\n        } : function(a, b, c) {\n            ((a.JSBNG__detachEvent && a.JSBNG__detachEvent(((\"JSBNG__on\" + b)), c)));\n        })), L.JSBNG__Event = function(a, b) {\n            if (!((this instanceof L.JSBNG__Event))) {\n                return new L.JSBNG__Event(a, b);\n            }\n        ;\n        ;\n            ((((a && a.type)) ? (this.originalEvent = a, this.type = a.type, this.isDefaultPrevented = ((((((a.defaultPrevented || ((a.returnValue === !1)))) || ((a.getPreventDefault && a.getPreventDefault())))) ? i : g))) : this.type = a)), ((b && L.extend(this, b))), this.timeStamp = ((((a && a.timeStamp)) || L.now())), this[L.expando] = !0;\n        }, L.JSBNG__Event.prototype = {\n            preventDefault: function() {\n                this.isDefaultPrevented = i;\n                var a = this.originalEvent;\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a.preventDefault ? a.preventDefault() : a.returnValue = !1));\n            },\n            stopPropagation: function() {\n                this.isPropagationStopped = i;\n                var a = this.originalEvent;\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a.stopPropagation && a.stopPropagation())), a.cancelBubble = !0;\n            },\n            stopImmediatePropagation: function() {\n                this.isImmediatePropagationStopped = i, this.stopPropagation();\n            },\n            isDefaultPrevented: g,\n            isPropagationStopped: g,\n            isImmediatePropagationStopped: g\n        }, L.each({\n            mouseenter: \"mouseover\",\n            mouseleave: \"mouseout\"\n        }, function(a, b) {\n            L.JSBNG__event.special[a] = {\n                delegateType: b,\n                bindType: b,\n                handle: function(a) {\n                    var c = this, d = a.relatedTarget, e = a.handleObj, f = e.selector, g;\n                    if (((!d || ((((d !== c)) && !L.contains(c, d)))))) {\n                        a.type = e.origType, g = e.handler.apply(this, arguments), a.type = b;\n                    }\n                ;\n                ;\n                    return g;\n                }\n            };\n        }), ((L.support.submitBubbles || (L.JSBNG__event.special.submit = {\n            setup: function() {\n                if (L.nodeName(this, \"form\")) {\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.add(this, \"click._submit keypress._submit\", function(a) {\n                    var c = a.target, d = ((((L.nodeName(c, \"input\") || L.nodeName(c, \"button\"))) ? c.form : b));\n                    ((((d && !d._submit_attached)) && (L.JSBNG__event.add(d, \"submit._submit\", function(a) {\n                        ((((this.parentNode && !a.isTrigger)) && L.JSBNG__event.simulate(\"submit\", this.parentNode, a, !0)));\n                    }), d._submit_attached = !0)));\n                });\n            },\n            teardown: function() {\n                if (L.nodeName(this, \"form\")) {\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.remove(this, \"._submit\");\n            }\n        }))), ((L.support.changeBubbles || (L.JSBNG__event.special.change = {\n            setup: function() {\n                if (bb.test(this.nodeName)) {\n                    if (((((this.type === \"checkbox\")) || ((this.type === \"radio\"))))) {\n                        L.JSBNG__event.add(this, \"propertychange._change\", function(a) {\n                            ((((a.originalEvent.propertyName === \"checked\")) && (this._just_changed = !0)));\n                        }), L.JSBNG__event.add(this, \"click._change\", function(a) {\n                            ((((this._just_changed && !a.isTrigger)) && (this._just_changed = !1, L.JSBNG__event.simulate(\"change\", this, a, !0))));\n                        });\n                    }\n                ;\n                ;\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.add(this, \"beforeactivate._change\", function(a) {\n                    var b = a.target;\n                    ((((bb.test(b.nodeName) && !b._change_attached)) && (L.JSBNG__event.add(b, \"change._change\", function(a) {\n                        ((((((this.parentNode && !a.isSimulated)) && !a.isTrigger)) && L.JSBNG__event.simulate(\"change\", this.parentNode, a, !0)));\n                    }), b._change_attached = !0)));\n                });\n            },\n            handle: function(a) {\n                var b = a.target;\n                if (((((((((this !== b)) || a.isSimulated)) || a.isTrigger)) || ((((b.type !== \"radio\")) && ((b.type !== \"checkbox\"))))))) {\n                    return a.handleObj.handler.apply(this, arguments);\n                }\n            ;\n            ;\n            },\n            teardown: function() {\n                return L.JSBNG__event.remove(this, \"._change\"), bb.test(this.nodeName);\n            }\n        }))), ((L.support.focusinBubbles || L.each({\n            JSBNG__focus: \"focusin\",\n            JSBNG__blur: \"focusout\"\n        }, function(a, b) {\n            var c = 0, d = function(a) {\n                L.JSBNG__event.simulate(b, a.target, L.JSBNG__event.fix(a), !0);\n            };\n            L.JSBNG__event.special[b] = {\n                setup: function() {\n                    ((((c++ === 0)) && I.JSBNG__addEventListener(a, d, !0)));\n                },\n                teardown: function() {\n                    ((((--c === 0)) && I.JSBNG__removeEventListener(a, d, !0)));\n                }\n            };\n        }))), L.fn.extend({\n            JSBNG__on: function(a, c, d, e, f) {\n                var i, j;\n                if (((typeof a == \"object\"))) {\n                    ((((typeof c != \"string\")) && (d = c, c = b)));\n                    for (j in a) {\n                        this.JSBNG__on(j, c, d, a[j], f);\n                    ;\n                    };\n                ;\n                    return this;\n                }\n            ;\n            ;\n                ((((((d == null)) && ((e == null)))) ? (e = c, d = c = b) : ((((e == null)) && ((((typeof c == \"string\")) ? (e = d, d = b) : (e = d, d = c, c = b)))))));\n                if (((e === !1))) {\n                    e = g;\n                }\n                 else {\n                    if (!e) {\n                        return this;\n                    }\n                ;\n                }\n            ;\n            ;\n                return ((((f === 1)) && (i = e, e = function(a) {\n                    return L().off(a), i.apply(this, arguments);\n                }, e.guid = ((i.guid || (i.guid = L.guid++)))))), this.each(function() {\n                    L.JSBNG__event.add(this, a, e, d, c);\n                });\n            },\n            JSBNG__one: function(a, b, c, d) {\n                return this.JSBNG__on.call(this, a, b, c, d, 1);\n            },\n            off: function(a, c, d) {\n                if (((((a && a.preventDefault)) && a.handleObj))) {\n                    var e = a.handleObj;\n                    return L(a.delegateTarget).off(((e.namespace ? ((((e.type + \".\")) + e.namespace)) : e.type)), e.selector, e.handler), this;\n                }\n            ;\n            ;\n                if (((typeof a == \"object\"))) {\n                    for (var f in a) {\n                        this.off(f, c, a[f]);\n                    ;\n                    };\n                ;\n                    return this;\n                }\n            ;\n            ;\n                if (((((c === !1)) || ((typeof c == \"function\"))))) {\n                    d = c, c = b;\n                }\n            ;\n            ;\n                return ((((d === !1)) && (d = g))), this.each(function() {\n                    L.JSBNG__event.remove(this, a, d, c);\n                });\n            },\n            bind: function(a, b, c) {\n                return this.JSBNG__on(a, null, b, c);\n            },\n            unbind: function(a, b) {\n                return this.off(a, null, b);\n            },\n            live: function(a, b, c) {\n                return L(this.context).JSBNG__on(a, this.selector, b, c), this;\n            },\n            die: function(a, b) {\n                return L(this.context).off(a, ((this.selector || \"**\")), b), this;\n            },\n            delegate: function(a, b, c, d) {\n                return this.JSBNG__on(b, a, c, d);\n            },\n            undelegate: function(a, b, c) {\n                return ((((arguments.length == 1)) ? this.off(a, \"**\") : this.off(b, a, c)));\n            },\n            trigger: function(a, b) {\n                return this.each(function() {\n                    L.JSBNG__event.trigger(a, b, this);\n                });\n            },\n            triggerHandler: function(a, b) {\n                if (this[0]) {\n                    return L.JSBNG__event.trigger(a, b, this[0], !0);\n                }\n            ;\n            ;\n            },\n            toggle: function(a) {\n                var b = arguments, c = ((a.guid || L.guid++)), d = 0, e = function(c) {\n                    var e = ((((L._data(this, ((\"lastToggle\" + a.guid))) || 0)) % d));\n                    return L._data(this, ((\"lastToggle\" + a.guid)), ((e + 1))), c.preventDefault(), ((b[e].apply(this, arguments) || !1));\n                };\n                e.guid = c;\n                while (((d < b.length))) {\n                    b[d++].guid = c;\n                ;\n                };\n            ;\n                return this.click(e);\n            },\n            hover: function(a, b) {\n                return this.mouseenter(a).mouseleave(((b || a)));\n            }\n        }), L.each(\"blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu\".split(\" \"), function(a, b) {\n            L.fn[b] = function(a, c) {\n                return ((((c == null)) && (c = a, a = null))), ((((arguments.length > 0)) ? this.JSBNG__on(b, null, a, c) : this.trigger(b)));\n            }, ((L.attrFn && (L.attrFn[b] = !0))), ((eb.test(b) && (L.JSBNG__event.fixHooks[b] = L.JSBNG__event.keyHooks))), ((fb.test(b) && (L.JSBNG__event.fixHooks[b] = L.JSBNG__event.mouseHooks)));\n        });\n        (function() {\n            function a(a, b, c, d, f, g) {\n                for (var i = 0, j = d.length; ((i < j)); i++) {\n                    var k = d[i];\n                    if (k) {\n                        var l = !1;\n                        k = k[a];\n                        while (k) {\n                            if (((k[e] === c))) {\n                                l = d[k.sizset];\n                                break;\n                            }\n                        ;\n                        ;\n                            ((((((k.nodeType === 1)) && !g)) && (k[e] = c, k.sizset = i)));\n                            if (((k.nodeName.toLowerCase() === b))) {\n                                l = k;\n                                break;\n                            }\n                        ;\n                        ;\n                            k = k[a];\n                        };\n                    ;\n                        d[i] = l;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            function c(a, b, c, d, f, g) {\n                for (var i = 0, j = d.length; ((i < j)); i++) {\n                    var k = d[i];\n                    if (k) {\n                        var l = !1;\n                        k = k[a];\n                        while (k) {\n                            if (((k[e] === c))) {\n                                l = d[k.sizset];\n                                break;\n                            }\n                        ;\n                        ;\n                            if (((k.nodeType === 1))) {\n                                ((g || (k[e] = c, k.sizset = i)));\n                                if (((typeof b != \"string\"))) {\n                                    if (((k === b))) {\n                                        l = !0;\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                                 else if (((n.filter(b, [k,]).length > 0))) {\n                                    l = k;\n                                    break;\n                                }\n                                \n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            k = k[a];\n                        };\n                    ;\n                        d[i] = l;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            var d = /((?:\\((?:\\([^()]+\\)|[^()]+)+\\)|\\[(?:\\[[^\\[\\]]*\\]|['\"][^'\"]*['\"]|[^\\[\\]'\"]+)+\\]|\\\\.|[^ >+~,(\\[\\\\]+)+|[>+~])(\\s*,\\s*)?((?:.|\\r|\\n)*)/g, e = ((\"sizcache\" + ((Math.JSBNG__random() + \"\")).replace(\".\", \"\"))), f = 0, g = Object.prototype.toString, i = !1, j = !0, k = /\\\\/g, l = /\\r\\n/g, m = /\\W/;\n            [0,0,].sort(function() {\n                return j = !1, 0;\n            });\n            var n = function(a, b, c, e) {\n                c = ((c || [])), b = ((b || I));\n                var f = b;\n                if (((((b.nodeType !== 1)) && ((b.nodeType !== 9))))) {\n                    return [];\n                }\n            ;\n            ;\n                if (((!a || ((typeof a != \"string\"))))) {\n                    return c;\n                }\n            ;\n            ;\n                var i, j, k, l, m, o, r, s, u = !0, v = n.isXML(b), w = [], y = a;\n                do {\n                    d.exec(\"\"), i = d.exec(y);\n                    if (i) {\n                        y = i[3], w.push(i[1]);\n                        if (i[2]) {\n                            l = i[3];\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                } while (i);\n                if (((((w.length > 1)) && q.exec(a)))) if (((((w.length === 2)) && p.relative[w[0]]))) j = x(((w[0] + w[1])), b, e);\n                 else {\n                    j = ((p.relative[w[0]] ? [b,] : n(w.shift(), b)));\n                    while (w.length) {\n                        a = w.shift(), ((p.relative[a] && (a += w.shift()))), j = x(a, j, e);\n                    ;\n                    };\n                ;\n                }\n                \n                 else {\n                    ((((((((((((!e && ((w.length > 1)))) && ((b.nodeType === 9)))) && !v)) && p.match.ID.test(w[0]))) && !p.match.ID.test(w[((w.length - 1))]))) && (m = n.JSBNG__find(w.shift(), b, v), b = ((m.expr ? n.filter(m.expr, m.set)[0] : m.set[0])))));\n                    if (b) {\n                        m = ((e ? {\n                            expr: w.pop(),\n                            set: t(e)\n                        } : n.JSBNG__find(w.pop(), ((((((((w.length !== 1)) || ((((w[0] !== \"~\")) && ((w[0] !== \"+\")))))) || !b.parentNode)) ? b : b.parentNode)), v))), j = ((m.expr ? n.filter(m.expr, m.set) : m.set)), ((((w.length > 0)) ? k = t(j) : u = !1));\n                        while (w.length) {\n                            o = w.pop(), r = o, ((p.relative[o] ? r = w.pop() : o = \"\")), ((((r == null)) && (r = b))), p.relative[o](k, r, v);\n                        ;\n                        };\n                    ;\n                    }\n                     else k = w = [];\n                ;\n                ;\n                }\n            ;\n            ;\n                ((k || (k = j))), ((k || n.error(((o || a)))));\n                if (((g.call(k) === \"[object Array]\"))) {\n                    if (!u) {\n                        c.push.apply(c, k);\n                    }\n                     else {\n                        if (((b && ((b.nodeType === 1))))) {\n                            for (s = 0; ((k[s] != null)); s++) {\n                                ((((k[s] && ((((k[s] === !0)) || ((((k[s].nodeType === 1)) && n.contains(b, k[s]))))))) && c.push(j[s])));\n                            ;\n                            };\n                        }\n                         else {\n                            for (s = 0; ((k[s] != null)); s++) {\n                                ((((k[s] && ((k[s].nodeType === 1)))) && c.push(j[s])));\n                            ;\n                            };\n                        }\n                    ;\n                    }\n                ;\n                }\n                 else {\n                    t(k, c);\n                }\n            ;\n            ;\n                return ((l && (n(l, f, c, e), n.uniqueSort(c)))), c;\n            };\n            n.uniqueSort = function(a) {\n                if (v) {\n                    i = j, a.sort(v);\n                    if (i) {\n                        for (var b = 1; ((b < a.length)); b++) {\n                            ((((a[b] === a[((b - 1))])) && a.splice(b--, 1)));\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return a;\n            }, n.matches = function(a, b) {\n                return n(a, null, null, b);\n            }, n.matchesSelector = function(a, b) {\n                return ((n(b, null, null, [a,]).length > 0));\n            }, n.JSBNG__find = function(a, b, c) {\n                var d, e, f, g, i, j;\n                if (!a) {\n                    return [];\n                }\n            ;\n            ;\n                for (e = 0, f = p.order.length; ((e < f)); e++) {\n                    i = p.order[e];\n                    if (g = p.leftMatch[i].exec(a)) {\n                        j = g[1], g.splice(1, 1);\n                        if (((j.substr(((j.length - 1))) !== \"\\\\\"))) {\n                            g[1] = ((g[1] || \"\")).replace(k, \"\"), d = p.JSBNG__find[i](g, b, c);\n                            if (((d != null))) {\n                                a = a.replace(p.match[i], \"\");\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((d || (d = ((((typeof b.getElementsByTagName != \"undefined\")) ? b.getElementsByTagName(\"*\") : []))))), {\n                    set: d,\n                    expr: a\n                };\n            }, n.filter = function(a, c, d, e) {\n                var f, g, i, j, k, l, m, o, q, r = a, s = [], t = c, u = ((((c && c[0])) && n.isXML(c[0])));\n                while (((a && c.length))) {\n                    for (i in p.filter) {\n                        if ((((((f = p.leftMatch[i].exec(a)) != null)) && f[2]))) {\n                            l = p.filter[i], m = f[1], g = !1, f.splice(1, 1);\n                            if (((m.substr(((m.length - 1))) === \"\\\\\"))) {\n                                continue;\n                            }\n                        ;\n                        ;\n                            ((((t === s)) && (s = [])));\n                            if (p.preFilter[i]) {\n                                f = p.preFilter[i](f, t, d, s, e, u);\n                                if (!f) {\n                                    g = j = !0;\n                                }\n                                 else {\n                                    if (((f === !0))) {\n                                        continue;\n                                    }\n                                ;\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            if (f) {\n                                for (o = 0; (((k = t[o]) != null)); o++) {\n                                    ((k && (j = l(k, f, o, t), q = ((e ^ j)), ((((d && ((j != null)))) ? ((q ? g = !0 : t[o] = !1)) : ((q && (s.push(k), g = !0))))))));\n                                ;\n                                };\n                            }\n                        ;\n                        ;\n                            if (((j !== b))) {\n                                ((d || (t = s))), a = a.replace(p.match[i], \"\");\n                                if (!g) {\n                                    return [];\n                                }\n                            ;\n                            ;\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((a === r))) {\n                        if (((g != null))) {\n                            break;\n                        }\n                    ;\n                    ;\n                        n.error(a);\n                    }\n                ;\n                ;\n                    r = a;\n                };\n            ;\n                return t;\n            }, n.error = function(a) {\n                throw new Error(((\"Syntax error, unrecognized expression: \" + a)));\n            };\n            var o = n.getText = function(a) {\n                var b, c, d = a.nodeType, e = \"\";\n                if (d) {\n                    if (((((d === 1)) || ((d === 9))))) {\n                        if (((typeof a.textContent == \"string\"))) {\n                            return a.textContent;\n                        }\n                    ;\n                    ;\n                        if (((typeof a.innerText == \"string\"))) {\n                            return a.innerText.replace(l, \"\");\n                        }\n                    ;\n                    ;\n                        for (a = a.firstChild; a; a = a.nextSibling) {\n                            e += o(a);\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((((d === 3)) || ((d === 4))))) {\n                        return a.nodeValue;\n                    }\n                    \n                ;\n                ;\n                }\n                 else for (b = 0; c = a[b]; b++) {\n                    ((((c.nodeType !== 8)) && (e += o(c))));\n                ;\n                }\n            ;\n            ;\n                return e;\n            }, p = n.selectors = {\n                order: [\"ID\",\"NAME\",\"TAG\",],\n                match: {\n                    ID: /#((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)/,\n                    CLASS: /\\.((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)/,\n                    NAME: /\\[name=['\"]*((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)['\"]*\\]/,\n                    ATTR: /\\[\\s*((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)\\s*(?:(\\S?=)\\s*(?:(['\"])(.*?)\\3|(#?(?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)*)|)|)\\s*\\]/,\n                    TAG: /^((?:[\\w\\u00c0-\\uFFFF\\*\\-]|\\\\.)+)/,\n                    CHILD: /:(only|nth|last|first)-child(?:\\(\\s*(even|odd|(?:[+\\-]?\\d+|(?:[+\\-]?\\d*)?n\\s*(?:[+\\-]\\s*\\d+)?))\\s*\\))?/,\n                    POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\\((\\d*)\\))?(?=[^\\-]|$)/,\n                    PSEUDO: /:((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)(?:\\((['\"]?)((?:\\([^\\)]+\\)|[^\\(\\)]*)+)\\2\\))?/\n                },\n                leftMatch: {\n                },\n                attrMap: {\n                    class: \"className\",\n                    \"for\": \"htmlFor\"\n                },\n                attrHandle: {\n                    href: function(a) {\n                        return a.getAttribute(\"href\");\n                    },\n                    type: function(a) {\n                        return a.getAttribute(\"type\");\n                    }\n                },\n                relative: {\n                    \"+\": function(a, b) {\n                        var c = ((typeof b == \"string\")), d = ((c && !m.test(b))), e = ((c && !d));\n                        ((d && (b = b.toLowerCase())));\n                        for (var f = 0, g = a.length, i; ((f < g)); f++) {\n                            if (i = a[f]) {\n                                while ((((i = i.previousSibling) && ((i.nodeType !== 1))))) {\n                                ;\n                                };\n                            ;\n                                a[f] = ((((e || ((i && ((i.nodeName.toLowerCase() === b)))))) ? ((i || !1)) : ((i === b))));\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        ((e && n.filter(b, a, !0)));\n                    },\n                    \"\\u003E\": function(a, b) {\n                        var c, d = ((typeof b == \"string\")), e = 0, f = a.length;\n                        if (((d && !m.test(b)))) {\n                            b = b.toLowerCase();\n                            for (; ((e < f)); e++) {\n                                c = a[e];\n                                if (c) {\n                                    var g = c.parentNode;\n                                    a[e] = ((((g.nodeName.toLowerCase() === b)) ? g : !1));\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                         else {\n                            for (; ((e < f)); e++) {\n                                c = a[e], ((c && (a[e] = ((d ? c.parentNode : ((c.parentNode === b)))))));\n                            ;\n                            };\n                        ;\n                            ((d && n.filter(b, a, !0)));\n                        }\n                    ;\n                    ;\n                    },\n                    \"\": function(b, d, e) {\n                        var g, i = f++, j = c;\n                        ((((((typeof d == \"string\")) && !m.test(d))) && (d = d.toLowerCase(), g = d, j = a))), j(\"parentNode\", d, i, b, g, e);\n                    },\n                    \"~\": function(b, d, e) {\n                        var g, i = f++, j = c;\n                        ((((((typeof d == \"string\")) && !m.test(d))) && (d = d.toLowerCase(), g = d, j = a))), j(\"previousSibling\", d, i, b, g, e);\n                    }\n                },\n                JSBNG__find: {\n                    ID: function(a, b, c) {\n                        if (((((typeof b.getElementById != \"undefined\")) && !c))) {\n                            var d = b.getElementById(a[1]);\n                            return ((((d && d.parentNode)) ? [d,] : []));\n                        }\n                    ;\n                    ;\n                    },\n                    NAME: function(a, b) {\n                        if (((typeof b.getElementsByName != \"undefined\"))) {\n                            var c = [], d = b.getElementsByName(a[1]);\n                            for (var e = 0, f = d.length; ((e < f)); e++) {\n                                ((((d[e].getAttribute(\"JSBNG__name\") === a[1])) && c.push(d[e])));\n                            ;\n                            };\n                        ;\n                            return ((((c.length === 0)) ? null : c));\n                        }\n                    ;\n                    ;\n                    },\n                    TAG: function(a, b) {\n                        if (((typeof b.getElementsByTagName != \"undefined\"))) {\n                            return b.getElementsByTagName(a[1]);\n                        }\n                    ;\n                    ;\n                    }\n                },\n                preFilter: {\n                    CLASS: function(a, b, c, d, e, f) {\n                        a = ((((\" \" + a[1].replace(k, \"\"))) + \" \"));\n                        if (f) {\n                            return a;\n                        }\n                    ;\n                    ;\n                        for (var g = 0, i; (((i = b[g]) != null)); g++) {\n                            ((i && ((((e ^ ((i.className && ((((((\" \" + i.className)) + \" \")).replace(/[\\t\\n\\r]/g, \" \").indexOf(a) >= 0)))))) ? ((c || d.push(i))) : ((c && (b[g] = !1)))))));\n                        ;\n                        };\n                    ;\n                        return !1;\n                    },\n                    ID: function(a) {\n                        return a[1].replace(k, \"\");\n                    },\n                    TAG: function(a, b) {\n                        return a[1].replace(k, \"\").toLowerCase();\n                    },\n                    CHILD: function(a) {\n                        if (((a[1] === \"nth\"))) {\n                            ((a[2] || n.error(a[0]))), a[2] = a[2].replace(/^\\+|\\s*/g, \"\");\n                            var b = /(-?)(\\d*)(?:n([+\\-]?\\d*))?/.exec(((((((((((a[2] === \"even\")) && \"2n\")) || ((((a[2] === \"odd\")) && \"2n+1\")))) || ((!/\\D/.test(a[2]) && ((\"0n+\" + a[2])))))) || a[2])));\n                            a[2] = ((((b[1] + ((b[2] || 1)))) - 0)), a[3] = ((b[3] - 0));\n                        }\n                         else ((a[2] && n.error(a[0])));\n                    ;\n                    ;\n                        return a[0] = f++, a;\n                    },\n                    ATTR: function(a, b, c, d, e, f) {\n                        var g = a[1] = a[1].replace(k, \"\");\n                        return ((((!f && p.attrMap[g])) && (a[1] = p.attrMap[g]))), a[4] = ((((a[4] || a[5])) || \"\")).replace(k, \"\"), ((((a[2] === \"~=\")) && (a[4] = ((((\" \" + a[4])) + \" \"))))), a;\n                    },\n                    PSEUDO: function(a, b, c, e, f) {\n                        if (((a[1] === \"not\"))) {\n                            if (!((((((d.exec(a[3]) || \"\")).length > 1)) || /^\\w/.test(a[3])))) {\n                                var g = n.filter(a[3], b, c, ((!0 ^ f)));\n                                return ((c || e.push.apply(e, g))), !1;\n                            }\n                        ;\n                        ;\n                            a[3] = n(a[3], null, null, b);\n                        }\n                         else if (((p.match.POS.test(a[0]) || p.match.CHILD.test(a[0])))) {\n                            return !0;\n                        }\n                        \n                    ;\n                    ;\n                        return a;\n                    },\n                    POS: function(a) {\n                        return a.unshift(!0), a;\n                    }\n                },\n                filters: {\n                    enabled: function(a) {\n                        return ((((a.disabled === !1)) && ((a.type !== \"hidden\"))));\n                    },\n                    disabled: function(a) {\n                        return ((a.disabled === !0));\n                    },\n                    checked: function(a) {\n                        return ((a.checked === !0));\n                    },\n                    selected: function(a) {\n                        return ((a.parentNode && a.parentNode.selectedIndex)), ((a.selected === !0));\n                    },\n                    parent: function(a) {\n                        return !!a.firstChild;\n                    },\n                    empty: function(a) {\n                        return !a.firstChild;\n                    },\n                    has: function(a, b, c) {\n                        return !!n(c[3], a).length;\n                    },\n                    header: function(a) {\n                        return /h\\d/i.test(a.nodeName);\n                    },\n                    text: function(a) {\n                        var b = a.getAttribute(\"type\"), c = a.type;\n                        return ((((((a.nodeName.toLowerCase() === \"input\")) && ((\"text\" === c)))) && ((((b === c)) || ((b === null))))));\n                    },\n                    radio: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"radio\" === a.type))));\n                    },\n                    checkbox: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"checkbox\" === a.type))));\n                    },\n                    file: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"file\" === a.type))));\n                    },\n                    password: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"password\" === a.type))));\n                    },\n                    submit: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) || ((b === \"button\")))) && ((\"submit\" === a.type))));\n                    },\n                    image: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"image\" === a.type))));\n                    },\n                    reset: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) || ((b === \"button\")))) && ((\"reset\" === a.type))));\n                    },\n                    button: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) && ((\"button\" === a.type)))) || ((b === \"button\"))));\n                    },\n                    input: function(a) {\n                        return /input|select|textarea|button/i.test(a.nodeName);\n                    },\n                    JSBNG__focus: function(a) {\n                        return ((a === a.ownerDocument.activeElement));\n                    }\n                },\n                setFilters: {\n                    first: function(a, b) {\n                        return ((b === 0));\n                    },\n                    last: function(a, b, c, d) {\n                        return ((b === ((d.length - 1))));\n                    },\n                    even: function(a, b) {\n                        return ((((b % 2)) === 0));\n                    },\n                    odd: function(a, b) {\n                        return ((((b % 2)) === 1));\n                    },\n                    lt: function(a, b, c) {\n                        return ((b < ((c[3] - 0))));\n                    },\n                    gt: function(a, b, c) {\n                        return ((b > ((c[3] - 0))));\n                    },\n                    nth: function(a, b, c) {\n                        return ((((c[3] - 0)) === b));\n                    },\n                    eq: function(a, b, c) {\n                        return ((((c[3] - 0)) === b));\n                    }\n                },\n                filter: {\n                    PSEUDO: function(a, b, c, d) {\n                        var e = b[1], f = p.filters[e];\n                        if (f) {\n                            return f(a, c, b, d);\n                        }\n                    ;\n                    ;\n                        if (((e === \"contains\"))) {\n                            return ((((((((a.textContent || a.innerText)) || o([a,]))) || \"\")).indexOf(b[3]) >= 0));\n                        }\n                    ;\n                    ;\n                        if (((e === \"not\"))) {\n                            var g = b[3];\n                            for (var i = 0, j = g.length; ((i < j)); i++) {\n                                if (((g[i] === a))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            return !0;\n                        }\n                    ;\n                    ;\n                        n.error(e);\n                    },\n                    CHILD: function(a, b) {\n                        var c, d, f, g, i, j, k, l = b[1], m = a;\n                        switch (l) {\n                          case \"JSBNG__only\":\n                        \n                          case \"first\":\n                            while (m = m.previousSibling) {\n                                if (((m.nodeType === 1))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            if (((l === \"first\"))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                            m = a;\n                          case \"last\":\n                            while (m = m.nextSibling) {\n                                if (((m.nodeType === 1))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            return !0;\n                          case \"nth\":\n                            c = b[2], d = b[3];\n                            if (((((c === 1)) && ((d === 0))))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                            f = b[0], g = a.parentNode;\n                            if (((g && ((((g[e] !== f)) || !a.nodeIndex))))) {\n                                j = 0;\n                                for (m = g.firstChild; m; m = m.nextSibling) {\n                                    ((((m.nodeType === 1)) && (m.nodeIndex = ++j)));\n                                ;\n                                };\n                            ;\n                                g[e] = f;\n                            }\n                        ;\n                        ;\n                            return k = ((a.nodeIndex - d)), ((((c === 0)) ? ((k === 0)) : ((((((k % c)) === 0)) && ((((k / c)) >= 0))))));\n                        };\n                    ;\n                    },\n                    ID: function(a, b) {\n                        return ((((a.nodeType === 1)) && ((a.getAttribute(\"id\") === b))));\n                    },\n                    TAG: function(a, b) {\n                        return ((((((b === \"*\")) && ((a.nodeType === 1)))) || ((!!a.nodeName && ((a.nodeName.toLowerCase() === b))))));\n                    },\n                    CLASS: function(a, b) {\n                        return ((((((\" \" + ((a.className || a.getAttribute(\"class\"))))) + \" \")).indexOf(b) > -1));\n                    },\n                    ATTR: function(a, b) {\n                        var c = b[1], d = ((n.attr ? n.attr(a, c) : ((p.attrHandle[c] ? p.attrHandle[c](a) : ((((a[c] != null)) ? a[c] : a.getAttribute(c))))))), e = ((d + \"\")), f = b[2], g = b[4];\n                        return ((((d == null)) ? ((f === \"!=\")) : ((((!f && n.attr)) ? ((d != null)) : ((((f === \"=\")) ? ((e === g)) : ((((f === \"*=\")) ? ((e.indexOf(g) >= 0)) : ((((f === \"~=\")) ? ((((((\" \" + e)) + \" \")).indexOf(g) >= 0)) : ((g ? ((((f === \"!=\")) ? ((e !== g)) : ((((f === \"^=\")) ? ((e.indexOf(g) === 0)) : ((((f === \"$=\")) ? ((e.substr(((e.length - g.length))) === g)) : ((((f === \"|=\")) ? ((((e === g)) || ((e.substr(0, ((g.length + 1))) === ((g + \"-\")))))) : !1)))))))) : ((e && ((d !== !1))))))))))))))));\n                    },\n                    POS: function(a, b, c, d) {\n                        var e = b[2], f = p.setFilters[e];\n                        if (f) {\n                            return f(a, c, b, d);\n                        }\n                    ;\n                    ;\n                    }\n                }\n            }, q = p.match.POS, r = function(a, b) {\n                return ((\"\\\\\" + ((((b - 0)) + 1))));\n            };\n            for (var s in p.match) {\n                p.match[s] = new RegExp(((p.match[s].source + /(?![^\\[]*\\])(?![^\\(]*\\))/.source))), p.leftMatch[s] = new RegExp(((/(^(?:.|\\r|\\n)*?)/.source + p.match[s].source.replace(/\\\\(\\d+)/g, r))));\n            ;\n            };\n        ;\n            var t = function(a, b) {\n                return a = Array.prototype.slice.call(a, 0), ((b ? (b.push.apply(b, a), b) : a));\n            };\n            try {\n                Array.prototype.slice.call(I.documentElement.childNodes, 0)[0].nodeType;\n            } catch (u) {\n                t = function(a, b) {\n                    var c = 0, d = ((b || []));\n                    if (((g.call(a) === \"[object Array]\"))) {\n                        Array.prototype.push.apply(d, a);\n                    }\n                     else {\n                        if (((typeof a.length == \"number\"))) {\n                            for (var e = a.length; ((c < e)); c++) {\n                                d.push(a[c]);\n                            ;\n                            };\n                        }\n                         else {\n                            for (; a[c]; c++) {\n                                d.push(a[c]);\n                            ;\n                            };\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    return d;\n                };\n            };\n        ;\n            var v, w;\n            ((I.documentElement.compareDocumentPosition ? v = function(a, b) {\n                return ((((a === b)) ? (i = !0, 0) : ((((!a.compareDocumentPosition || !b.compareDocumentPosition)) ? ((a.compareDocumentPosition ? -1 : 1)) : ((((a.compareDocumentPosition(b) & 4)) ? -1 : 1))))));\n            } : (v = function(a, b) {\n                if (((a === b))) {\n                    return i = !0, 0;\n                }\n            ;\n            ;\n                if (((a.sourceIndex && b.sourceIndex))) {\n                    return ((a.sourceIndex - b.sourceIndex));\n                }\n            ;\n            ;\n                var c, d, e = [], f = [], g = a.parentNode, j = b.parentNode, k = g;\n                if (((g === j))) {\n                    return w(a, b);\n                }\n            ;\n            ;\n                if (!g) {\n                    return -1;\n                }\n            ;\n            ;\n                if (!j) {\n                    return 1;\n                }\n            ;\n            ;\n                while (k) {\n                    e.unshift(k), k = k.parentNode;\n                ;\n                };\n            ;\n                k = j;\n                while (k) {\n                    f.unshift(k), k = k.parentNode;\n                ;\n                };\n            ;\n                c = e.length, d = f.length;\n                for (var l = 0; ((((l < c)) && ((l < d)))); l++) {\n                    if (((e[l] !== f[l]))) {\n                        return w(e[l], f[l]);\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((((l === c)) ? w(a, f[l], -1) : w(e[l], b, 1)));\n            }, w = function(a, b, c) {\n                if (((a === b))) {\n                    return c;\n                }\n            ;\n            ;\n                var d = a.nextSibling;\n                while (d) {\n                    if (((d === b))) {\n                        return -1;\n                    }\n                ;\n                ;\n                    d = d.nextSibling;\n                };\n            ;\n                return 1;\n            }))), function() {\n                var a = I.createElement(\"div\"), c = ((\"script\" + (new JSBNG__Date).getTime())), d = I.documentElement;\n                a.innerHTML = ((((\"\\u003Ca name='\" + c)) + \"'/\\u003E\")), d.insertBefore(a, d.firstChild), ((I.getElementById(c) && (p.JSBNG__find.ID = function(a, c, d) {\n                    if (((((typeof c.getElementById != \"undefined\")) && !d))) {\n                        var e = c.getElementById(a[1]);\n                        return ((e ? ((((((e.id === a[1])) || ((((typeof e.getAttributeNode != \"undefined\")) && ((e.getAttributeNode(\"id\").nodeValue === a[1])))))) ? [e,] : b)) : []));\n                    }\n                ;\n                ;\n                }, p.filter.ID = function(a, b) {\n                    var c = ((((typeof a.getAttributeNode != \"undefined\")) && a.getAttributeNode(\"id\")));\n                    return ((((((a.nodeType === 1)) && c)) && ((c.nodeValue === b))));\n                }))), d.removeChild(a), d = a = null;\n            }(), function() {\n                var a = I.createElement(\"div\");\n                a.appendChild(I.createComment(\"\")), ((((a.getElementsByTagName(\"*\").length > 0)) && (p.JSBNG__find.TAG = function(a, b) {\n                    var c = b.getElementsByTagName(a[1]);\n                    if (((a[1] === \"*\"))) {\n                        var d = [];\n                        for (var e = 0; c[e]; e++) {\n                            ((((c[e].nodeType === 1)) && d.push(c[e])));\n                        ;\n                        };\n                    ;\n                        c = d;\n                    }\n                ;\n                ;\n                    return c;\n                }))), a.innerHTML = \"\\u003Ca href='#'\\u003E\\u003C/a\\u003E\", ((((((a.firstChild && ((typeof a.firstChild.getAttribute != \"undefined\")))) && ((a.firstChild.getAttribute(\"href\") !== \"#\")))) && (p.attrHandle.href = function(a) {\n                    return a.getAttribute(\"href\", 2);\n                }))), a = null;\n            }(), ((I.querySelectorAll && function() {\n                var a = n, b = I.createElement(\"div\"), c = \"__sizzle__\";\n                b.innerHTML = \"\\u003Cp class='TEST'\\u003E\\u003C/p\\u003E\";\n                if (((b.querySelectorAll && ((b.querySelectorAll(\".TEST\").length === 0))))) {\n                    return;\n                }\n            ;\n            ;\n                n = function(b, d, e, f) {\n                    d = ((d || I));\n                    if (((!f && !n.isXML(d)))) {\n                        var g = /^(\\w+$)|^\\.([\\w\\-]+$)|^#([\\w\\-]+$)/.exec(b);\n                        if (((g && ((((d.nodeType === 1)) || ((d.nodeType === 9))))))) {\n                            if (g[1]) {\n                                return t(d.getElementsByTagName(b), e);\n                            }\n                        ;\n                        ;\n                            if (((((g[2] && p.JSBNG__find.CLASS)) && d.getElementsByClassName))) {\n                                return t(d.getElementsByClassName(g[2]), e);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (((d.nodeType === 9))) {\n                            if (((((b === \"body\")) && d.body))) {\n                                return t([d.body,], e);\n                            }\n                        ;\n                        ;\n                            if (((g && g[3]))) {\n                                var i = d.getElementById(g[3]);\n                                if (((!i || !i.parentNode))) {\n                                    return t([], e);\n                                }\n                            ;\n                            ;\n                                if (((i.id === g[3]))) {\n                                    return t([i,], e);\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            try {\n                                return t(d.querySelectorAll(b), e);\n                            } catch (j) {\n                            \n                            };\n                        ;\n                        }\n                         else if (((((d.nodeType === 1)) && ((d.nodeName.toLowerCase() !== \"object\"))))) {\n                            var k = d, l = d.getAttribute(\"id\"), m = ((l || c)), o = d.parentNode, q = /^\\s*[+~]/.test(b);\n                            ((l ? m = m.replace(/'/g, \"\\\\$&\") : d.setAttribute(\"id\", m))), ((((q && o)) && (d = d.parentNode)));\n                            try {\n                                if (((!q || o))) {\n                                    return t(d.querySelectorAll(((((((\"[id='\" + m)) + \"'] \")) + b))), e);\n                                }\n                            ;\n                            ;\n                            } catch (r) {\n                            \n                            } finally {\n                                ((l || k.removeAttribute(\"id\")));\n                            };\n                        ;\n                        }\n                        \n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return a(b, d, e, f);\n                };\n                for (var d in a) {\n                    n[d] = a[d];\n                ;\n                };\n            ;\n                b = null;\n            }())), function() {\n                var a = I.documentElement, b = ((((((a.matchesSelector || a.mozMatchesSelector)) || a.webkitMatchesSelector)) || a.msMatchesSelector));\n                if (b) {\n                    var c = !b.call(I.createElement(\"div\"), \"div\"), d = !1;\n                    try {\n                        b.call(I.documentElement, \"[test!='']:sizzle\");\n                    } catch (e) {\n                        d = !0;\n                    };\n                ;\n                    n.matchesSelector = function(a, e) {\n                        e = e.replace(/\\=\\s*([^'\"\\]]*)\\s*\\]/g, \"='$1']\");\n                        if (!n.isXML(a)) {\n                            try {\n                                if (((d || ((!p.match.PSEUDO.test(e) && !/!=/.test(e)))))) {\n                                    var f = b.call(a, e);\n                                    if (((((f || !c)) || ((a.JSBNG__document && ((a.JSBNG__document.nodeType !== 11))))))) {\n                                        return f;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            } catch (g) {\n                            \n                            };\n                        }\n                    ;\n                    ;\n                        return ((n(e, null, null, [a,]).length > 0));\n                    };\n                }\n            ;\n            ;\n            }(), function() {\n                var a = I.createElement(\"div\");\n                a.innerHTML = \"\\u003Cdiv class='test e'\\u003E\\u003C/div\\u003E\\u003Cdiv class='test'\\u003E\\u003C/div\\u003E\";\n                if (((!a.getElementsByClassName || ((a.getElementsByClassName(\"e\").length === 0))))) {\n                    return;\n                }\n            ;\n            ;\n                a.lastChild.className = \"e\";\n                if (((a.getElementsByClassName(\"e\").length === 1))) {\n                    return;\n                }\n            ;\n            ;\n                p.order.splice(1, 0, \"CLASS\"), p.JSBNG__find.CLASS = function(a, b, c) {\n                    if (((((typeof b.getElementsByClassName != \"undefined\")) && !c))) {\n                        return b.getElementsByClassName(a[1]);\n                    }\n                ;\n                ;\n                }, a = null;\n            }(), ((I.documentElement.contains ? n.contains = function(a, b) {\n                return ((((a !== b)) && ((a.contains ? a.contains(b) : !0))));\n            } : ((I.documentElement.compareDocumentPosition ? n.contains = function(a, b) {\n                return !!((a.compareDocumentPosition(b) & 16));\n            } : n.contains = function() {\n                return !1;\n            })))), n.isXML = function(a) {\n                var b = ((a ? ((a.ownerDocument || a)) : 0)).documentElement;\n                return ((b ? ((b.nodeName !== \"HTML\")) : !1));\n            };\n            var x = function(a, b, c) {\n                var d, e = [], f = \"\", g = ((b.nodeType ? [b,] : b));\n                while (d = p.match.PSEUDO.exec(a)) {\n                    f += d[0], a = a.replace(p.match.PSEUDO, \"\");\n                ;\n                };\n            ;\n                a = ((p.relative[a] ? ((a + \"*\")) : a));\n                for (var i = 0, j = g.length; ((i < j)); i++) {\n                    n(a, g[i], e, c);\n                ;\n                };\n            ;\n                return n.filter(f, e);\n            };\n            n.attr = L.attr, n.selectors.attrMap = {\n            }, L.JSBNG__find = n, L.expr = n.selectors, L.expr[\":\"] = L.expr.filters, L.unique = n.uniqueSort, L.text = n.getText, L.isXMLDoc = n.isXML, L.contains = n.contains;\n        })();\n        var lb = /Until$/, mb = /^(?:parents|prevUntil|prevAll)/, nb = /,/, ob = /^.[^:#\\[\\.,]*$/, pb = Array.prototype.slice, qb = L.expr.match.POS, rb = {\n            children: !0,\n            contents: !0,\n            next: !0,\n            prev: !0\n        };\n        L.fn.extend({\n            JSBNG__find: function(a) {\n                var b = this, c, d;\n                if (((typeof a != \"string\"))) {\n                    return L(a).filter(function() {\n                        for (c = 0, d = b.length; ((c < d)); c++) {\n                            if (L.contains(b[c], this)) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    });\n                }\n            ;\n            ;\n                var e = this.pushStack(\"\", \"JSBNG__find\", a), f, g, i;\n                for (c = 0, d = this.length; ((c < d)); c++) {\n                    f = e.length, L.JSBNG__find(a, this[c], e);\n                    if (((c > 0))) {\n                        for (g = f; ((g < e.length)); g++) {\n                            for (i = 0; ((i < f)); i++) {\n                                if (((e[i] === e[g]))) {\n                                    e.splice(g--, 1);\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return e;\n            },\n            has: function(a) {\n                var b = L(a);\n                return this.filter(function() {\n                    for (var a = 0, c = b.length; ((a < c)); a++) {\n                        if (L.contains(this, b[a])) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                });\n            },\n            not: function(a) {\n                return this.pushStack(k(this, a, !1), \"not\", a);\n            },\n            filter: function(a) {\n                return this.pushStack(k(this, a, !0), \"filter\", a);\n            },\n            is: function(a) {\n                return ((!!a && ((((typeof a == \"string\")) ? ((qb.test(a) ? ((L(a, this.context).index(this[0]) >= 0)) : ((L.filter(a, this).length > 0)))) : ((this.filter(a).length > 0))))));\n            },\n            closest: function(a, b) {\n                var c = [], d, e, f = this[0];\n                if (L.isArray(a)) {\n                    var g = 1;\n                    while (((((f && f.ownerDocument)) && ((f !== b))))) {\n                        for (d = 0; ((d < a.length)); d++) {\n                            ((L(f).is(a[d]) && c.push({\n                                selector: a[d],\n                                elem: f,\n                                level: g\n                            })));\n                        ;\n                        };\n                    ;\n                        f = f.parentNode, g++;\n                    };\n                ;\n                    return c;\n                }\n            ;\n            ;\n                var i = ((((qb.test(a) || ((typeof a != \"string\")))) ? L(a, ((b || this.context))) : 0));\n                for (d = 0, e = this.length; ((d < e)); d++) {\n                    f = this[d];\n                    while (f) {\n                        if (((i ? ((i.index(f) > -1)) : L.JSBNG__find.matchesSelector(f, a)))) {\n                            c.push(f);\n                            break;\n                        }\n                    ;\n                    ;\n                        f = f.parentNode;\n                        if (((((((!f || !f.ownerDocument)) || ((f === b)))) || ((f.nodeType === 11))))) {\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                };\n            ;\n                return c = ((((c.length > 1)) ? L.unique(c) : c)), this.pushStack(c, \"closest\", a);\n            },\n            index: function(a) {\n                return ((a ? ((((typeof a == \"string\")) ? L.inArray(this[0], L(a)) : L.inArray(((a.jquery ? a[0] : a)), this))) : ((((this[0] && this[0].parentNode)) ? this.prevAll().length : -1))));\n            },\n            add: function(a, b) {\n                var c = ((((typeof a == \"string\")) ? L(a, b) : L.makeArray(((((a && a.nodeType)) ? [a,] : a))))), d = L.merge(this.get(), c);\n                return this.pushStack(((((j(c[0]) || j(d[0]))) ? d : L.unique(d))));\n            },\n            andSelf: function() {\n                return this.add(this.prevObject);\n            }\n        }), L.each({\n            parent: function(a) {\n                var b = a.parentNode;\n                return ((((b && ((b.nodeType !== 11)))) ? b : null));\n            },\n            parents: function(a) {\n                return L.dir(a, \"parentNode\");\n            },\n            parentsUntil: function(a, b, c) {\n                return L.dir(a, \"parentNode\", c);\n            },\n            next: function(a) {\n                return L.nth(a, 2, \"nextSibling\");\n            },\n            prev: function(a) {\n                return L.nth(a, 2, \"previousSibling\");\n            },\n            nextAll: function(a) {\n                return L.dir(a, \"nextSibling\");\n            },\n            prevAll: function(a) {\n                return L.dir(a, \"previousSibling\");\n            },\n            nextUntil: function(a, b, c) {\n                return L.dir(a, \"nextSibling\", c);\n            },\n            prevUntil: function(a, b, c) {\n                return L.dir(a, \"previousSibling\", c);\n            },\n            siblings: function(a) {\n                return L.sibling(a.parentNode.firstChild, a);\n            },\n            children: function(a) {\n                return L.sibling(a.firstChild);\n            },\n            contents: function(a) {\n                return ((L.nodeName(a, \"div\") ? ((a.contentDocument || a.contentWindow.JSBNG__document)) : L.makeArray(a.childNodes)));\n            }\n        }, function(a, b) {\n            L.fn[a] = function(c, d) {\n                var e = L.map(this, b, c);\n                return ((lb.test(a) || (d = c))), ((((d && ((typeof d == \"string\")))) && (e = L.filter(d, e)))), e = ((((((this.length > 1)) && !rb[a])) ? L.unique(e) : e)), ((((((((this.length > 1)) || nb.test(d))) && mb.test(a))) && (e = e.reverse()))), this.pushStack(e, a, pb.call(arguments).join(\",\"));\n            };\n        }), L.extend({\n            filter: function(a, b, c) {\n                return ((c && (a = ((((\":not(\" + a)) + \")\"))))), ((((b.length === 1)) ? ((L.JSBNG__find.matchesSelector(b[0], a) ? [b[0],] : [])) : L.JSBNG__find.matches(a, b)));\n            },\n            dir: function(a, c, d) {\n                var e = [], f = a[c];\n                while (((((f && ((f.nodeType !== 9)))) && ((((((d === b)) || ((f.nodeType !== 1)))) || !L(f).is(d)))))) {\n                    ((((f.nodeType === 1)) && e.push(f))), f = f[c];\n                ;\n                };\n            ;\n                return e;\n            },\n            nth: function(a, b, c, d) {\n                b = ((b || 1));\n                var e = 0;\n                for (; a; a = a[c]) {\n                    if (((((a.nodeType === 1)) && ((++e === b))))) {\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                return a;\n            },\n            sibling: function(a, b) {\n                var c = [];\n                for (; a; a = a.nextSibling) {\n                    ((((((a.nodeType === 1)) && ((a !== b)))) && c.push(a)));\n                ;\n                };\n            ;\n                return c;\n            }\n        });\n        var sb = \"abbr|article|aside|audio|canvas|datalist|details|figcaption|figure|footer|header|hgroup|mark|meter|nav|output|progress|section|summary|time|video\", tb = / jQuery\\d+=\"(?:\\d+|null)\"/g, ub = /^\\s+/, vb = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\\w:]+)[^>]*)\\/>/gi, wb = /<([\\w:]+)/, xb = /<tbody/i, yb = /<|&#?\\w+;/, zb = /<(?:script|style)/i, Ab = /<(?:script|object|embed|option|style)/i, Bb = new RegExp(((((\"\\u003C(?:\" + sb)) + \")\")), \"i\"), Cb = /checked\\s*(?:[^=]|=\\s*.checked.)/i, Db = /\\/(java|ecma)script/i, Eb = /^\\s*<!(?:\\[CDATA\\[|\\-\\-)/, Fb = {\n            option: [1,\"\\u003Cselect multiple='multiple'\\u003E\",\"\\u003C/select\\u003E\",],\n            legend: [1,\"\\u003Cfieldset\\u003E\",\"\\u003C/fieldset\\u003E\",],\n            thead: [1,\"\\u003Ctable\\u003E\",\"\\u003C/table\\u003E\",],\n            tr: [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\",\"\\u003C/tbody\\u003E\\u003C/table\\u003E\",],\n            td: [3,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\",\"\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\",],\n            col: [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003C/tbody\\u003E\\u003Ccolgroup\\u003E\",\"\\u003C/colgroup\\u003E\\u003C/table\\u003E\",],\n            area: [1,\"\\u003Cmap\\u003E\",\"\\u003C/map\\u003E\",],\n            _default: [0,\"\",\"\",]\n        }, Gb = l(I);\n        Fb.optgroup = Fb.option, Fb.tbody = Fb.tfoot = Fb.colgroup = Fb.caption = Fb.thead, Fb.th = Fb.td, ((L.support.htmlSerialize || (Fb._default = [1,\"div\\u003Cdiv\\u003E\",\"\\u003C/div\\u003E\",]))), L.fn.extend({\n            text: function(a) {\n                return ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this);\n                    c.text(a.call(this, b, c.text()));\n                }) : ((((((typeof a != \"object\")) && ((a !== b)))) ? this.empty().append(((((this[0] && this[0].ownerDocument)) || I)).createTextNode(a)) : L.text(this)))));\n            },\n            wrapAll: function(a) {\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).wrapAll(a.call(this, b));\n                    });\n                }\n            ;\n            ;\n                if (this[0]) {\n                    var b = L(a, this[0].ownerDocument).eq(0).clone(!0);\n                    ((this[0].parentNode && b.insertBefore(this[0]))), b.map(function() {\n                        var a = this;\n                        while (((a.firstChild && ((a.firstChild.nodeType === 1))))) {\n                            a = a.firstChild;\n                        ;\n                        };\n                    ;\n                        return a;\n                    }).append(this);\n                }\n            ;\n            ;\n                return this;\n            },\n            wrapInner: function(a) {\n                return ((L.isFunction(a) ? this.each(function(b) {\n                    L(this).wrapInner(a.call(this, b));\n                }) : this.each(function() {\n                    var b = L(this), c = b.contents();\n                    ((c.length ? c.wrapAll(a) : b.append(a)));\n                })));\n            },\n            wrap: function(a) {\n                var b = L.isFunction(a);\n                return this.each(function(c) {\n                    L(this).wrapAll(((b ? a.call(this, c) : a)));\n                });\n            },\n            unwrap: function() {\n                return this.parent().each(function() {\n                    ((L.nodeName(this, \"body\") || L(this).replaceWith(this.childNodes)));\n                }).end();\n            },\n            append: function() {\n                return this.domManip(arguments, !0, function(a) {\n                    ((((this.nodeType === 1)) && this.appendChild(a)));\n                });\n            },\n            prepend: function() {\n                return this.domManip(arguments, !0, function(a) {\n                    ((((this.nodeType === 1)) && this.insertBefore(a, this.firstChild)));\n                });\n            },\n            before: function() {\n                if (((this[0] && this[0].parentNode))) {\n                    return this.domManip(arguments, !1, function(a) {\n                        this.parentNode.insertBefore(a, this);\n                    });\n                }\n            ;\n            ;\n                if (arguments.length) {\n                    var a = L.clean(arguments);\n                    return a.push.apply(a, this.toArray()), this.pushStack(a, \"before\", arguments);\n                }\n            ;\n            ;\n            },\n            after: function() {\n                if (((this[0] && this[0].parentNode))) {\n                    return this.domManip(arguments, !1, function(a) {\n                        this.parentNode.insertBefore(a, this.nextSibling);\n                    });\n                }\n            ;\n            ;\n                if (arguments.length) {\n                    var a = this.pushStack(this, \"after\", arguments);\n                    return a.push.apply(a, L.clean(arguments)), a;\n                }\n            ;\n            ;\n            },\n            remove: function(a, b) {\n                for (var c = 0, d; (((d = this[c]) != null)); c++) {\n                    if (((!a || L.filter(a, [d,]).length))) {\n                        ((((!b && ((d.nodeType === 1)))) && (L.cleanData(d.getElementsByTagName(\"*\")), L.cleanData([d,])))), ((d.parentNode && d.parentNode.removeChild(d)));\n                    }\n                ;\n                ;\n                };\n            ;\n                return this;\n            },\n            empty: function() {\n                for (var a = 0, b; (((b = this[a]) != null)); a++) {\n                    ((((b.nodeType === 1)) && L.cleanData(b.getElementsByTagName(\"*\"))));\n                    while (b.firstChild) {\n                        b.removeChild(b.firstChild);\n                    ;\n                    };\n                ;\n                };\n            ;\n                return this;\n            },\n            clone: function(a, b) {\n                return a = ((((a == null)) ? !1 : a)), b = ((((b == null)) ? a : b)), this.map(function() {\n                    return L.clone(this, a, b);\n                });\n            },\n            html: function(a) {\n                if (((a === b))) {\n                    return ((((this[0] && ((this[0].nodeType === 1)))) ? this[0].innerHTML.replace(tb, \"\") : null));\n                }\n            ;\n            ;\n                if (((((((((typeof a == \"string\")) && !zb.test(a))) && ((L.support.leadingWhitespace || !ub.test(a))))) && !Fb[((wb.exec(a) || [\"\",\"\",]))[1].toLowerCase()]))) {\n                    a = a.replace(vb, \"\\u003C$1\\u003E\\u003C/$2\\u003E\");\n                    try {\n                        for (var c = 0, d = this.length; ((c < d)); c++) {\n                            ((((this[c].nodeType === 1)) && (L.cleanData(this[c].getElementsByTagName(\"*\")), this[c].innerHTML = a)));\n                        ;\n                        };\n                    ;\n                    } catch (e) {\n                        this.empty().append(a);\n                    };\n                ;\n                }\n                 else ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this);\n                    c.html(a.call(this, b, c.html()));\n                }) : this.empty().append(a)));\n            ;\n            ;\n                return this;\n            },\n            replaceWith: function(a) {\n                return ((((this[0] && this[0].parentNode)) ? ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this), d = c.html();\n                    c.replaceWith(a.call(this, b, d));\n                }) : (((((typeof a != \"string\")) && (a = L(a).detach()))), this.each(function() {\n                    var b = this.nextSibling, c = this.parentNode;\n                    L(this).remove(), ((b ? L(b).before(a) : L(c).append(a)));\n                })))) : ((this.length ? this.pushStack(L(((L.isFunction(a) ? a() : a))), \"replaceWith\", a) : this))));\n            },\n            detach: function(a) {\n                return this.remove(a, !0);\n            },\n            domManip: function(a, c, d) {\n                var e, f, g, i, j = a[0], k = [];\n                if (((((((!L.support.checkClone && ((arguments.length === 3)))) && ((typeof j == \"string\")))) && Cb.test(j)))) {\n                    return this.each(function() {\n                        L(this).domManip(a, c, d, !0);\n                    });\n                }\n            ;\n            ;\n                if (L.isFunction(j)) {\n                    return this.each(function(e) {\n                        var f = L(this);\n                        a[0] = j.call(this, e, ((c ? f.html() : b))), f.domManip(a, c, d);\n                    });\n                }\n            ;\n            ;\n                if (this[0]) {\n                    i = ((j && j.parentNode)), ((((((((L.support.parentNode && i)) && ((i.nodeType === 11)))) && ((i.childNodes.length === this.length)))) ? e = {\n                        fragment: i\n                    } : e = L.buildFragment(a, this, k))), g = e.fragment, ((((g.childNodes.length === 1)) ? f = g = g.firstChild : f = g.firstChild));\n                    if (f) {\n                        c = ((c && L.nodeName(f, \"tr\")));\n                        for (var l = 0, n = this.length, o = ((n - 1)); ((l < n)); l++) {\n                            d.call(((c ? m(this[l], f) : this[l])), ((((e.cacheable || ((((n > 1)) && ((l < o)))))) ? L.clone(g, !0, !0) : g)));\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    ((k.length && L.each(k, t)));\n                }\n            ;\n            ;\n                return this;\n            }\n        }), L.buildFragment = function(a, b, c) {\n            var d, e, f, g, i = a[0];\n            return ((((b && b[0])) && (g = ((b[0].ownerDocument || b[0]))))), ((g.createDocumentFragment || (g = I))), ((((((((((((((((((a.length === 1)) && ((typeof i == \"string\")))) && ((i.length < 512)))) && ((g === I)))) && ((i.charAt(0) === \"\\u003C\")))) && !Ab.test(i))) && ((L.support.checkClone || !Cb.test(i))))) && ((L.support.html5Clone || !Bb.test(i))))) && (e = !0, f = L.fragments[i], ((((f && ((f !== 1)))) && (d = f)))))), ((d || (d = g.createDocumentFragment(), L.clean(a, g, d, c)))), ((e && (L.fragments[i] = ((f ? d : 1))))), {\n                fragment: d,\n                cacheable: e\n            };\n        }, L.fragments = {\n        }, L.each({\n            appendTo: \"append\",\n            prependTo: \"prepend\",\n            insertBefore: \"before\",\n            insertAfter: \"after\",\n            replaceAll: \"replaceWith\"\n        }, function(a, b) {\n            L.fn[a] = function(c) {\n                var d = [], e = L(c), f = ((((this.length === 1)) && this[0].parentNode));\n                if (((((((f && ((f.nodeType === 11)))) && ((f.childNodes.length === 1)))) && ((e.length === 1))))) {\n                    return e[b](this[0]), this;\n                }\n            ;\n            ;\n                for (var g = 0, i = e.length; ((g < i)); g++) {\n                    var j = ((((g > 0)) ? this.clone(!0) : this)).get();\n                    L(e[g])[b](j), d = d.concat(j);\n                };\n            ;\n                return this.pushStack(d, a, e.selector);\n            };\n        }), L.extend({\n            clone: function(a, b, c) {\n                var d, e, f, g = ((((L.support.html5Clone || !Bb.test(((\"\\u003C\" + a.nodeName))))) ? a.cloneNode(!0) : s(a)));\n                if (((((((!L.support.noCloneEvent || !L.support.noCloneChecked)) && ((((a.nodeType === 1)) || ((a.nodeType === 11)))))) && !L.isXMLDoc(a)))) {\n                    o(a, g), d = p(a), e = p(g);\n                    for (f = 0; d[f]; ++f) {\n                        ((e[f] && o(d[f], e[f])));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                if (b) {\n                    n(a, g);\n                    if (c) {\n                        d = p(a), e = p(g);\n                        for (f = 0; d[f]; ++f) {\n                            n(d[f], e[f]);\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return d = e = null, g;\n            },\n            clean: function(a, b, c, d) {\n                var e;\n                b = ((b || I)), ((((typeof b.createElement == \"undefined\")) && (b = ((((b.ownerDocument || ((b[0] && b[0].ownerDocument)))) || I)))));\n                var f = [], g;\n                for (var i = 0, j; (((j = a[i]) != null)); i++) {\n                    ((((typeof j == \"number\")) && (j += \"\")));\n                    if (!j) {\n                        continue;\n                    }\n                ;\n                ;\n                    if (((typeof j == \"string\"))) {\n                        if (!yb.test(j)) j = b.createTextNode(j);\n                         else {\n                            j = j.replace(vb, \"\\u003C$1\\u003E\\u003C/$2\\u003E\");\n                            var k = ((wb.exec(j) || [\"\",\"\",]))[1].toLowerCase(), m = ((Fb[k] || Fb._default)), n = m[0], o = b.createElement(\"div\");\n                            ((((b === I)) ? Gb.appendChild(o) : l(b).appendChild(o))), o.innerHTML = ((((m[1] + j)) + m[2]));\n                            while (n--) {\n                                o = o.lastChild;\n                            ;\n                            };\n                        ;\n                            if (!L.support.tbody) {\n                                var p = xb.test(j), q = ((((((k === \"table\")) && !p)) ? ((o.firstChild && o.firstChild.childNodes)) : ((((((m[1] === \"\\u003Ctable\\u003E\")) && !p)) ? o.childNodes : []))));\n                                for (g = ((q.length - 1)); ((g >= 0)); --g) {\n                                    ((((L.nodeName(q[g], \"tbody\") && !q[g].childNodes.length)) && q[g].parentNode.removeChild(q[g])));\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                            ((((!L.support.leadingWhitespace && ub.test(j))) && o.insertBefore(b.createTextNode(ub.exec(j)[0]), o.firstChild))), j = o.childNodes;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    var s;\n                    if (!L.support.appendChecked) {\n                        if (((j[0] && ((typeof (s = j.length) == \"number\"))))) {\n                            for (g = 0; ((g < s)); g++) {\n                                r(j[g]);\n                            ;\n                            };\n                        }\n                         else {\n                            r(j);\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    ((j.nodeType ? f.push(j) : f = L.merge(f, j)));\n                };\n            ;\n                if (c) {\n                    e = function(a) {\n                        return ((!a.type || Db.test(a.type)));\n                    };\n                    for (i = 0; f[i]; i++) {\n                        if (((((d && L.nodeName(f[i], \"script\"))) && ((!f[i].type || ((f[i].type.toLowerCase() === \"text/javascript\"))))))) d.push(((f[i].parentNode ? f[i].parentNode.removeChild(f[i]) : f[i])));\n                         else {\n                            if (((f[i].nodeType === 1))) {\n                                var t = L.grep(f[i].getElementsByTagName(\"script\"), e);\n                                f.splice.apply(f, [((i + 1)),0,].concat(t));\n                            }\n                        ;\n                        ;\n                            c.appendChild(f[i]);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return f;\n            },\n            cleanData: function(a) {\n                var b, c, d = L.cache, e = L.JSBNG__event.special, f = L.support.deleteExpando;\n                for (var g = 0, i; (((i = a[g]) != null)); g++) {\n                    if (((i.nodeName && L.noData[i.nodeName.toLowerCase()]))) {\n                        continue;\n                    }\n                ;\n                ;\n                    c = i[L.expando];\n                    if (c) {\n                        b = d[c];\n                        if (((b && b.events))) {\n                            for (var j in b.events) {\n                                ((e[j] ? L.JSBNG__event.remove(i, j) : L.removeEvent(i, j, b.handle)));\n                            ;\n                            };\n                        ;\n                            ((b.handle && (b.handle.elem = null)));\n                        }\n                    ;\n                    ;\n                        ((f ? delete i[L.expando] : ((i.removeAttribute && i.removeAttribute(L.expando))))), delete d[c];\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        });\n        var Hb = /alpha\\([^)]*\\)/i, Ib = /opacity=([^)]*)/, Jb = /([A-Z]|^ms)/g, Kb = /^-?\\d+(?:px)?$/i, Lb = /^-?\\d/, Mb = /^([\\-+])=([\\-+.\\de]+)/, Nb = {\n            position: \"absolute\",\n            visibility: \"hidden\",\n            display: \"block\"\n        }, Ob = [\"Left\",\"Right\",], Pb = [\"Top\",\"Bottom\",], Qb, Rb, Sb;\n        L.fn.css = function(a, c) {\n            return ((((((arguments.length === 2)) && ((c === b)))) ? this : L.access(this, a, c, !0, function(a, c, d) {\n                return ((((d !== b)) ? L.style(a, c, d) : L.css(a, c)));\n            })));\n        }, L.extend({\n            cssHooks: {\n                opacity: {\n                    get: function(a, b) {\n                        if (b) {\n                            var c = Qb(a, \"opacity\", \"opacity\");\n                            return ((((c === \"\")) ? \"1\" : c));\n                        }\n                    ;\n                    ;\n                        return a.style.opacity;\n                    }\n                }\n            },\n            cssNumber: {\n                fillOpacity: !0,\n                fontWeight: !0,\n                lineHeight: !0,\n                opacity: !0,\n                orphans: !0,\n                widows: !0,\n                zIndex: !0,\n                zoom: !0\n            },\n            cssProps: {\n                float: ((L.support.cssFloat ? \"cssFloat\" : \"styleFloat\"))\n            },\n            style: function(a, c, d, e) {\n                if (((((((!a || ((a.nodeType === 3)))) || ((a.nodeType === 8)))) || !a.style))) {\n                    return;\n                }\n            ;\n            ;\n                var f, g, i = L.camelCase(c), j = a.style, k = L.cssHooks[i];\n                c = ((L.cssProps[i] || i));\n                if (((d === b))) {\n                    return ((((((k && ((\"get\" in k)))) && (((f = k.get(a, !1, e)) !== b)))) ? f : j[c]));\n                }\n            ;\n            ;\n                g = typeof d, ((((((g === \"string\")) && (f = Mb.exec(d)))) && (d = ((((+((f[1] + 1)) * +f[2])) + parseFloat(L.css(a, c)))), g = \"number\")));\n                if (((((d == null)) || ((((g === \"number\")) && isNaN(d)))))) {\n                    return;\n                }\n            ;\n            ;\n                ((((((g === \"number\")) && !L.cssNumber[i])) && (d += \"px\")));\n                if (((((!k || !((\"set\" in k)))) || (((d = k.set(a, d)) !== b))))) {\n                    try {\n                        j[c] = d;\n                    } catch (l) {\n                    \n                    };\n                }\n            ;\n            ;\n            },\n            css: function(a, c, d) {\n                var e, f;\n                c = L.camelCase(c), f = L.cssHooks[c], c = ((L.cssProps[c] || c)), ((((c === \"cssFloat\")) && (c = \"float\")));\n                if (((((f && ((\"get\" in f)))) && (((e = f.get(a, !0, d)) !== b))))) {\n                    return e;\n                }\n            ;\n            ;\n                if (Qb) {\n                    return Qb(a, c);\n                }\n            ;\n            ;\n            },\n            swap: function(a, b, c) {\n                var d = {\n                };\n                for (var e in b) {\n                    d[e] = a.style[e], a.style[e] = b[e];\n                ;\n                };\n            ;\n                c.call(a);\n                for (e in b) {\n                    a.style[e] = d[e];\n                ;\n                };\n            ;\n            }\n        }), L.curCSS = L.css, L.each([\"height\",\"width\",], function(a, b) {\n            L.cssHooks[b] = {\n                get: function(a, c, d) {\n                    var e;\n                    if (c) {\n                        return ((((a.offsetWidth !== 0)) ? u(a, b, d) : (L.swap(a, Nb, function() {\n                            e = u(a, b, d);\n                        }), e)));\n                    }\n                ;\n                ;\n                },\n                set: function(a, b) {\n                    if (!Kb.test(b)) {\n                        return b;\n                    }\n                ;\n                ;\n                    b = parseFloat(b);\n                    if (((b >= 0))) {\n                        return ((b + \"px\"));\n                    }\n                ;\n                ;\n                }\n            };\n        }), ((L.support.opacity || (L.cssHooks.opacity = {\n            get: function(a, b) {\n                return ((Ib.test(((((((b && a.currentStyle)) ? a.currentStyle.filter : a.style.filter)) || \"\"))) ? ((((parseFloat(RegExp.$1) / 100)) + \"\")) : ((b ? \"1\" : \"\"))));\n            },\n            set: function(a, b) {\n                var c = a.style, d = a.currentStyle, e = ((L.isNumeric(b) ? ((((\"alpha(opacity=\" + ((b * 100)))) + \")\")) : \"\")), f = ((((((d && d.filter)) || c.filter)) || \"\"));\n                c.zoom = 1;\n                if (((((b >= 1)) && ((L.trim(f.replace(Hb, \"\")) === \"\"))))) {\n                    c.removeAttribute(\"filter\");\n                    if (((d && !d.filter))) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                c.filter = ((Hb.test(f) ? f.replace(Hb, e) : ((((f + \" \")) + e))));\n            }\n        }))), L(function() {\n            ((L.support.reliableMarginRight || (L.cssHooks.marginRight = {\n                get: function(a, b) {\n                    var c;\n                    return L.swap(a, {\n                        display: \"inline-block\"\n                    }, function() {\n                        ((b ? c = Qb(a, \"margin-right\", \"marginRight\") : c = a.style.marginRight));\n                    }), c;\n                }\n            })));\n        }), ((((I.defaultView && I.defaultView.JSBNG__getComputedStyle)) && (Rb = function(a, b) {\n            var c, d, e;\n            return b = b.replace(Jb, \"-$1\").toLowerCase(), (((((d = a.ownerDocument.defaultView) && (e = d.JSBNG__getComputedStyle(a, null)))) && (c = e.getPropertyValue(b), ((((((c === \"\")) && !L.contains(a.ownerDocument.documentElement, a))) && (c = L.style(a, b))))))), c;\n        }))), ((I.documentElement.currentStyle && (Sb = function(a, b) {\n            var c, d, e, f = ((a.currentStyle && a.currentStyle[b])), g = a.style;\n            return ((((((((f === null)) && g)) && (e = g[b]))) && (f = e))), ((((!Kb.test(f) && Lb.test(f))) && (c = g.left, d = ((a.runtimeStyle && a.runtimeStyle.left)), ((d && (a.runtimeStyle.left = a.currentStyle.left))), g.left = ((((b === \"fontSize\")) ? \"1em\" : ((f || 0)))), f = ((g.pixelLeft + \"px\")), g.left = c, ((d && (a.runtimeStyle.left = d)))))), ((((f === \"\")) ? \"auto\" : f));\n        }))), Qb = ((Rb || Sb)), ((((L.expr && L.expr.filters)) && (L.expr.filters.hidden = function(a) {\n            var b = a.offsetWidth, c = a.offsetHeight;\n            return ((((((b === 0)) && ((c === 0)))) || ((!L.support.reliableHiddenOffsets && ((((((a.style && a.style.display)) || L.css(a, \"display\"))) === \"none\"))))));\n        }, L.expr.filters.visible = function(a) {\n            return !L.expr.filters.hidden(a);\n        })));\n        var Tb = /%20/g, Ub = /\\[\\]$/, Vb = /\\r?\\n/g, Wb = /#.*$/, Xb = /^(.*?):[ \\t]*([^\\r\\n]*)\\r?$/gm, Yb = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i, Zb = /^(?:about|app|app\\-storage|.+\\-extension|file|res|widget):$/, $b = /^(?:GET|HEAD)$/, _b = /^\\/\\//, ac = /\\?/, bc = /<script\\b[^<]*(?:(?!<\\/script>)<[^<]*)*<\\/script>/gi, cc = /^(?:select|textarea)/i, dc = /\\s+/, ec = /([?&])_=[^&]*/, fc = /^([\\w\\+\\.\\-]+:)(?:\\/\\/([^\\/?#:]*)(?::(\\d+))?)?/, gc = L.fn.load, hc = {\n        }, ic = {\n        }, jc, kc, lc = (([\"*/\",] + [\"*\",]));\n        try {\n            jc = K.href;\n        } catch (mc) {\n            jc = I.createElement(\"a\"), jc.href = \"\", jc = jc.href;\n        };\n    ;\n        kc = ((fc.exec(jc.toLowerCase()) || [])), L.fn.extend({\n            load: function(a, c, d) {\n                if (((((typeof a != \"string\")) && gc))) {\n                    return gc.apply(this, arguments);\n                }\n            ;\n            ;\n                if (!this.length) {\n                    return this;\n                }\n            ;\n            ;\n                var e = a.indexOf(\" \");\n                if (((e >= 0))) {\n                    var f = a.slice(e, a.length);\n                    a = a.slice(0, e);\n                }\n            ;\n            ;\n                var g = \"GET\";\n                ((c && ((L.isFunction(c) ? (d = c, c = b) : ((((typeof c == \"object\")) && (c = L.param(c, L.ajaxSettings.traditional), g = \"POST\")))))));\n                var i = this;\n                return L.ajax({\n                    url: a,\n                    type: g,\n                    dataType: \"html\",\n                    data: c,\n                    complete: function(a, b, c) {\n                        c = a.responseText, ((a.isResolved() && (a.done(function(a) {\n                            c = a;\n                        }), i.html(((f ? L(\"\\u003Cdiv\\u003E\").append(c.replace(bc, \"\")).JSBNG__find(f) : c)))))), ((d && i.each(d, [c,b,a,])));\n                    }\n                }), this;\n            },\n            serialize: function() {\n                return L.param(this.serializeArray());\n            },\n            serializeArray: function() {\n                return this.map(function() {\n                    return ((this.elements ? L.makeArray(this.elements) : this));\n                }).filter(function() {\n                    return ((((this.JSBNG__name && !this.disabled)) && ((((this.checked || cc.test(this.nodeName))) || Yb.test(this.type)))));\n                }).map(function(a, b) {\n                    var c = L(this).val();\n                    return ((((c == null)) ? null : ((L.isArray(c) ? L.map(c, function(a, c) {\n                        return {\n                            JSBNG__name: b.JSBNG__name,\n                            value: a.replace(Vb, \"\\u000d\\u000a\")\n                        };\n                    }) : {\n                        JSBNG__name: b.JSBNG__name,\n                        value: c.replace(Vb, \"\\u000d\\u000a\")\n                    }))));\n                }).get();\n            }\n        }), L.each(\"ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend\".split(\" \"), function(a, b) {\n            L.fn[b] = function(a) {\n                return this.JSBNG__on(b, a);\n            };\n        }), L.each([\"get\",\"post\",], function(a, c) {\n            L[c] = function(a, d, e, f) {\n                return ((L.isFunction(d) && (f = ((f || e)), e = d, d = b))), L.ajax({\n                    type: c,\n                    url: a,\n                    data: d,\n                    success: e,\n                    dataType: f\n                });\n            };\n        }), L.extend({\n            getScript: function(a, c) {\n                return L.get(a, b, c, \"script\");\n            },\n            getJSON: function(a, b, c) {\n                return L.get(a, b, c, \"json\");\n            },\n            ajaxSetup: function(a, b) {\n                return ((b ? x(a, L.ajaxSettings) : (b = a, a = L.ajaxSettings))), x(a, b), a;\n            },\n            ajaxSettings: {\n                url: jc,\n                isLocal: Zb.test(kc[1]),\n                global: !0,\n                type: \"GET\",\n                contentType: \"application/x-www-form-urlencoded\",\n                processData: !0,\n                async: !0,\n                accepts: {\n                    xml: \"application/xml, text/xml\",\n                    html: \"text/html\",\n                    text: \"text/plain\",\n                    json: \"application/json, text/javascript\",\n                    \"*\": lc\n                },\n                contents: {\n                    xml: /xml/,\n                    html: /html/,\n                    json: /json/\n                },\n                responseFields: {\n                    xml: \"responseXML\",\n                    text: \"responseText\"\n                },\n                converters: {\n                    \"* text\": a.String,\n                    \"text html\": !0,\n                    \"text json\": L.parseJSON,\n                    \"text xml\": L.parseXML\n                },\n                flatOptions: {\n                    context: !0,\n                    url: !0\n                }\n            },\n            ajaxPrefilter: v(hc),\n            ajaxTransport: v(ic),\n            ajax: function(a, c) {\n                function d(a, c, d, m) {\n                    if (((t === 2))) {\n                        return;\n                    }\n                ;\n                ;\n                    t = 2, ((r && JSBNG__clearTimeout(r))), q = b, o = ((m || \"\")), x.readyState = ((((a > 0)) ? 4 : 0));\n                    var n, p, s, v = c, w = ((d ? z(e, x, d) : b)), y, B;\n                    if (((((((a >= 200)) && ((a < 300)))) || ((a === 304))))) {\n                        if (e.ifModified) {\n                            if (y = x.getResponseHeader(\"Last-Modified\")) {\n                                L.lastModified[l] = y;\n                            }\n                        ;\n                        ;\n                            if (B = x.getResponseHeader(\"Etag\")) {\n                                L.etag[l] = B;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (((a === 304))) {\n                            v = \"notmodified\", n = !0;\n                        }\n                         else {\n                            try {\n                                p = A(e, w), v = \"success\", n = !0;\n                            } catch (C) {\n                                v = \"parsererror\", s = C;\n                            };\n                        }\n                    ;\n                    ;\n                    }\n                     else {\n                        s = v;\n                        if (((!v || a))) {\n                            v = \"error\", ((((a < 0)) && (a = 0)));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    x.JSBNG__status = a, x.statusText = ((\"\" + ((c || v)))), ((n ? i.resolveWith(f, [p,v,x,]) : i.rejectWith(f, [x,v,s,]))), x.statusCode(k), k = b, ((u && g.trigger(((\"ajax\" + ((n ? \"Success\" : \"Error\")))), [x,e,((n ? p : s)),]))), j.fireWith(f, [x,v,]), ((u && (g.trigger(\"ajaxComplete\", [x,e,]), ((--L.active || L.JSBNG__event.trigger(\"ajaxStop\"))))));\n                };\n            ;\n                ((((typeof a == \"object\")) && (c = a, a = b))), c = ((c || {\n                }));\n                var e = L.ajaxSetup({\n                }, c), f = ((e.context || e)), g = ((((((f !== e)) && ((f.nodeType || ((f instanceof L)))))) ? L(f) : L.JSBNG__event)), i = L.Deferred(), j = L.Callbacks(\"JSBNG__once memory\"), k = ((e.statusCode || {\n                })), l, m = {\n                }, n = {\n                }, o, p, q, r, s, t = 0, u, v, x = {\n                    readyState: 0,\n                    setRequestHeader: function(a, b) {\n                        if (!t) {\n                            var c = a.toLowerCase();\n                            a = n[c] = ((n[c] || a)), m[a] = b;\n                        }\n                    ;\n                    ;\n                        return this;\n                    },\n                    getAllResponseHeaders: function() {\n                        return ((((t === 2)) ? o : null));\n                    },\n                    getResponseHeader: function(a) {\n                        var c;\n                        if (((t === 2))) {\n                            if (!p) {\n                                p = {\n                                };\n                                while (c = Xb.exec(o)) {\n                                    p[c[1].toLowerCase()] = c[2];\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                            c = p[a.toLowerCase()];\n                        }\n                    ;\n                    ;\n                        return ((((c === b)) ? null : c));\n                    },\n                    overrideMimeType: function(a) {\n                        return ((t || (e.mimeType = a))), this;\n                    },\n                    abort: function(a) {\n                        return a = ((a || \"abort\")), ((q && q.abort(a))), d(0, a), this;\n                    }\n                };\n                i.promise(x), x.success = x.done, x.error = x.fail, x.complete = j.add, x.statusCode = function(a) {\n                    if (a) {\n                        var b;\n                        if (((t < 2))) {\n                            for (b in a) {\n                                k[b] = [k[b],a[b],];\n                            ;\n                            };\n                        }\n                         else {\n                            b = a[x.JSBNG__status], x.then(b, b);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return this;\n                }, e.url = ((((a || e.url)) + \"\")).replace(Wb, \"\").replace(_b, ((kc[1] + \"//\"))), e.dataTypes = L.trim(((e.dataType || \"*\"))).toLowerCase().split(dc), ((((e.crossDomain == null)) && (s = fc.exec(e.url.toLowerCase()), e.crossDomain = !((!s || ((((((s[1] == kc[1])) && ((s[2] == kc[2])))) && ((((s[3] || ((((s[1] === \"http:\")) ? 80 : 443)))) == ((kc[3] || ((((kc[1] === \"http:\")) ? 80 : 443))))))))))))), ((((((e.data && e.processData)) && ((typeof e.data != \"string\")))) && (e.data = L.param(e.data, e.traditional)))), w(hc, e, c, x);\n                if (((t === 2))) {\n                    return !1;\n                }\n            ;\n            ;\n                u = e.global, e.type = e.type.toUpperCase(), e.hasContent = !$b.test(e.type), ((((u && ((L.active++ === 0)))) && L.JSBNG__event.trigger(\"ajaxStart\")));\n                if (!e.hasContent) {\n                    ((e.data && (e.url += ((((ac.test(e.url) ? \"&\" : \"?\")) + e.data)), delete e.data))), l = e.url;\n                    if (((e.cache === !1))) {\n                        var y = L.now(), B = e.url.replace(ec, ((\"$1_=\" + y)));\n                        e.url = ((B + ((((B === e.url)) ? ((((((ac.test(e.url) ? \"&\" : \"?\")) + \"_=\")) + y)) : \"\"))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((((((((e.data && e.hasContent)) && ((e.contentType !== !1)))) || c.contentType)) && x.setRequestHeader(\"Content-Type\", e.contentType))), ((e.ifModified && (l = ((l || e.url)), ((L.lastModified[l] && x.setRequestHeader(\"If-Modified-Since\", L.lastModified[l]))), ((L.etag[l] && x.setRequestHeader(\"If-None-Match\", L.etag[l])))))), x.setRequestHeader(\"Accept\", ((((e.dataTypes[0] && e.accepts[e.dataTypes[0]])) ? ((e.accepts[e.dataTypes[0]] + ((((e.dataTypes[0] !== \"*\")) ? ((((\", \" + lc)) + \"; q=0.01\")) : \"\")))) : e.accepts[\"*\"])));\n                for (v in e.headers) {\n                    x.setRequestHeader(v, e.headers[v]);\n                ;\n                };\n            ;\n                if (((!e.beforeSend || ((((e.beforeSend.call(f, x, e) !== !1)) && ((t !== 2))))))) {\n                    for (v in {\n                        success: 1,\n                        error: 1,\n                        complete: 1\n                    }) {\n                        x[v](e[v]);\n                    ;\n                    };\n                ;\n                    q = w(ic, e, c, x);\n                    if (!q) d(-1, \"No Transport\");\n                     else {\n                        x.readyState = 1, ((u && g.trigger(\"ajaxSend\", [x,e,]))), ((((e.async && ((e.timeout > 0)))) && (r = JSBNG__setTimeout(function() {\n                            x.abort(\"timeout\");\n                        }, e.timeout))));\n                        try {\n                            t = 1, q.send(m, d);\n                        } catch (C) {\n                            if (!((t < 2))) {\n                                throw C;\n                            }\n                        ;\n                        ;\n                            d(-1, C);\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return x;\n                }\n            ;\n            ;\n                return x.abort(), !1;\n            },\n            param: function(a, c) {\n                var d = [], e = function(a, b) {\n                    b = ((L.isFunction(b) ? b() : b)), d[d.length] = ((((encodeURIComponent(a) + \"=\")) + encodeURIComponent(b)));\n                };\n                ((((c === b)) && (c = L.ajaxSettings.traditional)));\n                if (((L.isArray(a) || ((a.jquery && !L.isPlainObject(a)))))) {\n                    L.each(a, function() {\n                        e(this.JSBNG__name, this.value);\n                    });\n                }\n                 else {\n                    for (var f in a) {\n                        y(f, a[f], c, e);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return d.join(\"&\").replace(Tb, \"+\");\n            }\n        }), L.extend({\n            active: 0,\n            lastModified: {\n            },\n            etag: {\n            }\n        });\n        var nc = L.now(), oc = /(\\=)\\?(&|$)|\\?\\?/i;\n        L.ajaxSetup({\n            jsonp: \"callback\",\n            jsonpCallback: function() {\n                return ((((L.expando + \"_\")) + nc++));\n            }\n        }), L.ajaxPrefilter(\"json jsonp\", function(b, c, d) {\n            var e = ((((b.contentType === \"application/x-www-form-urlencoded\")) && ((typeof b.data == \"string\"))));\n            if (((((b.dataTypes[0] === \"jsonp\")) || ((((b.jsonp !== !1)) && ((oc.test(b.url) || ((e && oc.test(b.data)))))))))) {\n                var f, g = b.jsonpCallback = ((L.isFunction(b.jsonpCallback) ? b.jsonpCallback() : b.jsonpCallback)), i = a[g], j = b.url, k = b.data, l = ((((\"$1\" + g)) + \"$2\"));\n                return ((((b.jsonp !== !1)) && (j = j.replace(oc, l), ((((b.url === j)) && (((e && (k = k.replace(oc, l)))), ((((b.data === k)) && (j += ((((((((/\\?/.test(j) ? \"&\" : \"?\")) + b.jsonp)) + \"=\")) + g))))))))))), b.url = j, b.data = k, a[g] = function(a) {\n                    f = [a,];\n                }, d.always(function() {\n                    a[g] = i, ((((f && L.isFunction(i))) && a[g](f[0])));\n                }), b.converters[\"script json\"] = function() {\n                    return ((f || L.error(((g + \" was not called\"))))), f[0];\n                }, b.dataTypes[0] = \"json\", \"script\";\n            }\n        ;\n        ;\n        }), L.ajaxSetup({\n            accepts: {\n                script: \"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript\"\n            },\n            contents: {\n                script: /javascript|ecmascript/\n            },\n            converters: {\n                \"text script\": function(a) {\n                    return L.globalEval(a), a;\n                }\n            }\n        }), L.ajaxPrefilter(\"script\", function(a) {\n            ((((a.cache === b)) && (a.cache = !1))), ((a.crossDomain && (a.type = \"GET\", a.global = !1)));\n        }), L.ajaxTransport(\"script\", function(a) {\n            if (a.crossDomain) {\n                var c, d = ((((I.head || I.getElementsByTagName(\"head\")[0])) || I.documentElement));\n                return {\n                    send: function(_, e) {\n                        c = I.createElement(\"script\"), c.async = \"async\", ((a.scriptCharset && (c.charset = a.scriptCharset))), c.src = a.url, c.JSBNG__onload = c.JSBNG__onreadystatechange = function(_, a) {\n                            if (((((a || !c.readyState)) || /loaded|complete/.test(c.readyState)))) {\n                                c.JSBNG__onload = c.JSBNG__onreadystatechange = null, ((((d && c.parentNode)) && d.removeChild(c))), c = b, ((a || e(200, \"success\")));\n                            }\n                        ;\n                        ;\n                        }, d.insertBefore(c, d.firstChild);\n                    },\n                    abort: function() {\n                        ((c && c.JSBNG__onload(0, 1)));\n                    }\n                };\n            }\n        ;\n        ;\n        });\n        var pc = ((a.ActiveXObject ? function() {\n            for (var a in rc) {\n                rc[a](0, 1);\n            ;\n            };\n        ;\n        } : !1)), qc = 0, rc;\n        L.ajaxSettings.xhr = ((a.ActiveXObject ? function() {\n            return ((((!this.isLocal && B())) || C()));\n        } : B)), function(a) {\n            L.extend(L.support, {\n                ajax: !!a,\n                cors: ((!!a && ((\"withCredentials\" in a))))\n            });\n        }(L.ajaxSettings.xhr()), ((L.support.ajax && L.ajaxTransport(function(c) {\n            if (((!c.crossDomain || L.support.cors))) {\n                var d;\n                return {\n                    send: function(e, f) {\n                        var g = c.xhr(), i, j;\n                        ((c.username ? g.open(c.type, c.url, c.async, c.username, c.password) : g.open(c.type, c.url, c.async)));\n                        if (c.xhrFields) {\n                            for (j in c.xhrFields) {\n                                g[j] = c.xhrFields[j];\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        ((((c.mimeType && g.overrideMimeType)) && g.overrideMimeType(c.mimeType))), ((((!c.crossDomain && !e[\"X-Requested-With\"])) && (e[\"X-Requested-With\"] = \"JSBNG__XMLHttpRequest\")));\n                        try {\n                            for (j in e) {\n                                g.setRequestHeader(j, e[j]);\n                            ;\n                            };\n                        ;\n                        } catch (_) {\n                        \n                        };\n                    ;\n                        g.send(((((c.hasContent && c.data)) || null))), d = function(_, a) {\n                            var e, j, k, l, m;\n                            try {\n                                if (((d && ((a || ((g.readyState === 4))))))) {\n                                    d = b, ((i && (g.JSBNG__onreadystatechange = L.noop, ((pc && delete rc[i])))));\n                                    if (a) ((((g.readyState !== 4)) && g.abort()));\n                                     else {\n                                        e = g.JSBNG__status, k = g.getAllResponseHeaders(), l = {\n                                        }, m = g.responseXML, ((((m && m.documentElement)) && (l.xml = m))), l.text = g.responseText;\n                                        try {\n                                            j = g.statusText;\n                                        } catch (n) {\n                                            j = \"\";\n                                        };\n                                    ;\n                                        ((((((!e && c.isLocal)) && !c.crossDomain)) ? e = ((l.text ? 200 : 404)) : ((((e === 1223)) && (e = 204)))));\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            } catch (o) {\n                                ((a || f(-1, o)));\n                            };\n                        ;\n                            ((l && f(e, j, l, k)));\n                        }, ((((!c.async || ((g.readyState === 4)))) ? d() : (i = ++qc, ((pc && (((rc || (rc = {\n                        }, L(a).unload(pc)))), rc[i] = d))), g.JSBNG__onreadystatechange = d)));\n                    },\n                    abort: function() {\n                        ((d && d(0, 1)));\n                    }\n                };\n            }\n        ;\n        ;\n        })));\n        var sc = {\n        }, tc, uc, vc = /^(?:toggle|show|hide)$/, wc = /^([+\\-]=)?([\\d+.\\-]+)([a-z%]*)$/i, xc, yc = [[\"height\",\"marginTop\",\"marginBottom\",\"paddingTop\",\"paddingBottom\",],[\"width\",\"marginLeft\",\"marginRight\",\"paddingLeft\",\"paddingRight\",],[\"opacity\",],], zc;\n        L.fn.extend({\n            show: function(a, b, c) {\n                var d, e;\n                if (((a || ((a === 0))))) {\n                    return this.animate(F(\"show\", 3), a, b, c);\n                }\n            ;\n            ;\n                for (var f = 0, g = this.length; ((f < g)); f++) {\n                    d = this[f], ((d.style && (e = d.style.display, ((((!L._data(d, \"olddisplay\") && ((e === \"none\")))) && (e = d.style.display = \"\"))), ((((((e === \"\")) && ((L.css(d, \"display\") === \"none\")))) && L._data(d, \"olddisplay\", G(d.nodeName)))))));\n                ;\n                };\n            ;\n                for (f = 0; ((f < g)); f++) {\n                    d = this[f];\n                    if (d.style) {\n                        e = d.style.display;\n                        if (((((e === \"\")) || ((e === \"none\"))))) {\n                            d.style.display = ((L._data(d, \"olddisplay\") || \"\"));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return this;\n            },\n            hide: function(a, b, c) {\n                if (((a || ((a === 0))))) {\n                    return this.animate(F(\"hide\", 3), a, b, c);\n                }\n            ;\n            ;\n                var d, e, f = 0, g = this.length;\n                for (; ((f < g)); f++) {\n                    d = this[f], ((d.style && (e = L.css(d, \"display\"), ((((((e !== \"none\")) && !L._data(d, \"olddisplay\"))) && L._data(d, \"olddisplay\", e))))));\n                ;\n                };\n            ;\n                for (f = 0; ((f < g)); f++) {\n                    ((this[f].style && (this[f].style.display = \"none\")));\n                ;\n                };\n            ;\n                return this;\n            },\n            _toggle: L.fn.toggle,\n            toggle: function(a, b, c) {\n                var d = ((typeof a == \"boolean\"));\n                return ((((L.isFunction(a) && L.isFunction(b))) ? this._toggle.apply(this, arguments) : ((((((a == null)) || d)) ? this.each(function() {\n                    var b = ((d ? a : L(this).is(\":hidden\")));\n                    L(this)[((b ? \"show\" : \"hide\"))]();\n                }) : this.animate(F(\"toggle\", 3), a, b, c))))), this;\n            },\n            fadeTo: function(a, b, c, d) {\n                return this.filter(\":hidden\").css(\"opacity\", 0).show().end().animate({\n                    opacity: b\n                }, a, c, d);\n            },\n            animate: function(a, b, c, d) {\n                function e() {\n                    ((((f.queue === !1)) && L._mark(this)));\n                    var b = L.extend({\n                    }, f), c = ((this.nodeType === 1)), d = ((c && L(this).is(\":hidden\"))), e, g, i, j, k, l, m, n, o;\n                    b.animatedProperties = {\n                    };\n                    for (i in a) {\n                        e = L.camelCase(i), ((((i !== e)) && (a[e] = a[i], delete a[i]))), g = a[e], ((L.isArray(g) ? (b.animatedProperties[e] = g[1], g = a[e] = g[0]) : b.animatedProperties[e] = ((((((b.specialEasing && b.specialEasing[e])) || b.easing)) || \"swing\"))));\n                        if (((((((g === \"hide\")) && d)) || ((((g === \"show\")) && !d))))) {\n                            return b.complete.call(this);\n                        }\n                    ;\n                    ;\n                        ((((c && ((((e === \"height\")) || ((e === \"width\")))))) && (b.overflow = [this.style.overflow,this.style.overflowX,this.style.overflowY,], ((((((L.css(this, \"display\") === \"inline\")) && ((L.css(this, \"float\") === \"none\")))) && ((((!L.support.inlineBlockNeedsLayout || ((G(this.nodeName) === \"inline\")))) ? this.style.display = \"inline-block\" : this.style.zoom = 1)))))));\n                    };\n                ;\n                    ((((b.overflow != null)) && (this.style.overflow = \"hidden\")));\n                    for (i in a) {\n                        j = new L.fx(this, b, i), g = a[i], ((vc.test(g) ? (o = ((L._data(this, ((\"toggle\" + i))) || ((((g === \"toggle\")) ? ((d ? \"show\" : \"hide\")) : 0)))), ((o ? (L._data(this, ((\"toggle\" + i)), ((((o === \"show\")) ? \"hide\" : \"show\"))), j[o]()) : j[g]()))) : (k = wc.exec(g), l = j.cur(), ((k ? (m = parseFloat(k[2]), n = ((k[3] || ((L.cssNumber[i] ? \"\" : \"px\")))), ((((n !== \"px\")) && (L.style(this, i, ((((m || 1)) + n))), l = ((((((m || 1)) / j.cur())) * l)), L.style(this, i, ((l + n)))))), ((k[1] && (m = ((((((((k[1] === \"-=\")) ? -1 : 1)) * m)) + l))))), j.custom(l, m, n)) : j.custom(l, g, \"\"))))));\n                    ;\n                    };\n                ;\n                    return !0;\n                };\n            ;\n                var f = L.speed(b, c, d);\n                return ((L.isEmptyObject(a) ? this.each(f.complete, [!1,]) : (a = L.extend({\n                }, a), ((((f.queue === !1)) ? this.each(e) : this.queue(f.queue, e))))));\n            },\n            JSBNG__stop: function(a, c, d) {\n                return ((((typeof a != \"string\")) && (d = c, c = a, a = b))), ((((c && ((a !== !1)))) && this.queue(((a || \"fx\")), []))), this.each(function() {\n                    function b(a, b, c) {\n                        var e = b[c];\n                        L.removeData(a, c, !0), e.JSBNG__stop(d);\n                    };\n                ;\n                    var c, e = !1, f = L.timers, g = L._data(this);\n                    ((d || L._unmark(!0, this)));\n                    if (((a == null))) {\n                        for (c in g) {\n                            ((((((g[c] && g[c].JSBNG__stop)) && ((c.indexOf(\".run\") === ((c.length - 4)))))) && b(this, g, c)));\n                        ;\n                        };\n                    }\n                     else {\n                        ((((g[c = ((a + \".run\"))] && g[c].JSBNG__stop)) && b(this, g, c)));\n                    }\n                ;\n                ;\n                    for (c = f.length; c--; ) {\n                        ((((((f[c].elem === this)) && ((((a == null)) || ((f[c].queue === a)))))) && (((d ? f[c](!0) : f[c].saveState())), e = !0, f.splice(c, 1))));\n                    ;\n                    };\n                ;\n                    ((((!d || !e)) && L.dequeue(this, a)));\n                });\n            }\n        }), L.each({\n            slideDown: F(\"show\", 1),\n            slideUp: F(\"hide\", 1),\n            slideToggle: F(\"toggle\", 1),\n            fadeIn: {\n                opacity: \"show\"\n            },\n            fadeOut: {\n                opacity: \"hide\"\n            },\n            fadeToggle: {\n                opacity: \"toggle\"\n            }\n        }, function(a, b) {\n            L.fn[a] = function(a, c, d) {\n                return this.animate(b, a, c, d);\n            };\n        }), L.extend({\n            speed: function(a, b, c) {\n                var d = ((((a && ((typeof a == \"object\")))) ? L.extend({\n                }, a) : {\n                    complete: ((((c || ((!c && b)))) || ((L.isFunction(a) && a)))),\n                    duration: a,\n                    easing: ((((c && b)) || ((((b && !L.isFunction(b))) && b))))\n                }));\n                d.duration = ((L.fx.off ? 0 : ((((typeof d.duration == \"number\")) ? d.duration : ((((d.duration in L.fx.speeds)) ? L.fx.speeds[d.duration] : L.fx.speeds._default))))));\n                if (((((d.queue == null)) || ((d.queue === !0))))) {\n                    d.queue = \"fx\";\n                }\n            ;\n            ;\n                return d.old = d.complete, d.complete = function(a) {\n                    ((L.isFunction(d.old) && d.old.call(this))), ((d.queue ? L.dequeue(this, d.queue) : ((((a !== !1)) && L._unmark(this)))));\n                }, d;\n            },\n            easing: {\n                linear: function(a, b, c, d) {\n                    return ((c + ((d * a))));\n                },\n                swing: function(a, b, c, d) {\n                    return ((((((((-Math.cos(((a * Math.PI))) / 2)) + 128416)) * d)) + c));\n                }\n            },\n            timers: [],\n            fx: function(a, b, c) {\n                this.options = b, this.elem = a, this.prop = c, b.orig = ((b.orig || {\n                }));\n            }\n        }), L.fx.prototype = {\n            update: function() {\n                ((this.options.step && this.options.step.call(this.elem, this.now, this))), ((L.fx.step[this.prop] || L.fx.step._default))(this);\n            },\n            cur: function() {\n                if (((((this.elem[this.prop] == null)) || ((!!this.elem.style && ((this.elem.style[this.prop] != null))))))) {\n                    var a, b = L.css(this.elem, this.prop);\n                    return ((isNaN(a = parseFloat(b)) ? ((((!b || ((b === \"auto\")))) ? 0 : b)) : a));\n                }\n            ;\n            ;\n                return this.elem[this.prop];\n            },\n            custom: function(a, c, d) {\n                function e(a) {\n                    return f.step(a);\n                };\n            ;\n                var f = this, g = L.fx;\n                this.startTime = ((zc || D())), this.end = c, this.now = this.start = a, this.pos = this.state = 0, this.unit = ((((d || this.unit)) || ((L.cssNumber[this.prop] ? \"\" : \"px\")))), e.queue = this.options.queue, e.elem = this.elem, e.saveState = function() {\n                    ((((f.options.hide && ((L._data(f.elem, ((\"fxshow\" + f.prop))) === b)))) && L._data(f.elem, ((\"fxshow\" + f.prop)), f.start)));\n                }, ((((((e() && L.timers.push(e))) && !xc)) && (xc = JSBNG__setInterval(g.tick, g.interval))));\n            },\n            show: function() {\n                var a = L._data(this.elem, ((\"fxshow\" + this.prop)));\n                this.options.orig[this.prop] = ((a || L.style(this.elem, this.prop))), this.options.show = !0, ((((a !== b)) ? this.custom(this.cur(), a) : this.custom(((((((this.prop === \"width\")) || ((this.prop === \"height\")))) ? 1 : 0)), this.cur()))), L(this.elem).show();\n            },\n            hide: function() {\n                this.options.orig[this.prop] = ((L._data(this.elem, ((\"fxshow\" + this.prop))) || L.style(this.elem, this.prop))), this.options.hide = !0, this.custom(this.cur(), 0);\n            },\n            step: function(a) {\n                var b, c, d, e = ((zc || D())), f = !0, g = this.elem, i = this.options;\n                if (((a || ((e >= ((i.duration + this.startTime))))))) {\n                    this.now = this.end, this.pos = this.state = 1, this.update(), i.animatedProperties[this.prop] = !0;\n                    for (b in i.animatedProperties) {\n                        ((((i.animatedProperties[b] !== !0)) && (f = !1)));\n                    ;\n                    };\n                ;\n                    if (f) {\n                        ((((((i.overflow != null)) && !L.support.shrinkWrapBlocks)) && L.each([\"\",\"X\",\"Y\",], function(a, b) {\n                            g.style[((\"overflow\" + b))] = i.overflow[a];\n                        }))), ((i.hide && L(g).hide()));\n                        if (((i.hide || i.show))) {\n                            for (b in i.animatedProperties) {\n                                L.style(g, b, i.orig[b]), L.removeData(g, ((\"fxshow\" + b)), !0), L.removeData(g, ((\"toggle\" + b)), !0);\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        d = i.complete, ((d && (i.complete = !1, d.call(g))));\n                    }\n                ;\n                ;\n                    return !1;\n                }\n            ;\n            ;\n                return ((((i.duration == Infinity)) ? this.now = e : (c = ((e - this.startTime)), this.state = ((c / i.duration)), this.pos = L.easing[i.animatedProperties[this.prop]](this.state, c, 0, 1, i.duration), this.now = ((this.start + ((((this.end - this.start)) * this.pos))))))), this.update(), !0;\n            }\n        }, L.extend(L.fx, {\n            tick: function() {\n                var a, b = L.timers, c = 0;\n                for (; ((c < b.length)); c++) {\n                    a = b[c], ((((!a() && ((b[c] === a)))) && b.splice(c--, 1)));\n                ;\n                };\n            ;\n                ((b.length || L.fx.JSBNG__stop()));\n            },\n            interval: 13,\n            JSBNG__stop: function() {\n                JSBNG__clearInterval(xc), xc = null;\n            },\n            speeds: {\n                slow: 600,\n                fast: 200,\n                _default: 400\n            },\n            step: {\n                opacity: function(a) {\n                    L.style(a.elem, \"opacity\", a.now);\n                },\n                _default: function(a) {\n                    ((((a.elem.style && ((a.elem.style[a.prop] != null)))) ? a.elem.style[a.prop] = ((a.now + a.unit)) : a.elem[a.prop] = a.now));\n                }\n            }\n        }), L.each([\"width\",\"height\",], function(a, b) {\n            L.fx.step[b] = function(a) {\n                L.style(a.elem, b, ((Math.max(0, a.now) + a.unit)));\n            };\n        }), ((((L.expr && L.expr.filters)) && (L.expr.filters.animated = function(a) {\n            return L.grep(L.timers, function(b) {\n                return ((a === b.elem));\n            }).length;\n        })));\n        var Ac = /^t(?:able|d|h)$/i, Bc = /^(?:body|html)$/i;\n        ((((\"getBoundingClientRect\" in I.documentElement)) ? L.fn.offset = function(a) {\n            var b = this[0], c;\n            if (a) {\n                return this.each(function(b) {\n                    L.offset.setOffset(this, a, b);\n                });\n            }\n        ;\n        ;\n            if (((!b || !b.ownerDocument))) {\n                return null;\n            }\n        ;\n        ;\n            if (((b === b.ownerDocument.body))) {\n                return L.offset.bodyOffset(b);\n            }\n        ;\n        ;\n            try {\n                c = b.getBoundingClientRect();\n            } catch (d) {\n            \n            };\n        ;\n            var e = b.ownerDocument, f = e.documentElement;\n            if (((!c || !L.contains(f, b)))) {\n                return ((c ? {\n                    JSBNG__top: c.JSBNG__top,\n                    left: c.left\n                } : {\n                    JSBNG__top: 0,\n                    left: 0\n                }));\n            }\n        ;\n        ;\n            var g = e.body, i = H(e), j = ((((f.clientTop || g.clientTop)) || 0)), k = ((((f.clientLeft || g.clientLeft)) || 0)), l = ((((i.JSBNG__pageYOffset || ((L.support.boxModel && f.scrollTop)))) || g.scrollTop)), m = ((((i.JSBNG__pageXOffset || ((L.support.boxModel && f.scrollLeft)))) || g.scrollLeft)), n = ((((c.JSBNG__top + l)) - j)), o = ((((c.left + m)) - k));\n            return {\n                JSBNG__top: n,\n                left: o\n            };\n        } : L.fn.offset = function(a) {\n            var b = this[0];\n            if (a) {\n                return this.each(function(b) {\n                    L.offset.setOffset(this, a, b);\n                });\n            }\n        ;\n        ;\n            if (((!b || !b.ownerDocument))) {\n                return null;\n            }\n        ;\n        ;\n            if (((b === b.ownerDocument.body))) {\n                return L.offset.bodyOffset(b);\n            }\n        ;\n        ;\n            var c, d = b.offsetParent, e = b, f = b.ownerDocument, g = f.documentElement, i = f.body, j = f.defaultView, k = ((j ? j.JSBNG__getComputedStyle(b, null) : b.currentStyle)), l = b.offsetTop, m = b.offsetLeft;\n            while ((((((b = b.parentNode) && ((b !== i)))) && ((b !== g))))) {\n                if (((L.support.fixedPosition && ((k.position === \"fixed\"))))) {\n                    break;\n                }\n            ;\n            ;\n                c = ((j ? j.JSBNG__getComputedStyle(b, null) : b.currentStyle)), l -= b.scrollTop, m -= b.scrollLeft, ((((b === d)) && (l += b.offsetTop, m += b.offsetLeft, ((((L.support.doesNotAddBorder && ((!L.support.doesAddBorderForTableAndCells || !Ac.test(b.nodeName))))) && (l += ((parseFloat(c.borderTopWidth) || 0)), m += ((parseFloat(c.borderLeftWidth) || 0))))), e = d, d = b.offsetParent))), ((((L.support.subtractsBorderForOverflowNotVisible && ((c.overflow !== \"visible\")))) && (l += ((parseFloat(c.borderTopWidth) || 0)), m += ((parseFloat(c.borderLeftWidth) || 0))))), k = c;\n            };\n        ;\n            if (((((k.position === \"relative\")) || ((k.position === \"static\"))))) {\n                l += i.offsetTop, m += i.offsetLeft;\n            }\n        ;\n        ;\n            return ((((L.support.fixedPosition && ((k.position === \"fixed\")))) && (l += Math.max(g.scrollTop, i.scrollTop), m += Math.max(g.scrollLeft, i.scrollLeft)))), {\n                JSBNG__top: l,\n                left: m\n            };\n        })), L.offset = {\n            bodyOffset: function(a) {\n                var b = a.offsetTop, c = a.offsetLeft;\n                return ((L.support.doesNotIncludeMarginInBodyOffset && (b += ((parseFloat(L.css(a, \"marginTop\")) || 0)), c += ((parseFloat(L.css(a, \"marginLeft\")) || 0))))), {\n                    JSBNG__top: b,\n                    left: c\n                };\n            },\n            setOffset: function(a, b, c) {\n                var d = L.css(a, \"position\");\n                ((((d === \"static\")) && (a.style.position = \"relative\")));\n                var e = L(a), f = e.offset(), g = L.css(a, \"JSBNG__top\"), i = L.css(a, \"left\"), j = ((((((d === \"absolute\")) || ((d === \"fixed\")))) && ((L.inArray(\"auto\", [g,i,]) > -1)))), k = {\n                }, l = {\n                }, m, n;\n                ((j ? (l = e.position(), m = l.JSBNG__top, n = l.left) : (m = ((parseFloat(g) || 0)), n = ((parseFloat(i) || 0))))), ((L.isFunction(b) && (b = b.call(a, c, f)))), ((((b.JSBNG__top != null)) && (k.JSBNG__top = ((((b.JSBNG__top - f.JSBNG__top)) + m))))), ((((b.left != null)) && (k.left = ((((b.left - f.left)) + n))))), ((((\"using\" in b)) ? b.using.call(a, k) : e.css(k)));\n            }\n        }, L.fn.extend({\n            position: function() {\n                if (!this[0]) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this[0], b = this.offsetParent(), c = this.offset(), d = ((Bc.test(b[0].nodeName) ? {\n                    JSBNG__top: 0,\n                    left: 0\n                } : b.offset()));\n                return c.JSBNG__top -= ((parseFloat(L.css(a, \"marginTop\")) || 0)), c.left -= ((parseFloat(L.css(a, \"marginLeft\")) || 0)), d.JSBNG__top += ((parseFloat(L.css(b[0], \"borderTopWidth\")) || 0)), d.left += ((parseFloat(L.css(b[0], \"borderLeftWidth\")) || 0)), {\n                    JSBNG__top: ((c.JSBNG__top - d.JSBNG__top)),\n                    left: ((c.left - d.left))\n                };\n            },\n            offsetParent: function() {\n                return this.map(function() {\n                    var a = ((this.offsetParent || I.body));\n                    while (((((a && !Bc.test(a.nodeName))) && ((L.css(a, \"position\") === \"static\"))))) {\n                        a = a.offsetParent;\n                    ;\n                    };\n                ;\n                    return a;\n                });\n            }\n        }), L.each([\"Left\",\"Top\",], function(a, c) {\n            var d = ((\"JSBNG__scroll\" + c));\n            L.fn[d] = function(c) {\n                var e, f;\n                return ((((c === b)) ? (e = this[0], ((e ? (f = H(e), ((f ? ((((\"JSBNG__pageXOffset\" in f)) ? f[((a ? \"JSBNG__pageYOffset\" : \"JSBNG__pageXOffset\"))] : ((((L.support.boxModel && f.JSBNG__document.documentElement[d])) || f.JSBNG__document.body[d])))) : e[d]))) : null))) : this.each(function() {\n                    f = H(this), ((f ? f.JSBNG__scrollTo(((a ? L(f).scrollLeft() : c)), ((a ? c : L(f).scrollTop()))) : this[d] = c));\n                })));\n            };\n        }), L.each([\"Height\",\"Width\",], function(a, c) {\n            var d = c.toLowerCase();\n            L.fn[((\"JSBNG__inner\" + c))] = function() {\n                var a = this[0];\n                return ((a ? ((a.style ? parseFloat(L.css(a, d, \"padding\")) : this[d]())) : null));\n            }, L.fn[((\"JSBNG__outer\" + c))] = function(a) {\n                var b = this[0];\n                return ((b ? ((b.style ? parseFloat(L.css(b, d, ((a ? \"margin\" : \"border\")))) : this[d]())) : null));\n            }, L.fn[d] = function(a) {\n                var e = this[0];\n                if (!e) {\n                    return ((((a == null)) ? null : this));\n                }\n            ;\n            ;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        var c = L(this);\n                        c[d](a.call(this, b, c[d]()));\n                    });\n                }\n            ;\n            ;\n                if (L.isWindow(e)) {\n                    var f = e.JSBNG__document.documentElement[((\"client\" + c))], g = e.JSBNG__document.body;\n                    return ((((((((e.JSBNG__document.compatMode === \"CSS1Compat\")) && f)) || ((g && g[((\"client\" + c))])))) || f));\n                }\n            ;\n            ;\n                if (((e.nodeType === 9))) {\n                    return Math.max(e.documentElement[((\"client\" + c))], e.body[((\"JSBNG__scroll\" + c))], e.documentElement[((\"JSBNG__scroll\" + c))], e.body[((\"offset\" + c))], e.documentElement[((\"offset\" + c))]);\n                }\n            ;\n            ;\n                if (((a === b))) {\n                    var i = L.css(e, d), j = parseFloat(i);\n                    return ((L.isNumeric(j) ? j : i));\n                }\n            ;\n            ;\n                return this.css(d, ((((typeof a == \"string\")) ? a : ((a + \"px\")))));\n            };\n        }), a.jQuery = a.$ = L, ((((((((typeof define == \"function\")) && define.amd)) && define.amd.jQuery)) && define(\"jquery\", [], function() {\n            return L;\n        })));\n    })(window), a();\n});\nprovide(\"libwrap/jquery\", function(a) {\n    using(((((window.twttr && window.twttr.isT1)) ? \"$lib/jquery-1.7.1.js\" : \"$lib/jquery-1.5.2.js\")), function() {\n        a(jQuery);\n    });\n});\nprovide(\"$lib/json2.js\", function(exports) {\n    ((this.JSON || (this.JSON = {\n    }))), function() {\n        function f(a) {\n            return ((((a < 10)) ? ((\"0\" + a)) : a));\n        };\n    ;\n        function quote(a) {\n            return escapable.lastIndex = 0, ((escapable.test(a) ? ((((\"\\\"\" + a.replace(escapable, function(a) {\n                var b = meta[a];\n                return ((((typeof b == \"string\")) ? b : ((\"\\\\u\" + ((\"0000\" + a.charCodeAt(0).toString(16))).slice(-4)))));\n            }))) + \"\\\"\")) : ((((\"\\\"\" + a)) + \"\\\"\"))));\n        };\n    ;\n        function str(a, b) {\n            var c, d, e, f, g = gap, i, j = b[a];\n            ((((((j && ((typeof j == \"object\")))) && ((typeof j.toJSON == \"function\")))) && (j = j.toJSON(a)))), ((((typeof rep == \"function\")) && (j = rep.call(b, a, j))));\n            switch (typeof j) {\n              case \"string\":\n                return quote(j);\n              case \"number\":\n                return ((isFinite(j) ? String(j) : \"null\"));\n              case \"boolean\":\n            \n              case \"null\":\n                return String(j);\n              case \"object\":\n                if (!j) {\n                    return \"null\";\n                }\n            ;\n            ;\n                gap += indent, i = [];\n                if (((Object.prototype.toString.apply(j) === \"[object Array]\"))) {\n                    f = j.length;\n                    for (c = 0; ((c < f)); c += 1) {\n                        i[c] = ((str(c, j) || \"null\"));\n                    ;\n                    };\n                ;\n                    return e = ((((i.length === 0)) ? \"[]\" : ((gap ? ((((((((((\"[\\u000a\" + gap)) + i.join(((\",\\u000a\" + gap))))) + \"\\u000a\")) + g)) + \"]\")) : ((((\"[\" + i.join(\",\"))) + \"]\")))))), gap = g, e;\n                }\n            ;\n            ;\n                if (((rep && ((typeof rep == \"object\"))))) {\n                    f = rep.length;\n                    for (c = 0; ((c < f)); c += 1) {\n                        d = rep[c], ((((typeof d == \"string\")) && (e = str(d, j), ((e && i.push(((((quote(d) + ((gap ? \": \" : \":\")))) + e))))))));\n                    ;\n                    };\n                ;\n                }\n                 else for (d in j) {\n                    ((Object.hasOwnProperty.call(j, d) && (e = str(d, j), ((e && i.push(((((quote(d) + ((gap ? \": \" : \":\")))) + e))))))));\n                ;\n                }\n            ;\n            ;\n                return e = ((((i.length === 0)) ? \"{}\" : ((gap ? ((((((((((\"{\\u000a\" + gap)) + i.join(((\",\\u000a\" + gap))))) + \"\\u000a\")) + g)) + \"}\")) : ((((\"{\" + i.join(\",\"))) + \"}\")))))), gap = g, e;\n            };\n        ;\n        };\n    ;\n        ((((typeof JSBNG__Date.prototype.toJSON != \"function\")) && (JSBNG__Date.prototype.toJSON = function(a) {\n            return ((isFinite(this.valueOf()) ? ((((((((((((((((((((((this.getUTCFullYear() + \"-\")) + f(((this.getUTCMonth() + 1))))) + \"-\")) + f(this.getUTCDate()))) + \"T\")) + f(this.getUTCHours()))) + \":\")) + f(this.getUTCMinutes()))) + \":\")) + f(this.getUTCSeconds()))) + \"Z\")) : null));\n        }, String.prototype.toJSON = Number.prototype.toJSON = Boolean.prototype.toJSON = function(a) {\n            return this.valueOf();\n        })));\n        var cx = /[\\u0000\\u00ad\\u0600-\\u0604\\u070f\\u17b4\\u17b5\\u200c-\\u200f\\u2028-\\u202f\\u2060-\\u206f\\ufeff\\ufff0-\\uffff]/g, escapable = /[\\\\\\\"\\x00-\\x1f\\x7f-\\x9f\\u00ad\\u0600-\\u0604\\u070f\\u17b4\\u17b5\\u200c-\\u200f\\u2028-\\u202f\\u2060-\\u206f\\ufeff\\ufff0-\\uffff]/g, gap, indent, meta = {\n            \"\\u0008\": \"\\\\b\",\n            \"\\u0009\": \"\\\\t\",\n            \"\\u000a\": \"\\\\n\",\n            \"\\u000c\": \"\\\\f\",\n            \"\\u000d\": \"\\\\r\",\n            \"\\\"\": \"\\\\\\\"\",\n            \"\\\\\": \"\\\\\\\\\"\n        }, rep;\n        ((((typeof JSON.stringify != \"function\")) && (JSON.stringify = function(a, b, c) {\n            var d;\n            gap = \"\", indent = \"\";\n            if (((typeof c == \"number\"))) {\n                for (d = 0; ((d < c)); d += 1) {\n                    indent += \" \";\n                ;\n                };\n            }\n             else {\n                ((((typeof c == \"string\")) && (indent = c)));\n            }\n        ;\n        ;\n            rep = b;\n            if (((((!b || ((typeof b == \"function\")))) || ((((typeof b == \"object\")) && ((typeof b.length == \"number\"))))))) {\n                return str(\"\", {\n                    \"\": a\n                });\n            }\n        ;\n        ;\n            throw new Error(\"JSON.stringify\");\n        }))), ((((typeof JSON.parse != \"function\")) && (JSON.parse = function(text, reviver) {\n            function walk(a, b) {\n                var c, d, e = a[b];\n                if (((e && ((typeof e == \"object\"))))) {\n                    for (c in e) {\n                        ((Object.hasOwnProperty.call(e, c) && (d = walk(e, c), ((((d !== undefined)) ? e[c] = d : delete e[c])))));\n                    ;\n                    };\n                }\n            ;\n            ;\n                return reviver.call(a, b, e);\n            };\n        ;\n            var j;\n            cx.lastIndex = 0, ((cx.test(text) && (text = text.replace(cx, function(a) {\n                return ((\"\\\\u\" + ((\"0000\" + a.charCodeAt(0).toString(16))).slice(-4)));\n            }))));\n            if (/^[\\],:{}\\s]*$/.test(text.replace(/\\\\(?:[\"\\\\\\/bfnrt]|u[0-9a-fA-F]{4})/g, \"@\").replace(/\"[^\"\\\\\\n\\r]*\"|true|false|null|-?\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d+)?/g, \"]\").replace(/(?:^|:|,)(?:\\s*\\[)+/g, \"\"))) {\n                return j = eval(((((\"(\" + text)) + \")\"))), ((((typeof reviver == \"function\")) ? walk({\n                    \"\": j\n                }, \"\") : j));\n            }\n        ;\n        ;\n            throw new SyntaxError(\"JSON.parse\");\n        })));\n    }(), exports();\n});\nprovide(\"libwrap/json\", function(a) {\n    using(\"$lib/json2.js\", function() {\n        a(JSON);\n    });\n});\nprovide(\"$lib/hogan.js\", function(a) {\n    var b = {\n    }, c = !1;\n    ((((typeof window != \"undefined\")) && (c = ((window.$.browser.msie && ((parseInt(window.$.browser.version, 10) <= 7))))))), function(a, b) {\n        function c(a, b) {\n            function c() {\n            \n            };\n        ;\n            function d() {\n            \n            };\n        ;\n            c.prototype = a, d.prototype = a.subs;\n            var e = new c;\n            e.subs = new d;\n            for (var f in b) {\n                e.subs[f] = b[f];\n            ;\n            };\n        ;\n            return e;\n        };\n    ;\n        function d(a) {\n            return String(((((((a === null)) || ((a === undefined)))) ? \"\" : a)));\n        };\n    ;\n        function e(a) {\n            return a = d(a), ((l.test(a) ? a.replace(f, \"&amp;\").replace(g, \"&lt;\").replace(i, \"&gt;\").replace(j, \"&#39;\").replace(k, \"&quot;\") : a));\n        };\n    ;\n        a.Template = function(a, c, d, e) {\n            a = ((a || {\n            })), this.r = ((a.main || this.r)), this.c = d, this.options = e, this.text = ((c || \"\")), this.buf = ((b ? [] : \"\")), this.partials = ((a.partials || {\n            })), this.subs = ((a.subs || {\n            }));\n        }, a.Template.prototype = {\n            r: function(a, b, c) {\n                return \"\";\n            },\n            v: e,\n            t: d,\n            render: function(a, b, c) {\n                return this.ri([a,], ((b || {\n                })), c);\n            },\n            ri: function(a, b, c) {\n                return this.r(a, b, c);\n            },\n            ep: function(a, b) {\n                var d = this.partials[a], e = b[d.JSBNG__name];\n                if (((d.instance && ((d.base == e))))) {\n                    return d.instance;\n                }\n            ;\n            ;\n                if (((typeof e == \"string\"))) {\n                    if (!this.c) {\n                        throw new Error(\"No compiler available.\");\n                    }\n                ;\n                ;\n                    e = this.c.compile(e, this.options);\n                }\n            ;\n            ;\n                return ((e ? (this.partials[a].base = e, ((d.subs && (e = c(e, d.subs)))), this.partials[a].instance = e, e) : null));\n            },\n            rp: function(a, b, c, d) {\n                var e = this.ep(a, c);\n                return ((e ? e.ri(b, c, d) : \"\"));\n            },\n            rs: function(a, b, c) {\n                var d = a[((a.length - 1))];\n                if (!m(d)) {\n                    c(a, b, this);\n                    return;\n                }\n            ;\n            ;\n                for (var e = 0; ((e < d.length)); e++) {\n                    a.push(d[e]), c(a, b, this), a.pop();\n                ;\n                };\n            ;\n            },\n            s: function(a, b, c, d, e, f, g) {\n                var i;\n                return ((((m(a) && ((a.length === 0)))) ? !1 : (((((typeof a == \"function\")) && (a = this.ms(a, b, c, d, e, f, g)))), i = ((((a === \"\")) || !!a)), ((((((!d && i)) && b)) && b.push(((((typeof a == \"object\")) ? a : b[((b.length - 1))]))))), i)));\n            },\n            d: function(a, b, c, d) {\n                var e = a.split(\".\"), f = this.f(e[0], b, c, d), g = null;\n                if (((((a === \".\")) && m(b[((b.length - 2))])))) {\n                    return b[((b.length - 1))];\n                }\n            ;\n            ;\n                for (var i = 1; ((i < e.length)); i++) {\n                    ((((((f && ((typeof f == \"object\")))) && ((f[e[i]] != null)))) ? (g = f, f = f[e[i]]) : f = \"\"));\n                ;\n                };\n            ;\n                return ((((d && !f)) ? !1 : (((((!d && ((typeof f == \"function\")))) && (b.push(g), f = this.mv(f, b, c), b.pop()))), f)));\n            },\n            f: function(a, b, c, d) {\n                var e = !1, f = null, g = !1;\n                for (var i = ((b.length - 1)); ((i >= 0)); i--) {\n                    f = b[i];\n                    if (((((f && ((typeof f == \"object\")))) && ((f[a] != null))))) {\n                        e = f[a], g = !0;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((g ? (((((!d && ((typeof e == \"function\")))) && (e = this.mv(e, b, c)))), e) : ((d ? !1 : \"\"))));\n            },\n            ls: function(a, b, c, e, f) {\n                var g = this.options.delimiters;\n                return this.options.delimiters = f, this.b(this.ct(d(a.call(b, e)), b, c)), this.options.delimiters = g, !1;\n            },\n            ct: function(a, b, c) {\n                if (this.options.disableLambda) {\n                    throw new Error(\"Lambda features disabled.\");\n                }\n            ;\n            ;\n                return this.c.compile(a, this.options).render(b, c);\n            },\n            b: ((b ? function(a) {\n                this.buf.push(a);\n            } : function(a) {\n                this.buf += a;\n            })),\n            fl: ((b ? function() {\n                var a = this.buf.join(\"\");\n                return this.buf = [], a;\n            } : function() {\n                var a = this.buf;\n                return this.buf = \"\", a;\n            })),\n            ms: function(a, b, c, d, e, f, g) {\n                var i = b[((b.length - 1))], j = a.call(i);\n                return ((((typeof j == \"function\")) ? ((d ? !0 : this.ls(j, i, c, this.text.substring(e, f), g))) : j));\n            },\n            mv: function(a, b, c) {\n                var e = b[((b.length - 1))], f = a.call(e);\n                return ((((typeof f == \"function\")) ? this.ct(d(f.call(e)), e, c) : f));\n            },\n            sub: function(a, b, c) {\n                var d = this.subs[a];\n                ((d && d(b, c, this)));\n            }\n        };\n        var f = /&/g, g = /</g, i = />/g, j = /\\'/g, k = /\\\"/g, l = /[&<>\\\"\\']/, m = ((Array.isArray || function(a) {\n            return ((Object.prototype.toString.call(a) === \"[object Array]\"));\n        }));\n    }(b, c), function(a) {\n        function b(a) {\n            ((((a.n.substr(((a.n.length - 1))) === \"}\")) && (a.n = a.n.substring(0, ((a.n.length - 1))))));\n        };\n    ;\n        function c(a) {\n            return ((a.trim ? a.trim() : a.replace(/^\\s*|\\s*$/g, \"\")));\n        };\n    ;\n        function d(a, b, c) {\n            if (((b.charAt(c) != a.charAt(0)))) {\n                return !1;\n            }\n        ;\n        ;\n            for (var d = 1, e = a.length; ((d < e)); d++) {\n                if (((b.charAt(((c + d))) != a.charAt(d)))) {\n                    return !1;\n                }\n            ;\n            ;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function e(b, c, d, i) {\n            var j = [], k = null, l = null, m = null;\n            l = d[((d.length - 1))];\n            while (((b.length > 0))) {\n                m = b.shift();\n                if (!((((!l || ((l.tag != \"\\u003C\")))) || ((m.tag in u))))) {\n                    throw new Error(\"Illegal content in \\u003C super tag.\");\n                }\n            ;\n            ;\n                if (((((a.tags[m.tag] <= a.tags.$)) || f(m, i)))) d.push(m), m.nodes = e(b, m.tag, d, i);\n                 else {\n                    if (((m.tag == \"/\"))) {\n                        if (((d.length === 0))) {\n                            throw new Error(((\"Closing tag without opener: /\" + m.n)));\n                        }\n                    ;\n                    ;\n                        k = d.pop();\n                        if (((((m.n != k.n)) && !g(m.n, k.n, i)))) {\n                            throw new Error(((((((\"Nesting error: \" + k.n)) + \" vs. \")) + m.n)));\n                        }\n                    ;\n                    ;\n                        return k.end = m.i, j;\n                    }\n                ;\n                ;\n                    ((((m.tag == \"\\u000a\")) && (m.last = ((((b.length == 0)) || ((b[0].tag == \"\\u000a\")))))));\n                }\n            ;\n            ;\n                j.push(m);\n            };\n        ;\n            if (((d.length > 0))) {\n                throw new Error(((\"missing closing tag: \" + d.pop().n)));\n            }\n        ;\n        ;\n            return j;\n        };\n    ;\n        function f(a, b) {\n            for (var c = 0, d = b.length; ((c < d)); c++) {\n                if (((b[c].o == a.n))) {\n                    return a.tag = \"#\", !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function g(a, b, c) {\n            for (var d = 0, e = c.length; ((d < e)); d++) {\n                if (((((c[d].c == a)) && ((c[d].o == b))))) {\n                    return !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function i(a) {\n            var b = [];\n            for (var c in a) {\n                b.push(((((((((\"\\\"\" + k(c))) + \"\\\": function(c,p,t) {\")) + a[c])) + \"}\")));\n            ;\n            };\n        ;\n            return ((((\"{ \" + b.join(\",\"))) + \" }\"));\n        };\n    ;\n        function j(a, b, c) {\n            for (var d in a) {\n                b[d] = new Function(\"c\", \"p\", \"t\", a[d]);\n            ;\n            };\n        ;\n        };\n    ;\n        function k(a) {\n            return a.replace(t, \"\\\\\\\\\").replace(q, \"\\\\\\\"\").replace(r, \"\\\\n\").replace(s, \"\\\\r\");\n        };\n    ;\n        function l(a) {\n            return ((~a.indexOf(\".\") ? \"d\" : \"f\"));\n        };\n    ;\n        function m(a, b) {\n            var c = ((a.n + v++));\n            return b.partials[c] = {\n                JSBNG__name: a.n\n            }, b.code += ((((((((\"t.b(t.rp(\\\"\" + k(c))) + \"\\\",c,p,\\\"\")) + ((a.indent || \"\")))) + \"\\\"));\")), c;\n        };\n    ;\n        function n(a, b) {\n            b.code += ((((((((\"t.b(t.t(t.\" + l(a.n))) + \"(\\\"\")) + k(a.n))) + \"\\\",c,p,0)));\"));\n        };\n    ;\n        function o(a) {\n            return ((((\"t.b(\" + a)) + \");\"));\n        };\n    ;\n        var p = /\\S/, q = /\\\"/g, r = /\\n/g, s = /\\r/g, t = /\\\\/g;\n        a.tags = {\n            \"#\": 1,\n            \"^\": 2,\n            \"\\u003C\": 3,\n            $: 4,\n            \"/\": 5,\n            \"!\": 6,\n            \"\\u003E\": 7,\n            \"=\": 8,\n            _v: 9,\n            \"{\": 10,\n            \"&\": 11,\n            _t: 12\n        }, a.scan = function(e, f) {\n            function g() {\n                ((((t.length > 0)) && (u.push({\n                    tag: \"_t\",\n                    text: new String(t)\n                }), t = \"\")));\n            };\n        ;\n            function i() {\n                var b = !0;\n                for (var c = x; ((c < u.length)); c++) {\n                    b = ((((a.tags[u[c].tag] < a.tags._v)) || ((((u[c].tag == \"_t\")) && ((u[c].text.match(p) === null))))));\n                    if (!b) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return b;\n            };\n        ;\n            function j(a, b) {\n                g();\n                if (((a && i()))) {\n                    for (var c = x, d; ((c < u.length)); c++) {\n                        ((u[c].text && ((((((d = u[((c + 1))]) && ((d.tag == \"\\u003E\")))) && (d.indent = u[c].text.toString()))), u.splice(c, 1))));\n                    ;\n                    };\n                }\n                 else {\n                    ((b || u.push({\n                        tag: \"\\u000a\"\n                    })));\n                }\n            ;\n            ;\n                v = !1, x = u.length;\n            };\n        ;\n            function k(a, b) {\n                var d = ((\"=\" + z)), e = a.indexOf(d, b), f = c(a.substring(((a.indexOf(\"=\", b) + 1)), e)).split(\" \");\n                return y = f[0], z = f[1], ((((e + d.length)) - 1));\n            };\n        ;\n            var l = e.length, m = 0, n = 1, o = 2, q = m, r = null, s = null, t = \"\", u = [], v = !1, w = 0, x = 0, y = \"{{\", z = \"}}\";\n            ((f && (f = f.split(\" \"), y = f[0], z = f[1])));\n            for (w = 0; ((w < l)); w++) {\n                ((((q == m)) ? ((d(y, e, w) ? (--w, g(), q = n) : ((((e.charAt(w) == \"\\u000a\")) ? j(v) : t += e.charAt(w))))) : ((((q == n)) ? (w += ((y.length - 1)), s = a.tags[e.charAt(((w + 1)))], r = ((s ? e.charAt(((w + 1))) : \"_v\")), ((((r == \"=\")) ? (w = k(e, w), q = m) : (((s && w++)), q = o))), v = w) : ((d(z, e, w) ? (u.push({\n                    tag: r,\n                    n: c(t),\n                    otag: y,\n                    ctag: z,\n                    i: ((((r == \"/\")) ? ((v - z.length)) : ((w + y.length))))\n                }), t = \"\", w += ((z.length - 1)), q = m, ((((r == \"{\")) && ((((z == \"}}\")) ? w++ : b(u[((u.length - 1))])))))) : t += e.charAt(w)))))));\n            ;\n            };\n        ;\n            return j(v, !0), u;\n        };\n        var u = {\n            _t: !0,\n            \"\\u000a\": !0,\n            $: !0,\n            \"/\": !0\n        };\n        a.stringify = function(b, c, d) {\n            var e = [], f = ((((\"{main: function (c,p,i) { \" + a.wrapMain(b.code))) + \" }, partials: {\"));\n            for (var g in b.partials) {\n                e.push(((((((((\"\\\"\" + k(g))) + \"\\\": {name:\\\"\")) + k(b.partials[g].JSBNG__name))) + \"\\\"}\")));\n            ;\n            };\n        ;\n            return f += ((((((e.join(\",\") + \"}, subs: \")) + i(b.subs))) + \" }\")), f;\n        };\n        var v = 0;\n        a.generate = function(b, c, d) {\n            v = 0;\n            var e = {\n                code: \"\",\n                subs: {\n                },\n                partials: {\n                }\n            };\n            return a.walk(b, e), ((d.asString ? this.stringify(e, c, d) : this.makeTemplate(e, c, d)));\n        }, a.wrapMain = function(a) {\n            return ((((\"var t=this;t.b(i=i||\\\"\\\");\" + a)) + \"return t.fl();\"));\n        }, a.template = a.Template, a.makeTemplate = function(a, b, c) {\n            var d = {\n                main: new Function(\"c\", \"p\", \"i\", this.wrapMain(a.code)),\n                subs: {\n                },\n                partials: {\n                }\n            };\n            d.partials = a.partials;\n            for (var e in d.partials) {\n                j(d.partials[e].subs, d.partials[e].subs);\n            ;\n            };\n        ;\n            return j(a.subs, d.subs), new this.template(d, b, this, c);\n        }, a.codegen = {\n            \"#\": function(b, c) {\n                c.code += ((((((((((((((((((((((((((((((\"if(t.s(t.\" + l(b.n))) + \"(\\\"\")) + k(b.n))) + \"\\\",c,p,1),\")) + \"c,p,0,\")) + b.i)) + \",\")) + b.end)) + \",\\\"\")) + b.otag)) + \" \")) + b.ctag)) + \"\\\")){\")) + \"t.rs(c,p,\")) + \"function(c,p,t){\")), a.walk(b.nodes, c), c.code += \"});c.pop();}\";\n            },\n            \"^\": function(b, c) {\n                c.code += ((((((((\"if(!t.s(t.\" + l(b.n))) + \"(\\\"\")) + k(b.n))) + \"\\\",c,p,1),c,p,1,0,0,\\\"\\\")){\")), a.walk(b.nodes, c), c.code += \"};\";\n            },\n            \"\\u003E\": m,\n            \"\\u003C\": function(b, c) {\n                var d = {\n                    partials: c.partials,\n                    code: \"\",\n                    subs: {\n                    },\n                    inPartial: !0\n                };\n                a.walk(b.nodes, d), c.partials[m(b, c)].subs = d.subs;\n            },\n            $: function(b, c) {\n                var d = {\n                    subs: {\n                    },\n                    code: \"\",\n                    partials: c.partials\n                };\n                a.walk(b.nodes, d), c.subs[b.n] = d.code, ((c.inPartial || (c.code += ((((\"t.sub(\\\"\" + k(b.n))) + \"\\\",c,p);\")))));\n            },\n            \"\\u000a\": function(a, b) {\n                b.code += o(((\"\\\"\\\\n\\\"\" + ((a.last ? \"\" : \" + i\")))));\n            },\n            _v: function(a, b) {\n                b.code += ((((((((\"t.b(t.v(t.\" + l(a.n))) + \"(\\\"\")) + k(a.n))) + \"\\\",c,p,0)));\"));\n            },\n            _t: function(a, b) {\n                b.code += o(((((\"\\\"\" + k(a.text))) + \"\\\"\")));\n            },\n            \"{\": n,\n            \"&\": n\n        }, a.walk = function(b, c) {\n            var d;\n            for (var e = 0, f = b.length; ((e < f)); e++) {\n                d = a.codegen[b[e].tag], ((d && d(b[e], c)));\n            ;\n            };\n        ;\n            return c;\n        }, a.parse = function(a, b, c) {\n            return c = ((c || {\n            })), e(a, \"\", [], ((c.sectionTags || [])));\n        }, a.cache = {\n        }, a.cacheKey = function(a, b) {\n            return [a,!!b.asString,!!b.disableLambda,].join(\"||\");\n        }, a.compile = function(b, c) {\n            c = ((c || {\n            }));\n            var d = a.cacheKey(b, c), e = this.cache[d];\n            return ((e ? e : (e = this.generate(this.parse(this.scan(b, c.delimiters), b, c), b, c), this.cache[d] = e)));\n        };\n    }(b);\n    var d = function(a) {\n        function b(b, c, d, e) {\n            var f = c, g = this.partials[b], i = this.f(g.JSBNG__name, c, d, 0);\n            return ((i && (f = f.concat(i)))), a.Template.prototype.rp.call(this, b, f, d, e);\n        };\n    ;\n        function c(b, c, d, e) {\n            var f = c[((c.length - 1))], g = a.Template.prototype.f.call(this, b, c, d, e);\n            if (((g === !1))) {\n                var i = ((f.lookup_missing_property ? f : c[0]));\n                ((i.lookup_missing_property && (g = i.lookup_missing_property(b, f), ((((!e && ((typeof g == \"function\")))) && (g = this.lv(g, c, d)))))));\n            }\n        ;\n        ;\n            return g;\n        };\n    ;\n        function d(b, c, d) {\n            var f = a.parse.call(this, b, c, d), g = \"\";\n            for (var i = 0; ((i < f.length)); i++) {\n                if (((((f[i].tag == \"_v\")) && ((f[i].n.indexOf(\"%TRANSLATION-HINT\") == 0))))) {\n                    var j = f.splice(i, 1)[0];\n                    i--, g = j.n.substring(((j.n.indexOf(\"mode=\") + \"mode=\".length)));\n                }\n            ;\n            ;\n            };\n        ;\n            return e(f, g, c, d);\n        };\n    ;\n        function e(b, c, d, i) {\n            var j = [];\n            for (var k = 0; ((k < b.length)); k++) {\n                if (((((b[k].tag == \"#\")) && ((b[k].n == \"_i\"))))) {\n                    var l = g(d.substring(b[k].i, b[k].end), c);\n                    ((((l.tag == \"raw\")) ? j.push(l) : Array.prototype.push.apply(j, a.parse(a.scan(l, i.delimiters), d, i))));\n                }\n                 else ((((((b[k].tag == \"#\")) || ((b[k].tag == \"^\")))) ? (b[k].nodes = e(b[k].nodes, c, d, i), j.push(b[k])) : j.push(b[k])));\n            ;\n            ;\n            };\n        ;\n            return f(j);\n        };\n    ;\n        function f(a) {\n            if (((a.length == 0))) {\n                return a;\n            }\n        ;\n        ;\n            var b = [a[0],];\n            for (var c = 1; ((c < a.length)); c++) {\n                ((((((b[((b.length - 1))].tag != \"_t\")) || ((((a[c].tag != \"\\u000a\")) && ((a[c].tag != \"_t\")))))) ? b.push(a[c]) : b[((b.length - 1))].text += ((a[c].text || \"\\u000a\"))));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function g(a, b) {\n            var c = {\n                text: a,\n                mode: b\n            }, d = ((((typeof _ != \"undefined\")) ? _(c) : c.text));\n            return ((d ? d : a));\n        };\n    ;\n        var i = function(d, e, f, g) {\n            this.rp = b, this.f = c, a.Template.call(this, d, e, f, g);\n        };\n        i.prototype = a.Template.prototype;\n        var j, k = function() {\n        \n        };\n        return k.prototype = a, j = new k, j.template = i, j.parse = d, {\n            twitterHogan: j,\n            TwitterTemplate: i,\n            to_html: function(a, b, c, d) {\n                ((((a instanceof i)) || (a = j.compile(a, {\n                    sectionTags: [{\n                        o: \"_i\",\n                        c: \"i\"\n                    },]\n                }))));\n                var e = a.render(b, c);\n                if (!d) {\n                    return e;\n                }\n            ;\n            ;\n                d(e);\n            }\n        };\n    }(b);\n    ((((typeof window != \"undefined\")) && (window.Mustache = d))), ((((typeof module != \"undefined\")) && (module.exports = {\n        Mustache: d,\n        Hogan: b\n    }))), a();\n});\nprovide(\"libwrap/hogan\", function(a) {\n    using(\"$lib/hogan.js\", function() {\n        a(Mustache);\n    });\n});\nprovide(\"run/base\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, c) {\n        function d(a, b) {\n            var c = window, d = a.split(\".\");\n            for (var e = 0, f = d.length; ((e < f)); e++) {\n                var g = d[e];\n                ((((typeof c[g] == \"undefined\")) && (c[g] = {\n                }))), c = c[g];\n            };\n        ;\n            if (b) {\n                for (var i in b) {\n                    c[i] = b[i];\n                ;\n                };\n            }\n        ;\n        ;\n            return c;\n        };\n    ;\n        window.h = function(a) {\n            var b = $(\"\\u003Cdiv/\\u003E\"), c = function(a) {\n                return ((a ? b.text(a).html().replace(/\\\"/gi, \"&quot;\") : a));\n            };\n            return h = function(a) {\n                return c(a);\n            }, c(a);\n        }, ((((c.browser.msie && ((c.browser.version === \"7.0\")))) && (c.cleanData = function(a) {\n            var b, d, e = c.cache, f = c.JSBNG__event.special, g = c.support.deleteExpando;\n            for (var i = 0, j; (((j = a[i]) != null)); i++) {\n                if (((j.nodeName && c.noData[j.nodeName.toLowerCase()]))) {\n                    continue;\n                }\n            ;\n            ;\n                d = j[c.expando];\n                if (d) {\n                    b = e[d];\n                    if (((b && b.events))) {\n                        for (var k in b.events) {\n                            ((f[k] ? c.JSBNG__event.remove(j, k) : c.removeEvent(j, k, b.handle)));\n                        ;\n                        };\n                    ;\n                        ((b.handle && (b.handle.elem = null)));\n                    }\n                ;\n                ;\n                    ((g ? delete j[c.expando] : ((j.removeAttribute && j.removeAttribute(c.expando.toLowerCase()))))), delete e[d];\n                }\n            ;\n            ;\n            };\n        ;\n        })));\n        var e = /\\[native code\\]/;\n        d(\"twttr\", {\n            provide: d,\n            augmentObject: function(a, b) {\n                for (var c in b) {\n                    a[c] = b[c];\n                ;\n                };\n            ;\n                return a;\n            },\n            aug: function() {\n                return twttr.augmentObject.apply({\n                }, arguments);\n            },\n            augmentString: function(a, b) {\n                var c = window, d = a.split(\".\");\n                for (var e = 0, f = d.length; ((e < f)); ++e) {\n                    c = c[d[e]] = ((c[d[e]] || ((((typeof d[((e + 1))] != \"undefined\")) ? {\n                    } : b))));\n                ;\n                };\n            ;\n                return c;\n            },\n            each: function(a, b, c) {\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    ((c ? b.call(c, a[d], d, a) : b(a[d], d, a)));\n                ;\n                };\n            ;\n            },\n            localize: function(a, b) {\n                return ((((typeof a[twttr.pageLocale] == \"undefined\")) ? b : a[twttr.pageLocale]));\n            },\n            filter: function(a, b, c) {\n                var d;\n                if (twttr.is.array(a)) {\n                    var e = [];\n                    for (var f = 0, g = a.length; ((f < g)); ++f) {\n                        d = ((c ? b.call(c, a[f], f, a) : b(a[f], f, a)));\n                        if (!d) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        e.push(a[f]);\n                    };\n                ;\n                    return e;\n                }\n            ;\n            ;\n                if (twttr.is.object(a)) {\n                    var h = {\n                    };\n                    for (var i in a) {\n                        d = ((c ? b.call(c, i, a[i], a) : b(i, a[i], a)));\n                        if (!d) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        h[i] = a[i];\n                    };\n                ;\n                    return h;\n                }\n            ;\n            ;\n            },\n            map: function(a, b, c, d) {\n                var e = ((twttr.is.array(a) ? [] : {\n                }));\n                ((((d && ((d == \"array\")))) && (e = [])));\n                for (var f in a) {\n                    e[f] = ((c ? b.call(c, a[f], f, a) : b(a[f], f, a)));\n                ;\n                };\n            ;\n                return e;\n            },\n            every: function(a, b, c) {\n                var d;\n                for (var e = 0, f = a.length; ((e < f)); ++e) {\n                    d = ((c ? b.call(c, a[e], e, a) : b(a[e], e, a)));\n                    if (!d) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            inject: function() {\n                return this.reduce.apply(this, arguments);\n            },\n            reduce: function(a, b, c) {\n                return $.each(a, function(a, d) {\n                    b = c(b, a, d);\n                }), b;\n            },\n            exists: function(a, b) {\n                return ((((!twttr.is.object(a) || !twttr.is.def(b))) ? null : twttr.is.def(twttr.at(b, a))));\n            },\n            merge: function() {\n                var a = c.makeArray(arguments);\n                return ((((a.length === 1)) ? a[0] : (((twttr.is.bool(a[((a.length - 1))]) && a.unshift(a.pop()))), c.extend.apply(null, a))));\n            },\n            extend: function(a, b) {\n                function c() {\n                \n                };\n            ;\n                c.prototype = b.prototype, a.prototype = new c, a.prototype.constructor = a, a.uber = b.prototype, ((((b.prototype.constructor == Object.prototype.constructor)) && (b.prototype.constructor = b)));\n            },\n            method: function(a, b) {\n                return this.prototype[a] = b, this;\n            },\n            methods: function(a) {\n                this.prototype._namespace = this._namespace;\n                for (var b in a) {\n                    this.prototype[b] = a[b], ((twttr.is.fn(a[b]) && (this.prototype[b]._methodName = b)));\n                ;\n                };\n            ;\n                return this;\n            },\n            statics: function(a) {\n                return twttr.aug(this, a);\n            },\n            at: function(a, b) {\n                var c = a.split(\".\"), d = ((b || window));\n                while (((c.length > 0))) {\n                    d = d[c.shift()];\n                    if (((typeof d == \"undefined\"))) {\n                        return undefined;\n                    }\n                ;\n                ;\n                };\n            ;\n                return d;\n            },\n            klass: function(a, b) {\n                ((((typeof a != \"string\")) && (b = a, a = {\n                }[\"this evaluates to undefined\"])));\n                var c = ((b || function() {\n                    ((f.uberclass && f.uberclass.apply(this, arguments)));\n                })), d = [], f = function() {\n                    if (!((((!twttr.development && !twttr.isTestEnv)) || ((((this != window)) && !e.test(this.constructor)))))) {\n                        throw new Error(((((a ? a : \"(unnamed)\")) + \" constructor must be called with the 'new' keyword\")));\n                    }\n                ;\n                ;\n                    var b = this;\n                    c.apply(this, arguments), twttr.each(d, function(a) {\n                        new a(f, b);\n                    });\n                };\n                if (a) {\n                    twttr.augmentString(a, f);\n                    var g = a.split(\".\").pop();\n                    f.JSBNG__name = g.toLowerCase(), f._namespace = a, f._name = g;\n                }\n            ;\n            ;\n                return f.lazyLoad = function(a) {\n                    return d.push(a), f;\n                }, f.method = twttr.method, f.methods = twttr.methods, f.statics = twttr.statics, f._isKlass = !0, c._methodName = \"constructor\", f.subclassOf = function(a) {\n                    if (!a._isKlass) {\n                        throw \"You should not be subclassing something that is not a twttr.klass\";\n                    }\n                ;\n                ;\n                    twttr.extend(f, a);\n                    for (var b in a) {\n                        ((f.hasOwnProperty(b) || (f[b] = a[b])));\n                    ;\n                    };\n                ;\n                    return f.uberclass = a, f;\n                }, f.mixin = function() {\n                    for (var b = 0; ((b < arguments.length)); b++) {\n                        var c = arguments[b];\n                        ((twttr.is.def(c) ? c.call(f, f) : JSBNG__console.warn(((\"you have an undefined mixin coming from \" + a)))));\n                    };\n                ;\n                    return f;\n                }, f;\n            },\n            magic: function(a, b) {\n                return ((twttr.is.string(a) ? twttr.augmentString(a, b) : twttr.aug(a, b)));\n            },\n            bind: function(a, b, c) {\n                return function() {\n                    return b.apply(a, ((c ? c.concat(Array.prototype.slice.apply(arguments)) : arguments)));\n                };\n            }\n        }), twttr.deprecateAccess = function(a, b, c) {\n            c = ((c || {\n            }));\n            if (((((((((((!twttr.deprecateAccess.isActive || ((typeof JSBNG__console == \"undefined\")))) || ((typeof a.__defineGetter__ != \"function\")))) || ((typeof a.__defineSetter__ != \"function\")))) || ((typeof a.__lookupGetter__ != \"function\")))) || ((typeof a.__lookupSetter__ != \"function\"))))) {\n                return;\n            }\n        ;\n        ;\n            if (((a.__lookupGetter__(b) || a.__lookupSetter__(b)))) {\n                return;\n            }\n        ;\n        ;\n            ((((((!!c.now != !!c.daysRemaining)) && JSBNG__console)) && JSBNG__console.error(((((\"To deprecate \" + b)) + \", you must provide both a now property and a daysRemaining property, or neither\")))));\n            var d = a[b], e, g = new JSBNG__Date(((c.now + ((((((((c.daysRemaining * 1000)) * 60)) * 60)) * 24))))), i = ((g < new JSBNG__Date)), j = function() {\n                if (((e || f))) {\n                    return;\n                }\n            ;\n            ;\n                e = !0;\n                var d = [((((\"The property \\\"\" + b)) + \"\\\" on \")),a,\"is deprecated.\",];\n                ((c.replacement && d.push(((((\"  Please use \" + c.replacement)) + \" instead.\"))))), ((((c.daysRemaining && c.now)) && d.push(((\"\\u000aTHIS CODE WILL SELF-DESTRUCT ON \" + g.toString()))))), ((c.message && d.push(((\"\\u000aMessage: \" + message))))), d.push(\"\\u000aPlease remove the usage at \", {\n                    stack: (new Error).stack\n                }), JSBNG__console[((i ? \"error\" : \"warn\"))].apply(JSBNG__console, d);\n            };\n            a.__defineGetter__(b, function() {\n                return j(), d;\n            }), a.__defineSetter__(b, function(a) {\n                j(), d = a;\n            });\n        }, twttr.deprecateAccess.activate = function(a) {\n            ((((typeof a == \"undefined\")) && (a = !0))), twttr.deprecateAccess.isActive = a;\n        };\n        var f = !1;\n        twttr.unwarnedAccess = function(a, b) {\n            f = !0;\n            var c = a[b];\n            return f = !1, c;\n        }, twttr.klass.mixin = function(a, b) {\n            return twttr.magic(a, b);\n        }, d(\"twttr.is\", {\n            element: function(a) {\n                return ((!!a && !!((this.def(a.nodeType) || ((a.JSBNG__document && a.JSBNG__document.nodeType))))));\n            },\n            bool: function(a) {\n                return ((typeof a == \"boolean\"));\n            },\n            nil: function(a) {\n                return ((a === null));\n            },\n            def: function(a) {\n                return ((typeof a != \"undefined\"));\n            },\n            number: function(a) {\n                return ((((typeof a == \"number\")) && isFinite(a)));\n            },\n            fn: function(a) {\n                return ((typeof a == \"function\"));\n            },\n            array: function(a) {\n                return ((a ? ((this.number(a.length) && this.fn(a.splice))) : !1));\n            },\n            string: function(a) {\n                return ((typeof a == \"string\"));\n            },\n            blank: function(a) {\n                return ((a === \"\"));\n            },\n            falsy: function(a) {\n                return !a;\n            },\n            object: function(a) {\n                return !((!a || ((((typeof a != \"object\")) && !this.fn(a)))));\n            },\n            regex: function(a) {\n                return ((Object.prototype.toString.apply(a) === \"[object RegExp]\"));\n            },\n            inArray: function(a, b) {\n                var c = b.length, d = 0;\n                for (d = 0; ((d < c)); d++) {\n                    if (((b[d] === a))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            }\n        }), twttr.provide(\"twttr.assets\", {\n            getPathFromAbsoluteURL: function(a, b) {\n                if (!twttr.cdnBase) {\n                    return a;\n                }\n            ;\n            ;\n                if (((a.indexOf(\"/unversioned_dev_assets/\") === 0))) {\n                    return a;\n                }\n            ;\n            ;\n                var c;\n                if (a.match(/^https?:/)) {\n                    function d(a) {\n                        var b = a.split(\"://\")[1];\n                        return b.split(\"/\").slice(1).join(\"/\");\n                    };\n                ;\n                    c = d(a);\n                }\n                 else JSBNG__console.warn(\"A relative path (%o) was passed to getPathFromAbsoluteURL, which expects an absolute URL; you should use twttr.assets.path instead\", a), c = a;\n            ;\n            ;\n                return this.path(c, b);\n            },\n            path: function(a, b) {\n                if (!twttr.cdnBase) {\n                    return a;\n                }\n            ;\n            ;\n                if (a.match(/^https?:/)) {\n                    return ((((((typeof JSBNG__console != \"undefined\")) && JSBNG__console.warn)) && JSBNG__console.warn(\"A fully qualified URL (%o) was passed to twttr.assets.path, which expects a relative path; returning it unchanged\", a))), a;\n                }\n            ;\n            ;\n                b = ((b || {\n                }));\n                var c = ((((typeof b.isSSL == \"undefined\")) ? ((twttr.proto == \"https\")) : b.isSSL)), d = ((((typeof b.isVersioned == \"undefined\")) ? !0 : b.isVersioned)), e, f, g;\n                return ((d ? e = twttr.cdnBase.versioned : e = twttr.cdnBase.unversioned)), ((c ? (f = e.ssl, ((((e.ssl_akamai && twttr.decider.isAvailable(\"ssl_cdn_akamai_fraction\"))) && (f = e.ssl_akamai)))) : f = e.http)), ((((a[0] !== \"/\")) && (a = ((\"/\" + a))))), g = f[twttr.assets.stringToBucket(a, f.length)], ((g + a));\n            },\n            stringToBucket: function(a, b) {\n                if (!b) {\n                    throw new Error(\"Missing numberOfBuckets argument\");\n                }\n            ;\n            ;\n                var c = a.split(\"/\"), d = c[((c.length - 1))], e = 0;\n                for (var f = 0; ((f < d.length)); f++) {\n                    e += d.charCodeAt(f);\n                ;\n                };\n            ;\n                return ((e % b));\n            }\n        }), a(twttr);\n    });\n});\nprovide(\"_\", function(a) {\n    using(\"util\").as(function(b) {\n        var c = ((b.util.params().lang == \"en-xx\")), _ = window._ = function(a, b) {\n            var c = a, e;\n            return ((twttr.is.object(a) && (c = a.text, e = a.mode))), c = d(c, e), ((((b == null)) ? c : Mustache.to_html(c, b)));\n        };\n        _.pseudoTranslate = function(a) {\n            str = \"[\";\n            var b = 0;\n            for (var c = 0; ((c < a.length)); c++) {\n                ((((((a[c] == \"\\u003E\")) || ((a[c] == \"}\")))) ? b-- : ((((((a[c] == \"\\u003C\")) || ((a[c] == \"{\")))) && b++)))), ((((b > 0)) ? str += a[c] : str += a[c].replace(/a/g, \"\\u00e5\\u00e4\").replace(/e/g, \"\\u00e9\\u00ea\").replace(/i/g, \"\\u00ef\\u00ed\").replace(/o/g, \"\\u00f6\\u00f8\").replace(/u/g, \"\\u00fc\")));\n            ;\n            };\n        ;\n            return str += \"]\", str;\n        };\n        var d = function(a, b) {\n            var d = a;\n            if (!!twttr.i18n) {\n                var e = undefined;\n                ((b ? e = ((twttr.i18n[((((b + \":\")) + a))] || twttr.i18n[a])) : e = twttr.i18n[a])), ((e && (d = e)));\n            }\n        ;\n        ;\n            return ((c ? _.pseudoTranslate(d) : d));\n        };\n        a(_);\n    });\n});\nprovide(\"EventProvider\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.EventProvider\", {\n            events: null,\n            _provider: function() {\n                return ((this._eventProvider || (this._eventProvider = $(\"\\u003Cdiv/\\u003E\")))), this._eventProvider;\n            },\n            _createEvent: function(a) {\n                ((this.events || (this.events = {\n                }))), ((this.events[a] || (this.events[a] = new $.JSBNG__Event(a))));\n            },\n            trigger: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.trigger.apply(a, arguments);\n            },\n            bind: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.bind.apply(a, arguments);\n            },\n            JSBNG__one: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.JSBNG__one.apply(a, arguments);\n            },\n            unbind: function() {\n                var a = this._provider();\n                a.unbind.apply(a, arguments);\n            },\n            _signalProvider: function() {\n                return ((this._signalProviderObj || (this._signalProviderObj = {\n                    fired: {\n                    },\n                    queues: {\n                    }\n                }))), this._signalProviderObj;\n            },\n            signal: function(a) {\n                var b = this._signalProvider();\n                if (!b.fired[a]) {\n                    b.fired[a] = !0;\n                    var c = ((b.queues[a] || []));\n                    for (var d = 0; ((d < c.length)); d++) {\n                        c[d].call(null);\n                    ;\n                    };\n                ;\n                    delete b.queues[a];\n                }\n            ;\n            ;\n            },\n            waitForSignal: function(a, b) {\n                var c = this._signalProvider();\n                ((c.fired[a] ? b.call() : (((c.queues[a] || (c.queues[a] = []))), c.queues[a].push(b))));\n            }\n        }), a(twttr.EventProvider);\n    });\n});\nprovide(\"bluejs/init\", function(a) {\n    using(function() {\n        twttr.anywhere = ((twttr.anywhere || {\n        })), twttr.anywhere.api = ((twttr.anywhere.api || {\n        })), twttr.anywhere.remote = ((twttr.anywhere.remote || {\n        }));\n        var b = [\"models\",\"util\",\"proxies\",\"mixins\",];\n        for (var c = 0, d = b.length; ((c < d)); ++c) {\n            twttr.anywhere.api[b[c]] = {\n            };\n        ;\n        };\n    ;\n        twttr.anywhere.api.config = {\n            useLocalStorage: !1,\n            cacheObjects: !0,\n            includeEntities: !1\n        }, twttr.anywhere.api.updateConfig = function(a) {\n            twttr.aug(twttr.anywhere.api.config, a);\n        }, twttr.anywhere.api.initialize = function(a) {\n            this.updateConfig(a), twttr.anywhere.api.globalEvents = twttr.aug({\n            }, twttr.EventProvider);\n            for (var b in twttr.anywhere.api.models) {\n                if (((b == \"Base\"))) {\n                    continue;\n                }\n            ;\n            ;\n                (function() {\n                    twttr.anywhere.api.proxies[b] = twttr.anywhere.api.util.proxyModel(twttr.anywhere.api.models[b], function(a) {\n                        this.JSBNG__event = a;\n                    });\n                })();\n            };\n        ;\n            twttr.anywhere.api.util.BaseCollection._name = \"twttr.anywhere.proxies.Collection\", twttr.anywhere.api.proxies.Collection = twttr.anywhere.api.util.proxyModel(twttr.anywhere.api.util.BaseCollection, function(a) {\n                this.JSBNG__event = a;\n            }), delete twttr.anywhere.api.util.BaseCollection._name, ((((twttr.anywhere.api.config.useLocalStorage && window.JSBNG__localStorage)) ? twttr.anywhere.api.cache = new twttr.anywhere.api.util.LocalStorageCache : twttr.anywhere.api.cache = new twttr.anywhere.api.util.RequestCache));\n        }, a();\n    });\n});\nprovide(\"bluejs/config/endpoints\", function(a) {\n    using(function() {\n        var b = \"i\", c = \"1\", d = twttr.anywhere.api.endpoints = {\n            \"blocks/blocking/ids\": {\n                url: \"blocks/blocking/ids\",\n                type: \"GET\"\n            },\n            \":user/:list_id/subscribers/create\": {\n                url: \":user/:list_id/subscribers\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"promoted_content/:event_type/log\": {\n                url: \"promoted_content/:event_type/log\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/lists\": {\n                url: \":user/lists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/all\": {\n                url: \"lists/all\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/search\": {\n                url: \"geo/search\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"followers/ids\": {\n                url: \"followers/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/show\": {\n                url: \"users/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"urls/resolve\": {\n                url: \"urls/resolve\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/settings\": {\n                url: \"account/settings\",\n                type: \"GET\"\n            },\n            \"account/update_profile_background_image\": {\n                url: \"account/update_profile_background_image\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/recommendations/hide\": {\n                url: \"users/recommendations/hide\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/update\": {\n                url: \"friendships/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/lists/memberships\": {\n                url: \":user/lists/memberships\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/destroy\": {\n                url: \"lists/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"saved_searches/show/:id\": {\n                url: \"saved_searches/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/show\": {\n                url: \"friendships/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/statuses\": {\n                url: \"lists/statuses\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/friends\": {\n                url: \"statuses/friends\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/lookup\": {\n                url: \"users/lookup\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/show\": {\n                url: \"statuses/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/user_timeline\": {\n                url: \"statuses/user_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/profile_timeline\": {\n                url: \"statuses/profile_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/network_timeline\": {\n                url: \"statuses/network_timeline\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"statuses/media_timeline\": {\n                url: \"statuses/media_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/:id/retweeted_by/ids\": {\n                url: \"statuses/:id/retweeted_by/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/available\": {\n                url: \"trends/available\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:id/subscribers/destroy\": {\n                url: \":user/:id/subscribers\",\n                type: \"DELETE\",\n                optional_parameters: !0\n            },\n            \":user/:id/members/destroy\": {\n                url: \":user/:id/members\",\n                type: \"DELETE\",\n                optional_parameters: !0\n            },\n            \"lists/members/destroy\": {\n                url: \"lists/members/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/update_delivery_device\": {\n                url: \"account/update_delivery_device\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"direct_messages/new\": {\n                url: \"direct_messages/new\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/random\": {\n                url: \"users/suggestions/random\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/nearby_places\": {\n                url: \"geo/nearby_places\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/blocking\": {\n                url: \"blocks/blocking\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/accept\": {\n                url: \"friendships/accept\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update\": {\n                url: \"statuses/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update_with_media\": {\n                url: \"statuses/update_with_media\",\n                type: \"POST\",\n                host: twttr.domains.upload,\n                use_host_in_prod: !0,\n                optional_parameters: !0\n            },\n            \"saved_searches/create\": {\n                url: \"saved_searches/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/subscribers\": {\n                url: \":user/:list_id/subscribers\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweeted_to_me\": {\n                url: \"statuses/retweeted_to_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/subscribers/:id\": {\n                url: \":user/:list_id/subscribers/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweets/:id\": {\n                url: \"statuses/retweets/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/public_timeline\": {\n                url: \"statuses/public_timeline\",\n                type: \"GET\"\n            },\n            \"statuses/friends_timeline\": {\n                url: \"statuses/friends_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/weekly\": {\n                url: \"trends/weekly\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/update_profile_image\": {\n                url: \"account/update_profile_image\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/profile_image/:screen_name\": {\n                url: \"users/profile_image/:screen_name\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/suggestions\": {\n                url: \"users/suggestions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/cancel\": {\n                url: \"friendships/cancel\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/sample\": {\n                url: \"statuses/sample\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/update_profile\": {\n                url: \"account/update_profile\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"notifications/follow\": {\n                url: \"notifications/follow\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"geo/place\": {\n                url: \"geo/place\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"lists/show\": {\n                url: \"lists/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/followers\": {\n                url: \"statuses/followers\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/accept_all\": {\n                url: \"friendships/accept_all\",\n                type: \"POST\"\n            },\n            \"help/test\": {\n                url: \"help/test\",\n                type: \"GET\"\n            },\n            \":user/lists/subscriptions\": {\n                url: \":user/lists/subscriptions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"direct_messages/destroy\": {\n                url: \"direct_messages/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/home_timeline\": {\n                url: \"statuses/home_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members/:id\": {\n                url: \":user/:list_id/members/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            report_spam: {\n                url: \"report_spam\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"related_results/show/:id\": {\n                url: \"related_results/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/rate_limit_status\": {\n                url: \"account/rate_limit_status\",\n                type: \"GET\"\n            },\n            \"urls/shorten\": {\n                url: \"urls/shorten\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/reverse_geocode\": {\n                url: \"geo/reverse_geocode\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/daily\": {\n                url: \"trends/daily\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/verify_credentials\": {\n                url: \"account/verify_credentials\",\n                type: \"GET\"\n            },\n            \":user/lists/create\": {\n                url: \":user/lists\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/update_profile_colors\": {\n                url: \"account/update_profile_colors\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/:slug/members\": {\n                url: \"users/suggestions/:slug/members\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/similar_places\": {\n                url: \"geo/similar_places\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/create\": {\n                url: \"blocks/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members\": {\n                url: \":user/:list_id/members\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friends/ids\": {\n                url: \"friends/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/destroy/:id\": {\n                url: \"favorites/destroy/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"geo/id/:id\": {\n                url: \"geo/id/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweet\": {\n                url: \"statuses/retweet\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/:id\": {\n                url: \"favorites/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweeted_by_me\": {\n                url: \"statuses/retweeted_by_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members/create\": {\n                url: \":user/:list_id/members\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"lists/members/create\": {\n                url: \"lists/members/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/search\": {\n                url: \"users/search\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/typeahead_social\": {\n                url: \"search/typeahead\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"users/typeahead_global\": {\n                url: \"search/typeahead\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"statuses/filter\": {\n                url: \"statuses/filter\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/create\": {\n                url: \"friendships/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/create_all\": {\n                url: \"friendships/create_all\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/settings/create\": {\n                url: \"account/settings\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"trends/current\": {\n                url: \"trends/current\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/:slug\": {\n                url: \"users/suggestions/:slug\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/firehose\": {\n                url: \"statuses/firehose\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            saved_searches: {\n                url: \"saved_searches\",\n                type: \"GET\"\n            },\n            direct_messages: {\n                url: \"direct_messages\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/deny_all\": {\n                url: \"friendships/deny_all\",\n                type: \"POST\"\n            },\n            \"lists/update\": {\n                url: \"lists/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"blocks/destroy\": {\n                url: \"blocks/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/exists\": {\n                url: \"friendships/exists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/contributors\": {\n                url: \"users/contributors\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/mentions\": {\n                url: \"statuses/mentions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/create/:id\": {\n                url: \"favorites/create/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            trends: {\n                url: \"trends\",\n                type: \"GET\"\n            },\n            \"trends/:woeid\": {\n                url: \"trends/:woeid\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal_auth: !0\n            },\n            \"urls/shorten_multiple\": {\n                url: \"urls/shorten_multiple\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/destroy\": {\n                url: \"statuses/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/retweet/:id\": {\n                url: \"statuses/retweet/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"direct_messages/sent\": {\n                url: \"direct_messages/sent\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/exists\": {\n                url: \"blocks/exists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"saved_searches/destroy/:id\": {\n                url: \"saved_searches/destroy/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/retweets_of_me\": {\n                url: \"statuses/retweets_of_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/deny\": {\n                url: \"friendships/deny\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/destroy\": {\n                url: \"friendships/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/end_session\": {\n                url: \"account/end_session\",\n                type: \"POST\"\n            },\n            \"notifications/leave\": {\n                url: \"notifications/leave\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/:id/retweeted_by\": {\n                url: \"statuses/:id/retweeted_by\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/recommendations\": {\n                url: \"users/recommendations\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/view_possibly_sensitive\": {\n                url: \"account/view_possibly_sensitive\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_view_possibly_sensitive\": {\n                url: \"account/update_view_possibly_sensitive\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/personalization_settings\": {\n                url: \"account/personalization_settings\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_personalization_settings\": {\n                url: \"account/update_personalization_settings\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/has_dismissed_geo_promo\": {\n                url: \"account/has_dismissed_geo_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_has_dismissed_geo_promo\": {\n                url: \"account/update_has_dismissed_geo_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/geo_location\": {\n                url: \"account/geo_location\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/email_status\": {\n                url: \"account/email_status\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/send_recommendation_rating\": {\n                url: \"users/send_recommendation_rating\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/send_invites_by_email\": {\n                url: \"users/send_invites_by_email\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/following_followers_of\": {\n                url: \"users/following_followers_of\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/follows_in_common_with\": {\n                url: \"users/follows_in_common_with\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/update_discoverability\": {\n                url: \"users/update_discoverability\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/show_for_profile\": {\n                url: \"users/show_for_profile\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/services\": {\n                url: \"find_sources/contacts/services\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/matches\": {\n                url: \"find_sources/contacts/matches\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/others\": {\n                url: \"find_sources/contacts/others\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/follow_all\": {\n                url: \"find_sources/contacts/follow_all\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/add_to_list\": {\n                url: \"find_sources/contacts/add_to_list\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"promos/random_json_promo\": {\n                url: \"promos/random_json_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            search: {\n                url: \"phoenix_search\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"phoenix\"\n            },\n            \"i/search\": {\n                url: \"search\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"i/discovery\": {\n                url: \"discovery\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"api/related_results/show/:id\": {\n                url: \"api/related_results/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friendships/incoming\": {\n                url: \"friendships/incoming\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friend_requests/accept\": {\n                url: \"friend_requests/accept\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friend_requests/deny\": {\n                url: \"friend_requests/deny\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friendships/set_shares\": {\n                url: \"friendships/set_shares\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"bouncers/reset\": {\n                url: \"bouncers/reset\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/resend_confirmation_email\": {\n                url: \"account/resend_confirmation_email\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"download/apps\": {\n                url: \"download/apps\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"download/send_link\": {\n                url: \"download/send_link\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"devices/list\": {\n                url: \"devices/list\",\n                type: \"GET\",\n                internal: !0\n            },\n            \"devices/carriers\": {\n                url: \"devices/carriers\",\n                type: \"GET\",\n                internal: !0\n            },\n            \"devices/create\": {\n                url: \"devices/create\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"devices/destroy\": {\n                url: \"devices/destroy\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"statuses/flag_possibly_sensitive\": {\n                url: \"statuses/flag_possibly_sensitive\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update_possibly_sensitive\": {\n                url: \"statuses/update_possibly_sensitive\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"promoted_content/home_timeline\": {\n                url: \"promoted_content/home_timeline\",\n                type: \"GET\"\n            },\n            \"promoted_content/feedback\": {\n                url: \"promoted_content/feedback\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/oembed\": {\n                url: \"statuses/oembed\",\n                optional_parameters: !0\n            },\n            \"direct_messages/conversations\": {\n                url: \"direct_messages/conversations\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"direct_messages/conversation_with\": {\n                url: \"direct_messages/conversation_with\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"users/get_prompt\": {\n                url: \"users/get_prompt\",\n                type: \"GET\",\n                internal: !0,\n                optional_parameters: !0\n            },\n            \"users/dismiss_prompt\": {\n                url: \"users/dismiss_prompt\",\n                type: \"POST\",\n                internal: !0,\n                optional_parameters: !0\n            },\n            \"statuses/following_timeline\": {\n                url: \"statuses/following_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"search/facets\": {\n                url: \"search/facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"search/image_facets\": {\n                url: \"search/image_facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"search/video_facets\": {\n                url: \"search/video_facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"activity/activity_by_user\": {\n                url: \"activity/by_user\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"activity/activity_of_me\": {\n                url: \"activity/about_me\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"activity/activity_by_people_i_follow\": {\n                url: \"activity/by_friends\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"statuses/:id/activity\": {\n                url: \"statuses/:id/activity\",\n                optional_parameters: !1,\n                version: b\n            },\n            \"statuses/:id/activity/summary\": {\n                url: \"statuses/:id/activity/summary\",\n                optional_parameters: !1,\n                version: b\n            },\n            \"government_search/by_zip\": {\n                url: \"government_search/by_zip\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            }\n        };\n        a(d);\n    });\n});\nprovide(\"bluejs/util/request_helpers\", function(a) {\n    using(function() {\n        function b(a, b) {\n            return function(c, d, e) {\n                delete g[a];\n                if (((((!c || ((d === 0)))) || ((d >= 600))))) b({\n                    error: !0,\n                    JSBNG__status: 0,\n                    reason: \"No response or network disconnected.\"\n                });\n                 else {\n                    var f = e.getResponseHeader(\"X-Twitter-Identity\");\n                    ((f && (c._identity = f))), b(c);\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        function c(a, b) {\n            return function(c, d) {\n                function e(a) {\n                    try {\n                        return JSON.parse(a);\n                    } catch (b) {\n                        return {\n                        };\n                    };\n                ;\n                };\n            ;\n                delete g[a];\n                var f = \"An error occured\";\n                ((((c.JSBNG__status == 401)) ? f = \"Access denied\" : ((((c.JSBNG__status == 403)) && (f = \"Permission denied\"))))), b({\n                    error: !0,\n                    JSBNG__status: c.JSBNG__status,\n                    response: e(c.responseText),\n                    reason: f,\n                    xhr: c\n                });\n            };\n        };\n    ;\n        function d(a, b) {\n            var c = a.split(\"/\"), d = 0, e = $.map(c, function(a) {\n                return ((((a.indexOf(\":\") === 0)) ? b[d++] : a));\n            });\n            return e.join(\"/\");\n        };\n    ;\n        function e(a, b) {\n            if (b.headers) {\n                var c = b.headers;\n                b.headers = null, b.beforeSend = function(a) {\n                    for (var b in c) {\n                        a.setRequestHeader(b, c[b]);\n                    ;\n                    };\n                ;\n                };\n            }\n        ;\n        ;\n            var d = $.ajax(b);\n            g[a] = d;\n        };\n    ;\n        function f(a, b) {\n            var c, e, f = {\n                dataType: \"json\",\n                type: ((a.type || \"get\")),\n                url: \"\"\n            };\n            ((a.use_host_in_prod && (f.use_host_in_prod = !0))), f.type = f.type.toLowerCase(), ((a.domain ? f.url += a.domain : (f.url += \"/\", ((a.internal || (f.url += ((twttr.is.def(a.version) ? a.version : \"1\")), f.url += \"/\")))))), f.url += a.url, c = b.slice(0, ((a.url.split(\":\").length - 1))), ((((c.length > 0)) && (f.url = d(f.url, c)))), ((((a.mime_type !== \"\")) && (f.url += ((a.mime_type ? ((\".\" + a.mime_type)) : \".json\"))))), f.data = {\n            };\n            if (a.optional_parameters) {\n                e = b.slice(c.length);\n                if (((e.length > 1))) {\n                    throw new \"Optional parameter list is longer than expected\";\n                }\n            ;\n            ;\n                f.data = e[0];\n            }\n        ;\n        ;\n            if (((((f.type === \"delete\")) || ((f.type === \"put\"))))) {\n                f.data._method = a.type.toLowerCase(), f.type = \"post\";\n            }\n        ;\n        ;\n            ((a.headers && (f.headers = a.headers))), ((a.host && (f.host = a.host)));\n            if (((a.internal_auth || ((f.type !== \"get\"))))) {\n                f.data.post_authenticity_token = twttr.anywhere.api.config.postAuthenticityToken;\n            }\n        ;\n        ;\n            return f;\n        };\n    ;\n        var g = {\n        }, i = /localhost\\.twitter\\.com/, j = function() {\n            var a = 0, d, f;\n            return ((((window.JSBNG__XMLHttpRequest && ((((window.JSBNG__location.protocol !== \"file:\")) || !window.ActiveXObject)))) ? (d = function() {\n                return new twttr.anywhere.remote.server.contentWindow.JSBNG__XMLHttpRequest;\n            }, f = function(a) {\n                return function() {\n                    return new twttr.anywhere.api.util.RemoteRequest.hosts[a].contentWindow.JSBNG__XMLHttpRequest;\n                };\n            }) : (d = function() {\n                try {\n                    return new twttr.anywhere.remote.server.contentWindow.ActiveXObject(\"Microsoft.XMLHTTP\");\n                } catch (a) {\n                \n                };\n            ;\n            }, f = function(a) {\n                return function() {\n                    try {\n                        return new twttr.anywhere.api.util.RemoteRequest.hosts[a].contentWindow.ActiveXObject(\"Microsoft.XMLHTTP\");\n                    } catch (b) {\n                    \n                    };\n                ;\n                };\n            }))), function(g, j, k) {\n                var l = ++a;\n                return j.success = b(l, k), j.error = c(l, k), j.data = ((j.data || {\n                })), j.headers = ((j.headers || {\n                })), j.headers[\"X-PHX\"] = \"true\", ((((j.host && ((twttr.domains.local.match(i) || j.use_host_in_prod)))) ? (j.xhr = f(j.host), delete j.host, delete j.use_host_in_prod) : ((g || (j.xhr = d))))), e(l, j), l;\n            };\n        }();\n        ((window.isTestMode && (twttr.anywhere.api.buildRequestOptions = f))), twttr.anywhere.api.makeRequest = function(a, b, c) {\n            return j(a.internal, f(a, b), c);\n        }, twttr.anywhere.api.cancelApiRequest = function(a) {\n            var b = g[a];\n            ((b && b.abort()));\n        }, a({\n            makeRequest: twttr.anywhere.api.makeRequest,\n            cancelApiRequest: twttr.anywhere.api.cancelApiRequest\n        });\n    });\n});\nprovide(\"bluejs/util/local_storage_cache\", function(a) {\n    using(function() {\n        var b = {\n            \"users/show\": {\n            },\n            \"account/verify_credentials\": {\n            },\n            \"users/lookup\": {\n            }\n        }, c = 177443, d = twttr.klass(\"twttr.anywhere.api.util.LocalStorageCache\", function() {\n        \n        }).methods({\n            clear: function() {\n                for (var a in twttr.storage.getAll(/twitter_anywhere_cache_/)) {\n                    twttr.storage.expire(a);\n                ;\n                };\n            ;\n            },\n            put: function(a, d, e) {\n                if (((a in b))) {\n                    var f = this._createKey(a, d);\n                    return twttr.storage.setWithExpiry(f, JSON.stringify(e), c), !0;\n                }\n            ;\n            ;\n                return !1;\n            },\n            get: function(a, b) {\n                var c = this._createKey(a, b), d;\n                return (((d = twttr.storage.get(c)) ? JSON.parse(d) : null));\n            },\n            expire: function(a) {\n                for (var b in twttr.storage.getAll(/twitter_anywhere_cache_/)) {\n                    ((b.match(a) && twttr.storage.expire(b)));\n                ;\n                };\n            ;\n            },\n            writeThroughCallback: function(a, b, c) {\n                return twttr.bind(this, function(d) {\n                    this.put(a, b, d), c(d);\n                });\n            },\n            _createKey: function(a, b) {\n                return ((\"twitter_anywhere_cache_\" + JSON.stringify([a,b,])));\n            }\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/util/object_cache\", function(a) {\n    using(function() {\n        var b = twttr.klass(\"twttr.anywhere.api.util.ObjectCache\", function(a, b) {\n            this.store = {\n            }, this.size = 0, this.options = ((b || {\n            })), this.keys = ((this.options.keys || [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },{\n                JSBNG__name: \"id\",\n                type: \"string\"\n            },])), this.keyNames = {\n            };\n            for (var c = 0; ((c < this.keys.length)); c++) {\n                this.keyNames[this.keys[c].type] = this.keys[c].JSBNG__name;\n            ;\n            };\n        ;\n            this.shouldCacheAssociated = !!this.options.cacheAssociated, this.shouldExpireAssociated = !!this.options.expireAssociated, this.klass = a, this.constructor._instances.push(this), a._cache = this;\n        }).statics({\n            _capacity: 7000,\n            _instances: [],\n            _currentSize: 0,\n            _epoch: new JSBNG__Date,\n            _maxAge: 300000,\n            isAtCapacity: function() {\n                return ((this._currentSize === this._capacity));\n            },\n            eject: function() {\n                var a = this._instances[0];\n                for (var b = 1, c = this._instances.length; ((b < c)); ++b) {\n                    ((((this._instances[b].size > a.size)) && (a = this._instances[b])));\n                ;\n                };\n            ;\n                a.eject();\n            },\n            sweeper: function() {\n                var a;\n                for (var b = 0, c = this._instances.length; ((b < c)); ++b) {\n                    a = this._instances[b];\n                    for (var d in a) {\n                        ((((((a[d].createdAt - this._epoch)) > this._maxAge)) && a[d].expire()));\n                    ;\n                    };\n                ;\n                };\n            ;\n            },\n            flush: function() {\n                for (var a = 0, b = this._instances.length; ((a < b)); ++a) {\n                    this._instances[a].flush();\n                ;\n                };\n            ;\n            }\n        }).methods({\n            _persist: function(a, b) {\n                this.store[a] = {\n                    value: b.data(),\n                    accessCount: 1,\n                    lastAccess: new JSBNG__Date\n                }, this.size++, this.constructor._currentSize++;\n            },\n            _touch: function(a) {\n                var b = new JSBNG__Date;\n                this.store[a].accessCount++, this.store[a].createdAt = b, this.store[a].lastAccess = ((b - this.constructor._epoch));\n            },\n            _eject: function() {\n                this.size--, this.constructor._currentSize--;\n            },\n            eject: function() {\n                var a, b = ((new JSBNG__Date - this.constructor._epoch));\n                for (var c in this.store) {\n                    ((((this.store[c].lastAccess < b)) && (a = c, b = this.store[c].lastAccess)));\n                ;\n                };\n            ;\n                delete this.store[a], this._eject();\n            },\n            flush: function() {\n                this.constructor._currentSize -= this.size, this.store = {\n                }, this.size = 0;\n            },\n            get: function(a) {\n                var b = typeof a, c = this.keyNames[b];\n                ((((b === \"string\")) && (a = a.toLowerCase())));\n                var d = ((((c + \"_\")) + a));\n                return ((this.store[d] ? (this._touch(d), new this.klass(this.store[d].value)) : null));\n            },\n            getMulti: function(a) {\n                var b = [], c = [];\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    var f = this.get(a[d]);\n                    ((f ? b.push(f) : c.push(a[d])));\n                };\n            ;\n                return {\n                    hits: new twttr.anywhere.api.util.BaseCollection(b),\n                    misses: c\n                };\n            },\n            cache: function(a, b) {\n                b = ((b || {\n                }));\n                var c = this.shouldCacheAssociated;\n                ((twttr.is.def(b.shouldCacheAssociated) && (c = b.shouldCacheAssociated))), ((this.constructor.isAtCapacity() && this.constructor.eject()));\n                var d, e, f;\n                for (var g = 0, i = this.keys.length; ((g < i)); ++g) {\n                    f = this.keys[g].JSBNG__name, d = ((a[f] || \"\")), ((((this.keys[g].type === \"string\")) && (d = d.toLowerCase()))), e = ((((f + \"_\")) + d)), this._persist(e, a);\n                ;\n                };\n            ;\n                if (c) {\n                    var j = a.constructor._registry;\n                    if (j) {\n                        for (var k in j) {\n                            var l = a[k];\n                            ((l && this.cacheAssociated(l)));\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return a;\n            },\n            cacheAssociated: function(a) {\n                if (((((a instanceof twttr.anywhere.api.util.BaseCollection)) && a.length()))) {\n                    a = a.array;\n                    var b = a[0].constructor._cache;\n                    if (b) {\n                        for (var c = 0, d = a.length; ((c < d)); ++c) {\n                            b.cache(a[c]);\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var b = a.constructor._cache;\n                    ((b && b.cache(a)));\n                }\n            ;\n            ;\n            },\n            expire: function(a, b) {\n                b = ((b || {\n                }));\n                var c = this.shouldExpireAssociated;\n                ((twttr.is.def(b.shouldExpireAssociated) && (c = b.shouldExpireAssociated)));\n                var d, e;\n                for (var f = 0, g = this.keys.length; ((f < g)); ++f) {\n                    e = ((a[this.keys[f]] + \"\")), d = ((d || this.store[e])), delete this.store[e], this._eject();\n                ;\n                };\n            ;\n                if (d) {\n                    if (c) {\n                        var i = a.constructor._registry;\n                        if (i) {\n                            for (var j in i) {\n                                var k = a[j];\n                                ((k && this.expireAssociated(k)));\n                            };\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return !0;\n                }\n            ;\n            ;\n                return !1;\n            },\n            expireAssociated: function(a) {\n                if (((((a instanceof twttr.anywhere.api.util.BaseCollection)) && a.length()))) {\n                    a = a.array;\n                    var b = a[0].constructor._cache;\n                    if (b) {\n                        for (var c = 0, d = a.length; ((c < d)); ++c) {\n                            b.expire(a[c]);\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var b = a.constructor._cache;\n                    ((b && b.expire(a)));\n                }\n            ;\n            ;\n            }\n        });\n        twttr.augmentString(\"twttr.anywhere.api.util.expireObject\", function(a) {\n            this.constructor._cache.expire(this, a);\n        }), twttr.augmentString(\"twttr.anywhere.api.util.cacheObject\", function(a) {\n            this.constructor._cache.cache(this, a);\n        }), a(b);\n    });\n});\nprovide(\"bluejs/util/request_cache\", function(a) {\n    using(function() {\n        var b = {\n        }, c = twttr.klass(\"twttr.anywhere.api.util.RequestCache\", function() {\n            this.store = {\n            };\n        }).statics({\n            DEFAULT_TTL: 300000\n        }).methods({\n            clear: function() {\n                this.store = {\n                };\n            },\n            inject: function(a, b, c, d) {\n                var e = {\n                    response: c,\n                    timestamp: new JSBNG__Date\n                };\n                return ((d && (e.RTL = d))), this.store[twttr.anywhere.api.util._createRequestKey(a, b)] = e, !0;\n            },\n            put: function(a, c, d, e) {\n                return ((((a in b)) ? this.inject.apply(this, arguments) : !1));\n            },\n            get: function(a, b) {\n                var c = twttr.anywhere.api.util._createRequestKey(a, b), d, e = this.store[c];\n                if (e) {\n                    if (!((((((e.RTL !== undefined)) && ((e.RTL === 0)))) || ((((new JSBNG__Date - e.timestamp)) > this.constructor.DEFAULT_TTL))))) {\n                        return ((((e.RTL !== undefined)) && e.RTL--)), e.response;\n                    }\n                ;\n                ;\n                    delete this.store[c];\n                }\n            ;\n            ;\n                return null;\n            },\n            expire: function(a) {\n                for (var b in this.store) {\n                    ((b.match(a) && delete this.store[b]));\n                ;\n                };\n            ;\n            },\n            writeThroughCallback: function(a, b, c) {\n                return twttr.bind(this, function(d) {\n                    this.put(a, b, d), c(d);\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/util/helpers\", function(a) {\n    using(function() {\n        twttr.klass(\"twttr.anywhere.api.util.EventChain\", function() {\n        \n        }).methods(twttr.EventProvider);\n        var b = {\n            cast: !0,\n            cancel: !0,\n            success: !0,\n            complete: !0,\n            timeout: !0,\n            error: !0,\n            before: !0,\n            eventName: !0,\n            cacheOptions: !0\n        }, c = [\"phxcom\",];\n        twttr.augmentObject(twttr.anywhere.api.util, {\n            chain: new twttr.anywhere.api.util.EventChain,\n            noop: function() {\n            \n            },\n            defaultTrigger: \"current_user\",\n            camelize: function() {\n                var a = {\n                };\n                return function(b) {\n                    var c = a[b];\n                    return ((c || (c = b.replace(/_(.)/g, function(a, b) {\n                        return b.toUpperCase();\n                    }), a[b] = c))), c;\n                };\n            }(),\n            filterOptions: function(a, b) {\n                var d = {\n                }, e = a.concat(c);\n                for (var f = 0, g = e.length; ((f < g)); ++f) {\n                    var i = e[f];\n                    ((twttr.is.def(b[i]) && (d[i] = b[i])));\n                };\n            ;\n                return d;\n            },\n            underscore: function() {\n                var a = {\n                };\n                return function(b) {\n                    var c = a[b];\n                    return ((c || (c = b.replace(/([a-z])([A-Z])/g, function(a, b, c) {\n                        return ((((b + \"_\")) + c)).toLowerCase();\n                    }), a[b] = c))), c;\n                };\n            }(),\n            buildCollection: function(a, b) {\n                var c = new twttr.anywhere.api.util.BaseCollection;\n                for (var d = 0, e = b.length; ((d < e)); ++d) {\n                    c.push(new a(b[d]));\n                ;\n                };\n            ;\n                return c;\n            },\n            traverse: function(a, b) {\n                if (!b.length) {\n                    return a;\n                }\n            ;\n            ;\n                var c = b.shift();\n                if (((twttr.is.def(a[c]) && !twttr.is.nil(a[c])))) {\n                    return twttr.anywhere.api.util.traverse(a[c], b);\n                }\n            ;\n            ;\n                var d = twttr.anywhere.api.util.traverseCurrentTrends(a, c);\n                return ((d ? d : null));\n            },\n            traverseCurrentTrends: function(a, b) {\n                if (((b == \"current_trends\"))) {\n                    for (key in a) {\n                        if (a.hasOwnProperty(key)) {\n                            return a[key];\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return null;\n            },\n            cleanParams: function(a) {\n                var c = {\n                };\n                for (var d in a) {\n                    ((b[d] || (c[d] = a[d])));\n                ;\n                };\n            ;\n                return c;\n            },\n            optify: function(a) {\n                var b = {\n                    success: twttr.anywhere.api.util.noop,\n                    error: twttr.anywhere.api.util.noop,\n                    complete: twttr.anywhere.api.util.noop\n                };\n                return ((a ? ((twttr.is.fn(a) ? twttr.merge({\n                }, b, {\n                    success: a\n                }) : twttr.merge({\n                }, b, a))) : b));\n            },\n            useStringIdentifier: function(a, b) {\n                var c = ((b + \"_str\"));\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a[c] ? (a[b] = a[c].toString(), delete a[c]) : ((a[b] && (a[b] = a[b].toString())))));\n            },\n            normalizePromotedTweet: function(a) {\n                if (a.promoted_content) {\n                    var b = a.promoted_content;\n                    delete a.promoted_content, a = $.extend(a, b), a.socialContext = a.social_context, delete a.social_context;\n                }\n                 else if (((a.entities && a.entities.promoted_content))) {\n                    var b = a.entities.promoted_content;\n                    delete a.entities.promoted_content, a = $.extend(a, b);\n                }\n                \n            ;\n            ;\n                return a;\n            },\n            serializeArgs: function(a) {\n                var b = \"\";\n                for (var c = 0, d = a.length; ((c < d)); ++c) {\n                    var e = a[c], f = [];\n                    if (((typeof e == \"object\"))) {\n                        for (var g in e) {\n                            f.push(g);\n                        ;\n                        };\n                    ;\n                        f.sort();\n                        for (var i = 0, j = f.length; ((i < j)); ++i) {\n                            b += ((f[i] + e[f[i]]));\n                        ;\n                        };\n                    ;\n                    }\n                     else b += JSON.stringify(e);\n                ;\n                ;\n                };\n            ;\n                return b;\n            },\n            _createRequestKey: function(a, b) {\n                return JSON.stringify([a,twttr.anywhere.api.util.serializeArgs(b),]);\n            },\n            sanitize: function(a) {\n                if (!a) {\n                    return a;\n                }\n            ;\n            ;\n                var b = [\"\\u0000\",\"\\u200e\",\"\\u200f\",\"\\u2028\",\"\\u2029\",\"\\u202a\",\"\\u202b\",\"\\u202c\",\"\\u202d\",\"\\u202e\",\"\\ufffe\",\"\\ufeff\",\"\\uffff\",], c;\n                for (c = 0; ((c < b.length)); c++) {\n                    a = a.replace(new RegExp(b[c], \"g\"), \"\");\n                ;\n                };\n            ;\n                return a;\n            },\n            returnClassFromType: function(a) {\n                return ((twttr.is.array(a) ? [twttr.anywhere.api.models[a[0]],] : twttr.anywhere.api.models[a]));\n            },\n            genEventName: function() {\n                return ((((\"chain_\" + (new JSBNG__Date).getTime())) + ((Math.JSBNG__random() * 1000))));\n            },\n            proxyNameFromType: function(a) {\n                return ((((a === undefined)) ? null : ((((((a === null)) || twttr.is.array(a))) ? \"Collection\" : a))));\n            },\n            makeRemoteRequest: function(a, b, c, d) {\n                var e = this, f, g = b;\n                d = ((d || {\n                })), f = ((((typeof c == \"function\")) ? {\n                    success: c\n                } : c)), (new twttr.anywhere.api.util.RemoteRequest(twttr.merge({\n                    methodName: a,\n                    args: b,\n                    callbacks: f\n                }, d))).send();\n            },\n            callMethod: function(a) {\n                function b(b) {\n                    ((b.packed_response_type ? ((b.available_features && e.inject(\"account/available_features\", {\n                    }, b.available_features, 1))) : a.dataSource.shift()));\n                    var d = ((a.dataSource.length ? twttr.anywhere.api.util.traverse(b, a.dataSource) : b)), f = ((!twttr.is.def(d) || twttr.is.nil(d))), g;\n                    ((twttr.is.array(c) ? g = ((f ? new twttr.anywhere.api.util.BaseCollection : twttr.anywhere.api.util.buildCollection(c[0], d))) : ((f ? g = null : g = ((c ? new c(d) : d)))))), JSBNG__setTimeout(function() {\n                        a.options.success(g, b);\n                    }, 0);\n                };\n            ;\n                var c, d = twttr.anywhere.api.util.RemoteRequest.priorities.NORMAL, e = twttr.anywhere.api.cache, f = !0, g = {\n                };\n                ((a.options && (c = a.options.cast, delete a.options.cast, ((a.options.headers && (g = a.options.headers, delete a.options.headers))), ((a.options.priority && (d = a.options.priority, delete a.options.priority))), ((a.options.useRequestCache && (f = a.options.useRequestCache, delete a.options.useRequestCache)))))), c = ((c || a.cast));\n                var i = a.params[((a.params.length - 1))];\n                ((twttr.is.object(i) && (a.params[((a.params.length - 1))] = twttr.anywhere.api.util.cleanParams(i))));\n                var j;\n                if (((((e && f)) && (j = e.get(a.url, a.params))))) b(j);\n                 else {\n                    var k = {\n                        before: a.options.before,\n                        success: ((e ? e.writeThroughCallback(a.url, a.params, b) : b)),\n                        error: a.options.error,\n                        complete: a.options.complete,\n                        timeout: a.options.timeout,\n                        cancel: a.options.cancel\n                    };\n                    twttr.anywhere.api.util.makeRemoteRequest(a.url, a.params, k, {\n                        headers: g,\n                        priority: d\n                    });\n                }\n            ;\n            ;\n            },\n            chainableFn: function(a, b) {\n                function c(b, e) {\n                    ((((c._curry && ((b instanceof twttr.anywhere.api.util.BaseCollection)))) && ((((c._curry instanceof twttr.anywhere.api.util.BaseCollection)) ? b = b.concat(c._curry) : b.push(c._curry))))), a(b, {\n                        response: e\n                    }), twttr.anywhere.api.util.chain.trigger(d, [b,]);\n                };\n            ;\n                var d;\n                return ((b.eventName ? (d = b.eventName, delete b.eventName) : d = twttr.anywhere.api.util.genEventName())), c.JSBNG__event = d, c;\n            },\n            cacheFn: function(a, b) {\n                return function(c) {\n                    b = ((b || {\n                    }));\n                    var d;\n                    if (((c instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var e = c.toArray();\n                        for (var f = 0, g = e.length; ((f < g)); ++f) {\n                            ((((((twttr.is.object(e[f]) && e[f].constructor._isModel)) && e[f].constructor.isCacheable())) && (d = e[f].constructor._cache.get(e[f].toParam()), ((((b.skipOverwrite && d)) ? e[f] = d : e[f].cache(b))))));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((c instanceof twttr.anywhere.api.models.Base)) && c.constructor.isCacheable())) && (d = c.constructor._cache.get(c.toParam()), ((((b.skipOverwrite && d)) ? c = d : c.cache(b))))));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            expiryFn: function(a) {\n                return function(b) {\n                    if (((b instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var c = b.toArray();\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            ((((c[d].constructor._isModel && c[d].constructor.isCacheable())) && c[d].expire()));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((b instanceof twttr.anywhere.api.models.Base)) && b.constructor.isCacheable())) && b.expire()));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            writeThroughFn: function(a, b, c, d) {\n                var e = function(a, b) {\n                    var e;\n                    for (var f in b) {\n                        e = b[f], ((twttr.is.fn(e) && (e = e.apply(c, [a,].concat(d))))), a.sync(f, e);\n                    ;\n                    };\n                ;\n                };\n                return function(c) {\n                    if (((c instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var d = c.toArray();\n                        for (var f = 0, g = d.length; ((f < g)); ++f) {\n                            ((((d[f].constructor._isModel && d[f].constructor.isCacheable())) && e(d[f], b)));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((c instanceof twttr.anywhere.api.models.Base)) && c.constructor.isCacheable())) && e(c, b)));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            triggerFn: function(a, b, c) {\n                return function(d) {\n                    a.trigger(b, arguments), c.apply({\n                    }, arguments);\n                };\n            },\n            decorateCallbacks: function(a, b, c) {\n                var d, e = [\"success\",\"error\",\"complete\",\"before\",];\n                for (var f = 0, g = e.length; ((f < g)); ++f) {\n                    d = e[f], c.callbacks[d] = twttr.anywhere.api.util.triggerFn(a, ((((b + \"_\")) + d)), c.callbacks[d], c.args);\n                ;\n                };\n            ;\n            },\n            chainableMethod: function(a, b, c) {\n                ((twttr.is.fn(b) && (c = b, b = {\n                })));\n                var d = twttr.anywhere.api.util.proxyNameFromType(a), e = function() {\n                    var e = {\n                    }, f = ((((this instanceof twttr.anywhere.api.models.Base)) ? this.constructor : this)), g = Array.prototype.slice.call(arguments), i = g.pop();\n                    ((((((i !== undefined)) && ((i !== null)))) && ((((((twttr.is.array(i) || !twttr.is.object(i))) || ((((a === null)) && twttr.is.fn(i))))) ? g.push(i) : ((twttr.is.fn(i) ? e.success = i : e = i))))));\n                    var j = [].concat(((b.decorators || [])));\n                    e.success = ((e.success || twttr.anywhere.api.util.noop)), e.error = ((e.error || twttr.anywhere.api.util.noop)), e.before = ((e.before || twttr.anywhere.api.util.noop)), e.complete = ((e.complete || twttr.anywhere.api.util.noop)), ((b.writes ? (j.push({\n                        decorator: twttr.anywhere.api.util.writeThroughFn,\n                        args: [b.writes,this,g,]\n                    }), ((((!twttr.is.def(b.cache) || ((b.cache !== !1)))) && j.push({\n                        decorator: twttr.anywhere.api.util.cacheFn,\n                        args: [{\n                            skipOverwrite: !0\n                        },]\n                    })))) : (((((!twttr.is.def(b.cache) || ((b.cache !== !1)))) && j.push({\n                        decorator: twttr.anywhere.api.util.cacheFn,\n                        args: [e.cacheOptions,]\n                    }))), ((b.expire && j.push({\n                        decorator: twttr.anywhere.api.util.expiryFn,\n                        args: []\n                    }))))));\n                    var k, l;\n                    ((b.triggers && (l = ((twttr.is.fn(b.triggers) ? b.triggers(this) : b.triggers)), ((b.triggeredBy ? k = twttr.anywhere.api.models[b.triggeredBy] : k = f)), twttr.anywhere.api.util.decorateCallbacks(k, l, {\n                        callbacks: e,\n                        args: g\n                    })))), e = twttr.anywhere.api.util.optify(e), j.push({\n                        decorator: twttr.anywhere.api.util.chainableFn,\n                        args: [e,]\n                    }), e.cast = twttr.anywhere.api.util.returnClassFromType(a), g.push(e);\n                    var m = null;\n                    ((((((f._isModel && f.isCacheable())) && b.cacheLookup)) && (m = b.cacheLookup.apply(f, g))));\n                    if (((m && m.partialHit))) {\n                        for (var n = 0, o = j.length; ((n < o)); ++n) {\n                            e.success = j[n].decorator.apply(this, [e.success,].concat(j[n].args));\n                        ;\n                        };\n                    ;\n                        e.success._curry = m.curry, c.apply(this, m.args);\n                    }\n                     else if (m) e.success = twttr.anywhere.api.util.chainableFn(e.success, e), JSBNG__setTimeout(function() {\n                        e.success(m);\n                    }, 0);\n                     else {\n                        for (var n = 0, o = j.length; ((n < o)); ++n) {\n                            e.success = j[n].decorator.apply(this, [e.success,].concat(j[n].args));\n                        ;\n                        };\n                    ;\n                        m = c.apply(this, g);\n                    }\n                    \n                ;\n                ;\n                    return ((((((!e.eventName && d)) && ((this.constructor != twttr.anywhere.api.util.BaseCollection)))) ? new twttr.anywhere.api.proxies[d](e.success.JSBNG__event) : m));\n                };\n                return e.proxyName = d, e.returnType = a, e;\n            },\n            aliasMethod: function(a, b) {\n                var c = twttr.anywhere.api.util.proxyNameFromType(a), d = function() {\n                    return b.apply(this, arguments);\n                };\n                return d.proxyName = c, d;\n            },\n            proxyModel: function(a, b) {\n                var c = a._name.replace(\"models\", \"proxies\"), d = twttr.klass(c, b);\n                for (var e in a.prototype) {\n                    (function() {\n                        var b = e;\n                        d.prototype[b] = function() {\n                            var c = Array.prototype.slice.call(arguments), d = !!a.prototype[b].proxyName, e;\n                            if (d) {\n                                e = twttr.anywhere.api.util.genEventName();\n                                var f = c.pop(), g = {\n                                };\n                                ((((((f !== null)) && ((f !== undefined)))) && ((((((twttr.is.array(f) || !twttr.is.object(f))) || ((((a == twttr.anywhere.api.util.BaseCollection)) && twttr.is.fn(f))))) ? c.push(f) : g = f)))), g = twttr.anywhere.api.util.optify(g), g.eventName = e, c.push(g);\n                            }\n                        ;\n                        ;\n                            var i = this;\n                            twttr.anywhere.api.util.chain.JSBNG__one(this.JSBNG__event, function(d, e) {\n                                a.prototype[b].apply(e, c);\n                            });\n                            if (d) {\n                                return new twttr.anywhere.api.proxies[a.prototype[b].proxyName](e);\n                            }\n                        ;\n                        ;\n                        };\n                    })();\n                ;\n                };\n            ;\n                return d;\n            },\n            protoExtend: function(a) {\n                function b() {\n                \n                };\n            ;\n                return b.prototype = a, new b;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/util/model\", function(a) {\n    using(function() {\n        twttr.augmentObject(twttr.anywhere.api.util, {\n            model: function(a, b) {\n                function c(a) {\n                    return twttr.anywhere.api.util.underscore(a).toLowerCase();\n                };\n            ;\n                function d(a, b) {\n                    b = ((b || c(a))), ((e._registry || (e._registry = {\n                    }))), e._registry[b] = a;\n                };\n            ;\n                ((b || (b = function(a) {\n                    twttr.anywhere.api.models.Base.call(this, a);\n                })));\n                var e = twttr.klass(a, b).subclassOf(twttr.anywhere.api.models.Base).statics({\n                    _eventing: twttr.aug({\n                    }, twttr.EventProvider)\n                }).statics({\n                    _isModel: !0,\n                    _uniqueKey: \"id\",\n                    _extensionMethods: [],\n                    trigger: function() {\n                        this._eventing.trigger.apply(this._eventing, arguments);\n                    },\n                    _bindWrapper: function(a, b) {\n                        return function(c) {\n                            c.type = a, b.apply({\n                            }, arguments);\n                        };\n                    },\n                    _bind: function(a, b, c) {\n                        ((twttr.is.fn(c) && (c = {\n                            success: c\n                        })));\n                        var d = this, e = b.split(\".\"), f, g;\n                        f = e.shift(), e = e.join(\".\");\n                        for (var i in c) {\n                            (function() {\n                                var b = i;\n                                g = ((((f + \"_\")) + b)), ((((e !== \"\")) && (g += ((\".\" + e))))), a.call(d._eventing, g, d._bindWrapper(f, c[b]));\n                            })();\n                        ;\n                        };\n                    ;\n                    },\n                    bind: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._bind(this._eventing.bind, c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    JSBNG__one: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._bind(this._eventing.JSBNG__one, c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    unbind: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._unbind(c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    _unbind: function(a, b) {\n                        var c = [\"success\",\"error\",\"complete\",\"before\",];\n                        if (((a[0] == \".\"))) {\n                            this._eventing.unbind(a, b);\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = this, e = a.split(\".\"), f, g;\n                        f = e.shift(), e = e.join(\".\");\n                        for (var i = 0, j = c.length; ((i < j)); ++i) {\n                            (function() {\n                                var a = c[i];\n                                g = ((((f + \"_\")) + a)), ((((e !== \"\")) && (g += ((\".\" + e))))), d._eventing.unbind(g, b);\n                            })();\n                        ;\n                        };\n                    ;\n                    },\n                    identify: function(a) {\n                        var b = a;\n                        return ((((a instanceof this)) && (b = a[this._uniqueKey]))), b;\n                    },\n                    isCacheable: function() {\n                        return ((!!twttr.anywhere.api.config.cacheObjects && !!this._cache));\n                    }\n                }).methods({\n                    toParam: function() {\n                        return this.constructor.identify(this);\n                    },\n                    reload: twttr.anywhere.api.util.aliasMethod(a.split(\".\").pop(), function() {\n                        var a = [this.constructor.identify(this),].concat(Array.prototype.slice.apply(arguments));\n                        return this.constructor.JSBNG__find.apply(this.constructor, a);\n                    })\n                });\n                return e.hasMany = function(a, b) {\n                    return b = ((b || c(a))), ((e._registry || (e._registry = {\n                    }))), e._registry[b] = [a,], e;\n                }, e.belongsTo = function(a, b) {\n                    return d(a, b), e;\n                }, e.hasOne = function(a, b) {\n                    return d(a, b), e;\n                }, e.cache = function(a) {\n                    return new twttr.anywhere.api.util.ObjectCache(e, a), e.prototype.cache = twttr.anywhere.api.util.cacheObject, e.prototype.expire = twttr.anywhere.api.util.expireObject, e;\n                }, e.uniqueKey = function(a) {\n                    return e._uniqueKey = a, e;\n                }, e.extend = function(a) {\n                    return e._extensionMethods.push(a), e;\n                }, e;\n            }\n        }), a(twttr.anywhere.api.util.model);\n    });\n});\nprovide(\"bluejs/util/remote_request\", function(a) {\n    using(function() {\n        var b = /localhost\\.twitter\\.com/, c = twttr.klass(\"twttr.anywhere.api.util.RemoteRequest\", function(a) {\n            this.id = ++this.constructor.requestId, this.methodName = a.methodName, this.requestParameters = ((a.args || [])), ((this.constructor.piggybackWhitelist[this.methodName] ? this.signature = twttr.anywhere.api.util._createRequestKey(this.methodName, this.requestParameters) : this.signature = this.id)), this.priority = ((a.priority || this.constructor.priorities.NORMAL)), this.headers = ((a.headers || {\n            })), this.retryCount = 0, this.timeoutTimer = null, this.pendingRequestId = null;\n            var b = this, c = twttr.anywhere.api.util.noop;\n            this.requestCallbacks = {\n                before: ((a.callbacks.before || c)),\n                success: ((a.callbacks.success || c)),\n                error: ((a.callbacks.error || c)),\n                complete: ((a.callbacks.complete || c)),\n                timeout: ((a.callbacks.timeout || function(a) {\n                    a.wait();\n                })),\n                cancel: ((a.callbacks.cancel || c))\n            };\n            var d = this.requestCallbacks.error;\n            this.requestCallbacks.error = function(c) {\n                function e(b, c) {\n                    trackClient({\n                        page: \"api\",\n                        action: \"error\"\n                    }, {\n                        status_code: b,\n                        item_names: [((\"methodName=\" + a.methodName)),((\"args=\" + JSON.stringify(((a.args || []))))),((\"X-MID=\" + c.getResponseHeader(\"X-MID\"))),((\"X-Transaction=\" + c.getResponseHeader(\"X-Transaction\"))),((\"X-RateLimit-Remaining=\" + c.getResponseHeader(\"X-RateLimit-Remaining\"))),((\"X-RateLimit-Class=\" + c.getResponseHeader(\"X-RateLimit-Class\"))),]\n                    });\n                };\n            ;\n                if (((c.JSBNG__status === b.constructor.RATE_LIMIT_STATUS))) {\n                    var f = b.constructor.apiErrorCodeFromResponse(c);\n                    ((((f === b.constructor.RATE_LIMIT_API_CODE)) ? twttr.anywhere.api.globalEvents.trigger(\"rate_limited\") : ((((f == null)) && (twttr.anywhere.api.globalEvents.trigger(\"unknown_error\"), ((c.xhr && e(400, c.xhr))))))));\n                }\n            ;\n            ;\n                ((((((twttr.loggedIn && ((c.JSBNG__status == b.constructor.UNAUTHORIZED_STATUS)))) && ((c[\"response\"][\"error\"] == \"Could not authenticate you.\")))) && window.JSBNG__location.reload())), d.apply({\n                }, arguments), ((((((c.JSBNG__status === b.constructor.FORBIDDEN_STATUS)) && c.xhr)) && e(403, c.xhr)));\n            };\n            var e = this.constructor.timings[this.methodName];\n            if (((!twttr.is.def(e) || ((e.totalRequests > this.constructor.sampleWindow))))) {\n                this.constructor.timings[this.methodName] = {\n                    timeTotal: 0,\n                    totalRequests: 0\n                };\n            }\n        ;\n        ;\n            this.constructor.timings[this.methodName].totalRequests++;\n        }).statics({\n            RATE_LIMIT_STATUS: 400,\n            UNAUTHORIZED_STATUS: 401,\n            FORBIDDEN_STATUS: 403,\n            RATE_LIMIT_API_CODE: 88,\n            useDynamicBackoff: !1,\n            requestId: 1,\n            sampleWindow: 15,\n            maxRetries: 3,\n            maxProcessing: 3,\n            defaultRequestLatency: 5000,\n            latencySteps: [5000,10000,20000,],\n            priorities: {\n                IMMEDIATE: 4,\n                HIGH: 3,\n                NORMAL: 2,\n                LOW: 1\n            },\n            hosts: {\n            },\n            timings: {\n            },\n            processing: 0,\n            pipeline: [],\n            pending: {\n            },\n            piggybackWhitelist: {\n                \"activity/activity_by_people_i_follow\": !0\n            },\n            apiErrorCodeFromResponse: function(a) {\n                return ((((((((a.response && a.response.errors)) && a.response.errors.length)) && a.response.errors[0])) ? a.response.errors[0].code : null));\n            },\n            isReady: function(a) {\n                if (window.isTestMode) {\n                    throw new Error(((\"JS API methods must be stubbed when used in tests: \" + a.url)));\n                }\n            ;\n            ;\n                return twttr.is.def(twttr.anywhere.remote.server);\n            },\n            isBacklogged: function() {\n                return ((this.pipeline.length > 0));\n            },\n            isCapped: function() {\n                return !1;\n            },\n            isAvailable: function() {\n                return ((this.processing < this.maxProcessing));\n            },\n            isIdle: function() {\n                return ((this.processing === 0));\n            },\n            flush: function() {\n                if (!this.isBacklogged()) {\n                    return;\n                }\n            ;\n            ;\n                var a = ((this.maxProcessing - this.processing));\n                for (var b = 0, c = a; ((b < c)); ++b) {\n                    this.reschedule();\n                ;\n                };\n            ;\n            },\n            reschedule: function() {\n                if (!this.isBacklogged()) {\n                    return;\n                }\n            ;\n            ;\n                var a = 0, b = this.pipeline[a];\n                for (var c = 0, d = this.pipeline.length; ((c < d)); ++c) {\n                    ((((this.pipeline[c].request.priority > b.request.priority)) && (a = c, b = this.pipeline[c])));\n                ;\n                };\n            ;\n                this.pipeline.splice(a, 1), b.runner();\n            }\n        }).methods({\n            setStart: function(a) {\n                this.startedOn = a;\n            },\n            setEnd: function(a) {\n                this.endedOn = a, this.constructor.timings[this.methodName].timeTotal += this.latency();\n            },\n            latency: function() {\n                return ((this.endedOn - this.startedOn));\n            },\n            dynamicBackoff: function() {\n                var a = this.constructor.timings[this.methodName];\n                return ((((a.timeTotal !== 0)) ? Math.floor(((a.timeTotal / a.totalRequests))) : this.constructor.defaultRequestLatency));\n            },\n            incrementalBackoff: function() {\n                return this.constructor.latencySteps[this.retryCount];\n            },\n            _stop: function() {\n                this[((\"stopped_\" + this.retryCount))] = !0, delete this.constructor.pending[this.signature], ((this.pendingRequestId && twttr.anywhere.api.cancelApiRequest(this.pendingRequestId))), this._clearTimer();\n            },\n            _clearTimer: function() {\n                ((this.timeoutTimer && (JSBNG__clearTimeout(this.timeoutTimer), this.timeoutTimer = null)));\n            },\n            _startTimer: function(a) {\n                var b = this;\n                a = !!a;\n                var c = null;\n                ((a && (c = ((this.constructor.useDynamicBackoff ? this.dynamicBackoff : this.incrementalBackoff))))), this._clearTimer(), this.timeoutTimer = JSBNG__setTimeout(function() {\n                    var a = b.constructor.pending[b.signature];\n                    for (var c = 0, d = a.length; ((c < d)); ++c) {\n                        a[c].requestCallbacks.timeout(b);\n                    ;\n                    };\n                ;\n                }, ((a ? c.call(this) : this.constructor.defaultRequestLatency)));\n            },\n            cancel: function() {\n                var a = this.constructor.pending[this.signature];\n                if (((a.length > 1))) {\n                    for (var b = 0, c = a.length; ((b < c)); ++b) {\n                        ((((a[b].id === this.id)) && a.splice(b, 1)));\n                    ;\n                    };\n                }\n                 else {\n                    this._stop();\n                }\n            ;\n            ;\n                this.requestCallbacks.cancel(this);\n            },\n            retry: function() {\n                var a = this.constructor.pending[this.signature];\n                if (((a.length > 1))) {\n                    for (var b = 0, c = a.length; ((b < c)); ++b) {\n                        ((((a[b].id === this.id)) && a.splice(b, 1)));\n                    ;\n                    };\n                }\n                 else {\n                    this._stop();\n                }\n            ;\n            ;\n                this.retryCount++;\n                if (((this.retryCount > this.constructor.maxRetries))) {\n                    var d = {\n                        response: {\n                            error: \"Connection timeout\"\n                        }\n                    };\n                    this.requestCallbacks.error(d), this.requestCallbacks.complete(d);\n                    return;\n                }\n            ;\n            ;\n                this.signature = ((((this.signature + \"_\")) + this.retryCount)), this.send();\n            },\n            wait: function() {\n                this._startTimer();\n            },\n            request: function(a, b) {\n                if (((((!this.constructor.isReady(a) && !a.internal)) || this.constructor.isCapped()))) {\n                    this.constructor.pipeline.push({\n                        request: this,\n                        runner: b\n                    });\n                    return;\n                }\n            ;\n            ;\n                this._run(b);\n            },\n            _run: function(a) {\n                this.setStart(new JSBNG__Date), this._startTimer(), this.constructor.processing++, a.call(this);\n            },\n            responseHandler: function(a, b) {\n                var c = this;\n                return function(d) {\n                    c.constructor.processing--, ((((c.constructor.isAvailable() && c.constructor.isBacklogged())) && c.constructor.reschedule())), c.setEnd(new JSBNG__Date), ((c[((\"stopped_\" + a))] || b(d)));\n                };\n            },\n            _buildRequestCallback: function() {\n                var a = this, b = this.retryCount;\n                return this.responseHandler(b, function(b) {\n                    a._clearTimer();\n                    var c = a.constructor.pending[a.signature], d = ((((b && b.error)) ? \"error\" : \"success\"));\n                    for (var e = 0, f = c.length; ((e < f)); ++e) {\n                        c[e].requestCallbacks[d].apply({\n                        }, [b,a,]), c[e].requestCallbacks.complete.apply({\n                        }, [b,a,]);\n                    ;\n                    };\n                ;\n                    delete a.constructor.pending[a.signature];\n                });\n            },\n            send: function() {\n                function a() {\n                    var a = c._buildRequestCallback(), b = Array.prototype.slice.apply(c.requestParameters);\n                    c.requestCallbacks.before.apply({\n                    }, [c,]), c.pendingRequestId = twttr.anywhere.api.makeRequest(d, b, a);\n                };\n            ;\n                var c = this, d = twttr.anywhere.api.endpoints[this.methodName];\n                if (!d) {\n                    throw new Error(((((\"The endpoint, \" + this.methodName)) + \" is not a registered API method\")));\n                }\n            ;\n            ;\n                if (this.constructor.pending[this.signature]) {\n                    this.constructor.pending[this.signature].push(this), this.requestCallbacks.before.apply({\n                    }, [this,]);\n                    return;\n                }\n            ;\n            ;\n                this.constructor.pending[this.signature] = [this,], d = twttr.merge({\n                }, d, {\n                    headers: this.headers\n                }), ((((((((twttr.domains.local.match(b) || d.use_host_in_prod)) && d.host)) && !this.constructor.hosts[d.host])) ? (url = ((((((twttr.proto + \"://\")) + d.host)) + \"/receiver.html\")), twttr.createIframe(url, function() {\n                    c.constructor.hosts[d.host] = this, c.request(d, a);\n                })) : this.request(d, a)));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/util/base_collection\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = function(a) {\n            return b(null, function() {\n                var b = Array.prototype.slice.call(arguments, 0), c = b.pop(), d = a.apply(this, b);\n                return c.success(d), d;\n            });\n        }, d = twttr.klass(\"twttr.anywhere.api.util.BaseCollection\", function(a) {\n            this.array = ((a || []));\n        }).methods({\n            each: c(function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    a(this.array[b], b);\n                ;\n                };\n            ;\n                return this;\n            }),\n            sort: c(function() {\n                return this.array.sort.apply(this.array, arguments), this;\n            }),\n            isEmpty: function() {\n                return ((this.array.length === 0));\n            },\n            toArray: function() {\n                return this.array;\n            },\n            inject: function() {\n                return this.reduce.apply(this, arguments);\n            },\n            reduce: function(a, b) {\n                if (((arguments.length !== 2))) {\n                    throw \"Exception: Wrong number of arguments, 3 required\";\n                }\n            ;\n            ;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    a = b(a, this.array[c]);\n                ;\n                };\n            ;\n                return a;\n            },\n            join: function(a, b) {\n                ((twttr.is.fn(a) && (b = a, a = \"\")));\n                var c = this.array.join(a);\n                return ((b && b(c))), c;\n            },\n            concat: function(a) {\n                return ((((a instanceof this.constructor)) && (a = a.array))), new this.constructor(this.array.concat(a));\n            },\n            JSBNG__find: c(function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (a(this.array[b], b)) {\n                        return this.array[b];\n                    }\n                ;\n                ;\n                };\n            ;\n                return null;\n            }),\n            filter: c(function(a) {\n                var b = new this.constructor;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    ((a(this.array[c], c) && b.push(this.array[c])));\n                ;\n                };\n            ;\n                return b;\n            }),\n            some: function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (a.call(this.array, this.array[b], b, this.array)) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            every: function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (!a.call(this.array, this.array[b], b, this.array)) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            map: c(function(a) {\n                var b = new this.constructor;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    b.push(a(this.array[c], c));\n                ;\n                };\n            ;\n                return b;\n            }),\n            none: function(a) {\n                var b = this.any(a);\n                return !b;\n            },\n            length: function() {\n                return this.array.length;\n            },\n            get: c(function(a, b) {\n                var c = this.array[a];\n                return ((b && b(c))), c;\n            }),\n            push: function() {\n                return ((((arguments[0] instanceof this.constructor)) ? this.array.push.apply(this.array, arguments[0].array) : this.array.push.apply(this.array, arguments))), this;\n            },\n            pop: function(a, b) {\n                var c;\n                ((twttr.is.fn(a) && (b = a, a = undefined)));\n                if (a) {\n                    var d = ((this.array.length - a));\n                    c = new this.constructor(this.array.slice(d)), this.array = this.array.slice(0, d);\n                }\n                 else c = this.array.pop();\n            ;\n            ;\n                return ((b && b(c))), c;\n            },\n            shift: function() {\n                return this.array.shift();\n            },\n            unshift: function() {\n                return ((((arguments[0] instanceof this.constructor)) ? this.array.unshift.apply(this.array, arguments[0].array) : this.array.unshift.apply(this.array, arguments))), this;\n            },\n            first: c(function(a, b) {\n                ((a || (a = 1))), ((twttr.is.fn(a) && (b = a, a = 1)));\n                var c;\n                return ((((a == 1)) ? c = this.array[0] : c = new this.constructor(this.array.slice(0, a)))), ((b && b(c))), c;\n            }),\n            slice: function(a, b) {\n                var c = [a,];\n                ((((((b !== undefined)) && ((b !== null)))) && c.push(b)));\n                var d = this.array.slice.apply(this.array, c);\n                return new this.constructor(d);\n            },\n            reverse: c(function() {\n                return new this.constructor(this.array.reverse());\n            }),\n            last: c(function(a, b) {\n                ((a || (a = 1))), ((twttr.is.fn(a) && (b = a, a = 1)));\n                var c;\n                return ((((a == 1)) ? c = this.array[((this.array.length - 1))] : c = new this.constructor(this.array.slice(((this.array.length - a)))))), ((b && b(c))), c;\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/mixins/status_actions\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.augmentString(\"twttr.anywhere.api.mixins.StatusActions\", {\n            retweet: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.retweet(this, a);\n            }),\n            favorite: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.favorite(this, a);\n            }),\n            unfavorite: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.unfavorite(this, a);\n            }),\n            reply: c(\"Status\", function(a, b) {\n                return twttr.anywhere.api.models.Status.reply(this, a, b);\n            })\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.filterOptions, e = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.User\", function(a) {\n            return a.statics({\n                _bulkFollowing: 0,\n                startBulkFollowing: function() {\n                    this._bulkFollowing++;\n                },\n                stopBulkFollowing: function() {\n                    this._bulkFollowing--;\n                },\n                isBulkFollowing: function() {\n                    return ((this._bulkFollowing > 0));\n                },\n                findForProfile: b(\"User\", {\n                    cacheLookup: function(a, b) {\n                        var c = this._cache.get(a);\n                        if (c) {\n                            var d = {\n                                cursor: -1,\n                                count: 15,\n                                user_id: c.id\n                            };\n                            return (((cachedFriends = twttr.API._requestCache.get(\"statuses/friends\", [d,])) ? (twttr.API._requestCache.inject(\"statuses/friends\", [d,], cachedFriends, 1), c) : !1));\n                        }\n                    ;\n                    ;\n                        return !1;\n                    },\n                    decorators: [{\n                        decorator: function(a) {\n                            return function(b, c) {\n                                if (c.response.friends) {\n                                    var d = {\n                                        cursor: -1,\n                                        count: 15,\n                                        user_id: b.id\n                                    };\n                                    twttr.API._requestCache.inject(\"statuses/friends\", [d,], c.response.friends, 1);\n                                }\n                            ;\n                            ;\n                                if (c.response.recommendations) {\n                                    var e = {\n                                        limit: 4,\n                                        pc: !1,\n                                        user_id: b.id\n                                    };\n                                    twttr.API._requestCache.inject(\"users/recommendations\", [e,], c.response.recommendations, 1);\n                                }\n                            ;\n                            ;\n                                if (c.response.timeline) {\n                                    var f = {\n                                        include_entities: 1,\n                                        include_available_features: 1,\n                                        contributor_details: !0,\n                                        include_rts: !0,\n                                        user_id: b.id\n                                    };\n                                    ((twttr.decider.isAvailable(\"platform_enable_cards\") && (f.include_cards = 1))), twttr.API._requestCache.inject(\"statuses/user_timeline\", [f,], c.response.timeline, 1);\n                                }\n                            ;\n                            ;\n                                a.apply({\n                                }, arguments);\n                            };\n                        },\n                        args: []\n                    },]\n                }, function(a, b) {\n                    var d;\n                    ((twttr.is.string(a) ? d = {\n                        screen_name: a\n                    } : d = {\n                        user_id: a\n                    })), c({\n                        options: b,\n                        url: \"users/show_for_profile\",\n                        params: [d,],\n                        dataSource: [\"\",\"user\",]\n                    });\n                })\n            }), a.methods({\n                setWantRetweetsOn: b(\"User\", {\n                    expire: !0,\n                    triggers: \"does_want_retweets\",\n                    triggerTarget: function(a) {\n                        return \"current_user\";\n                    }\n                }, function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/update\",\n                        params: [twttr.merge(a, {\n                            user_id: this.id,\n                            retweets: \"1\"\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                }),\n                setWantRetweetsOff: b(\"User\", {\n                    expire: !0,\n                    triggers: \"doesnt_want_retweets\",\n                    triggerTarget: function(a) {\n                        return \"current_user\";\n                    }\n                }, function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/update\",\n                        params: [twttr.merge(a, {\n                            user_id: this.id,\n                            retweets: \"0\"\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a;\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/current_user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.filterOptions, e = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.CurrentUser\", function(a) {\n            return a.methods({\n                followingFollowersOf: b([\"User\",], function(a, b) {\n                    var d = {\n                        cursor: -1\n                    };\n                    ((twttr.is.string(a) ? d.screen_name = a : d.user_id = a)), c({\n                        options: b,\n                        url: \"users/following_followers_of\",\n                        params: [twttr.merge(d, b),],\n                        dataSource: [\"\",\"users\",]\n                    });\n                }),\n                followsInCommonWith: b([\"User\",], function(a, b) {\n                    var d = {\n                        cursor: -1\n                    };\n                    ((twttr.is.string(a) ? d.screen_name = a : d.user_id = a)), c({\n                        options: b,\n                        url: \"users/follows_in_common_with\",\n                        params: [twttr.merge(d, b),],\n                        dataSource: [\"\",\"users\",]\n                    });\n                }),\n                updateDiscoverability: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"users/update_discoverability\",\n                        params: [twttr.merge(a, {\n                            id: this.id\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                }),\n                viewPossiblySensitive: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/view_possibly_sensitive\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"view_possibly_sensitive\",]\n                    });\n                }),\n                updateViewPossiblySensitive: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_view_possibly_sensitive\",\n                        params: [{\n                            do_show: a\n                        },],\n                        dataSource: [\"\",\"view_possibly_sensitive\",]\n                    });\n                }),\n                personalizationSettings: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/personalization_settings\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                updatePersonalizationSettings: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_personalization_settings\",\n                        params: [{\n                            use_cookie_personalization: a.use_cookie_personalization,\n                            cookie_personalization_prompt_displayed: a.cookie_personalization_prompt_displayed\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                hasDismissedGeoPromo: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/has_dismissed_geo_promo\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"has_dismissed_geo_promo\",]\n                    });\n                }),\n                updateHasDismissedGeoPromo: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_has_dismissed_geo_promo\",\n                        params: [{\n                            has_dismissed_geo_promo: a\n                        },],\n                        dataSource: [\"\",\"has_dismissed_geo_promo\",]\n                    });\n                }),\n                emailStatus: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/email_status\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"email_status\",]\n                    });\n                }),\n                emailBounceReset: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"bouncers/reset\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                emailResendConfirmation: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/resend_confirmation_email\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                geoLocation: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/geo_location\",\n                        params: [a,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), twttr.augmentObject(a.prototype.friends, {\n                accept: b(\"User\", {\n                    triggers: \"acceptFollow\",\n                    triggeredBy: \"User\"\n                }, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/accept\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                acceptAll: b(\"User\", function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/accept_all\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                deny: b(\"User\", function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/deny\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                denyAll: b(\"User\", function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/deny_all\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                cancel: b(\"User\", {\n                    triggers: \"cancel_request\",\n                    triggeredBy: \"User\"\n                }, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/cancel\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                followAll: b(undefined, function(a, b) {\n                    b = ((b || {\n                    }));\n                    var d = this, e = [], f = [], g = b.stringifiedIds;\n                    for (var i = 0, j = a.length; ((i < j)); ++i) {\n                        ((((twttr.is.string(a[i]) && !g)) ? e.push(a[i]) : f.push(a[i])));\n                    ;\n                    };\n                ;\n                    twttr.API.User.findAll(a, {\n                        stringifiedIds: g,\n                        success: function(a) {\n                            var g = b.success;\n                            b.success = function(_, b) {\n                                var c = {\n                                };\n                                for (var e = 0; ((e < b.length)); ++e) {\n                                    var f = b[e];\n                                    c[f.id] = f;\n                                };\n                            ;\n                                a.each(function(a) {\n                                    var b = c[a.id], d = {\n                                        requestParameters: [{\n                                            user_id: a.id\n                                        },]\n                                    };\n                                    if (b.is_blocking) {\n                                        return;\n                                    }\n                                ;\n                                ;\n                                    ((b.is_protected_follow_request ? (twttr.API.User.trigger(\"follow_request_before\", d), twttr.API.User.trigger(\"follow_request_success\", a)) : (twttr.API.User.trigger(\"follow_before\", d), twttr.API.User.trigger(\"follow_success\", a))));\n                                }), ((g && g.apply(d, arguments)));\n                            }, c({\n                                options: b,\n                                url: \"friendships/create_all\",\n                                params: [{\n                                    user_id: f.join(\",\"),\n                                    screen_name: e.join(\",\")\n                                },],\n                                dataSource: [\"\",\"bulk_follow_results\",]\n                            });\n                        }\n                    });\n                })\n            }), a;\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/status\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.Status\", function(a) {\n            return a.belongsTo(\"Status\", \"retweetingStatus\"), a.extend(function() {\n                ((this.isPromoted() && twttr.anywhere.api.util.PromotedStore.putStatus(this)));\n            }), a.statics({\n                search: b([\"Status\",], function(a, b) {\n                    ((b.near && (b.near = encodeURIComponent(b.near)))), ((b.within && (b.within = encodeURIComponent(b.within)))), d({\n                        options: b,\n                        url: \"search\",\n                        params: [twttr.merge({\n                            q: a\n                        }, b),],\n                        dataSource: [\"\",\"statuses\",]\n                    });\n                }),\n                related: b([\"RelatedTweets\",], function(a, b) {\n                    var c = $.extend({\n                    }, b);\n                    d({\n                        options: b,\n                        url: \"related_results/show/:id\",\n                        params: [a,c,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a.methods({\n                related: c([\"RelatedTweets\",], function(a) {\n                    return twttr.anywhere.api.models.Status.related(this, a);\n                }),\n                isPromoted: function() {\n                    return !!this.impressionId;\n                },\n                logImpressionIfPromoted: function() {\n                    ((((this.isPromoted() && !this.loggedImpression)) && (twttr.API.util.PromotedContent.logImpression(this.impressionId), this.loggedImpression = !0)));\n                }\n            }), a;\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/rate_user_recommendation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.RateUserRecommendation\", function(a) {\n            return a.extend(function() {\n                ((!this.user.promotedContent || twttr.anywhere.api.util.PromotedStore.putUser(this.user)));\n            }), a.statics({\n                rate: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"users/send_recommendation_rating\",\n                        params: [a,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a;\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/base\", function(a) {\n    using(function() {\n        var b = 0, c = twttr.klass(\"twttr.anywhere.api.models.Base\", function(a) {\n            if (!a) {\n                return null;\n            }\n        ;\n        ;\n            if (((a.constructor.uber && ((a.constructor.uber.constructor == twttr.anywhere.api.models.Base))))) {\n                return a;\n            }\n        ;\n        ;\n            this.attributes = {\n            };\n            var c = this.constructor._registry;\n            for (var d in a) {\n                this.data(d, a[d]);\n                if (((d.indexOf(\"_\") !== 0))) {\n                    var e = twttr.anywhere.api.util.camelize(d);\n                    if (!this[e]) {\n                        var f = null, g = !1;\n                        if (((c && c[e]))) {\n                            var i = c[e];\n                            ((twttr.is.array(i) ? (i = i[0], ((twttr.is.fn(i) && (i = i(a))))) : ((twttr.is.fn(i) && (i = i(a)))))), ((i && (f = twttr.anywhere.api.models[i], g = twttr.is.array(c[e]))));\n                        }\n                    ;\n                    ;\n                        ((g ? this[e] = twttr.anywhere.api.util.buildCollection(f, this.data(d)) : ((f ? this[e] = new f(this.data(d)) : this[e] = this.data(d)))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            if (this.constructor._extensionMethods) {\n                var j = {\n                };\n                for (var k in this) {\n                    j[k] = !0;\n                ;\n                };\n            ;\n                for (var l = 0, m = this.constructor._extensionMethods.length; ((l < m)); ++l) {\n                    var n = this.constructor._extensionMethods[l];\n                    n.call(this, this);\n                };\n            ;\n                for (var k in this) {\n                    if (!twttr.is.def(j[k])) {\n                        var o = ((((this[k] && this[k].data)) && twttr.is.fn(this[k].data)));\n                        this.data(twttr.anywhere.api.util.underscore(k), ((o ? this[k].data() : this[k])));\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            this._objectId = ++b;\n        }).methods({\n            sync: function(a, b) {\n                var c = twttr.anywhere.api.util.underscore(a), d = twttr.anywhere.api.util.camelize(a);\n                return ((((b instanceof twttr.anywhere.api.models.Base)) ? this.attributes[c] = b.attributes : this.data(c, b))), this[d] = b, ((((this.constructor.isCacheable && this.constructor.isCacheable())) && this.cache())), b;\n            },\n            data: function(a, b) {\n                if (((((typeof a == \"string\")) && ((typeof b != \"undefined\"))))) {\n                    return this.attributes[a] = b, b;\n                }\n            ;\n            ;\n                if (((((typeof a == \"object\")) && ((typeof b == \"undefined\"))))) {\n                    return twttr.merge(this.attributes, a);\n                }\n            ;\n            ;\n                if (((((typeof a == \"string\")) && ((typeof b == \"undefined\"))))) {\n                    return this.attributes[a];\n                }\n            ;\n            ;\n                if (((((typeof a == \"undefined\")) && ((typeof b == \"undefined\"))))) {\n                    return this.attributes;\n                }\n            ;\n            ;\n            },\n            clone: function(a) {\n                var b = $.extend({\n                }, this);\n                b.attributes = $.extend({\n                }, this.attributes);\n                if (a) {\n                    for (var c in a) {\n                        b.sync(c, a[c]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return b;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.noop, g = twttr.anywhere.api.util.defaultTrigger, i = twttr.anywhere.api.models.Base, j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.User\", function(a) {\n            function b(a, b) {\n                return ((((a.length != 0)) && ((((b.length / a.length)) > 214823))));\n            };\n        ;\n            a.JSBNG__name = twttr.anywhere.api.util.sanitize(a.JSBNG__name);\n            if (((a.JSBNG__name && twttr.isRTL))) {\n                var c = a.JSBNG__name.match(twttr.constants.regexps.rtlChar);\n                if (((!c || !b(a.JSBNG__name, c)))) {\n                    a.JSBNG__name = ((((\"\\u202a\" + a.JSBNG__name)) + \"\\u202c\"));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            a.description = twttr.anywhere.api.util.sanitize(a.description), ((((((window.JSBNG__location.protocol === \"https:\")) && twttr.cdnBase)) && (((((a.profile_image_url && ((a.profile_image_url.indexOf(\"http:\") === 0)))) && (a.profile_image_url = twttr.assets.getPathFromAbsoluteURL(a.profile_image_url, {\n                isSSL: !0,\n                isVersioned: !1\n            })))), ((((a.profile_background_image_url && ((a.profile_background_image_url.indexOf(\"http:\") === 0)))) && (a.profile_background_image_url = twttr.assets.getPathFromAbsoluteURL(a.profile_background_image_url, {\n                isSSL: !0,\n                isVersioned: !1\n            }))))))), twttr.anywhere.api.models.Base.call(this, a);\n            var d = this;\n            this.lists = function() {\n                return twttr.anywhere.api.models.User.prototype.lists.apply(d, arguments);\n            }, this.lists.JSBNG__find = function() {\n                return twttr.anywhere.api.models.User.prototype.lists.JSBNG__find.apply(d, arguments);\n            };\n        }).uniqueKey(\"screenName\").cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },{\n                JSBNG__name: \"screenName\",\n                type: \"string\"\n            },]\n        }).hasOne(\"Status\").statics({\n            JSBNG__find: b(\"User\", {\n                cacheLookup: function(a, b) {\n                    var c = this._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                var c;\n                ((twttr.is.string(a) ? c = {\n                    screen_name: a\n                } : c = {\n                    user_id: a\n                })), d({\n                    options: b,\n                    url: \"users/show\",\n                    params: [c,],\n                    dataSource: [\"user\",]\n                });\n            }),\n            findAll: b([\"User\",], {\n                cacheLookup: function(a, b) {\n                    if (b.reload) {\n                        return delete b.reload, !1;\n                    }\n                ;\n                ;\n                    var c = this._cache.getMulti(a), d = c.hits;\n                    return ((c.misses.length ? ((d.isEmpty() ? !1 : {\n                        partialHit: !0,\n                        curry: d,\n                        args: [c.misses,b,]\n                    })) : d));\n                }\n            }, function(a, b) {\n                var c = [], e = [], f = ((b && b.stringifiedIds));\n                for (var g = 0, i = a.length; ((g < i)); ++g) {\n                    ((((twttr.is.string(a[g]) && !f)) ? c.push(a[g]) : e.push(a[g])));\n                ;\n                };\n            ;\n                d({\n                    options: b,\n                    url: \"users/lookup\",\n                    params: [{\n                        user_id: e.join(\",\"),\n                        screen_name: c.join(\",\")\n                    },],\n                    dataSource: [\"users\",]\n                });\n            }),\n            findAllCached: function(a) {\n                var b = this._cache.getMulti(a);\n                return b.hits;\n            },\n            current: b(\"CurrentUser\", function(a) {\n                d({\n                    options: a,\n                    url: \"account/verify_credentials\",\n                    params: [],\n                    dataSource: [\"user\",]\n                });\n            }),\n            typeaheadSocial: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/typeahead_social\",\n                    params: [twttr.merge(b, {\n                        prefetch: !0,\n                        result_type: \"users\"\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            typeaheadGlobal: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/typeahead_global\",\n                    params: [twttr.merge(b, {\n                        q: a\n                    }),],\n                    dataSource: [\"users\",]\n                });\n            }),\n            search: b([\"User\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/search\",\n                    params: [twttr.merge(b, {\n                        q: a\n                    }),],\n                    dataSource: [\"users\",]\n                });\n            }),\n            recommendedUsers: b([\"UserRecommendation\",], function(a) {\n                twttr.abdecider.choose(\"wtf_test_ranker_141\"), d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            recommendedUsers2: b([\"UserRecommendation\",], function(a) {\n                twttr.abdecider.choose(\"wtf_test_ranker_141\");\n                var b = {\n                    expanded_results_format: 1\n                };\n                (($.cookie(\"force_newt\") && (b.force_newt = !0))), (($.cookie(\"newt_ip\") && (b.ip = $.cookie(\"newt_ip\")))), d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [twttr.merge(b, a),],\n                    dataSource: [\"\",\"users\",]\n                });\n            })\n        }).methods({\n            bind: twttr.anywhere.api.util.bindMethod,\n            favorites: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"favorites/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            timeline: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/user_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            profileTimeline: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/profile_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            media: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/media_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            followingTweets: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/following_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            followers: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/followers\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            friends: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/friends\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            activity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_by_user\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            friendIds: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"friends/ids\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"ids\",]\n                });\n            }),\n            followerIds: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"followers/ids\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"ids\",]\n                });\n            }),\n            _isFollowing: function(a, b, c) {\n                twttr.anywhere.api.util.makeRemoteRequest(\"friendships/exists\", [{\n                    user_a: a,\n                    user_b: b\n                },], {\n                    success: c.success,\n                    error: c.error\n                });\n            },\n            isFollowing: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                this._isFollowing(this.id, c, b);\n            },\n            isFriend: function(a, b) {\n                this.isFollowing(a, b);\n            },\n            isFollowedBy: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                this._isFollowing(c, this.id, b);\n            },\n            isMutual: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a), d = b.success;\n                return b.success = function(a) {\n                    d(((a.following && a.followedBy)));\n                }, this.relationshipWith(a, b);\n            },\n            relationshipWith: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = this, d = twttr.anywhere.api.models.User.identify(a), e = {\n                    source_id: this.id\n                };\n                ((twttr.is.string(d) ? e.target_screen_name = d : e.target_id = d)), twttr.anywhere.api.util.makeRemoteRequest(\"friendships/show\", [e,], {\n                    success: function(a) {\n                        var d = {\n                            following: a.relationship.source.following,\n                            followedBy: a.relationship.source.followed_by\n                        };\n                        ((((c instanceof twttr.anywhere.api.models.CurrentUser)) && (d.notifications = a.relationship.source.notifications_enabled, d.blocking = a.relationship.source.blocking, d.wantRetweets = a.relationship.source.want_retweets, d.canDM = a.relationship.source.can_dm))), b.success(d);\n                    },\n                    error: b.error\n                });\n            },\n            block: b(\"User\", {\n                expire: !0,\n                triggers: \"block\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/create\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            unblock: b(\"User\", {\n                expire: !0,\n                triggers: \"unblock\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/destroy\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            similarUsers: b([\"UserRecommendation\",], function(a) {\n                d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            directMessage: c(\"DirectMessage\", function(a, b) {\n                return twttr.anywhere.api.models.DirectMessage.send(this.id, a, b);\n            }),\n            dm: c(\"DirectMessage\", function(a, b) {\n                return this.directMessage(a, b);\n            }),\n            follow: b(\"User\", {\n                expire: !0,\n                writes: {\n                    followRequestSent: function(a) {\n                        return ((a[\"protected\"] ? !0 : !1));\n                    },\n                    following: function(a) {\n                        return ((a[\"protected\"] ? !1 : !0));\n                    }\n                },\n                triggers: function(a) {\n                    return ((((a[\"protected\"] && !a.following)) ? \"follow_request\" : \"follow\"));\n                },\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/create\",\n                    params: [$.extend({\n                        user_id: this.id\n                    }, a),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            unfollow: b(\"User\", {\n                expire: !0,\n                writes: {\n                    followRequestSent: !1,\n                    following: !1\n                },\n                triggers: \"unfollow\",\n                triggerTarget: g\n            }, function(a) {\n                var b = ((((this[\"protected\"] && this.followRequestSent)) ? \"friendships/cancel\" : \"friendships/destroy\"));\n                d({\n                    options: a,\n                    url: b,\n                    params: [$.extend({\n                        user_id: this.id\n                    }, a),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            report: b(\"User\", {\n                expire: !0,\n                triggers: \"report\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"report_spam\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            setNotificationsOn: b(\"User\", {\n                expire: !0,\n                writes: {\n                    notifications: !0\n                },\n                triggers: \"subscribe\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/update\",\n                    params: [{\n                        user_id: this.id,\n                        device: \"1\"\n                    },],\n                    dataSource: [\"user\",]\n                });\n            }),\n            setNotificationsOff: b(\"User\", {\n                expire: !0,\n                writes: {\n                    notifications: !1\n                },\n                triggers: \"unsubscribe\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/update\",\n                    params: [{\n                        user_id: this.id,\n                        device: \"0\"\n                    },],\n                    dataSource: [\"user\",]\n                });\n            }),\n            lists: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            allLists: b([\"List\",], function(a) {\n                a.user_id = this.id, a.reverse = !0, d({\n                    options: a,\n                    url: \"lists/all\",\n                    params: [a,],\n                    dataSource: [\"lists_list\",]\n                });\n            }),\n            memberships: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists/memberships\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            subscriptions: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists/subscriptions\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            contributors: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"users/contributors\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.User);\n        twttr.klass(\"twttr.anywhere.api.models.CurrentUser\", function(a) {\n            twttr.anywhere.api.models.User.call(this, a);\n            var b = this;\n            this.lists.create = function() {\n                return b.constructor.prototype.lists.create.apply(b, arguments);\n            };\n        }).subclassOf(twttr.anywhere.api.models.User).statics({\n            _eventing: twttr.aug({\n            }, twttr.EventProvider)\n        }).methods({\n            recommendedUsers: c([\"UserRecommendation\",], function(a) {\n                return twttr.anywhere.api.models.User.recommendedUsers(a);\n            }),\n            recommendedUsers2: c([\"UserRecommendation\",], function(a) {\n                return twttr.anywhere.api.models.User.recommendedUsers2(a);\n            }),\n            inboundActivity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_of_me\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            networkActivity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_by_people_i_follow\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            directMessages: b([\"DirectMessage\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"direct_messages\",\n                    params: [a,],\n                    dataSource: [\"direct_messages\",]\n                });\n            }),\n            dms: c([\"DirectMessage\",], function(a) {\n                return this.directMessages(a);\n            }),\n            conversations: b([\"Conversation\",], function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/conversations\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            conversationWith: b([\"DirectMessage\",], function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/conversation_with\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            _isFollowing: function(a, b, c) {\n                twttr.anywhere.api.util.makeRemoteRequest(\"friendships/exists\", [{\n                    user_a: a,\n                    user_b: b\n                },], {\n                    success: c.success,\n                    error: c.error\n                });\n            },\n            isFollowing: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                ((((this.constructor.isCacheable() && !((a instanceof twttr.anywhere.api.models.User)))) && (a = this.constructor._cache.get(c))));\n                if (((a instanceof twttr.anywhere.api.models.User))) {\n                    b.success(a.following);\n                    return;\n                }\n            ;\n            ;\n                this._isFollowing(this.id, c, b);\n            },\n            receivedMessages: c([\"DirectMessage\",], function(a) {\n                return this.directMessages(a);\n            }),\n            sentMessages: b([\"DirectMessage\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"direct_messages/sent\",\n                    params: [a,],\n                    dataSource: [\"direct_messages\",]\n                });\n            }),\n            homeTimeline: b([\"Status\",], function(a) {\n                var b = \"statuses/home_timeline\";\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), ((a.withoutRetweets && (b = \"statuses/friends_timeline\"))), d({\n                    options: a,\n                    url: b,\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            mentions: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/mentions\",\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            _retweets: b([\"Status\",], function(a, b) {\n                d({\n                    options: b,\n                    url: a,\n                    params: [b,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            trendLocation: b([\"Location\",], function(a) {\n                d({\n                    options: a,\n                    url: \"account/settings\",\n                    params: [],\n                    dataSource: [\"\",\"trend_location\",]\n                });\n            }),\n            setTrendLocation: b([\"Location\",], {\n                triggers: \"changedLocation\"\n            }, function(a, b, c) {\n                var e = {\n                    trend_location_woeid: a\n                };\n                ((b && (e.personalized_trends = b))), d({\n                    options: c,\n                    url: \"account/settings/create\",\n                    params: [e,],\n                    dataSource: [\"\",\"trend_location\",]\n                });\n            }),\n            setGeoEnabled: function(a, b) {\n                var c = this, e = b.success;\n                b.success = function() {\n                    c.sync(\"geoEnabled\", a), ((e && e.apply(c, arguments)));\n                }, d({\n                    options: b,\n                    url: \"account/settings/create\",\n                    params: [{\n                        geo_enabled: a\n                    },],\n                    dataSource: [\"\",\"geo_enabled\",]\n                });\n            },\n            setLanguage: b([\"Language\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"account/settings/create\",\n                    params: [{\n                        lang: a\n                    },],\n                    dataSource: []\n                });\n            }),\n            retweeting: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweeted_by_me\", a);\n            }),\n            retweets: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweeted_to_me\", a);\n            }),\n            retweeted: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweets_of_me\", a);\n            }),\n            blocks: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/blocking\",\n                    params: [a,],\n                    dataSource: [\"users\",]\n                });\n            }),\n            lists: c([\"List\",], function(a) {\n                return this.constructor.uber.lists.call(this, a);\n            }),\n            friends: c([\"User\",], function(a) {\n                return this.constructor.uber.friends.call(this, a);\n            }),\n            isBlocking: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                twttr.anywhere.api.util.makeRemoteRequest(\"blocks/exists\", [{\n                    user_id: c\n                },], {\n                    success: function(a) {\n                        b.success(((a.user ? !0 : !1)));\n                    },\n                    error: function(a) {\n                        ((((a.JSBNG__status == 404)) ? b.success(!1) : b.error(a)));\n                    }\n                });\n            },\n            update: b(\"User\", {\n                expire: !0,\n                triggers: \"update\",\n                triggeredBy: \"User\"\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"account/update_profile\",\n                    params: [a,],\n                    dataSource: [\"user\",]\n                });\n            }),\n            profileImage: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/profile_image/:screen_name\",\n                    params: [a,twttr.merge({\n                        redirect: !1\n                    }, b),],\n                    dataSource: [\"\",]\n                });\n            }),\n            savedSearches: b([\"SavedSearch\",], function(a) {\n                d({\n                    options: a,\n                    url: \"saved_searches\",\n                    params: [],\n                    dataSource: [\"saved_searches\",]\n                });\n            }),\n            searches: c([\"SavedSearch\",], function(a) {\n                return this.savedSearches(a);\n            }),\n            logout: function(a) {\n                parent.twttr.anywhere.signOut();\n            }\n        }), twttr.augmentObject(twttr.anywhere.api.models.User.prototype.lists, {\n            JSBNG__find: b(\"List\", {\n                cacheLookup: function(a, b) {\n                    var c = twttr.API.List._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                b = twttr.anywhere.api.util.optify(b), ((twttr.is.string(a) ? b.slug = a : b.list_id = a)), d({\n                    options: b,\n                    url: \"lists/show\",\n                    params: [twttr.merge({\n                        owner_id: this.id\n                    }, b),],\n                    dataSource: [\"list\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.lists, {\n            create: b(\"List\", {\n                triggers: \"create\",\n                triggeredBy: \"List\"\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \":user/lists/create\",\n                    params: [this.id,twttr.merge(b, {\n                        JSBNG__name: a,\n                        send_error_codes: !0\n                    }),],\n                    dataSource: [\"list\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.savedSearches, {\n            JSBNG__find: b(\"SavedSearch\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"saved_searches/show/:id\",\n                    params: [a,b,],\n                    dataSource: [\"saved_search\",]\n                });\n            }),\n            create: b(\"SavedSearch\", {\n                triggers: \"create\",\n                triggeredBy: \"SavedSearch\"\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"saved_searches/create\",\n                    params: [{\n                        query: a\n                    },],\n                    dataSource: [\"saved_search\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.friends, {\n            pending: b(undefined, function(a) {\n                var b = e([\"cursor\",], a);\n                d({\n                    options: a,\n                    url: \"friendships/incoming\",\n                    params: [b,],\n                    dataSource: [\"\",\"ids\",]\n                });\n            })\n        }), twttr.anywhere.api.models.CurrentUser.prototype._name = function() {\n            return \"current_user\";\n        }, twttr.anywhere.api.models.CurrentUser.identify = twttr.anywhere.api.models.User.identify, twttr.anywhere.api.models.CurrentUser._registry = twttr.anywhere.api.models.User._registry, twttr.anywhere.api.models.CurrentUser._extensionMethods = twttr.anywhere.api.models.User._extensionMethods, twttr.anywhere.api.models.CurrentUser.isCacheable = twttr.anywhere.api.models.User.isCacheable, ((twttr.anywhere.api.models.CurrentUser.isCacheable() && (twttr.anywhere.api.models.CurrentUser._cache = twttr.anywhere.api.models.User._cache)));\n        var k = [\"trigger\",\"bind\",\"_bind\",\"unbind\",\"_unbind\",\"JSBNG__one\",\"_bindWrapper\",];\n        for (var l = 0, m = k.length; ((l < m)); ++l) {\n            twttr.anywhere.api.models.CurrentUser[k[l]] = twttr.anywhere.api.models.User[k[l]];\n        ;\n        };\n    ;\n        var n = [\"block\",\"unblock\",\"report\",\"follow\",\"unfollow\",\"setNotificationsOn\",\"setNotificationsOff\",];\n        for (var l = 0, m = n.length; ((l < m)); ++l) {\n            twttr.anywhere.api.models.CurrentUser.prototype[n[l]] = f;\n        ;\n        };\n    ;\n        twttr.anywhere.api.models.CurrentUser.mixin(twttr.anywhere.api.mixins.phoenix.CurrentUser), a(j);\n    });\n});\nprovide(\"bluejs/models/direct_message\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.DirectMessage\", function(a) {\n            ((a && twttr.anywhere.api.util.useStringIdentifier(a, \"id\"))), this.constructor.uberclass.call(this, a);\n        }).belongsTo(\"User\", \"sender\").belongsTo(\"User\", \"recipient\").statics({\n            send: b(\"DirectMessage\", {\n                triggers: \"send\",\n                triggerSource: e,\n                triggerTarget: function(a) {\n                    return a.recipient;\n                }\n            }, function(a, b, c) {\n                d({\n                    options: c,\n                    url: \"direct_messages/new\",\n                    params: [{\n                        user: twttr.anywhere.api.models.User.identify(a),\n                        text: b\n                    },],\n                    dataSource: [\"direct_message\",]\n                });\n            })\n        }).methods({\n            destroy: b(\"DirectMessage\", {\n                triggers: \"delete\",\n                triggerTarget: e\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/destroy\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"direct_message\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/saved_search\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SavedSearch\").methods({\n            destroy: b(\"SavedSearch\", {\n                triggers: \"delete\",\n                triggerTarget: e\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"saved_searches/destroy/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"saved_search\",]\n                });\n            }),\n            results: b([\"SearchResult\",], function(a) {\n                a.q = this.query, d({\n                    options: a,\n                    url: \"search\",\n                    params: [a,],\n                    dataSource: [\"\",\"results\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/list\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.defaultTrigger, g = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.List\").cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },],\n            shouldCacheAssociated: !1\n        }).belongsTo(\"User\").methods({\n            subscribe: b(\"List\", {\n                expire: !0,\n                triggers: \"follow\",\n                triggerTarget: f,\n                writes: {\n                    subscriberCount: function() {\n                        return ((this.subscriberCount + 1));\n                    }\n                }\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/subscribers/create\",\n                    params: [this.user.id,this.id,{\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            follow: c(\"List\", function(a) {\n                return this.subscribe(a);\n            }),\n            unsubscribe: b(\"List\", {\n                expire: !0,\n                triggers: \"unfollow\",\n                triggerTarget: f,\n                writes: {\n                    subscriberCount: function() {\n                        return ((this.subscriberCount - 1));\n                    }\n                }\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \":user/:id/subscribers/destroy\",\n                    params: [this.user.id,this.id,{\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            unfollow: c(\"List\", function(a) {\n                return this.unsubscribe(a);\n            }),\n            add: b(\"List\", {\n                expire: !0,\n                triggers: \"add\",\n                triggerTarget: f,\n                writes: {\n                    memberCount: function() {\n                        return this.memberCount;\n                    }\n                }\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"lists/members/create\",\n                    params: [{\n                        list_id: this.id,\n                        user_id: a.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            remove: b(\"List\", {\n                expire: !0,\n                triggers: \"remove\",\n                triggerTarget: f,\n                writes: {\n                    memberCount: function() {\n                        return ((this.memberCount - 1));\n                    }\n                }\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"lists/members/destroy\",\n                    params: [{\n                        list_id: this.id,\n                        user_id: a.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            owner: function() {\n                return this.user;\n            },\n            isMember: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = b.error;\n                b.error = function(a) {\n                    ((((((a.JSBNG__status === 404)) && a.reason.match(\"not a member\"))) ? b.success(!1) : ((c && c(a)))));\n                };\n                var e = b.success;\n                b.success = function(a) {\n                    ((a.screenName ? e(!0) : e(!1)));\n                }, d({\n                    options: b,\n                    url: \":user/:list_id/members/:id\",\n                    params: [this.user.id,this.id,twttr.anywhere.api.models.User.identify(a),{\n                    },],\n                    cast: twttr.anywhere.api.models.User,\n                    dataSource: [\"user\",]\n                });\n            },\n            isSubscriber: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = b.error;\n                b.error = function(a) {\n                    ((((((a.JSBNG__status === 404)) && a.reason.match(\"not a subscriber\"))) ? b.success(!1) : ((c && c(a)))));\n                };\n                var e = b.success;\n                b.success = function(a) {\n                    ((a.screenName ? e(!0) : e(!1)));\n                }, d({\n                    options: b,\n                    url: \":user/:list_id/subscribers/:id\",\n                    params: [this.user.id,this.id,twttr.anywhere.api.models.User.identify(a),{\n                    },],\n                    cast: twttr.anywhere.api.models.User,\n                    dataSource: [\"user\",]\n                });\n            },\n            destroy: b(\"List\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"delete\",\n                triggerTarget: f\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"lists/destroy\",\n                    params: [{\n                        list_id: this.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            update: b(\"List\", {\n                expire: !0,\n                triggers: \"update\",\n                triggerTarget: f\n            }, function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                var b = e([\"JSBNG__name\",\"description\",\"mode\",], a);\n                d({\n                    options: a,\n                    url: \"lists/update\",\n                    params: [twttr.merge({\n                        list_id: this.id,\n                        send_error_codes: !0\n                    }, b),],\n                    dataSource: [\"list\",]\n                });\n            }),\n            statuses: b([\"Status\",], function(a) {\n                a = twttr.anywhere.api.util.optify(a), ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"lists/statuses\",\n                    params: [twttr.merge({\n                        list_id: this.id\n                    }, a),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            subscribers: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/subscribers\",\n                    params: [this.user.id,this.id,a,],\n                    dataSource: [\"users_list\",\"users\",]\n                });\n            }),\n            followers: c([\"User\",], function(a) {\n                return this.subscribers(a);\n            }),\n            members: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/members\",\n                    params: [this.user.id,this.id,a,],\n                    dataSource: [\"users_list\",\"users\",]\n                });\n            }),\n            following: c([\"User\",], function(a) {\n                return this.members(a);\n            })\n        });\n        a(g);\n    });\n});\nprovide(\"bluejs/models/location\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.cache, g = twttr.anywhere.api.util.noop, i = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Location\").uniqueKey(\"woeid\").statics({\n            trends: b([\"Trend\",], function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"trends/:woeid\",\n                    params: [c,b,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).methods({\n            trends: c([\"Trend\",], function(a) {\n                return this.constructor.trends(this.woeid, a);\n            })\n        });\n        a(i);\n    });\n});\nprovide(\"bluejs/models/trend\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.cache, g = twttr.anywhere.api.util.noop, i = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Trend\").uniqueKey(\"query\").statics({\n            locations: b([\"Location\",], function(a) {\n                var b = e([\"lat\",\"long\",\"lang\",], a);\n                d({\n                    options: a,\n                    url: \"trends/available\",\n                    params: [b,],\n                    dataSource: [\"\",]\n                });\n            }),\n            current: b([\"Trend\",], function(a) {\n                d({\n                    options: a,\n                    url: \"trends/current\",\n                    params: [a,],\n                    dataSource: [\"\",\"trends\",\"current_trends\",]\n                });\n            })\n        });\n        a(i);\n    });\n});\nprovide(\"bluejs/models/status\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.filterOptions, g = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Status\", function(a) {\n            ((a && (a = twttr.anywhere.api.util.normalizePromotedTweet(a), twttr.anywhere.api.util.useStringIdentifier(a, \"id\"), twttr.anywhere.api.util.useStringIdentifier(a, \"in_reply_to_status_id\"), twttr.anywhere.api.util.useStringIdentifier(a.current_user_retweet, \"id\"), a.text = twttr.anywhere.api.util.sanitize(a.text)))), this.constructor.uberclass.call(this, a);\n        }).cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"string\"\n            },],\n            cacheAssociated: !0\n        }).belongsTo(\"User\").belongsTo(\"Status\", \"retweetedStatus\").hasOne(\"Place\").extend(function() {\n            this.isRetweet = !!this.retweetedStatus;\n        }).statics({\n            JSBNG__find: b(\"Status\", {\n                cacheLookup: function(a, b) {\n                    var c = this._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                var c = f([\"trim_user\",\"include_entities\",\"contributor_details\",\"include_cards\",], b);\n                ((((twttr.decider.isAvailable(\"platform_enable_cards\") && !twttr.is.def(c.include_cards))) && (c.include_cards = 1))), ((twttr.is.def(c.include_entities) || (c.include_entities = twttr.anywhere.api.config.includeEntities))), ((twttr.is.def(c.contributor_details) || (c.contributor_details = !0))), ((twttr.is.def(c.include_entities) || (c.include_entities = 1))), d({\n                    options: b,\n                    url: \"statuses/show\",\n                    params: [twttr.merge(c, {\n                        id: a\n                    }),],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            unretweet: b(\"Status\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"unretweet\",\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a), e = b.success;\n                b.success = function(a) {\n                    a.expire(), e.apply(a, arguments);\n                }, d({\n                    options: b,\n                    url: \"statuses/destroy\",\n                    params: [{\n                        id: c\n                    },],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            update: b(\"Status\", {\n                triggers: \"update\",\n                triggerTarget: e\n            }, function(a, b) {\n                b.include_entities = !0, ((twttr.decider.isAvailable(\"platform_enable_cards\") && (b.include_cards = 1))), b.JSBNG__status = a, d({\n                    options: b,\n                    url: \"statuses/update\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            updateWithMedia: b(\"Status\", {\n                triggers: \"update_with_media\",\n                triggerTarget: e\n            }, function(a, b) {\n                b.include_entities = !0, ((twttr.decider.isAvailable(\"platform_enable_cards\") && (b.include_cards = 1))), b.JSBNG__status = a, d({\n                    options: b,\n                    url: \"statuses/update_with_media\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            publicTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/public_timeline\",\n                    params: [],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            networkTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/network_timeline\",\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            promotedHomeTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"promoted_content/home_timeline\",\n                    params: [],\n                    dataSource: [\"\",\"promoted_tweets\",]\n                });\n            }),\n            retweet: b(\"Status\", {\n                triggers: \"retweet\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"statuses/retweet/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            favorite: b(\"Status\", {\n                triggers: \"favorite\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"favorites/create/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            unfavorite: b(\"Status\", {\n                triggers: \"unfavorite\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"favorites/destroy/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            reply: c(\"Status\", function(a, b, c) {\n                var d = this.identify(a);\n                return c = twttr.merge(twttr.anywhere.api.util.optify(c), {\n                    in_reply_to_status_id: d\n                }), this.update(b, c);\n            }),\n            search: b([\"SearchResult\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"search\",\n                    params: [twttr.merge({\n                        q: a\n                    }, b),],\n                    dataSource: [\"\",\"results\",]\n                });\n            })\n        }).methods(twttr.anywhere.api.mixins.StatusActions).methods({\n            bind: twttr.anywhere.api.util.bindMethod,\n            activity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/activity\",\n                    params: [this.id,],\n                    dataSource: [\"\",]\n                });\n            }),\n            summary: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/activity/summary\",\n                    params: [this.id,],\n                    dataSource: [\"\",]\n                });\n            }),\n            destroy: b(\"Status\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"delete\",\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a) {\n                var b = this, c = a.success;\n                a.success = function() {\n                    b.expire(), c.apply(b, arguments);\n                }, d({\n                    options: a,\n                    url: \"statuses/destroy\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            retweets: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/retweets/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            retweeters: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/retweeted_by\",\n                    params: [this.id,a,],\n                    dataSource: [\"users\",]\n                });\n            }),\n            contributor: c([\"User\",], function(a) {\n                var b = this.data(\"contributors\");\n                if (((((b && twttr.is.array(b))) && ((b.length === 1))))) {\n                    return twttr.anywhere.api.models.User.JSBNG__find(this.data(\"contributors\")[0], a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            inReplyToUser: c(\"User\", function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                if (this.inReplyToUserId) {\n                    return twttr.anywhere.api.models.User.JSBNG__find(this.inReplyToUserId, a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            inReplyTo: c(\"Status\", function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                if (this.inReplyToStatusId) {\n                    return twttr.anywhere.api.models.Status.JSBNG__find(this.inReplyToStatusId, a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            flag: b(undefined, function(a) {\n                var b, c = {\n                    id: this.id\n                };\n                ((a.isOurTweet ? (b = \"statuses/update_possibly_sensitive\", c.possibly_sensitive = ((((typeof a.possibly_sensitive == \"undefined\")) || a.possibly_sensitive))) : b = \"statuses/flag_possibly_sensitive\")), d({\n                    options: a,\n                    url: b,\n                    params: [c,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            oembed: b(undefined, function(a) {\n                var b = {\n                    url: ((((((\"http://twitter.com/\" + this.user.status_name)) + \"/statuses/\")) + this.id)),\n                    lang: a.lang,\n                    target: a.target,\n                    align: a.align\n                };\n                d({\n                    options: a,\n                    url: \"statuses/oembed\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.Status);\n        a(g);\n    });\n});\nprovide(\"bluejs/models/promptbird\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = null, e = function(a, b) {\n            a = ((a || {\n            })), c({\n                options: b,\n                url: \"users/get_prompt\",\n                params: [a,],\n                dataSource: [\"\",]\n            });\n        }, f = b(d, e), g = function(a, b) {\n            a = ((a || {\n            })), c({\n                options: b,\n                url: \"users/dismiss_prompt\",\n                params: [a,],\n                dataSource: [\"\",]\n            });\n        }, i = b(d, g), j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Promptbird\").statics({\n            getPrompt: f,\n            dismissPrompt: i\n        });\n        a(j);\n    });\n});\nprovide(\"bluejs/models/search_result\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.aliasMethod, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SearchResult\").methods(twttr.anywhere.api.mixins.StatusActions);\n        a(c);\n    });\n});\nprovide(\"bluejs/models/place\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Place\").belongsTo(\"Place\", \"contained_within\").statics({\n            JSBNG__find: b(\"Place\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"geo/id/:id\",\n                    params: [a,b,],\n                    dataSource: [\"place\",]\n                });\n            }),\n            search: b([\"Place\",], function(a) {\n                var b = [\"lat\",\"long\",\"lon\",\"query\",\"ip\",\"granularity\",\"accuracy\",\"autocomplete\",\"max_results\",\"contained_within\",\"attribute:street_address\",\"require_activity\",], c = e(b, a);\n                d({\n                    options: a,\n                    url: \"geo/search\",\n                    params: [c,],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            }),\n            reverseGeocode: b([\"Place\",], function(a, b, c) {\n                var f = [\"long\",\"accuracy\",\"granularity\",\"max_results\",], g = e(f, c);\n                ((g[\"long\"] && (b = g[\"long\"], delete g[\"long\"]))), d({\n                    options: c,\n                    url: \"geo/reverse_geocode\",\n                    params: [twttr.merge({\n                    }, g, {\n                        lat: a,\n                        lon: b\n                    }),],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            }),\n            create: b(\"Place\", function(a, b, c, f, g, i) {\n                var j = [\"long\",\"attribute:street_address\",\"accuracy\",], k = e(j, i);\n                ((k[\"long\"] && (c = k[\"long\"], delete k[\"long\"]))), d({\n                    options: i,\n                    url: \"geo/place\",\n                    params: [twttr.merge({\n                    }, k, {\n                        token: a,\n                        lat: b,\n                        lon: c,\n                        JSBNG__name: f,\n                        contained_within: g\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            similar: b([\"Place\",], function(a, b, c, f) {\n                var g = [\"long\",\"contained_within\",\"attribute:street_address\",\"accuracy\",], i = e(g, f);\n                ((i[\"long\"] && (b = i[\"long\"], delete i[\"long\"]))), d({\n                    options: f,\n                    url: \"geo/similar_places\",\n                    params: [twttr.merge({\n                    }, i, {\n                        lat: a,\n                        lon: b,\n                        JSBNG__name: c\n                    }),],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/user_recommendation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UserRecommendation\").hasOne(\"User\").hasMany(\"User\", \"connections\").statics({\n            hide: b([\"UserRecommendation\",], function(a, b, d) {\n                d.recommended_user_id = a, d.token = b, c({\n                    options: d,\n                    url: \"users/recommendations/hide\",\n                    params: [d,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.RateUserRecommendation);\n        a(d);\n    });\n});\nprovide(\"bluejs/models/suggestion_category\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SuggestionCategory\").hasMany(\"SuggestionCategory\", \"categories\").hasMany(\"User\", \"users\").hasMany(\"User\", \"sample\").statics({\n            getAll: b.chainableMethod([\"SuggestionCategory\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            randomSample: b.chainableMethod([\"User\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions/random\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).methods({\n            members: b.chainableMethod([\"User\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions/:slug/members\",\n                    params: [this.slug,a,],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/related_tweets\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.RelatedTweets\").hasMany(\"RelatedResult\", \"results\");\n        a(b);\n    });\n});\nprovide(\"bluejs/models/related_result\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.RelatedResult\").hasOne(\"Status\", \"value\");\n        a(b);\n    });\n});\nprovide(\"bluejs/util/promoted_content\", function(a) {\n    using(\"constants\").as(function(b, c) {\n        var d = twttr.anywhere.api.util.filterOptions, e = c.promotedContent.linkType, f = twttr.klass(\"twttr.anywhere.api.util.PromotedContent\", twttr.anywhere.api.util.noop).statics({\n            loggedImpressions: {\n            },\n            logImpression: function(a) {\n                ((this.loggedImpressions[a] || (this.loggedImpressions[a] = !0, this._logImpressionIdEvent(a, e.DISPLAYED))));\n            },\n            logProfileImageClick: function(a) {\n                this._logImpressionIdEvent(a, e.PROFILE_PIC);\n            },\n            logScreenNameClick: function(a) {\n                this._logImpressionIdEvent(a, e.SCREEN_NAME);\n            },\n            logPermalinkClick: function(a) {\n                this._logImpressionIdEvent(a, e.PERMALINK);\n            },\n            logDismissUser: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_WITHOUT_REASON);\n            },\n            logShowDetails: function(a) {\n                this._logImpressionIdEvent(a, e.DETAIL);\n            },\n            logHashtagClick: function(a, b) {\n                b = b.replace(/^#/, \"\"), this._logImpressionIdEvent(a, e.HASHTAG, {\n                    q: b\n                });\n            },\n            logUserMentionClick: function(a, b) {\n                this._logImpressionIdEvent(a, e.USER_NAME, {\n                    username: b\n                });\n            },\n            logUrlClick: function(a, b) {\n                this._logImpressionIdEvent(a, e.JSBNG__URL, {\n                    src: b\n                });\n            },\n            logDismissUninteresting: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_UNINTERESTING);\n            },\n            logDismissRepetitive: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_REPETITIVE);\n            },\n            logDismissSpam: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_SPAM);\n            },\n            logDismissOther: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_WITHOUT_REASON);\n            },\n            logFooterProfileClick: function(a) {\n                this._logImpressionIdEvent(a, e.FOOTER_PROFILE);\n            },\n            logTrendImpression: function(a, b) {\n                this._logPromotedTrendIdEvent(a, \"i\", b);\n            },\n            logTrendClick: function(a, b) {\n                this._logPromotedTrendIdEvent(a, \"c\", b);\n            },\n            feedback: function(a) {\n                var b = d([\"impression_id\",\"status_id\",\"reason\",\"comments\",], a);\n                callMethod({\n                    options: a,\n                    url: \"promoted_content/feedback\",\n                    params: [b,],\n                    dataSource: [\"\",]\n                });\n            },\n            _logPromotedTrendIdEvent: function(a, b, c) {\n                ((((a && b)) && (c = $.extend({\n                    promoted_trend_id: a\n                }, c), this._logEvent(b, c))));\n            },\n            _logImpressionIdEvent: function(a, b, c) {\n                ((((a && b)) && (c = $.extend({\n                    impression_id: a\n                }, c), this._logEvent(b, c))));\n            },\n            _logEvent: function(a, b) {\n                var c = ((((((((twttr.hosts.remote + \"/1/promoted_content/\")) + a)) + \"/log.png?\")) + $.param(b)));\n                (new JSBNG__Image).src = c;\n            }\n        });\n        twttr.klass(\"twttr.anywhere.api.util.PromotedStore\", twttr.anywhere.api.util.noop).statics({\n            get: function(a) {\n                return this._store()[a];\n            },\n            putStatus: function(a) {\n                var b = a.impressionId;\n                this._store()[b] = this._promotedDataForStatus(a);\n            },\n            putUser: function(a) {\n                var b = a.promotedContent.impression_id;\n                this._store()[b] = this._promotedDataForUser(a);\n            },\n            getPromotedUserInstance: function(a, b) {\n                var c = twttr.anywhere.api.util.protoExtend;\n                a = c(a), a.attributes = c(a.attributes), a.impressionId = b, a.attributes.impression_id = b;\n                var d = this.get(b);\n                return ((d && (a.promotedContent = d.promotedContent, a.attributes.promoted_content = d.promotedContent))), a;\n            },\n            getPromotedStatusInstance: function(a, b) {\n                var c = twttr.anywhere.api.util.protoExtend, d = this.get(b);\n                return a = c(a), a.impressionId = d.impressionId, a.experiments = d.experiments, a.attributes = c(a.attributes), a.attributes.impression_id = d.impressionId, a.attributes.experiments = d.experiments, a;\n            },\n            _promotedDataForStatus: function(a) {\n                return a = $.extend({\n                }, a), {\n                    impressionId: a.impressionId,\n                    experiments: a.experiments\n                };\n            },\n            _promotedDataForUser: function(a) {\n                return a = $.extend({\n                }, a), {\n                    promotedContent: a.promotedContent\n                };\n            },\n            _store: function() {\n                return this.store = ((this.store || {\n                })), this.store;\n            }\n        }), a(f);\n    });\n});\nprovide(\"bluejs/models/address_book\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.AddressBook\").statics({\n            contactsServices: b(undefined, function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/services\",\n                    params: [a,],\n                    dataSource: [\"\",\"services\",]\n                });\n            }),\n            contactsMatches: b([\"User\",], function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/matches\",\n                    params: [a,],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            contactsOthers: b(\"\", function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/others\",\n                    params: [a,],\n                    dataSource: [\"\",\"contacts\",]\n                });\n            }),\n            followAllContacts: b(\"\", function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/follow_all\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            addContactsToList: b(\"\", function(a, b) {\n                c({\n                    options: b,\n                    url: \"find_sources/contacts/add_to_list\",\n                    params: [{\n                        list_id: a\n                    },],\n                    dataSource: [\"\",\"user_ids\",]\n                });\n            }),\n            sendInvitesByEmail: b(undefined, function(a, b) {\n                source = ((b && b.source)), c({\n                    options: b,\n                    url: \"users/send_invites_by_email\",\n                    params: [{\n                        addresses: a.join(\",\"),\n                        source: source\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/promo\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Promo\").statics({\n            JSBNG__random: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"promos/random_json_promo\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/urls\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Urls\").statics({\n            resolve: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/resolve\",\n                    params: [{\n                        urls: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            }),\n            shorten: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/shorten\",\n                    params: [{\n                        url: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            }),\n            shortenMultiple: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/shorten_multiple\",\n                    params: [{\n                        urls: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/blob\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.aliasMethod, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.JSBNG__Blob\").methods({\n            get: function(a) {\n                a(this);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/device\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Device\").statics({\n            list: b(null, function(a) {\n                c({\n                    options: a,\n                    url: \"devices/list\",\n                    params: [],\n                    dataSource: [\"\",]\n                });\n            }),\n            carriers: b(\"JSBNG__Blob\", function(a) {\n                c({\n                    options: a,\n                    url: \"devices/carriers\",\n                    params: [a,],\n                    dataSource: [\"carriers\",]\n                });\n            }),\n            create: b(null, function(a, b) {\n                c({\n                    options: b,\n                    url: \"devices/create\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            destroy: b(null, function(a, b) {\n                c({\n                    options: b,\n                    url: \"devices/destroy\",\n                    params: [{\n                        id: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/search\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Search\", function(a) {\n            this.constructor.uberclass.call(this, a);\n        }).statics({\n            search: b(\"SearchStory\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"i/search\",\n                    params: [twttr.merge({\n                        q: a\n                    }, b),],\n                    dataSource: [\"\",]\n                });\n            }),\n            imageFacets: b([\"Status\",], function(a, b) {\n                twttr.anywhere.api.models.Search._requestFacets(\"search/image_facets\", a, b);\n            }),\n            videoFacets: b([\"Status\",], function(a, b) {\n                twttr.anywhere.api.models.Search._requestFacets(\"search/video_facets\", a, b);\n            }),\n            _requestFacets: function(a, b, c) {\n                ((twttr.is.def(c.include_entities) || (c.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: c,\n                    url: a,\n                    params: [twttr.merge({\n                        q: b\n                    }, c),],\n                    dataSource: [\"statuses\",]\n                });\n            }\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/conversation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Conversation\", function(a) {\n            ((a && twttr.anywhere.api.util.useStringIdentifier(a, \"id\"))), this.constructor.uberclass.call(this, a);\n        }).belongsTo(\"User\");\n        a(f);\n    });\n});\nprovide(\"bluejs/models/activity\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.camelize, g = twttr.anywhere.api.util.BaseCollection, i = {\n            favorite: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: null\n            },\n            mention: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: \"Status\"\n            },\n            reply: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: \"Status\"\n            },\n            retweet: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: \"Status\"\n            },\n            follow: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: null\n            },\n            list_member_added: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: \"List\"\n            },\n            list_created: {\n                sources: \"User\",\n                targets: \"List\",\n                target_objects: null\n            }\n        }, j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Activity\", function(a) {\n            ((a.JSBNG__event ? a.action = a.JSBNG__event : ((a.action && (a.JSBNG__event = a.action))))), twttr.anywhere.api.models.Base.call(this, a);\n            for (var b in i) {\n                this.sync(((\"is_\" + b)), ((this.JSBNG__event === b)));\n            ;\n            };\n        ;\n            this.sync(\"timestamp\", twttr.helpers.parseDateString(this.createdAt));\n        });\n        j.hasMany(function(a) {\n            return ((i[a.JSBNG__event].sources || null));\n        }, \"sources\").hasMany(function(a) {\n            return ((i[a.JSBNG__event].targets || null));\n        }, \"targets\").hasMany(function(a) {\n            return ((i[a.JSBNG__event].target_objects || null));\n        }, \"targetObjects\").statics({\n            classMap: i\n        }), a(j);\n    });\n});\nprovide(\"bluejs/models/topic_story\", function(a) {\n    using(function() {\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.TopicStory\").methods({\n            getId: function() {\n                return this.attributes.query;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/models/news_article\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.NewsArticle\").methods({\n            getId: function() {\n                return this.getExpandedUrl();\n            },\n            getDisplayUrl: function() {\n                return this.url.display_url;\n            },\n            getExpandedUrl: function() {\n                return this.url.expanded_url;\n            },\n            getImage: function(a) {\n                for (var b = 0, c = this.media.length; ((b < c)); b++) {\n                    var d = this.media[b];\n                    if (((d.type === \"photo\"))) {\n                        return ((((a && d.media_url_https)) || d.media_url));\n                    }\n                ;\n                ;\n                };\n            ;\n                return null;\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/news_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.NewsStory\").hasMany(\"NewsArticle\", \"articles\").methods({\n            getId: function() {\n                return this.articles.get(0).getId();\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/user_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UserStory\");\n        b.hasMany(\"User\", \"users\"), a(b);\n    });\n});\nprovide(\"bluejs/models/tweet_story\", function(a) {\n    using(function() {\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.TweetStory\").hasOne(\"Status\", \"JSBNG__status\").methods({\n            getId: function() {\n                return this.JSBNG__status.id;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/models/story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Story\", function(a) {\n            var b = {\n            };\n            $.extend(b, a), b.JSBNG__content = a.data, delete b.data, twttr.anywhere.api.models.Base.call(this, b);\n        }).methods({\n            getId: function() {\n                return this.JSBNG__content.getId();\n            }\n        }).hasOne(\"SocialProof\", \"socialProof\").hasOne(function(a) {\n            return ((twttr.util.capitalize(a.type) + \"Story\"));\n        }, \"JSBNG__content\");\n        a(b);\n    });\n});\nprovide(\"bluejs/models/search_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SearchStory\");\n        b.hasMany(\"Story\", \"stories\"), a(b);\n    });\n});\nprovide(\"bluejs/models/stories\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Stories\");\n        b.hasMany(\"Story\", \"stories\"), a();\n    });\n});\nprovide(\"bluejs/models/discovery\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod;\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Discovery\", function(a) {\n            this.constructor.uberclass.call(this, a);\n        }).statics({\n            discovery: b(\"Stories\", function(a) {\n                c({\n                    options: a,\n                    url: \"i/discovery\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        }), a();\n    });\n});\nprovide(\"bluejs/models/sports_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SportsStory\").hasOne(function(a) {\n            return ((twttr.util.capitalize(a.sport) + \"SportsEvents\"));\n        }, \"events\");\n        a();\n    });\n});\nprovide(\"bluejs/models/soccer_events\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SoccerSportsEvents\").methods({\n            getMatchedEvent: function() {\n                return this.items[this.matchedEventId];\n            },\n            getMatchedEventData: function() {\n                return this.items[this.matchedEventId].event_data;\n            },\n            getMatchedTeam: function(a) {\n                var b = ((a ? this.getMatchedEventData().home_team : this.getMatchedEventData().away_team));\n                return b.team_logo_url = ((((b.team_logo_url_https && twttr.isSSL())) ? b.team_logo_url_https : b.team_logo_url_http)), ((b.team_logo_url || (b.team_logo_url = ((((b.user.profile_image_url_https && twttr.isSSL())) ? b.user.profile_image_url_https : b.user.profile_image_url))))), b;\n            },\n            getMatchState: function() {\n                return this.getMatchedEventData().match_state;\n            },\n            getOtherMatchState: function() {\n                var a = this, b = jQuery.map(this.items, function(b, c) {\n                    if (((((b.event_data.match_state.current_status === \"scheduled\")) || ((c === a.matchedEventId))))) {\n                        return null;\n                    }\n                ;\n                ;\n                    var d = decodeURIComponent(b.event_data.match_hashtag);\n                    return {\n                        event_id: c,\n                        home_name: b.event_data.home_team.team_name,\n                        away_name: b.event_data.away_team.team_name,\n                        score: b.event_data.match_state.score,\n                        search_path: twttr.router.searchResultsPath({\n                            query: d\n                        }),\n                        live: ((b.event_data.match_state.current_status == \"inprogress\")),\n                        hashtag: d\n                    };\n                });\n                return b;\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/us_political_rep\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UsPoliticalRep\").hasOne(\"User\").statics({\n            findByZip: b([\"UsPoliticalRep\",], function(a, b) {\n                c({\n                    options: b,\n                    url: \"government_search/by_zip\",\n                    params: [twttr.merge(b, {\n                        zip: a\n                    }),],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/social_proof\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SocialProof\").hasOne(\"ReferencedBy\", \"referencedBy\");\n        a();\n    });\n});\nprovide(\"bluejs/models/referenced_by\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.ReferencedBy\").hasMany(\"Status\", \"statuses\");\n        a();\n    });\n});\nprovide(\"extendAPI\", function(a) {\n    using().as(function(b) {\n        twttr.extendAPI = function() {\n            twttr.API.DirectMessage.extend(function() {\n                this.threadId = ((((this.senderScreenName === twttr.currentUser.screenName)) ? this.recipientScreenName : this.senderScreenName));\n            });\n            var a = function(a) {\n                var c = a.retweetedStatus, d = new twttr.API.Status, e;\n                for (e in a) {\n                    if (((e === \"activities\"))) {\n                        continue;\n                    }\n                ;\n                ;\n                    d[e] = a[e], delete a[e];\n                };\n            ;\n                for (e in c) {\n                    a[e] = c[e];\n                ;\n                };\n            ;\n                a.retweetingStatus = d, a.wasRetweeted = !0, ((((((twttr.currentUser && d.user)) && ((d.user.id === twttr.currentUser.id)))) && c.sync(\"current_user_retweet\", {\n                    id: d.id\n                }))), delete a.retweetingStatus.retweetedStatus, delete a.retweetingStatus.attributes.retweeted_status, b(a);\n            }, b = function(a) {\n                ((a.retweetingStatus.isPromoted() && (a.attributes.impression_id = a.retweetingStatus.attributes.impression_id, a.attributes.experiments = a.retweetingStatus.attributes.experiments, a.attributes.disclosure_text = a.retweetingStatus.attributes.disclosure_text, a.attributes.disclosure_type = a.retweetingStatus.attributes.disclosure_type, a.impressionId = a.retweetingStatus.impressionId, a.experiments = a.retweetingStatus.experiments, a.disclosureText = a.retweetingStatus.disclosureText, a.disclosureType = a.retweetingStatus.disclosureType, delete a.retweetingStatus.impressionId, delete a.retweetingStatus.experiments, delete a.retweetingStatus.attributes.impression_id, delete a.retweetingStatus.attributes.experiments, delete a.retweetingStatus.disclosureText, delete a.retweetingStatus.disclosureType, delete a.retweetingStatus.attributes.disclosure_text, delete a.retweetingStatus.attributes.disclosure_type)));\n            };\n            twttr.API.Status.extend(function() {\n                function b(a) {\n                    return ((((a === null)) || ((typeof a == \"undefined\"))));\n                };\n            ;\n                ((this.isRetweet && a(this))), this.isReply = !!this.inReplyToStatusId, this.hasGeo = Boolean(((!b(this.coordinates) || ((this.place && this.place.id))))), ((this.hasGeo && (this.placeName = ((((this.place && this.place.fullName)) ? this.place.fullName : null)))));\n                var c = ((!b(this.coordinates) || ((!b(this.place) && ((this.place.placeType == \"poi\")))))), d = ((((this.entities && this.entities.places)) && ((this.entities.places.length > 0))));\n                this.showGeoMap = ((c && !d)), this.showGeoIcon = ((c || d));\n            }), twttr.API.User.extend(function() {\n                var a = ((twttr.currentUserScreenName === this.screenName));\n                this.is_only_admin_accessible = ((((twttr.isAdmin && !a)) && ((((this.deactivated_bit || this.suspended)) || ((this[\"protected\"] && !this.following))))));\n            }), twttr.API.CurrentUser.extend(function() {\n                var a = this;\n                this.hasLists = function() {\n                    return ((a.counts && ((a.counts.lists.owned || a.counts.lists.subscribed))));\n                }, this.hasSavedSearches = function() {\n                    return ((a.counts && a.counts.saved_searches));\n                };\n            }), twttr.API.List.extend(function() {\n                this.isOwnList = ((twttr.currentUser ? ((twttr.currentUser.id === this.user.id)) : null));\n            }), twttr.API.SavedSearch.extend(function() {\n                var a = this.query.match(/^place:([a-f0-9]{16})$/);\n                this.isPlaceSearch = Boolean(a), ((a && (this.placeId = a[1])));\n            });\n        }, a(twttr.extendAPI);\n    });\n});\nprovide(\"bluejs/api\", function(a) {\n    using(\"bluejs/init\", function() {\n        twttr.anywhere.api.initialize();\n        var b = {\n        };\n        twttr.aug(b, twttr.anywhere.api.models), twttr.aug(b, {\n            globalEvents: twttr.anywhere.api.globalEvents\n        }), b.setConfig = twttr.anywhere.api.updateConfig, b.getConfig = function() {\n            return twttr.anywhere.api.config;\n        }, ((b.util || (b.util = {\n        }))), twttr.aug(b.util, twttr.anywhere.api.util), ((b._requestCache || (b._requestCache = twttr.anywhere.api.cache))), a(b);\n    });\n});\nprovide(\"$lib/jquery.color.js\", function(a) {\n    (function(a) {\n        function b(b) {\n            var c;\n            return ((((((b && ((b.constructor == Array)))) && ((b.length == 3)))) ? b : (((c = /rgb\\(\\s*([0-9]{1,3})\\s*,\\s*([0-9]{1,3})\\s*,\\s*([0-9]{1,3})\\s*\\)/.exec(b)) ? [parseInt(c[1]),parseInt(c[2]),parseInt(c[3]),] : (((c = /rgb\\(\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*,\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*,\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*\\)/.exec(b)) ? [((parseFloat(c[1]) * 2.55)),((parseFloat(c[2]) * 2.55)),((parseFloat(c[3]) * 2.55)),] : (((c = /#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(b)) ? [parseInt(c[1], 16),parseInt(c[2], 16),parseInt(c[3], 16),] : (((c = /#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(b)) ? [parseInt(((c[1] + c[1])), 16),parseInt(((c[2] + c[2])), 16),parseInt(((c[3] + c[3])), 16),] : d[a.trim(b).toLowerCase()]))))))))));\n        };\n    ;\n        function c(c, d) {\n            var e;\n            do {\n                e = a.curCSS(c, d);\n                if (((((((e != \"\")) && ((e != \"transparent\")))) || a.nodeName(c, \"body\")))) {\n                    break;\n                }\n            ;\n            ;\n                d = \"backgroundColor\";\n            } while (c = c.parentNode);\n            return b(e);\n        };\n    ;\n        a.each([\"backgroundColor\",\"borderBottomColor\",\"borderLeftColor\",\"borderRightColor\",\"borderTopColor\",\"color\",\"outlineColor\",], function(d, e) {\n            a.fx.step[e] = function(a) {\n                ((((a.state == 0)) && (a.start = c(a.elem, e), a.end = b(a.end)))), a.elem.style[e] = ((((\"rgb(\" + [Math.max(Math.min(parseInt(((((a.pos * ((a.end[0] - a.start[0])))) + a.start[0]))), 255), 0),Math.max(Math.min(parseInt(((((a.pos * ((a.end[1] - a.start[1])))) + a.start[1]))), 255), 0),Math.max(Math.min(parseInt(((((a.pos * ((a.end[2] - a.start[2])))) + a.start[2]))), 255), 0),].join(\",\"))) + \")\"));\n            };\n        });\n        var d = {\n            aqua: [0,255,255,],\n            azure: [240,255,255,],\n            beige: [245,245,220,],\n            black: [0,0,0,],\n            blue: [0,0,255,],\n            brown: [165,42,42,],\n            cyan: [0,255,255,],\n            darkblue: [0,0,139,],\n            darkcyan: [0,139,139,],\n            darkgrey: [169,169,169,],\n            darkgreen: [0,100,0,],\n            darkkhaki: [189,183,107,],\n            darkmagenta: [139,0,139,],\n            darkolivegreen: [85,107,47,],\n            darkorange: [255,140,0,],\n            darkorchid: [153,50,204,],\n            darkred: [139,0,0,],\n            darksalmon: [233,150,122,],\n            darkviolet: [148,0,211,],\n            fuchsia: [255,0,255,],\n            gold: [255,215,0,],\n            green: [0,128,0,],\n            indigo: [75,0,130,],\n            khaki: [240,230,140,],\n            lightblue: [173,216,230,],\n            lightcyan: [224,255,255,],\n            lightgreen: [144,238,144,],\n            lightgrey: [211,211,211,],\n            lightpink: [255,182,193,],\n            lightyellow: [255,255,224,],\n            lime: [0,255,0,],\n            magenta: [255,0,255,],\n            maroon: [128,0,0,],\n            navy: [0,0,128,],\n            olive: [128,128,0,],\n            orange: [255,165,0,],\n            pink: [255,192,203,],\n            purple: [128,0,128,],\n            violet: [128,0,128,],\n            red: [255,0,0,],\n            silver: [192,192,192,],\n            white: [255,255,255,],\n            yellow: [255,255,0,]\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/modernizr-1.5.js\", function(a) {\n    window.Modernizr = function(a, b, c) {\n        function d(a) {\n            q.cssText = a;\n        };\n    ;\n        function e(a, b) {\n            return d(((gb.join(((a + \";\"))) + ((b || \"\")))));\n        };\n    ;\n        function f(a, b) {\n            return ((((\"\" + a)).indexOf(b) !== -1));\n        };\n    ;\n        function g(a, b) {\n            for (var d in a) {\n                if (((((q[a[d]] !== c)) && ((!b || b(a[d], p)))))) {\n                    return !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function i(a, b) {\n            var c = ((a.charAt(0).toUpperCase() + a.substr(1))), d = [a,((\"Webkit\" + c)),((\"Moz\" + c)),((\"O\" + c)),((\"ms\" + c)),((\"Khtml\" + c)),];\n            return !!g(d, b);\n        };\n    ;\n        function j() {\n            l[L] = function(a) {\n                for (var b = 0, c = a.length; ((b < c)); b++) {\n                    jb[a[b]] = ((a[b] in r));\n                ;\n                };\n            ;\n                return jb;\n            }(\"autocomplete autofocus list placeholder max min multiple pattern required step\".split(\" \")), l[M] = function(a) {\n                for (var b = 0, c, d = a.length; ((b < d)); b++) {\n                    r.setAttribute(\"type\", a[b]), c = ((r.type !== \"text\")), ((c && (r.value = eb, ((/tel|search/.test(r.type) || ((/url|email/.test(r.type) ? c = ((r.checkValidity && ((r.checkValidity() === !1)))) : c = ((r.value != eb))))))))), ib[a[b]] = !!c;\n                ;\n                };\n            ;\n                return ib;\n            }(\"search tel url email datetime date month week time datetime-local number range color\".split(\" \"));\n        };\n    ;\n        var k = \"1.5\", l = {\n        }, m = !0, n = b.documentElement, o = \"modernizr\", p = b.createElement(o), q = p.style, r = b.createElement(\"input\"), s = \"canvas\", t = \"canvastext\", u = \"rgba\", v = \"hsla\", w = \"multiplebgs\", x = \"backgroundsize\", y = \"borderimage\", z = \"borderradius\", A = \"boxshadow\", B = \"opacity\", C = \"cssanimations\", D = \"csscolumns\", E = \"cssgradients\", F = \"cssreflections\", G = \"csstransforms\", H = \"csstransforms3d\", I = \"csstransitions\", J = \"video\", K = \"audio\", L = \"input\", M = ((L + \"types\")), N = \"svg\", O = \"smil\", P = ((N + \"clippaths\")), Q = \"background\", R = ((Q + \"Color\")), S = \"canPlayType\", T = \"JSBNG__localStorage\", U = \"JSBNG__sessionStorage\", V = \"JSBNG__applicationCache\", W = \"webworkers\", X = \"hashchange\", Y = \"crosswindowmessaging\", Z = \"historymanagement\", ab = \"draganddrop\", bb = \"websqldatabase\", cb = \"indexedDB\", db = \"websockets\", eb = \":)\", fb = Object.prototype.toString, gb = \" -o- -moz- -ms- -webkit- -khtml- \".split(\" \"), hb = {\n        }, ib = {\n        }, jb = {\n        }, kb = [], lb = function() {\n            function a(a, d) {\n                var e = ((arguments.length == 1));\n                if (((e && c[a]))) {\n                    return c[a];\n                }\n            ;\n            ;\n                d = ((d || JSBNG__document.createElement(((b[a] || \"div\"))))), a = ((\"JSBNG__on\" + a));\n                var f = ((a in d));\n                return ((((!f && d.setAttribute)) && (d.setAttribute(a, \"return;\"), f = ((typeof d[a] == \"function\"))))), d = null, ((e ? c[a] = f : f));\n            };\n        ;\n            var b = {\n                select: \"input\",\n                change: \"input\",\n                submit: \"form\",\n                reset: \"form\",\n                error: \"img\",\n                load: \"img\",\n                abort: \"img\"\n            }, c = {\n            };\n            return a;\n        }(), mb = {\n        }.hasOwnProperty, nb;\n        ((((((typeof mb != \"undefined\")) && ((typeof mb.call != \"undefined\")))) ? nb = function(a, b) {\n            return mb.call(a, b);\n        } : nb = function(a, b) {\n            return ((((b in a)) && ((typeof a.constructor.prototype[b] == \"undefined\"))));\n        })), hb[s] = function() {\n            return !!b.createElement(s).getContext;\n        }, hb[t] = function() {\n            return ((!!hb[s]() && ((typeof b.createElement(s).getContext(\"2d\").fillText == \"function\"))));\n        }, hb[Y] = function() {\n            return !!a.JSBNG__postMessage;\n        }, hb[bb] = function() {\n            var b = !!a.JSBNG__openDatabase;\n            if (b) {\n                try {\n                    b = !!JSBNG__openDatabase(\"testdb\", \"1.0\", \"html5 test db\", 200000);\n                } catch (c) {\n                    b = !1;\n                };\n            }\n        ;\n        ;\n            return b;\n        }, hb[cb] = function() {\n            return !!a[cb];\n        }, hb[X] = function() {\n            return ((lb(X, a) && ((((JSBNG__document.documentMode === c)) || ((JSBNG__document.documentMode > 7))))));\n        }, hb[Z] = function() {\n            return ((!!a.JSBNG__history && !!JSBNG__history.pushState));\n        }, hb[ab] = function() {\n            return ((((((((((((lb(\"drag\") && lb(\"dragstart\"))) && lb(\"dragenter\"))) && lb(\"dragover\"))) && lb(\"dragleave\"))) && lb(\"dragend\"))) && lb(\"drop\")));\n        }, hb[db] = function() {\n            return ((\"JSBNG__WebSocket\" in a));\n        }, hb[u] = function() {\n            return d(((Q + \"-color:rgba(150,255,150,.5)\"))), f(q[R], u);\n        }, hb[v] = function() {\n            return d(((Q + \"-color:hsla(120,40%,100%,.5)\"))), f(q[R], u);\n        }, hb[w] = function() {\n            return d(((Q + \":url(//:),url(//:),red url(//:)\"))), (new RegExp(\"(url\\\\s*\\\\(.*?){3}\")).test(q[Q]);\n        }, hb[x] = function() {\n            return i(((Q + \"Size\")));\n        }, hb[y] = function() {\n            return i(\"borderImage\");\n        }, hb[z] = function() {\n            return i(\"borderRadius\", \"\", function(a) {\n                return f(a, \"orderRadius\");\n            });\n        }, hb[A] = function() {\n            return i(\"boxShadow\");\n        }, hb[B] = function() {\n            return e(\"opacity:.5\"), f(q[B], \"0.5\");\n        }, hb[C] = function() {\n            return i(\"animationName\");\n        }, hb[D] = function() {\n            return i(\"columnCount\");\n        }, hb[E] = function() {\n            var a = ((Q + \"-image:\")), b = \"gradient(linear,left top,right bottom,from(#9f9),to(white));\", c = \"linear-gradient(left top,#9f9, white);\";\n            return d(((((a + gb.join(((b + a))))) + gb.join(((c + a))))).slice(0, -a.length)), f(q.backgroundImage, \"gradient\");\n        }, hb[F] = function() {\n            return i(\"boxReflect\");\n        }, hb[G] = function() {\n            return !!g([\"transformProperty\",\"WebkitTransform\",\"MozTransform\",\"OTransform\",\"msTransform\",]);\n        }, hb[H] = function() {\n            var a = !!g([\"perspectiveProperty\",\"WebkitPerspective\",\"MozPerspective\",\"OPerspective\",\"msPerspective\",]);\n            if (a) {\n                var c = JSBNG__document.createElement(\"style\"), d = b.createElement(\"div\");\n                c.textContent = ((((\"@media (\" + gb.join(\"transform-3d),(\"))) + \"modernizr){#modernizr{height:3px}}\")), b.getElementsByTagName(\"head\")[0].appendChild(c), d.id = \"modernizr\", n.appendChild(d), a = ((d.offsetHeight === 3)), c.parentNode.removeChild(c), d.parentNode.removeChild(d);\n            }\n        ;\n        ;\n            return a;\n        }, hb[I] = function() {\n            return i(\"transitionProperty\");\n        }, hb[J] = function() {\n            var a = b.createElement(J), c = !1;\n            try {\n                if (c = !!a.canPlayType) {\n                    c = new Boolean(c), c.ogg = a.canPlayType(\"video/ogg; codecs=\\\"theora\\\"\");\n                    var d = \"video/mp4; codecs=\\\"avc1.42E01E\";\n                    c.h264 = ((a.canPlayType(((d + \"\\\"\"))) || a.canPlayType(((d + \", mp4a.40.2\\\"\"))))), c.webm = a.canPlayType(\"video/webm; codecs=\\\"vp8, vorbis\\\"\");\n                }\n            ;\n            ;\n            } catch (e) {\n            \n            };\n        ;\n            return c;\n        }, hb[K] = function() {\n            var a = b.createElement(K), c = !1;\n            try {\n                if (c = !!a.canPlayType) {\n                    c = new Boolean(c), c.ogg = a.canPlayType(\"audio/ogg; codecs=\\\"vorbis\\\"\"), c.mp3 = a.canPlayType(\"audio/mpeg;\"), c.wav = a.canPlayType(\"audio/wav; codecs=\\\"1\\\"\"), c.m4a = ((a.canPlayType(\"audio/x-m4a;\") || a.canPlayType(\"audio/aac;\")));\n                }\n            ;\n            ;\n            } catch (d) {\n            \n            };\n        ;\n            return c;\n        }, hb[T] = function() {\n            try {\n                return ((((\"JSBNG__localStorage\" in a)) && ((a[T] !== null))));\n            } catch (b) {\n                return !1;\n            };\n        ;\n        }, hb[U] = function() {\n            try {\n                return ((((\"JSBNG__sessionStorage\" in a)) && ((a[U] !== null))));\n            } catch (b) {\n                return !1;\n            };\n        ;\n        }, hb[W] = function() {\n            return !!a.JSBNG__Worker;\n        }, hb[V] = function() {\n            var b = a[V];\n            return ((((((!!b && ((typeof b.JSBNG__status != \"undefined\")))) && ((typeof b.update == \"function\")))) && ((typeof b.swapCache == \"function\"))));\n        }, hb[N] = function() {\n            return ((!!b.createElementNS && !!b.createElementNS(\"http://www.w3.org/2000/svg\", \"svg\").createSVGRect));\n        }, hb[O] = function() {\n            return ((!!b.createElementNS && /SVG/.test(fb.call(b.createElementNS(\"http://www.w3.org/2000/svg\", \"animate\")))));\n        }, hb[P] = function() {\n            return ((!!b.createElementNS && /SVG/.test(fb.call(b.createElementNS(\"http://www.w3.org/2000/svg\", \"clipPath\")))));\n        };\n        for (var ob in hb) {\n            ((nb(hb, ob) && kb.push((((((l[ob.toLowerCase()] = hb[ob]()) ? \"\" : \"no-\")) + ob.toLowerCase())))));\n        ;\n        };\n    ;\n        return ((l[L] || j())), l.addTest = function(a, b) {\n            a = a.toLowerCase();\n            if (l[a]) {\n                return;\n            }\n        ;\n        ;\n            return b = !!b(), n.className += ((((\" \" + ((b ? \"\" : \"no-\")))) + a)), l[a] = b, l;\n        }, d(\"\"), p = r = null, ((((m && function() {\n            var a = b.createElement(\"div\");\n            return a.innerHTML = \"\\u003Celem\\u003E\\u003C/elem\\u003E\", ((a.childNodes.length !== 1));\n        }())) && function(a, b) {\n            function c(a, d) {\n                if (j[a]) j[a].styleSheet.cssText += d;\n                 else {\n                    var e = g[o], f = b[p](\"style\");\n                    f.media = a, e.insertBefore(f, e[o]), j[a] = f, c(a, d);\n                }\n            ;\n            ;\n            };\n        ;\n            function d(a, b) {\n                for (var e = new RegExp(((((\"\\\\b(\" + k)) + \")\\\\b(?!.*[;}])\")), \"gi\"), f = function(a) {\n                    return ((\".iepp_\" + a));\n                }, h = -1; ((++h < a.length)); ) {\n                    b = ((a[h].media || b)), d(a[h].imports, b), c(b, a[h].cssText.replace(e, f));\n                ;\n                };\n            ;\n            };\n        ;\n            function e() {\n                for (var a, c = b.getElementsByTagName(\"*\"), e, f, h = new RegExp(((((\"^\" + k)) + \"$\")), \"i\"), g = -1; ((++g < c.length)); ) {\n                    (((((a = c[g]) && (f = a.nodeName.match(h)))) && (e = new RegExp(((((((((\"^\\\\s*\\u003C\" + f)) + \"(.*)\\\\/\")) + f)) + \"\\u003E\\\\s*$\")), \"i\"), i.innerHTML = a.outerHTML.replace(/\\r|\\n/g, \" \").replace(e, ((((a.currentStyle.display == \"block\")) ? \"\\u003Cdiv$1/div\\u003E\" : \"\\u003Cspan$1/span\\u003E\"))), e = i.childNodes[0], e.className += ((\" iepp_\" + f)), e = m[m.length] = [a,e,], a.parentNode.replaceChild(e[1], e[0]))));\n                ;\n                };\n            ;\n                d(b.styleSheets, \"all\");\n            };\n        ;\n            function f() {\n                for (var a = -1, b; ((++a < m.length)); ) {\n                    m[a][1].parentNode.replaceChild(m[a][0], m[a][1]);\n                ;\n                };\n            ;\n                for (b in j) {\n                    g[o].removeChild(j[b]);\n                ;\n                };\n            ;\n                j = {\n                }, m = [];\n            };\n        ;\n            for (var g = b.documentElement, i = b.createDocumentFragment(), j = {\n            }, k = \"abbr|article|aside|audio|canvas|command|datalist|details|figure|figcaption|footer|header|hgroup|keygen|mark|meter|nav|output|progress|section|source|summary|time|video\", l = k.split(\"|\"), m = [], n = -1, o = \"firstChild\", p = \"createElement\"; ((++n < l.length)); ) {\n                b[p](l[n]), i[p](l[n]);\n            ;\n            };\n        ;\n            i = i.appendChild(b[p](\"div\")), a.JSBNG__attachEvent(\"JSBNG__onbeforeprint\", e), a.JSBNG__attachEvent(\"JSBNG__onafterprint\", f);\n        }(this, b))), l._enableHTML5 = m, l._version = k, n.className = ((n.className.replace(/\\bno-js\\b/, \"\") + \" js\")), l;\n    }(this, this.JSBNG__document), a();\n});\nprovide(\"$lib/jquery.hashchange.js\", function(a) {\n    (function($) {\n        var a = function() {\n            function a(a, d) {\n                var e = ((arguments.length == 1));\n                if (((e && c[a]))) {\n                    return c[a];\n                }\n            ;\n            ;\n                d = ((d || JSBNG__document.createElement(((b[a] || \"div\"))))), a = ((\"JSBNG__on\" + a));\n                var f = ((a in d));\n                return ((((!f && d.setAttribute)) && (d.setAttribute(a, \"return;\"), f = ((typeof d[a] == \"function\"))))), d = null, ((e ? c[a] = f : f));\n            };\n        ;\n            var b = {\n                select: \"input\",\n                change: \"input\",\n                submit: \"form\",\n                reset: \"form\",\n                error: \"img\",\n                load: \"img\",\n                abort: \"img\"\n            }, c = {\n            };\n            return a;\n        }();\n        $.fn.hashchange = function(b) {\n            if (((a(\"hashchange\", window) && ((((JSBNG__document.documentMode === undefined)) || ((JSBNG__document.documentMode > 7))))))) this.bind(\"hashchange\", b);\n             else {\n                var c = JSBNG__location.hash;\n                JSBNG__setInterval(function() {\n                    ((((c !== JSBNG__location.hash)) && (b($.JSBNG__Event(\"hashchange\")), c = JSBNG__location.hash)));\n                }, 250);\n            }\n        ;\n        ;\n            return this;\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.cookie.js\", function(a) {\n    jQuery.cookie = function(a, b, c) {\n        if (((typeof b == \"undefined\"))) {\n            var d = null;\n            if (((JSBNG__document.cookie && ((JSBNG__document.cookie != \"\"))))) {\n                var e = JSBNG__document.cookie.split(\";\");\n                for (var f = 0; ((f < e.length)); f++) {\n                    var g = jQuery.trim(e[f]);\n                    if (((g.substring(0, ((a.length + 1))) == ((a + \"=\"))))) {\n                        d = decodeURIComponent(g.substring(((a.length + 1))));\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return d;\n        }\n    ;\n    ;\n        c = ((c || {\n        })), ((((b === null)) && (b = \"\", c.expires = -1)));\n        var i = \"\";\n        if (((c.expires && ((((typeof c.expires == \"number\")) || c.expires.toUTCString))))) {\n            var j;\n            ((((typeof c.expires == \"number\")) ? (j = new JSBNG__Date, j.setTime(((j.getTime() + ((((((((c.expires * 24)) * 60)) * 60)) * 1000)))))) : j = c.expires)), i = ((\"; expires=\" + j.toUTCString()));\n        }\n    ;\n    ;\n        var k = ((c.path ? ((\"; path=\" + c.path)) : \"\")), l = ((c.domain ? ((\"; domain=\" + c.domain)) : \"\")), m = ((c.secure ? \"; secure\" : \"\"));\n        JSBNG__document.cookie = [a,\"=\",encodeURIComponent(b),i,k,l,m,].join(\"\");\n    }, a();\n});\nprovide(\"$lib/jquery.tipsy.js\", function(a) {\n    (function($) {\n        function a(a, b) {\n            this.$element = $(a), this.options = b, this.enabled = !0, this.fixTitle();\n        };\n    ;\n        a.prototype = {\n            show: function() {\n                var a = this.getTitle();\n                if (((a && this.enabled))) {\n                    var b = this.tip();\n                    b.JSBNG__find(\".tipsy-inner\")[((this.options.html ? \"html\" : \"text\"))](a), b[0].className = \"tipsy\", b.remove().css({\n                        JSBNG__top: 0,\n                        left: 0,\n                        visibility: \"hidden\",\n                        display: \"block\"\n                    }).appendTo(JSBNG__document.body);\n                    var c = $.extend({\n                    }, this.$element.offset(), {\n                        width: this.$element[0].offsetWidth,\n                        height: this.$element[0].offsetHeight\n                    }), d = b[0].offsetWidth, e = b[0].offsetHeight, f = ((((typeof this.options.gravity == \"function\")) ? this.options.gravity.call(this.$element[0]) : this.options.gravity));\n                    function g(a) {\n                        return ((twttr.isRTL ? ((((a === \"e\")) ? \"w\" : \"e\")) : a));\n                    };\n                ;\n                    var i;\n                    switch (f.charAt(0)) {\n                      case \"n\":\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + c.height)) + this.options.offset)),\n                            left: ((((c.left + ((c.width / 2)))) - ((d / 2))))\n                        };\n                        break;\n                      case \"s\":\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top - e)) - this.options.offset)),\n                            left: ((((c.left + ((c.width / 2)))) - ((d / 2))))\n                        };\n                        break;\n                      case g(\"e\"):\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + ((c.height / 2)))) - ((e / 2)))),\n                            left: ((((c.left - d)) - this.options.offset))\n                        };\n                        break;\n                      case g(\"w\"):\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + ((c.height / 2)))) - ((e / 2)))),\n                            left: ((((c.left + c.width)) + this.options.offset))\n                        };\n                    };\n                ;\n                    ((((f.length == 2)) && ((((f.charAt(1) == g(\"w\"))) ? i.left = ((((c.left + ((c.width / 2)))) - 15)) : i.left = ((((((c.left + ((c.width / 2)))) - d)) + 15)))))), b.css(i).addClass(((\"tipsy-\" + f))), ((this.options.fade ? b.JSBNG__stop().css({\n                        opacity: 0,\n                        display: \"block\",\n                        visibility: \"visible\"\n                    }).animate({\n                        opacity: this.options.opacity\n                    }) : b.css({\n                        visibility: \"visible\",\n                        opacity: this.options.opacity\n                    }))), ((this.options.className && b.addClass(this.options.className)));\n                }\n            ;\n            ;\n            },\n            hide: function() {\n                ((this.options.fade ? this.tip().JSBNG__stop().fadeOut(function() {\n                    $(this).remove();\n                }) : this.tip().remove()));\n            },\n            fixTitle: function() {\n                var a = this.$element;\n                ((((a.attr(\"title\") || ((typeof a.attr(\"original-title\") != \"string\")))) && a.attr(\"original-title\", ((a.attr(\"title\") || \"\"))).removeAttr(\"title\")));\n            },\n            getTitle: function() {\n                var a, b = this.$element, c = this.options;\n                this.fixTitle();\n                var a, c = this.options;\n                return ((((typeof c.title == \"string\")) ? a = b.attr(((((c.title == \"title\")) ? \"original-title\" : c.title))) : ((((typeof c.title == \"function\")) && (a = c.title.call(b[0])))))), a = ((\"\" + a)).replace(/(^\\s*|\\s*$)/, \"\"), ((a || c.fallback));\n            },\n            tip: function() {\n                return ((this.$tip || (this.$tip = $(\"\\u003Cdiv class=\\\"tipsy\\\"\\u003E\\u003C/div\\u003E\").html(\"\\u003Cdiv class=\\\"tipsy-arrow\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"tipsy-inner\\\"\\u003E\\u003C/div\\u003E\")))), this.$tip;\n            },\n            validate: function() {\n                ((this.$element[0].parentNode || (this.hide(), this.$element = null, this.options = null)));\n            },\n            enable: function() {\n                this.enabled = !0;\n            },\n            disable: function() {\n                this.enabled = !1;\n            },\n            toggleEnabled: function() {\n                this.enabled = !this.enabled;\n            }\n        }, $.fn.tipsy = function(b) {\n            function c(c) {\n                var d = $.data(c, \"tipsy\");\n                return ((d || (d = new a(c, $.fn.tipsy.elementOptions(c, b)), $.data(c, \"tipsy\", d)))), d;\n            };\n        ;\n            function d() {\n                var a = c(this);\n                a.hoverState = \"in\", ((((b.delayIn == 0)) ? a.show() : (a.fixTitle(), JSBNG__setTimeout(function() {\n                    ((((a.hoverState == \"in\")) && a.show()));\n                }, b.delayIn))));\n            };\n        ;\n            function e() {\n                var a = c(this);\n                a.hoverState = \"out\", ((((b.delayOut == 0)) ? a.hide() : JSBNG__setTimeout(function() {\n                    ((((a.hoverState == \"out\")) && a.hide()));\n                }, b.delayOut)));\n            };\n        ;\n            if ((($.browser.msie && (($.browser.version < 9))))) {\n                return this;\n            }\n        ;\n        ;\n            if (((b === !0))) {\n                return this.data(\"tipsy\");\n            }\n        ;\n        ;\n            if (((typeof b == \"string\"))) {\n                var f = this.data(\"tipsy\");\n                return ((f && f[b]())), this;\n            }\n        ;\n        ;\n            b = $.extend({\n            }, $.fn.tipsy.defaults, b);\n            if (b.stopThat) {\n                this.each(function() {\n                    c(this).hide();\n                });\n                return;\n            }\n        ;\n        ;\n            ((b.live || this.each(function() {\n                c(this);\n            })));\n            if (((b.trigger != \"manual\"))) {\n                var g = ((b.live ? \"live\" : \"bind\")), i = ((((b.trigger == \"hover\")) ? \"mouseenter\" : \"JSBNG__focus\")), j = ((((b.trigger == \"hover\")) ? \"mouseleave\" : \"JSBNG__blur\"));\n                this[g](i, d)[g](j, e);\n            }\n        ;\n        ;\n            return this;\n        }, $.fn.tipsy.defaults = {\n            delayIn: 0,\n            delayOut: 0,\n            fade: !1,\n            fallback: \"\",\n            gravity: \"n\",\n            html: !1,\n            live: !1,\n            offset: 0,\n            opacity: 278071,\n            title: \"title\",\n            trigger: \"hover\"\n        }, $.fn.tipsy.elementOptions = function(a, b) {\n            return (($.metadata ? $.extend({\n            }, b, $(a).metadata()) : b));\n        }, $.fn.tipsy.autoNS = function() {\n            return (((($(this).offset().JSBNG__top > (($(JSBNG__document).scrollTop() + (($(window).height() / 2)))))) ? \"s\" : \"n\"));\n        }, $.fn.tipsy.autoWE = function() {\n            return (((($(this).offset().left > (($(JSBNG__document).scrollLeft() + (($(window).width() / 2)))))) ? \"e\" : \"w\"));\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.cssanimation.js\", function(a) {\n    (function($) {\n        var a = /([A-Z])/g;\n        $.fn.stopCssAnimation = function() {\n            this.each(function() {\n                var b = $(this), c = b.data(\"cssAnimatedProps\"), d = window.JSBNG__getComputedStyle(this, null), e = {\n                };\n                for (var f in c) {\n                    f = f.replace(a, \"-$1\").toLowerCase(), e[f] = d.getPropertyValue(f);\n                ;\n                };\n            ;\n                b.css({\n                    \"-moz-transition-property\": \"none\",\n                    \"-moz-transition-duration\": \"\",\n                    \"-moz-transition-timing-function\": \"\",\n                    \"-webkit-transition-property\": \"none\",\n                    \"-webkit-transition-duration\": \"\",\n                    \"-webkit-transition-timing-function\": \"\"\n                });\n                for (var f in e) {\n                    b.css(f, e[f]);\n                ;\n                };\n            ;\n                b.data(\"cssAnimatedProps\", null);\n                var g = b.data(\"cssTimeoutId\");\n                ((((g != null)) && (JSBNG__clearTimeout(g), b.data(\"cssTimeoutId\", null))));\n            });\n        }, $.fn.animateWithCss = function(b, c, d, e) {\n            var f = jQuery.speed(c, d, e);\n            if (jQuery.isEmptyObject(b)) {\n                return this.each(f.complete);\n            }\n        ;\n        ;\n            var g = {\n                bounce: \"cubic-bezier(0.0, 0.35, .5, 1.3)\",\n                linear: \"linear\",\n                swing: \"ease-in-out\"\n            };\n            f.easing = ((f.easing || \"swing\")), f.easing = ((g[f.easing] ? g[f.easing] : f.easing)), this.each(function() {\n                $(this).data(\"cssAnimatedProps\", b);\n                var c = window.JSBNG__getComputedStyle(this, null);\n                for (var d in b) {\n                    d = d.replace(a, \"-$1\").toLowerCase(), $(this).css(d, c.getPropertyValue(d));\n                ;\n                };\n            ;\n            });\n            var i = [];\n            for (var j in b) {\n                i.push(j);\n            ;\n            };\n        ;\n            var k = ((i.length ? i.join(\",\") : \"all\"));\n            this.css({\n                \"-moz-transition-property\": k,\n                \"-moz-transition-duration\": ((f.duration + \"ms\")),\n                \"-moz-transition-timing-function\": f.easing,\n                \"-webkit-transition-property\": k,\n                \"-webkit-transition-duration\": ((f.duration + \"ms\")),\n                \"-webkit-transition-timing-function\": f.easing\n            }), this.css(b);\n            var l = this, m = JSBNG__setTimeout(function() {\n                l.css({\n                    \"-moz-transition-property\": \"none\",\n                    \"-moz-transition-duration\": \"\",\n                    \"-moz-transition-timing-function\": \"\",\n                    \"-webkit-transition-property\": \"none\",\n                    \"-webkit-transition-duration\": \"\",\n                    \"-webkit-transition-timing-function\": \"\"\n                }), l.data(\"cssAnimatedProps\", null), l.data(\"cssTimeoutId\", null), ((jQuery.isFunction(f.complete) && f.complete.apply(l)));\n            }, f.duration);\n            return this.data(\"cssTimeoutId\", m), this;\n        };\n    })(jQuery), a();\n});\nprovide(\"div\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.IFrame\"), twttr.IFrame = function() {\n            function a() {\n                var a = [\"webkit\",\"mozilla\",\"JSBNG__opera\",\"msie\",];\n                for (var b = 0; ((b < a.length)); b++) {\n                    if ($.browser[a[b]]) {\n                        return a[b];\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            var b = \"\\u003C!DOCTYPE html\\u003E\\u003Chtml\\u003E\\u003Chead\\u003E\", c = \"\\u003C/head\\u003E\\u003Cbody\\u003E\", d = \"\\u003C/body\\u003E\\u003C/html\\u003E\", e = function(a, b) {\n                for (var c in b) {\n                    a[c] = b[c];\n                ;\n                };\n            ;\n                return a;\n            }, f = function(a) {\n                return jQuery.map(((a || [])), function(a, b) {\n                    return ((((\"\\u003Clink rel=\\\"stylesheet\\\" href=\\\"\" + a)) + \"\\\" type=\\\"text/css\\\"\\u003E\"));\n                }).join(\"\");\n            }, g = 0, i = function(a) {\n                return ((a ? (g = a.length, jQuery.map(((a || [])), function(a, b) {\n                    return ((((((((((\"\\u003Cscript \" + (($.browser.msie ? \"JSBNG__onReadyStateChange\" : \"JSBNG__onLoad\")))) + \"=\\\"scriptReady(this);\\\" type=\\\"text/javascript\\\" src=\\\"\")) + a)) + \"\\\"\\u003E\\u003C/scr\")) + \"ipt\\u003E\"));\n                }).join(\"\")) : \"\"));\n            }, j = function(i) {\n                var j = i.window.JSBNG__document, k = this, l = $(\"\\u003Ciframe allowtransparency=\\\"true\\\" frameborder=\\\"0\\\" tabindex=\\\"-1\\\" role=\\\"presentation\\\" scrolling=\\\"no\\\"/\\u003E\", j), m = l[0], n = i.complete, o = i.JSBNG__content, p = $.browser;\n                ((i.css && l.css(i.css))), this.node = m;\n                var q = function() {\n                    this.window = this.contentWindow = m.contentWindow, this.$node = l, $(m.contentWindow.JSBNG__document.body).addClass(a());\n                    var b = e(function(a) {\n                        return $(a, m.contentWindow.JSBNG__document);\n                    }, $);\n                    this.jQuery = b;\n                    try {\n                        ((this.window.jQuery || (this.window.jQuery = b, this.window.$ = b)));\n                    } catch (c) {\n                    \n                    };\n                ;\n                    n(this);\n                };\n                if (o) {\n                    if (twttr.is.string(o)) ((n && l.bind(\"load\", twttr.bind(this, function() {\n                        l.unbind(\"load\"), q.call(this);\n                    })))), m.src = o;\n                     else {\n                        var r = \"\";\n                        ((p.mozilla && (m.src = ((((\"javascript:\" + (new JSBNG__Date).getTime())) + \";'';\"))))), ((((p.msie && i.domain)) && (m.src = ((((\"javascript:'\\u003Cscript\\u003Ewindow.JSBNG__onload=function(){document.write(\\\\'\\u003Cscript\\u003Edocument.domain=\\\\\\\"\" + JSBNG__document.domain)) + \"\\\\\\\";\\u003C\\\\\\\\/script\\u003E\\\\');document.close();};\\u003C/script\\u003E'\")), r = ((((\"\\u003Cscript\\u003Edocument.domain = \\\"\" + i.domain)) + \"\\\";\\u003C/script\\u003E\"))))), l.bind(\"load\", twttr.bind(this, function(a) {\n                            l.unbind(\"load\"), m.contentWindow.JSBNG__document.scriptReady = function(a) {\n                                if (((((a.readyState && ((((a.readyState == \"loaded\")) || ((a.readyState == \"complete\")))))) || !$.browser.msie))) {\n                                    g--, ((g || q.call(j)));\n                                }\n                            ;\n                            ;\n                            };\n                            var e = m.contentWindow.JSBNG__document, i = ((((((((((((b + r)) + f(o.css))) + ((o.styles ? ((((((((\"\\u003Cbase href=\\\"\" + twttr.assets.path(\"/\"))) + \"\\\"\\u003E\\u003Cstyle type=\\\"text/css\\\"\\u003E\")) + o.styles)) + \"\\u003C/style\\u003E\")) : \"\")))) + c)) + ((o.body || \"\")))) + d)), j = this;\n                            e.open(), e.write(i), e.close(), ((g || q.call(j)));\n                        }));\n                    }\n                ;\n                ;\n                    var s = i.parentNode;\n                    ((((typeof i.parentNode == \"string\")) ? s = $(i.parentNode, j) : s = i.parentNode)), l[((i.insert || \"appendTo\"))](((s || j.body)));\n                }\n            ;\n            ;\n            };\n            return {\n                create: function(a, b) {\n                    return a = e({\n                        window: window,\n                        complete: b\n                    }, a), (new j(a)).node;\n                }\n            };\n        }(), a(twttr.IFrame);\n    });\n});\nprovide(\"util\", function(a) {\n    using(\"run/base\").as(function(b) {\n        var c = null, d = /([a-zA-Z0-9])([A-Z])/g, e = /_(.)/g, f = /\\?(.*)/, g = {\n            supplant: function() {\n                var a = /\\{([^\\{\\}]*)\\}/g;\n                return function(b, c) {\n                    return b.replace(a, function(a, b) {\n                        var d = c[b];\n                        return ((((twttr.is.string(d) || twttr.is.number(d))) ? d : a));\n                    });\n                };\n            }(),\n            joinPath: function(a, b) {\n                return ((((a.substr(-1) === \"/\")) ? ((a + b)) : ((((a + \"/\")) + b))));\n            },\n            defaulted: function(a, b) {\n                return ((twttr.is.def(a) ? a : b));\n            },\n            create: function(a) {\n                function b() {\n                \n                };\n            ;\n                return b.prototype = a, b.constructor = b, new b;\n            },\n            params: function(a) {\n                if (((!a && c))) {\n                    return c;\n                }\n            ;\n            ;\n                var b = {\n                }, d = ((a || window.JSBNG__location.search));\n                return ((d ? (((((d.charAt(0) === \"?\")) && (d = d.slice(1)))), twttr.each(d.split(\"&\"), function(a) {\n                    a = a.split(\"=\");\n                    var c = a.shift(), d = decodeURIComponent(a.join(\"=\"));\n                    b[c] = d.replace(/\\+/, \" \");\n                }), ((a || (c = b))), b) : b));\n            },\n            paramsFromUrl: function(a) {\n                return ((((!a || ((a.indexOf(\"?\") < 0)))) ? null : g.params(a.split(f)[1])));\n            },\n            underscore: function(a) {\n                return ((((a.toUpperCase() === a)) ? a : a.replace(d, function(a, b, c) {\n                    return ((((b + \"_\")) + c));\n                }).toLowerCase()));\n            },\n            camelize: function(a) {\n                return a.replace(e, function(a, b) {\n                    return b.toUpperCase();\n                });\n            },\n            camelizeObject: function(a) {\n                if (!twttr.is.object(a)) {\n                    throw new Error(\"The carmelizeObject() method only accepts apples.\");\n                }\n            ;\n            ;\n                var b = {\n                };\n                for (var c in a) {\n                    b[g.camelize(c)] = a[c];\n                ;\n                };\n            ;\n                return b;\n            },\n            capitalize: function(a) {\n                return ((a.charAt(0).toUpperCase() + a.substr(1)));\n            },\n            addCommas: function(a, b) {\n                return b = ((b || \",\")), parseInt(a, 10).toString().replace(/(.)(?=(.{3})+$)/g, function(a, c) {\n                    return ((c + b));\n                });\n            },\n            _numberFormats: {\n                de: {\n                    grouping_separator: \".\"\n                },\n                en: {\n                    grouping_separator: \",\"\n                },\n                es: {\n                    grouping_separator: \".\"\n                },\n                fr: {\n                    grouping_separator: \" \"\n                },\n                it: {\n                    grouping_separator: \".\"\n                },\n                ja: {\n                    grouping_separator: \",\"\n                },\n                pt: {\n                    grouping_separator: \".\"\n                },\n                tr: {\n                    grouping_separator: \".\"\n                },\n                nl: {\n                    grouping_separator: \".\"\n                },\n                id: {\n                    grouping_separator: \".\"\n                }\n            },\n            formatNumber: function(a, b) {\n                var c = \",\";\n                return ((((twttr.is.def(b) && g._numberFormats[b])) && (c = g._numberFormats[b].grouping_separator))), g.addCommas(a, c);\n            },\n            diff: function(a, b, c) {\n                var d = {\n                };\n                if (((!twttr.is.object(a) || !twttr.is.object(b)))) {\n                    throw new Error(\"util.diff currently supports only single-level object comparison\");\n                }\n            ;\n            ;\n                for (var e in a) {\n                    ((c ? ((c(a[e], b[e]) || (d[e] = [a[e],b[e],]))) : ((((a[e] !== b[e])) && (d[e] = [a[e],b[e],])))));\n                ;\n                };\n            ;\n                for (var e in b) {\n                    ((d[e] || ((c ? ((c(b[e], a[e]) || (d[e] = [a[e],b[e],]))) : ((((a[e] !== b[e])) && (d[e] = [a[e],b[e],])))))));\n                ;\n                };\n            ;\n                return d;\n            },\n            trim: function(a) {\n                return a.replace(/(^\\s*|\\s*$)/g, \"\");\n            },\n            lazyBind: function() {\n                var a = {\n                }, b = function(b) {\n                    return JSBNG__setInterval(function() {\n                        $.each(a[b], function(a, b) {\n                            b.callback.call(b.node, b.JSBNG__event);\n                        }), a[b] = {\n                        };\n                    }, b);\n                }, c = {\n                }, d = 0, e = 0;\n                return function(f, g, i, j) {\n                    j = ((j || 1000)), a[j] = ((a[j] || {\n                    }));\n                    var k = $(f);\n                    ((i.id || (i.id = ++d))), ((k.data(\"lazy-id\") || k.data(\"lazy-id\", e++))), k.bind(g, function(b) {\n                        var c = ((((k.data(\"lazy-id\") + g)) + i.id));\n                        a[j][c] = {\n                            callback: i,\n                            JSBNG__event: b,\n                            node: f\n                        };\n                    }), ((c[j] || (c[j] = b(j), ((((!$.browser.msie && !twttr.selenium)) && ($(window).bind(\"JSBNG__blur\", function(a) {\n                        ((c[j] && (JSBNG__clearInterval(c[j]), c[j] = null)));\n                    }), $(window).bind(\"JSBNG__focus\", function() {\n                        ((c[j] || (c[j] = b(j))));\n                    })))))));\n                };\n            }(),\n            displayLength: function(a) {\n                if (((typeof a != \"string\"))) {\n                    throw new Error(\"displayLength() requires a single input of type string\");\n                }\n            ;\n            ;\n                var b = 0, c = 0, d = function(a, b) {\n                    var c = a.charCodeAt(b), d = \"\", e = \"\";\n                    if (((((55296 <= c)) && ((c <= 56319))))) {\n                        if (((a.length <= ((b + 1))))) {\n                            throw \"High surrogate without following low surrogate\";\n                        }\n                    ;\n                    ;\n                        d = a.charCodeAt(((b + 1)));\n                        if (((((56320 > d)) || ((d > 57343))))) {\n                            throw \"High surrogate without following low surrogate\";\n                        }\n                    ;\n                    ;\n                        return ((a.charAt(b) + a.charAt(((b + 1)))));\n                    }\n                ;\n                ;\n                    if (((((56320 <= c)) && ((c <= 57343))))) {\n                        if (((b === 0))) {\n                            throw \"Low surrogate without preceding high surrogate\";\n                        }\n                    ;\n                    ;\n                        e = a.charCodeAt(((b - 1)));\n                        if (((((55296 > e)) || ((e > 56319))))) {\n                            throw \"Low surrogate without preceding high surrogate\";\n                        }\n                    ;\n                    ;\n                        return !1;\n                    }\n                ;\n                ;\n                    return ((((((8206 == c)) || ((8207 == c)))) ? !1 : a.charAt(b)));\n                };\n                for (b = 0, c = 0; ((b < a.length)); b++) {\n                    if (((d(a, b) === !1))) {\n                        continue;\n                    }\n                ;\n                ;\n                    c++;\n                };\n            ;\n                return c;\n            },\n            objKeys: function(a) {\n                var b = [];\n                for (var c in a) {\n                    ((Object.prototype.hasOwnProperty.call(a, c) && b.push(c)));\n                ;\n                };\n            ;\n                return b;\n            },\n            arrayUniq: function(a) {\n                var b = 0;\n                while (((b < a.length))) {\n                    (((($.inArray(a[b], a) < b)) ? a.splice(b, 1) : b++));\n                ;\n                };\n            ;\n                return a;\n            },\n            arrayMap: function(a, b) {\n                var c = [];\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    c.push(b.call(a[d], a[d], d, a));\n                ;\n                };\n            ;\n                return c;\n            },\n            linkifyEntities: function(a, b) {\n                return ((((b.entities && b.entities.urls)) && twttr.each(b.entities.urls, function(b) {\n                    ((b.display_url && (a = a.replace(new RegExp(((((\"\\u003E\" + g.escapeRegExpChars(h(b.url)))) + \"\\u003C\\\\/a\\u003E\"))), function() {\n                        return ((((\"\\u003E\" + h(b.display_url))) + \"\\u003C/a\\u003E\"));\n                    })))), ((b.expanded_url && (a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(b.url)))) + \"[\\\"'])\"))), function(a, c) {\n                        return ((((((((((c + \" data-expanded-url=\\\"\")) + h(b.expanded_url))) + \"\\\" title=\\\"\")) + h(b.expanded_url))) + \"\\\"\"));\n                    }))));\n                }))), ((((((b.entities && b.entities.media)) && ((b.entities.media.length > 0)))) && twttr.each(b.entities.media, function(c) {\n                    var d = b.text.substring(c.indices[0], c.indices[1]);\n                    if (c.display_url) {\n                        var e = \"\";\n                        if (((c.sizes && c.sizes.medium))) {\n                            var f = c.sizes.medium;\n                            e = ((((((((\" data-media-h=\\\"\" + h(f.h))) + \"\\\" data-media-w=\\\"\")) + h(f.w))) + \"\\\"\"));\n                        }\n                    ;\n                    ;\n                        a = a.replace(new RegExp(((((\"\\u003E\" + g.escapeRegExpChars(h(d)))) + \"\\u003C\\\\/a\\u003E\"))), function() {\n                            return ((((((e + \" data-twitter-media-url=\\\"true\\\"\\u003E\")) + h(c.display_url))) + \"\\u003C/a\\u003E\"));\n                        });\n                    }\n                ;\n                ;\n                    if (c.expanded_url) {\n                        if (((twttr.domains.local.indexOf(\"staging\") === 0))) {\n                            var i = c.expanded_url.replace(/http[s]?:\\/\\/twitter.com/, ((\"//\" + twttr.domains.local)));\n                            a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(d)))) + \"[\\\"'])\"))), function() {\n                                return ((((((((((((\"href=\\\"\" + h(i))) + \"\\\" data-expanded-url=\\\"\")) + h(c.expanded_url))) + \"\\\" title=\\\"\")) + h(c.expanded_url))) + \"\\\"\"));\n                            });\n                        }\n                         else a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(d)))) + \"[\\\"'])\"))), function(a, b) {\n                            return ((((((((((b + \" data-expanded-url=\\\"\")) + h(c.expanded_url))) + \"\\\" title=\\\"\")) + h(c.expanded_url))) + \"\\\"\"));\n                        });\n                    ;\n                    }\n                ;\n                ;\n                }))), a;\n            },\n            linkify: function(a) {\n                var b = twttr.decider.isAvailable(((twttr.loggedIn ? \"swift_profile\" : \"swift_profile_logged_out\"))), c = {\n                    hashtagClass: \"twitter-hashtag pretty-link\",\n                    hashtagUrlBase: ((((\"/search/?src=\" + twttr.search.urlParamQuerySource.HASHTAG)) + \"&q=%23\")),\n                    symbolTag: \"s\",\n                    textWithSymbolTag: \"b\",\n                    linkAttributeBlock: function(a, b) {\n                        ((a.hashtag && (b[\"data-query-source\"] = twttr.search.searchQuerySource.HASHTAG))), ((a.url && (b.rel = \"nofollow\")));\n                    },\n                    cashtagClass: \"twitter-cashtag pretty-link\",\n                    cashtagUrlBase: \"/#!/search/%24\",\n                    usernameClass: \"twitter-atreply pretty-link\",\n                    usernameUrlBase: ((b ? \"/\" : \"/#!/\")),\n                    usernameIncludeSymbol: !0,\n                    listClass: \"twitter-listname pretty-link\",\n                    urlClass: \"twitter-timeline-link\",\n                    urlTarget: \"_blank\",\n                    suppressNoFollow: !0\n                };\n                return ((((twttr.decider && !twttr.decider.isAvailable(\"linkify_cashtags\"))) ? twttr.txt.autoLinkUsernamesOrLists(twttr.txt.autoLinkUrlsCustom(twttr.txt.autoLinkHashtags(a, c), c), c) : twttr.txt.autoLink(a, c)));\n            },\n            queryHighlight: function(a, b) {\n                var c = a.replace(/\"/gi, \"\"), d = b.replace(/<[^>]+>/g, \"\");\n                return twttr.txt.hitHighlight(b, g.highlightIndices(c, d), {\n                    tag: \"strong\"\n                });\n            },\n            escapeRegExpChars: function() {\n                var a = \"\\\\/{}|()[]?.*+:^$\";\n                return specialCharsMatcher = new RegExp(((((\"((\\\\\" + a.split(\"\").join(\")|(\\\\\"))) + \"))\")), \"gi\"), function(a) {\n                    return a.replace(specialCharsMatcher, function(a, b) {\n                        return ((\"\\\\\" + b));\n                    });\n                };\n            }(),\n            normalizeCharacters: function(a) {\n                return a.replace(/[ÄÅÖØÜäåöøüÆæß]/g, function(a) {\n                    switch (a) {\n                      case \"\\u00c4\":\n                        return \"AE\";\n                      case \"\\u00c5\":\n                        return \"AA\";\n                      case \"\\u00d6\":\n                    \n                      case \"\\u00d8\":\n                        return \"OE\";\n                      case \"\\u00dc\":\n                        return \"UE\";\n                      case \"\\u00e4\":\n                        return \"ae\";\n                      case \"\\u00e5\":\n                        return \"aa\";\n                      case \"\\u00f6\":\n                    \n                      case \"\\u00f8\":\n                        return \"oe\";\n                      case \"\\u00fc\":\n                        return \"ue\";\n                      case \"\\u00c6\":\n                        return \"AE\";\n                      case \"\\u00e6\":\n                        return \"ae\";\n                      case \"\\u00df\":\n                        return \"ss\";\n                      default:\n                        return a;\n                    };\n                ;\n                });\n            },\n            highlightIndices: function(a, b) {\n                a = g.escapeRegExpChars(a);\n                var c;\n                ((twttr.decider.isAvailable(\"escape_ampersands_in_search_highlighter\") ? c = twttr.util.arrayMap(a.split(/\\s+/), function(a) {\n                    return a.replace(\"&\", \"&amp;\");\n                }) : c = a.split(/\\s+/)));\n                var d = [];\n                for (var e in c) {\n                    d.push(g.normalizeCharacters(c[e]));\n                ;\n                };\n            ;\n                var f = [], i = ((((((((\"(\" + c.join(\")|(\"))) + \")|(\")) + d.join(\")|(\"))) + \")\")), j = \"!#%&+,-./:;\\u003C=\\u003E?@^_{|}~\".split(\"\").join(\"\\\\\"), k = new RegExp(((((((((((((\"(^|\\\\b|\\\\W|[\" + j)) + \"])(\")) + i)) + \")(\\\\b|\\\\s|$|[\")) + j)) + \"])\")), \"gi\");\n                return b.replace(k, function(a, b, c) {\n                    var d = ((arguments[((arguments.length - 2))] + b.length));\n                    f.push([d,((d + c.length)),]);\n                }), f;\n            },\n            inspect: function(a) {\n                JSBNG__console.clear();\n                var b = $(a), c = b.data(\"events\"), d = 0, e = 0, f = [], g = [];\n                for (key in c) {\n                    f.push(key), d++, g.push(\"\\u000a*******************\\u000a\"), g.push(((((\"Events for \" + key)) + \"\\u000a\\u000a\")));\n                    for (fn in c[key]) {\n                        var i = c[key][fn];\n                        e++, g.push(((i.toSource() + \"\\u000a\")));\n                    };\n                ;\n                };\n            ;\n                JSBNG__console.log(\"************* Summary *************\"), JSBNG__console.log(\"for target\", b), JSBNG__console.log(((d + \" types of events\")), f), JSBNG__console.log(e, \"Total Event Listeners\"), JSBNG__console.log(\"Event listeners assigned to target\"), JSBNG__console.log(g.join(\" \"));\n            },\n            regexSupplant: function(a, b) {\n                return b = ((b || \"\")), ((((typeof a != \"string\")) && (((((a.global && ((b.indexOf(\"g\") < 0)))) && (b += \"g\"))), ((((a.ignoreCase && ((b.indexOf(\"i\") < 0)))) && (b += \"i\"))), ((((a.multiline && ((b.indexOf(\"m\") < 0)))) && (b += \"m\"))), a = a.source))), new RegExp(a.replace(/#\\{(\\w+)\\}/g, function(a, b) {\n                    var c = ((twttr.regexps[b] || \"\"));\n                    return ((((typeof c != \"string\")) && (c = c.source))), c;\n                }), b);\n            },\n            leven: function(a, b) {\n                var c, d, e = a.length, f = b.length;\n                if (!e) {\n                    return f;\n                }\n            ;\n            ;\n                if (!f) {\n                    return e;\n                }\n            ;\n            ;\n                var g = [];\n                for (var i = 0; ((i <= e)); i++) {\n                    g[i] = [], g[i][0] = i;\n                ;\n                };\n            ;\n                for (var j = 0; ((j <= f)); j++) {\n                    g[0][j] = j;\n                ;\n                };\n            ;\n                for (var i = 1; ((i <= e)); i++) {\n                    c = a.charAt(((i - 1)));\n                    for (var j = 1; ((j <= f)); j++) {\n                        g[i][j] = Math.min(((g[((i - 1))][j] + 1)), ((g[i][((j - 1))] + 1)), ((g[((i - 1))][((j - 1))] + ((((c == b.charAt(((j - 1))))) ? 0 : 1)))));\n                    ;\n                    };\n                ;\n                };\n            ;\n                return g[e][f];\n            },\n            uriRegex: new RegExp(\"^(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)?(?:\\\\?([^#]*))?(?:#(.*))?$\", \"i\"),\n            noopInT1: function() {\n            \n            },\n            noopInP1: function() {\n            \n            }\n        };\n        g.Location = twttr.klass(function(a) {\n            ((a.match(/^\\/\\//) ? a = ((\"http:\" + a)) : ((a.match(/^[a-z]+:\\/\\//) || (a = ((\"http://\" + a)))))));\n            var b = a.match(/^([a-z]+:)\\/\\/([\\w\\-\\.]+)(\\:\\d+)?(.+)?/);\n            this.href = a, this.protocol = b[1], this.hostname = b[2], this.host = ((b[2] + ((b[3] || \"\")))), this.port = ((b[3] ? b[3].slice(1) : ((((b[1] === \"https:\")) ? \"443\" : \"80\"))));\n            var c = b[2].match(/\\.(\\w+)$/);\n            ((c ? this.extension = c[1] : this.ext = \"\"));\n            if (!b[4]) this.hash = \"\", this.search = \"\", this.pathname = \"/\";\n             else {\n                ((b[4].match(/^\\//) || (b[4] = ((\"/\" + b[4])))));\n                var d = b[4].split(\"?\"), e = b[4].split(\"#\");\n                this.pathname = d[0], ((/\\/$/.test(this.pathname) || (this.pathname = ((this.pathname + \"/\"))))), this.search = ((((d.length > 1)) ? ((\"?\" + function() {\n                    return d.shift(), d.join(\"\").replace(/#.*$/, \"\");\n                }())) : \"\")), this.hash = ((((e.length > 1)) ? ((\"#\" + e[1])) : \"\"));\n            }\n        ;\n        ;\n        }).methods({\n            query: function(a) {\n                return ((this.search ? ((g.params(this.search)[a] || \"\")) : \"\"));\n            }\n        }), g.WaitQueue = twttr.klass(function() {\n            this._methods = [], this._response = null, this._flushed = !1;\n        }).methods({\n            add: function(a) {\n                ((this._flushed ? a(this._response) : this._methods.push(a)));\n            },\n            flush: function(a) {\n                if (this._flushed) {\n                    return;\n                }\n            ;\n            ;\n                this._response = a, this._flushed = !0;\n                while (this._methods[0]) {\n                    this._methods.shift()(a);\n                ;\n                };\n            ;\n            }\n        }), twttr.provide(\"twttr.util\", g), a(g);\n    });\n});\nprovide(\"constants\", function(a) {\n    using().as(function(b) {\n        var c = {\n            sessionPollInterval: 10000,\n            directMessagePollInterval: 90000,\n            defaultScribeCategory: \"webclient\",\n            scribeHostName: \"scribe.twitter.com\",\n            maxUrlLength: 2083,\n            tcoLength: 20,\n            japaneseAdUrl: \"//pages.quantumads.com/transformer/async.js?callback=twttr.components.JapaneseAd.callbacks.\",\n            japaneseAdIframeUrl: \"//web-jp.ad-v.jp/adam/detect?tag=htm&cat=twitter.all&format=side_banner\",\n            keyCodes: {\n                enter: 13,\n                escape: 27,\n                esc: 27,\n                tab: 9,\n                del: 8,\n                spacebar: 32,\n                upArrow: 38,\n                downArrow: 40,\n                leftArrow: 37,\n                rightArrow: 39\n            },\n            which: {\n                period: 46\n            },\n            charCodes: {\n                space: 32,\n                questionMark: 63\n            },\n            placeTypes: {\n                city: 7\n            },\n            promotedContent: {\n                linkType: {\n                    JSBNG__URL: 1,\n                    PROFILE_PIC: 2,\n                    SCREEN_NAME: 3,\n                    HASHTAG: 4,\n                    USER_NAME: 5,\n                    DISPLAYED: 27,\n                    DETAIL: 28,\n                    DISMISS_WITHOUT_REASON: 31,\n                    DISMISS_UNINTERESTING: 32,\n                    DISMISS_REPETITIVE: 33,\n                    DISMISS_SPAM: 34,\n                    DISMISS_OTHER: 35,\n                    FOOTER_PROFILE: 36,\n                    PERMALINK: 40\n                }\n            },\n            videos: {\n                widescreen: \"16:9\",\n                fullscreen: \"4:3\"\n            },\n            jQueryEvents: \"blur hover focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error\".split(\" \"),\n            errorCodes: {\n                notFollowing: \"NotFollowingErrorMessage\",\n                duplicateTweet: \"DuplicateTweetErrorMessage\",\n                malwareTweet: \"MalwareErrorMessage\",\n                dailyLimit: \"DailyLimitErrorMessage\",\n                tooLongTweet: \"TooLongErrorMessage\",\n                whale: \"DefaultErrorMessage\",\n                otherUserSuspended: \"OtherUserSuspendedErrorMessage\",\n                suspended: \"SuspendedErrorMessage\",\n                permission: \"PermissionErrorMessage\",\n                photoTimeout: \"PhotoTimeoutErrorMessage\",\n                followingLimitReached: \"FollowingLimitReachedErrorMessage\",\n                blockedFromFollowing: \"BlockedFromFollowingErrorMessage\",\n                tooLongListName: \"TooLongListNameErrorMessage\",\n                tooLongListDescription: \"TooLongListDescriptionErrorMessage\",\n                noLetterStartListName: \"NoLetterStartListNameErrorMessage\",\n                userNotFound: \"UserNotFoundErrorMessage\",\n                tweetNotFound: \"TweetNotFoundErrorMessage\"\n            },\n            regexps: {\n                JSBNG__name: /\\S+/,\n                usernameForSignup: /^[@＠]?([a-zA-Z0-9_]{1,15})$/,\n                username: /^[@＠]?([a-zA-Z0-9_]{1,22})$/,\n                usernameWithAt: /^[@＠]{1}([a-zA-Z0-9_]{1,22}) /,\n                usernameWithSpace: /^[@＠]{1}(\\w{1,22})\\s*$/,\n                suggestionCategoryPath: /\\/(who_to_follow|welcome)\\/interests\\/([^\\/]+)/,\n                userSearchPath: /(\\/(who_to_follow|welcome)\\/search\\/|\\/search\\/users\\/)([^\\/]+)/,\n                email: /^[\\w-]+([^@,\\s\\<\\>\\(\\)]*[\\w-]+)?\\@[\\w-]+(\\.[\\w-]+)*\\.[a-z]{2,}$/i,\n                rtlChar: /[\\u0600-\\u06FF]|[\\u0750-\\u077F]|[\\u0590-\\u05FF]|[\\uFE70-\\uFEFF]/gm,\n                dirMark: /\\u200e|\\u200f/gm,\n                rtlHashtag: /^#.*([\\u0600-\\u06FF]|[\\u0750-\\u077F]|[\\u0590-\\u05FF]|[\\uFE70-\\uFEFF])+/gm\n            },\n            recaptcha: {\n                srcUrl: ((twttr.recaptchaUrlForTest || \"https://www.google.com/recaptcha/api/js/recaptcha_ajax.js\")),\n                publicKey: \"6LfbTAAAAAAAAE0hk8Vnfd1THHnn9lJuow6fgulO\"\n            },\n            noob: {\n                dismissed: -2,\n                notNoob: -1,\n                total: 0,\n                invited: 1,\n                friendless: 2,\n                silent: 3,\n                talking: 4,\n                popular: 5,\n                lonely: 6,\n                struggling: 7\n            },\n            imageSizes: {\n                small: \"small\",\n                medium: \"medium\",\n                large: \"large\",\n                original: \"original\"\n            },\n            slideshow: {\n                fadeOutArrowTimeout: 2000,\n                fadeInArrowTimeout: 750,\n                fadeAnimationTime: 400,\n                photoMinHeight: 340,\n                videoMinHeight: 390,\n                videoMaxWidth: 480\n            },\n            clientEvent: {\n                itemType: {\n                    tweet: 0,\n                    promotedTweet: 1,\n                    popularTweet: 2,\n                    user: 3,\n                    promotedUser: 4,\n                    activity: 5,\n                    message: 6,\n                    story: 7\n                }\n            },\n            media: {\n                photoIcon: \"photo\"\n            },\n            users: {\n                maxLookupSize: 100\n            },\n            scribe: {\n                CLIENT_SIDE_USER: 0,\n                CLIENT_SIDE_APP: 2\n            }\n        };\n        twttr.constants = c, a(c);\n    });\n});\nprovide(\"cache\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.cache\"), twttr.provide(\"twttr.caches\"), twttr.klass(\"twttr.cache.Simple\", function() {\n            this._cache = {\n            };\n        }).methods({\n            set: function(a, b, c) {\n                this._cache[a] = {\n                    value: b,\n                    expire: ((twttr.is.number(c) ? ((this._getTime() + c)) : null))\n                };\n                var d = this._writeThrough();\n                return ((((d === !1)) && this.remove(a))), b;\n            },\n            get: function(a) {\n                return this._checkExpiry(a), ((this._cache[a] ? this._cache[a].value : undefined));\n            },\n            remove: function(a) {\n                delete this._cache[a], this._writeThrough();\n            },\n            clear: function() {\n                this._cache = {\n                }, this._writeThrough();\n            },\n            _checkExpiry: function(a) {\n                ((((((this._cache[a] && this._cache[a].expire)) && ((this._cache[a].expire < this._getTime())))) && this.remove(a)));\n            },\n            _getTime: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            _writeThrough: function() {\n                return !0;\n            }\n        }), function() {\n            function a(a) {\n                return window.JSBNG__localStorage.getItem(a);\n            };\n        ;\n            function b(a, b) {\n                return window.JSBNG__localStorage.setItem(a, b);\n            };\n        ;\n            function c(a) {\n                return window.JSBNG__localStorage.removeItem(a);\n            };\n        ;\n            function d(a) {\n                return window.JSBNG__sessionStorage.getItem(a);\n            };\n        ;\n            function e(a, b) {\n                return window.JSBNG__sessionStorage.setItem(a, b);\n            };\n        ;\n            function f(a) {\n                return window.JSBNG__sessionStorage.removeItem(a);\n            };\n        ;\n            function g() {\n            \n            };\n        ;\n            var i, j, k = !1;\n            try {\n                i = ((((\"JSBNG__localStorage\" in window)) && ((window.JSBNG__localStorage !== null)))), j = ((((\"JSBNG__sessionStorage\" in window)) && ((window.JSBNG__sessionStorage !== null)))), k = !0;\n            } catch (l) {\n                i = !1, j = !1, k = !1;\n            };\n        ;\n            try {\n                if (JSBNG__document.documentElement.addBehavior) {\n                    k = !1, i = !0;\n                    var m = JSBNG__document.createElement(\"div\");\n                    JSBNG__document.body.appendChild(m), m.style.display = \"none\", m.addBehavior(\"#default#userData\"), m.load(\"phoenix\");\n                    var n = m.xmlDocument, o = n.documentElement;\n                    function p(a) {\n                        var b = o.childNodes, c, d = null;\n                        for (var e = 0, f = b.length; ((e < f)); e++) {\n                            c = b.item(e);\n                            if (((c.getAttribute(\"key\") == a))) {\n                                d = c;\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        return d;\n                    };\n                ;\n                    function q(a) {\n                        var b = p(a), c = null;\n                        return ((b && (c = b.getAttribute(\"value\")))), c;\n                    };\n                ;\n                    function r(a, b) {\n                        var c = p(a);\n                        return ((c ? c.setAttribute(\"value\", b) : (c = n.createNode(1, \"item\", \"\"), c.setAttribute(\"key\", a), c.setAttribute(\"value\", b), o.appendChild(c)))), m.save(\"phoenix\"), b;\n                    };\n                ;\n                    function s(a) {\n                        var b = p(a);\n                        ((b && o.removeChild(b))), m.save(\"phoenix\");\n                    };\n                ;\n                    function t() {\n                        while (o.firstChild) {\n                            o.removeChild(o.firstChild);\n                        ;\n                        };\n                    ;\n                        m.save(\"phoenix\");\n                    };\n                ;\n                }\n            ;\n            ;\n            } catch (l) {\n                i = !1;\n            };\n        ;\n            var u = g, v = g, w = g, x = g;\n            ((i && (u = ((k ? b : r)), v = ((k ? a : q)), w = ((k ? c : s)), x = ((k ? c : t))))), twttr.klass(\"twttr.cache.LocalProvider\", function(a) {\n                twttr.cache.Simple.call(this), this._namespace = a, this._cache = JSON.parse(((v(a) || \"{}\"))), twttr.cache.LocalProvider._caches.push(this);\n            }).subclassOf(twttr.cache.Simple).statics({\n                hasLocalStorage: i,\n                _caches: [],\n                clearAll: function() {\n                    twttr.each(this._caches, function(a) {\n                        a.clear();\n                    }), this._caches = [];\n                }\n            }).methods({\n                _writeThrough: function() {\n                    try {\n                        return u(this._namespace, JSON.stringify(this._cache)), !0;\n                    } catch (a) {\n                        return !1;\n                    };\n                ;\n                }\n            });\n        }(), twttr.klass(\"twttr.cache.local.User\", function(a) {\n            this.JSBNG__name = a, this.cache = new twttr.cache.LocalProvider(\":USER:\"), this.user = ((this.cache.get(a) || this.cache.set(a, {\n                login: (new JSBNG__Date).getTime(),\n                store: {\n                }\n            }))), this.clean();\n        }).methods({\n            _getTime: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            clean: function() {\n                this.user.login = (new JSBNG__Date).getTime();\n                var a = 0, b = (new JSBNG__Date).getTime(), c = null;\n                for (var d in this.cache._cache) {\n                    a++;\n                    var e = this.cache._cache[d], f = e.value.login;\n                    ((((f < b)) && (b = f, c = d)));\n                };\n            ;\n                ((((a > 3)) && this.cache.remove(c)));\n            },\n            remove: function(a) {\n                delete this.user.store[a], this.save();\n            },\n            get: function(a) {\n                var b = this.user.store[a];\n                if (!twttr.is.def(b)) {\n                    return undefined;\n                }\n            ;\n            ;\n                var c = this._getTime();\n                return ((((b.expire && ((b.expire < c)))) ? undefined : b.value));\n            },\n            set: function(a, b, c) {\n                var d = {\n                    value: b,\n                    expire: ((twttr.is.number(c) ? ((this._getTime() + c)) : null))\n                };\n                return this.user.store[a] = d, this.save(), b;\n            },\n            update: function(a, b, c) {\n                var d = ((twttr.is.def(this.user.store[a]) ? c : this.user.store[a].expire));\n                return this.set(a, b, d), b;\n            },\n            save: function() {\n                this.cache.set(this.JSBNG__name, this.user);\n            }\n        }), a({\n            Simple: twttr.cache.Simple,\n            LocalProvider: twttr.cache.LocalProvider,\n            User: twttr.cache.local.User,\n            caches: twttr.caches\n        });\n    });\n});\nprovide(\"singletons/namespaced_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.cache.NamespacedStore\", function(a) {\n            if (((this.cache_key === null))) {\n                throw \"You need to set a cache key to use a NamespacedStore.\";\n            }\n        ;\n        ;\n            this.cache = new twttr.cache.LocalProvider(a);\n        }).methods({\n            ttl: 60000,\n            cache_key: null,\n            clear: function() {\n                this.cache.remove(this.cache_key);\n            },\n            getData: function() {\n                var a = this.cache.get(this.cache_key);\n                try {\n                    return JSON.parse(a);\n                } catch (b) {\n                    return null;\n                };\n            ;\n            },\n            setData: function(a) {\n                this.cache.set(this.cache_key, JSON.stringify(a), this.ttl);\n            }\n        }), a(twttr.cache.NamespacedStore);\n    });\n});\nprovide(\"singletons/promoted_account_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.promotedAccountStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"promoted_accounts\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 60000,\n            cache_key: \"promoted_account\",\n            getAccount: function() {\n                return this.getData();\n            },\n            hasAccount: function() {\n                return !!this.getAccount();\n            },\n            setAccount: function(a, b) {\n                var c = {\n                    id: a,\n                    impressionId: b\n                };\n                this.setData(c);\n            }\n        }), twttr.promotedAccountStore = new twttr.promotedAccountStoreSingleton, a(twttr.promotedAccountStore);\n    });\n});\nprovide(\"singletons/promoted_tweet_store\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, $) {\n        var c = \"h\";\n        twttr.klass(\"twttr.promotedTweetStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"promoted_tweets\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 1800000,\n            cache_key: \"promoted_tweet\",\n            clear: function() {\n                this.constructor.uber.clear.apply(this, arguments), $.cookie(c, null);\n            },\n            getTweetInfo: function() {\n                if (!twttr.decider.isAvailable(\"ptw_reinjection\")) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this.getData();\n                return ((((((a && a.data)) && a.data.promoted_status)) ? (this.clear(), null) : a));\n            },\n            hasTweetInfo: function() {\n                return ((twttr.decider.isAvailable(\"ptw_reinjection\") ? !!this.getTweetInfo() : !1));\n            },\n            setTweetInfo: function(a, b, d) {\n                if (!twttr.decider.isAvailable(\"ptw_reinjection\")) {\n                    return;\n                }\n            ;\n            ;\n                var e = [b.id_str,a,((d ? \"po\" : \"pr\")),].join(\",\"), f = new JSBNG__Date;\n                f.setTime(((f.getTime() + this.ttl)));\n                var b = {\n                    olderTweetId: a,\n                    data: b\n                };\n                this.setData(b), $.cookie(c, e, {\n                    expires: f\n                });\n            }\n        }), twttr.promotedTweetStore = new twttr.promotedTweetStoreSingleton, a(twttr.promotedTweetStore);\n    });\n});\nprovide(\"decider\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.Decider\", function(a, b) {\n            a = ((a || {\n            })), this._updateFeatures(a), b = ((b || this.constructor.DEFAULT_REFRESH_INTERVAL)), JSBNG__setInterval(twttr.bind(this, this.updateFeatures), b);\n        }).statics({\n            DECIDER_URL: \"/account/available_features\",\n            DEFAULT_REFRESH_INTERVAL: 180000\n        }).methods(twttr.EventProvider).methods({\n            features: function() {\n                return ((this._features || {\n                }));\n            },\n            isActivityEnabled: function() {\n                return this.isAvailable(\"activity_read\");\n            },\n            isExpando: function() {\n                return ((twttr.expando || twttr.isT1));\n            },\n            isInfiniteScroll: function() {\n                return ((this.isAvailable(\"infinite_scroll\") && !(($.browser.msie && ((parseInt($.browser.version, 10) < 8))))));\n            },\n            hasInlineReplies: function() {\n                return ((twttr.decider.isAvailable(\"inline_reply_box\") || ((twttr.abdecider.choose(\"inline_reply_box_197\") === \"reply_box\"))));\n            },\n            isAvailable: function(a) {\n                return ((((twttr.deciderOverrides && ((twttr.deciderOverrides[a] !== undefined)))) ? !!twttr.deciderOverrides[a] : ((twttr.is.fn(a) ? a() : ((this._features ? !!this._features[a] : !1))))));\n            },\n            featureUrl: function(a) {\n                var b = ((a && a.spoof_country));\n                return ((b ? ((((this.constructor.DECIDER_URL + \"?spoof_country=\")) + b)) : this.constructor.DECIDER_URL));\n            },\n            updateFeatures: function() {\n                var a = twttr.API._requestCache.get(\"account/available_features\", {\n                });\n                ((a ? this._updateFeatures(a) : this._makeRemoteRequest()));\n            },\n            _makeRemoteRequest: function(a) {\n                $.getJSON(this.featureUrl(b.util.params()), twttr.bind(this, function(b) {\n                    ((b && this._updateFeatures(b))), ((a && a()));\n                }));\n            },\n            _updateFeatures: function(a, c) {\n                var d = ((this._features || {\n                }));\n                this._features = a;\n                if (c) {\n                    return;\n                }\n            ;\n            ;\n                var e = b.util.diff(d, this._features);\n                for (var f in e) {\n                    var g = {\n                        key: f,\n                        previous: e[f][0],\n                        current: e[f][1]\n                    };\n                    this.trigger(\"keyChanged\", g);\n                };\n            ;\n            },\n            goodAtCss: function() {\n                return (($.support.boxModel && !(($.browser.msie && ((parseFloat($.browser.version) <= 6))))));\n            }\n        }), twttr.decider = new twttr.Decider, signal(\"\\u003Edecider\"), a(twttr.decider);\n    });\n});\nprovide(\"multiGlobals/scribble\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.ScribeBuffer\", function() {\n            if (twttr.ScribeBuffer.instance) {\n                throw \"This is a singleton, yo\";\n            }\n        ;\n        ;\n            twttr.ScribeBuffer.instance = this, this.ajax = $.ajax, this.reset();\n            try {\n                var a = JSBNG__sessionStorage.getItem(\"ScribeTransport\");\n                if (a) {\n                    var b = this;\n                    twttr.each(JSON.parse(((((\"[\" + a)) + \"]\"))), function(a) {\n                        b.addData(a);\n                    }), JSBNG__sessionStorage.removeItem(\"ScribeTransport\");\n                }\n            ;\n            ;\n            } catch (c) {\n            \n            };\n        ;\n        }).methods({\n            getBuffer: \"\",\n            postBuffer: [],\n            maxLength: null,\n            reset: function() {\n                this.getBuffer = \"\", this.postBuffer = [];\n                var a = ((\"q=\" + (+(new JSBNG__Date)).toString().slice(-4)));\n                this.path = \"/scribe\", this.url = ((((this.path + \"?\")) + a)), ((window.JSBNG__location.hostname.match(/^(www\\.|[A-Z]{2}\\.|^)twitter.com$/i) && (this.url = ((((((window.JSBNG__location.protocol + \"//\")) + b.constants.scribeHostName)) + this.url))))), this.maxLength = ((((((twttr.decider.isAvailable(\"use_scribe_post\") ? ((twttr.scribeBufferSize || 10)) : 1)) * b.constants.maxUrlLength)) - this.url.length));\n            },\n            _isEmpty: function() {\n                return ((((this.getBuffer.length === 0)) && ((this.postBuffer.length === 0))));\n            },\n            send: function(a) {\n                if (this._isEmpty()) {\n                    return;\n                }\n            ;\n            ;\n                ((twttr.decider.isAvailable(\"use_scribe_post\") ? this.ajax({\n                    url: this.path,\n                    data: {\n                        log: this.postBuffer\n                    },\n                    type: \"POST\",\n                    async: !a\n                }) : (new JSBNG__Image).src = ((this.url + this.getBuffer)))), this.reset();\n            },\n            getPostBufferForForm: function() {\n                var a = this.postBuffer;\n                return this.reset(), JSON.stringify(a);\n            },\n            sendReliabilityEvent: function(a) {\n                this.ajax({\n                    url: this.path,\n                    data: {\n                        reliability_event: \"true\"\n                    },\n                    type: \"POST\",\n                    success: a\n                });\n            },\n            addData: function(a) {\n                var b = JSON.stringify(a), c = this._encodeStringifiedData(b);\n                ((((c.length > twttr.ScribeBuffer.instance.maxLength)) && (a = this._truncateData(a), b = JSON.stringify(a), c = this._encodeStringifiedData(b)))), ((((((((this.url.length + this.getBuffer.length)) + c.length)) > this.maxLength)) && this.send())), this.getBuffer += ((\"&\" + c)), this.postBuffer.push(b);\n                if (window.scribeConsole) {\n                    var d = ((((window.JSBNG__location.protocol + \"//\")) + window.JSBNG__location.host));\n                    try {\n                        window.scribeConsole.JSBNG__postMessage(a, d);\n                    } catch (e) {\n                        var f = ((((\"unserializable scribe data [\" + category)) + \"]\"));\n                        window.scribeConsole.JSBNG__postMessage({\n                            error: f,\n                            event_data: JSON.stringify(a)\n                        }, d);\n                    };\n                ;\n                }\n            ;\n            ;\n                ((twttr.is.array(twttr.allScribeEvents) && (twttr.allScribeEvents.push(b), JSBNG__localStorage.twttrAllScribeEvents = JSON.stringify(twttr.allScribeEvents))));\n                if ((($.cookie(\"phx_scribe_now\") == \"1\"))) {\n                    var g = this;\n                    window.JSBNG__setTimeout(function() {\n                        g.send();\n                    }, 0);\n                }\n            ;\n            ;\n            },\n            _encodeStringifiedData: function(a) {\n                return ((\"log%5B%5D=\" + encodeURIComponent(a)));\n            },\n            _truncateData: function(a) {\n                var b = {\n                };\n                for (var c in a) {\n                    ((((a.hasOwnProperty(c) && ((typeof a[c] != \"object\")))) && (b[c] = a[c])));\n                ;\n                };\n            ;\n                return b._truncated_for_scribe = !0, b;\n            }\n        }), twttr.klass(\"twttr.Scribbler\", function(a, c, d, e, f) {\n            this.expectedToHaveComponent = ((arguments.length > 0)), this.component = ((a || \"\")), this.contextData = ((c || {\n            })), this.category = ((d || b.constants.defaultScribeCategory)), this.eventPrefix = ((e || \"\")), this.options = ((f || {\n            }));\n        }).methods({\n            DECIDERED_CATEGORIES: {\n                client_event: 1\n            },\n            spawn: function(a, b) {\n                var c = twttr.merge({\n                }, this.contextData, ((a || {\n                })));\n                return new this.constructor(this.component, c, this.category, ((b || this.eventPrefix)), this.options);\n            },\n            _contextData: function() {\n                return twttr.merge({\n                }, this.contextData);\n            },\n            _mapAPIObjectData: function(a) {\n                var b = {\n                };\n                for (var c in a) {\n                    ((((((a[c] && a[c].array)) && twttr.is.array(a[c].array))) ? b[c] = a[c].array : b[c] = a[c]));\n                ;\n                };\n            ;\n                return b;\n            },\n            _isCategoryAvailable: function(a) {\n                return ((!this.DECIDERED_CATEGORIES[a] || twttr.decider.isAvailable(((\"scribe_\" + a)))));\n            },\n            scribe: function(a, b, c, d) {\n                if (((this.expectedToHaveComponent && !this.component))) {\n                    return;\n                }\n            ;\n            ;\n                if (((!twttr.decider.isAvailable(\"phoenix_scribe\") || !this._isCategoryAvailable(((c || this.category)))))) {\n                    return;\n                }\n            ;\n            ;\n                d = ((d || {\n                })), b = ((b || {\n                })), ((((twttr && !twttr.loggedIn)) && (b.user_id = 0))), b.page = twttr.audit.currentPage(), b._category_ = ((c || this.category)), b.ts = (new JSBNG__Date).getTime();\n                if (filter = ((d.filter || this.options.filter))) {\n                    b._filter_ = d.filter;\n                }\n            ;\n            ;\n                b = twttr.merge(this._contextData(), b);\n                for (var e in b) {\n                    ((twttr.is.fn(b[e]) && (b[e] = b[e].call(this.component, a, b, c))));\n                ;\n                };\n            ;\n                if (a) {\n                    ((twttr.is.fn(this.eventPrefix) ? a = this.eventPrefix.call(this.component, a) : a = ((this.eventPrefix + a))));\n                    var f = twttr.merge({\n                        event_name: a\n                    }, b);\n                    twttr.ScribeBuffer.instance.addData(this._mapAPIObjectData(f));\n                }\n            ;\n            ;\n            }\n        }), function() {\n            twttr.ScribeBuffer.instance = new twttr.ScribeBuffer, twttr.Scribbler.global = new twttr.Scribbler, window.scribble = twttr.scribble = function() {\n                return twttr.Scribbler.global.scribe.apply(twttr.Scribbler.global, arguments);\n            }, $(window).bind(\"unload\", function() {\n                twttr.ScribeBuffer.instance.send(!0);\n            }), $(JSBNG__document).delegate(\"form\", \"submit\", function() {\n                if (twttr.decider.isAvailable(\"scribe_form_piggyback\")) {\n                    var a = $(this).JSBNG__find(\"input[name='scribe_log']\"), b = $(this).JSBNG__find(\"input[name='reliability_event']\");\n                    ((((a.length && ((b.val() != \"true\")))) && a.val(twttr.ScribeBuffer.instance.getPostBufferForForm())));\n                }\n            ;\n            ;\n            }), (($.browser.msie ? JSBNG__document.JSBNG__onfocusout = function() {\n                twttr.ScribeBuffer.instance.send();\n            } : $(window).JSBNG__blur(function() {\n                twttr.ScribeBuffer.instance.send();\n            })));\n            var a = ((twttr.isPreflight || window.JSBNG__location.host.match(/^(localhost|staging)/gi)));\n            ((((a && window.JSBNG__postMessage)) && $(JSBNG__document).keypress(function(a) {\n                if (((((((a.charCode == 205)) && a.shiftKey)) && a.altKey))) {\n                    var b = \"menubar=no,toolbar=no,personalbar=no,location=no,resizable=yes,status=no,dependent=yes,height=600,width=600,screenX=100,screenY=100,scrollbars=yes\";\n                    window.scribeConsole = window.open(\"/scribe/console\", \"scribe_console\", b);\n                }\n            ;\n            ;\n            })));\n        }(), a();\n    });\n});\nprovide(\"abdecider\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.AbDecider\", function(a, b) {\n            this._impressions = {\n            }, this._updateExperiments(((a || {\n            }))), b = ((b || this.constructor.DEFAULT_REFRESH_INTERVAL));\n            if (((b > 0))) {\n                var c = this;\n                JSBNG__setTimeout(function() {\n                    JSBNG__setInterval(twttr.bind(c, c.updateExperiments), b);\n                }, ((b / 2)));\n            }\n        ;\n        ;\n        }).statics({\n            ABDECIDER_URL: \"/account/available_ab_buckets\",\n            LOG_EVENTS: !1,\n            DEFAULT_REFRESH_INTERVAL: -1\n        }).methods(twttr.EventProvider).methods({\n            experiments: function() {\n                return ((this._experiments || {\n                }));\n            },\n            choose: function(a, b) {\n                if (!this._experiments) {\n                    return \"\";\n                }\n            ;\n            ;\n                var c = this._experiments[a];\n                if (((!c || !c.bucket))) {\n                    return \"\";\n                }\n            ;\n            ;\n                var d = c.bucket, e = c.experiment_key;\n                return ((b || ((((this._impressions[e] != d)) && (this._trackInternal(a), this._impressions[e] = d))))), d;\n            },\n            chooseWithoutImpression: function(a) {\n                return this.choose(a, !0);\n            },\n            track: function(a, b, c) {\n                if (((b == this.constructor.AB_IMPRESSION_EVENT))) {\n                    return;\n                }\n            ;\n            ;\n                this._trackInternal(a, b, c);\n            },\n            updateExperiments: function() {\n                $.getJSON(this.constructor.ABDECIDER_URL, twttr.bind(this, function(a) {\n                    ((a && this._updateExperiments(a)));\n                }));\n            },\n            _updateExperiments: function(a, c) {\n                var d = ((this._experiments || {\n                }));\n                this._experiments = a;\n                if (c) {\n                    return;\n                }\n            ;\n            ;\n                var e = b.util.diff(d, this._experiments, function(a, b) {\n                    return ((((!a || !b)) ? !1 : ((((a.bucket === b.bucket)) && ((a.version === b.version))))));\n                });\n                for (var f in e) {\n                    var g = {\n                        key: f,\n                        previous: e[f][0],\n                        current: e[f][1]\n                    };\n                    this.trigger(\"keyChanged\", g);\n                };\n            ;\n            },\n            set: function(a, b) {\n                if (((!this._experiments || !this._experiments[a]))) {\n                    return;\n                }\n            ;\n            ;\n                this._experiments[a] = twttr.merge({\n                }, this._experiments[a], {\n                    bucket: b\n                });\n            },\n            remove: function(a) {\n                this._experiments[a] = null;\n            },\n            _trackInternal: function(a, b, c) {\n                if (!this._experiments) {\n                    return;\n                }\n            ;\n            ;\n                var d = this._experiments[a];\n                if (!d) {\n                    return;\n                }\n            ;\n            ;\n                var e = twttr.merge(((c || {\n                })), {\n                    bucket: d.bucket,\n                    experiment_key: d.experiment_key,\n                    version: d.version\n                });\n                ((this.constructor.LOG_EVENTS && JSBNG__console.log(((((a + \": \")) + ((b || \"impression\")))))));\n                if (b) {\n                    var f = b.replace(/[^0-9A-Z]+/gi, \"_\").toLowerCase(), g = ((((((((\"web:ddg:\" + d.experiment_key)) + \"::\")) + f)) + \":track\"));\n                    scribble(g, e, \"client_event\");\n                }\n                 else scribble(((((\"web:ddg:\" + d.experiment_key)) + \":::experiment\")), e, \"client_event\");\n            ;\n            ;\n            }\n        }), twttr.abdecider = new twttr.AbDecider, signal(\"\\u003Eab_decider\"), a(twttr.abdecider);\n    });\n});\nprovide(\"app\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.app\", twttr.merge({\n            init: function(a) {\n                var b = this;\n                this.signal(\"init\"), this.$globalActions = $(\"#global-actions\");\n                var c = [\"\\u003EallCodeLoaded\",];\n                ((a && c.push(\"\\u003EwokeUp\"))), using(c, function() {\n                    b._fullyLoaded = !0, b.signal(\"fullyLoaded\");\n                });\n            },\n            fullyLoaded: function() {\n                return !!this._fullyLoaded;\n            },\n            switchToPage: function(a) {\n                this.trigger(\"switchToPage\", a.toLowerCase());\n                if (((this.currentPageName() !== a))) {\n                    var c = this.currentPage();\n                    this._currentPageName = a;\n                    var d = b.util.capitalize(b.util.camelize(a)), e = !1, f = this.pages[a];\n                    ((f || (f = this.pages[a] = new twttr.PagePromise(d), f.whenUnavailable(function() {\n                        twttr.app.switchToPage(\"404\").send(\"notFound\");\n                    }), f.bind(\"loginRequired\", function() {\n                        twttr.ScribeBuffer.instance.send(), twttr.app.switchToPage(\"Login\").send(\"loginRequired\");\n                    }), f.bind(\"notFound\", function() {\n                        twttr.app.switchToPage(\"404\").send(\"notFound\");\n                    }), f.build(), e = !0))), ((c ? (c.send(\"JSBNG__onSwitchAway\"), c.$node.detach(), $(\"#page-container\").empty().append(f.$node)) : f.JSBNG__one(\"rendered\", function() {\n                        (((($(\"#page-container\").has(f.$node).length > 0)) || $(\"#page-container\").empty().append(f.$node)));\n                    }))), this.highlightGlobalNav(a), f.send(\"JSBNG__onSwitchTo\"), ((e && (f.send(\"JSBNG__onFirstSwitch\"), f.send(\"shouldAutoRender\", function(a) {\n                        ((a && f.send(\"render\")));\n                    })))), ((((!c && window.ttft)) && (window.ttft.firstPage = a)));\n                }\n                 else this.currentPage().send(\"initializeProfiler\");\n            ;\n            ;\n                return this.currentPage();\n            },\n            highlightGlobalNav: function(a, b) {\n                a = a.toLowerCase(), this.$globalActions.JSBNG__find(\"li.active[data-global-action]\").removeClass(\"active\"), ((((((a === \"profile\")) && ((b == undefined)))) && (b = twttr.helpers.isCurrentUser($(\"div.profile-header\").attr(\"data-screen-name\"))))), ((((a && ((((a !== \"profile\")) || b)))) && this.$globalActions.JSBNG__find(((((\"li[data-global-action='\" + a)) + \"']\"))).addClass(\"active\")));\n            },\n            currentPage: function() {\n                return this.pages[this._currentPageName];\n            },\n            currentPageName: function() {\n                return this._currentPageName;\n            },\n            getPage: function(a) {\n                return this.pages[a];\n            },\n            isOnPage: function(a) {\n                return ((a === this.currentPageName()));\n            },\n            recalculatePadding: function() {\n                var a = (($(\"div.js-banners\").children().length <= 1));\n                ((a ? this.resetPadding() : this._resizeTopBar()));\n            },\n            _resizeTopBar: function() {\n                var a = 20, b = ((twttr.isT1 ? $(\".js-banners\").height() : (($(\".js-topbar\").height() + a)))), c = $(\"#page-outer\");\n                c.css({\n                    \"padding-top\": b\n                }), ((twttr.isT1 && $(\"#message-drawer\").css({\n                    marginTop: b\n                }))), this._resizeDetailsPane();\n            },\n            _resizeDetailsPane: function() {\n                var a = this.currentPage();\n                ((a && a.send(\"resizeDetailsPane\")));\n            },\n            _repositionDetailsPane: function() {\n                var a = twttr.app.currentPage();\n                ((a && a.send(\"repositionDetailsPane\")));\n            },\n            resetPadding: function() {\n                var a = $(\"#page-outer\");\n                a.css({\n                    \"padding-top\": \"\"\n                }), ((twttr.isT1 && $(\"#message-drawer\").css({\n                    marginTop: \"\"\n                }))), this._resizeDetailsPane();\n            },\n            addComponentToAppBody: function(a) {\n                a.bind(\"destroyed\", function() {\n                    twttr.app.recalculatePadding(), twttr.app._repositionDetailsPane();\n                }), $(\"#page-outer\").prepend(a.$node);\n            },\n            pages: {\n            },\n            caches: {\n                deletedTweets: new twttr.cache.LocalProvider(\"deleted_tweets\"),\n                dmThreads: new twttr.cache.LocalProvider(\"dm_threads\"),\n                draftTweets: new twttr.cache.LocalProvider(\"draft_tweets\"),\n                searchQuerySource: new twttr.cache.LocalProvider(\"__searchQuerySource__:source\")\n            }\n        }, twttr.EventProvider)), a(twttr.app);\n    });\n});\nprovide(\"singletons/external_url_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.externalURLStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"external_urls\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 3600000,\n            cache_key: \"external_url\",\n            minimumDuration: 1000,\n            scribeFocusAfterClick: function() {\n                if (!twttr.decider.isAvailable(\"eurl_dwell_time_store\")) {\n                    return;\n                }\n            ;\n            ;\n                var a = this.getData();\n                if (a) {\n                    var b = ((this.currentTimeAsInt() - a.clickTime));\n                    if (((b > this.minimumDuration))) {\n                        var c = twttr.merge(a.scribeData, {\n                            duration_ms: b\n                        });\n                        trackClient({\n                            action: \"refocus\"\n                        }, c), this.clear();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            setData: function(a, b) {\n                if (!twttr.decider.isAvailable(\"eurl_dwell_time_store\")) {\n                    return;\n                }\n            ;\n            ;\n                if (this.isNotTwitterURL(a)) {\n                    var c = twttr.merge(b.scribeData, {\n                        event_info: \"external_link\",\n                        url: a\n                    }), d = {\n                        clickTime: this.currentTimeAsInt(),\n                        scribeData: c\n                    };\n                    this.constructor.uber.setData.apply(this, [d,]);\n                }\n            ;\n            ;\n            },\n            isNotTwitterURL: function(a) {\n                var b = a.split(\"/\");\n                return ((((b[0].indexOf(\"twitter.com\") == -1)) && ((b[2].indexOf(\"twitter.com\") == -1))));\n            },\n            currentTimeAsInt: function() {\n                return +(new JSBNG__Date);\n            }\n        }), twttr.externalURLStore = new twttr.externalURLStoreSingleton, twttr.app.waitForSignal(\"init\", function() {\n            twttr.externalURLStore.scribeFocusAfterClick();\n        }), a(twttr.externalURLStore);\n    });\n});\nprovide(\"singletons/Router\", function(a) {\n    using().as(function(b) {\n        var c = /^\\/*/, d = /\\/*$/;\n        twttr.klass(\"twttr.Router\", function() {\n            this._routes = [], this.routeMethodsForMustache = {\n            }, this.routeMethods = {\n            }, this.viewedPagesCount = 0, this.pageViewsPerRefresh = 50, this.routingEnabled = !0, this.swiftRoutes = {\n            };\n        }).statics(twttr.EventProvider).statics({\n            match: function(a, b) {\n                a = this.normalizePath(a), b = this.normalizePath(b);\n                var c = {\n                };\n                if (((a === b))) {\n                    return c;\n                }\n            ;\n            ;\n                if (((a === \"\"))) {\n                    return !1;\n                }\n            ;\n            ;\n                var d = a.split(\"/\"), e = b.split(\"/\");\n                if (((d.length !== e.length))) {\n                    return !1;\n                }\n            ;\n            ;\n                for (var f = 0; ((f < d.length)); f++) {\n                    if (((e[f].charAt(0) === \":\"))) {\n                        if (d[f].match(/^\\s*$/)) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        c[e[f].slice(1)] = decodeURIComponent(d[f]);\n                    }\n                     else if (((d[f] !== e[f]))) {\n                        return !1;\n                    }\n                    \n                ;\n                ;\n                };\n            ;\n                return c;\n            },\n            generatePathFunction: function(a) {\n                var b = this;\n                return function(c) {\n                    var d = b.supplantPath(a, c);\n                    return ((((((d === !1)) && !twttr.isTestEnv)) && JSBNG__console.error(\"Failed to generate a path\", a, c))), d;\n                };\n            },\n            supplantPath: function(a, b) {\n                var c = a.split(\"#\").join(\"/#\").split(\"=\").join(\"=/\").split(\"/\"), d = [];\n                for (var e = 0; ((e < c.length)); e++) {\n                    var f = c[e], g = !1;\n                    ((((f.charAt(0) === \"#\")) && (f = f.slice(1), g = !0)));\n                    if (((f.charAt(0) === \":\"))) {\n                        var i = f.slice(1);\n                        if (((typeof b[i] == \"undefined\"))) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        f = b[i], ((((typeof f == \"function\")) && (f = f.call(b)))), f = encodeURIComponent(f);\n                    }\n                ;\n                ;\n                    ((g && (f = ((\"#\" + f))))), d.push(f);\n                };\n            ;\n                return d.join(\"/\").split(\"=/\").join(\"=\").split(\"/#\").join(\"#\");\n            },\n            sanitizeRedirectUrl: function(a) {\n                var b = a, c = b.match(twttr.util.uriRegex), d = c[1];\n                return ((((d && ((d.indexOf(\"javascript\") >= 0)))) && (b = \"http://twitter.com/\"))), b;\n            },\n            performRedirect: function(a) {\n                window.JSBNG__location.assign(this.sanitizeRedirectUrl(a));\n            },\n            getWindowLocation: function() {\n                return window.JSBNG__location;\n            },\n            getCurrentPath: function() {\n                var a = this.getWindowLocation(), b = a.href;\n                if (((((a.hash === \"\")) && ((b.indexOf(\"#\") !== -1))))) {\n                    var c = a.pathname.split(\"/\");\n                    for (var d = 0; ((d < c.length)); d++) {\n                        c[d] = encodeURIComponent(c[d]);\n                    ;\n                    };\n                ;\n                    b = ((a.origin + c.join(\"/\")));\n                }\n            ;\n            ;\n                return this.getPathFromHref(b);\n            },\n            getPathFromHref: function(a) {\n                var b = a.split(\"/\").slice(2).join(\"/\");\n                ((((b.indexOf(\"#\") === -1)) && (b += \"#\")));\n                var c = b.split(\"#\"), d = c[0], e = c[1];\n                ((((d.indexOf(\"/\") === -1)) && (d += \"/\")));\n                var f = d.split(\"/\").slice(1).join(\"/\");\n                return ((((f.indexOf(\"?\") >= 0)) && (f = f.slice(0, f.indexOf(\"?\"))))), ((((e.indexOf(\"?\") >= 0)) && (e = e.slice(0, e.indexOf(\"?\"))))), ((twttr.decider.isAvailable(\"swift_home_timeline\") && (f = f.replace(/^(i$|i\\/)/, \"\")))), ((((((\"/\" + f)) + \"#\")) + e));\n            },\n            getCurrentQueryStringParams: function() {\n                return this.getQueryStringParamsFromHref(window.JSBNG__location.href);\n            },\n            getQueryStringParamsFromHref: function(a) {\n                var b = a.split(\"#\"), c = ((b[0].split(\"?\")[1] || \"\")), d = ((((b[1] || \"\")).split(\"?\")[1] || \"\"));\n                return twttr.merge(this.parseQueryString(c), this.parseQueryString(d));\n            },\n            parseQueryString: function(a) {\n                var b = a.split(\"&\"), c = {\n                };\n                for (var d = 0; ((d < b.length)); d++) {\n                    if (b[d]) {\n                        var e = b[d].split(\"=\");\n                        c[decodeURIComponent(e[0])] = ((e[1] ? decodeURIComponent(e[1].replace(/\\+/g, \"%20\")) : !0));\n                    }\n                ;\n                ;\n                };\n            ;\n                return c;\n            },\n            getHashUpdate: function(a, b) {\n                var c = this.normalizePath(a), d = this.normalizePath(b);\n                if (((c === d))) {\n                    return !1;\n                }\n            ;\n            ;\n                a = a.split(\"/#\").join(\"#\"), b = b.split(\"/#\").join(\"#\"), ((((a.indexOf(\"#\") === -1)) && (a += \"#\"))), ((((b.indexOf(\"#\") === -1)) && (b += \"#\")));\n                var e = a.split(\"#\"), f = b.split(\"#\");\n                return ((((e[0] === f[0])) ? ((\"#\" + f[1])) : ((((((e[1] === \"\")) && ((f[1] === \"\")))) ? ((\"#\" + f[0].slice(a.length))) : ((\"#\" + d))))));\n            },\n            normalizePath: function(a) {\n                if (((twttr.griffin && twttr.griffin.current))) {\n                    for (var b = 0; ((b < twttr.griffin.current.length)); b++) {\n                        if (((a.toLowerCase() == ((\"/#\" + twttr.griffin.current[b].toLowerCase()))))) {\n                            return a.toLowerCase();\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return this.trimSlashes(a.replace(/\\/?#(!|%21)?\\/?/g, \"/\"));\n            },\n            shouldRedirect: function(a, b) {\n                var c = b.split(\"#\"), d = a.split(\"#\");\n                return ((((this.trimSlashes(c[0]) === this.trimSlashes(d[0]))) ? !1 : ((((this.trimSlashes(c[1]) === this.trimSlashes(d[0]))) ? !1 : !0))));\n            },\n            trimSlashes: function(a) {\n                return ((a ? a.replace(c, \"\").replace(d, \"\") : a));\n            },\n            detectHistorySupport: function() {\n                return ((!!window.JSBNG__history && !!JSBNG__history.pushState));\n            }\n        }).methods(twttr.EventProvider).methods({\n            startRouting: function() {\n                this._callCurrentRoutingAction(), this._listenToUrl();\n            },\n            route: function(a, b, c) {\n                var d = this._addRouteMethods(a, b);\n                return this._routes.push({\n                    JSBNG__name: a,\n                    path: b,\n                    fn: c,\n                    method: d\n                }), d;\n            },\n            staticRoute: function(a, b) {\n                var c = this;\n                this.route(a, b, function() {\n                    c.constructor.performRedirect(b);\n                });\n            },\n            redirectRoute: function(a, b, c) {\n                var d = this;\n                this.route(a, b, function(a, b) {\n                    d.redirectTo(d.routeMethods[c](a, b));\n                });\n            },\n            redirectTo: function(a) {\n                this.performRoute(a, !0);\n            },\n            routeTo: function(a) {\n                this.performRoute(a, !1);\n            },\n            performRoute: function(a, b) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                if (((this.pageViewsPerRefresh <= this.viewedPagesCount))) {\n                    return this.constructor.performRedirect(a);\n                }\n            ;\n            ;\n                this.viewedPagesCount++;\n                if (((!this._useHistory() && this.constructor.shouldRedirect(this.constructor.getCurrentPath(), a)))) {\n                    return this.constructor.performRedirect(a);\n                }\n            ;\n            ;\n                this._changeUrlAndCallAction(a, b);\n            },\n            shouldRedirectTo: function(a) {\n                return ((this._useHistory() ? !1 : this.constructor.shouldRedirect(this.constructor.getCurrentPath(), a)));\n            },\n            findMatchingRoute: function(a) {\n                for (var b = 0; ((b < this._routes.length)); b++) {\n                    var c = this.constructor.match(a, this._routes[b].path);\n                    if (c) {\n                        return {\n                            JSBNG__name: this._routes[b].JSBNG__name,\n                            fn: this._routes[b].fn,\n                            args: c,\n                            method: this._routes[b].method,\n                            path: this._routes[b].path\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            getCurrentRoute: function() {\n                return this.findMatchingRoute(this.constructor.getCurrentPath());\n            },\n            _setLocationHash: function(a) {\n                (((($.browser.safari && !JSBNG__navigator.userAgent.match(/Chrome/))) ? window.JSBNG__location.href = ((window.JSBNG__location.href.split(\"#\")[0] + a)) : window.JSBNG__location.hash = a));\n            },\n            replaceHashWithoutRouting: function(a) {\n                this.ignoreNextHashChange = !0, window.JSBNG__location.hash = a;\n            },\n            _changeUrlAndCallAction: function(a, b) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                var c = !1, d = !1, e = this.findMatchingRoute(a);\n                ((this._useHistory() && (((b ? window.JSBNG__history.replaceState(null, null, a) : window.JSBNG__history.pushState(null, null, a))), d = !0)));\n                var f = this.constructor.getHashUpdate(this.constructor.getCurrentPath(), a);\n                if (((twttr.decider.isAvailable(\"swift_home_timeline\") && ((a == \"/\"))))) {\n                    window.JSBNG__location = \"/\";\n                    return;\n                }\n            ;\n            ;\n                ((f && ((b ? window.JSBNG__location.replace(a) : (this._setLocationHash(f), c = !0, d = !0))))), ((c || this._callRoutingActionFor(e))), this.trigger(\"routed\", [e,a,]), ((d && this.trigger(\"urlChanged\", [e,])));\n            },\n            _callRoutingActionForPath: function(a) {\n                var b = this.findMatchingRoute(a);\n                return ((b && this.trigger(\"routeFollowed\", [b,a,]))), this._callRoutingActionFor(b);\n            },\n            _callCurrentRoutingAction: function() {\n                return this._callRoutingActionForPath(this.constructor.getCurrentPath());\n            },\n            _callRoutingActionFor: function(a) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                if (!a) {\n                    this.trigger(\"routeNotFound\");\n                    return;\n                }\n            ;\n            ;\n                return a.fn.call(null, a.args, this.constructor.getCurrentQueryStringParams());\n            },\n            lookupAndNormalizeRoute: function(a) {\n                var b = this.findMatchingRoute(a);\n                return ((b ? this.routeMethods[b.JSBNG__name](b.args) : a));\n            },\n            _addRouteMethods: function(a, b) {\n                var c = this.constructor.generatePathFunction(b), d = ((a + \"Path\"));\n                return this[d] = c, this.routeMethods[a] = c, this.trigger(\"routeAdded\", [d,c,]), c;\n            },\n            _listenToUrl: function() {\n                var a = this;\n                $(window).hashchange(function(b) {\n                    if (a.ignoreNextHashChange) {\n                        a.ignoreNextHashChange = !1;\n                        return;\n                    }\n                ;\n                ;\n                    a._callCurrentRoutingAction();\n                }), ((this.constructor.detectHistorySupport() && $(window).bind(\"popstate\", function(b) {\n                    ((a._useHistory() && a._callCurrentRoutingAction()));\n                })));\n            },\n            _useHistory: function() {\n                return ((((twttr.secrets && twttr.secrets.html5Routing)) && this.constructor.detectHistorySupport()));\n            },\n            _current_path_and_hash: function() {\n                return ((window.JSBNG__location.pathname + window.JSBNG__location.hash));\n            },\n            _current_query_params: function() {\n                return window.JSBNG__location.search;\n            },\n            shouldRedirectToCanonicalUrl: function(a) {\n                var b = this.swiftRoutes[a.JSBNG__name];\n                if (((!b || !twttr.decider.isAvailable(b.decider)))) {\n                    return !1;\n                }\n            ;\n            ;\n                ((a.args.screen_name && (a.args.screen_name = a.args.screen_name.replace(/^@/, \"\"))));\n                var c = a.method(a.args), d = this._current_path_and_hash().split(\"?\")[0];\n                if (((((d !== \"/\")) && ((d !== c))))) {\n                    var e = this._current_query_params();\n                    return c.toLowerCase().replace(/(?=#|$)/, function() {\n                        return e;\n                    });\n                }\n            ;\n            ;\n                return !1;\n            }\n        }), a(twttr.Router);\n    });\n});\nprovide(\"streams/Stream\", function(a) {\n    using(\"_\", \"mixins/serverRenderableObject\").as(function(b, _, c) {\n        twttr.stream = twttr.klass;\n        var d = twttr.klass(\"twttr.streams.Stream\", function(a, b, c) {\n            this.params = ((a || {\n            })), b = ((b || [])), ((((b instanceof twttr.API.util.BaseCollection)) && (b = b.array))), this.items = b, this.screenName = this.params.screenName, this.newItemsCount = this.items.length, this.itemViewClass = ((this.params.itemViewClass || this.itemViewClass)), this.streamItemClass = ((this.params.streamItemClass || \"stream-item\")), this.additionalStreamItemClass = ((this.params.additionalStreamItemClass || this.additionalStreamItemClass)), this.oldItemsCount = 0, this._page = 1, this.focusedItemId = null, this.highlightedItemId = null, this.scribbler = ((this.params.scribbler || new twttr.Scribbler(!1))), this.scribeComponentName = \"stream\", this.ignoreScribeItemPosition = !0, this.streamManager = c, this.streamManagerDomNodeSelector = ((c ? c.domNodeSelector : null)), ((this.params._setHeader && this.methods({\n                _setHeader: a._setHeader\n            })));\n            var d = twttr.views[this.streamViewClass];\n            ((d || (((twttr.development && JSBNG__console.warn(((((\"Stream view class '\" + this.streamViewClass)) + \"' not found. Defaulting to twttr.views.Stream\"))))), d = twttr.views.Stream))), this.$node = this.$domNode(function() {\n                return (new d({\n                })).$html();\n            }), ((twttr.isT1 && this.$node.attr(\"data-component-term\", this.scribeComponentName)));\n        }).mixin(c).methods(twttr.EventProvider).methods({\n            domNodeSelector: function() {\n                if (!this.streamManagerDomNodeSelector) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this._namespace.match(/\\.([^.]+)$/)[1];\n                return streamClass = ((twttr.util.underscore(a) + \"-stream\")), ((((this.streamManagerDomNodeSelector + \" div.\")) + streamClass));\n            },\n            NEW_ITEMS_COUNT_MAX: 100,\n            NEW_ITEMS_COUNT_CUTOFF: 40,\n            _shouldCache: !0,\n            _expandable: !0,\n            streamViewClass: \"Stream\",\n            itemViewClass: null,\n            afterSwitchingToAgain: function(a) {\n                ((a ? a() : $.noop));\n            },\n            afterFirstSwitchingTo: function(a) {\n                ((a ? a() : $.noop));\n            },\n            beforeSwitchingAway: function() {\n            \n            },\n            _setTitle: function() {\n            \n            },\n            _getHeaderComponent: function() {\n            \n            },\n            hasPromotedContent: function() {\n                return !1;\n            },\n            getMoreOldItems: function(a) {\n                var b = this;\n                if (((((this._loadingMoreLock || this.noMoreOldItems)) || this._errorComponent))) {\n                    return;\n                }\n            ;\n            ;\n                var c = ((((this.page || this.cursor)) || this._sinceId));\n                this.isLoadingMore(), using(twttr.bundleMore, function() {\n                    b._fetchItems(function(d, e) {\n                        if (((e !== twttr.streams.SUCCESS))) b._showError(e);\n                         else {\n                            var f = b.items.slice(((b.items.length - b.oldItemsCount)));\n                            ((((c && ((c > 0)))) ? b.JSBNG__onGotOldItems(f) : b.JSBNG__onGotInitialResults(b.items))), b._showOldItems(), b._page++;\n                        }\n                    ;\n                    ;\n                        b.doneLoadingMore(), b.updateHeader(), ((a && a(d, e))), ((twttr.decider.isInfiniteScroll() && b.showLoadingSpinner()));\n                    });\n                });\n            },\n            getCurrentlyFocusedItem: function() {\n                return ((this.focusedItemId ? this.$streamItems().JSBNG__find(this.itemSelector(this.focusedItemId)) : null));\n            },\n            getCurrentlyHighlightedItem: function() {\n                return ((this.highlightedItemId ? this.$streamItems().JSBNG__find(this.itemSelector(this.highlightedItemId)) : null));\n            },\n            getFirstItem: function() {\n                return this.$streamItems().JSBNG__find(((((\".\" + this.streamItemClass)) + \":first\")));\n            },\n            focusItem: function(a) {\n                this.focusedItemId = a.attr(\"data-item-id\"), a.JSBNG__focus();\n            },\n            unfocusItem: function(a) {\n                this.focusedItemId = null, a.JSBNG__blur();\n            },\n            highlightItem: function(a) {\n                var b = this.getCurrentlyHighlightedItem();\n                ((b && b.removeClass(\"hovered-stream-item\").removeClass(\"js-had-hovered-stream-item\"))), this.focusedItemId = a.attr(\"data-item-id\"), this.highlightedItemId = a.attr(\"data-item-id\"), ((a.hasClass(\"open\") ? a.addClass(\"js-had-hovered-stream-item\") : a.addClass(\"hovered-stream-item\")));\n            },\n            highlightNext: function() {\n                this.shiftHighlight(!1);\n            },\n            highlightPrevious: function() {\n                this.shiftHighlight(!0);\n            },\n            shiftHighlight: function(a) {\n                var b = this.getCurrentlyHighlightedItem();\n                if (!b) {\n                    this.highlightItem(this.getFirstItem());\n                    return;\n                }\n            ;\n            ;\n                var c = ((a ? b.prev() : b.next()));\n                ((c.length && (this.highlightItem(c), this.scrollStreamTo(c))));\n            },\n            scrollStreamTo: function(a) {\n                var b = a.offset().JSBNG__top, c = Math.round(((b - ((twttr.$win.height() / 2)))));\n                twttr.$win.scrollTop(c);\n            },\n            dom: function() {\n                return this.$node;\n            },\n            $streamItems: function() {\n                return this.$find(\"div.stream-items\");\n            },\n            $find: function() {\n                var a = this.dom();\n                return a.JSBNG__find.apply(a, arguments);\n            },\n            itemSelector: function(a) {\n                return ((((((((\".\" + this.streamItemClass)) + \"[data-item-id='\")) + a)) + \"']\"));\n            },\n            selectedItem: function(a) {\n                return this.$streamItems().JSBNG__find(this.itemSelector(a));\n            },\n            unshift: function(a) {\n                ((twttr.is.array(a) ? (this.newItemsCount += a.length, this.items.unshift.apply(this.items, a)) : (this.newItemsCount += arguments.length, this.items.unshift(arguments)))), this.trigger(\"newItemsCountChanged\", [this.newItemsCount,]);\n            },\n            addAsNewItem: function(a) {\n                this.items.unshift(a), this.newItemsCount++, this.allowRerender(a);\n            },\n            push: function(a) {\n                ((twttr.is.array(a) ? (this.oldItemsCount += a.length, this.items.push.apply(this.items, a)) : (this.oldItemsCount += arguments.length, this.items.push(arguments))));\n            },\n            splice: function(a, b) {\n                var c;\n                ((twttr.is.array(b) ? (c = [a,0,].concat(b), this.items.splice.apply(this.items, c)) : (c = Array.prototype.slice.call(arguments), c.splice(1, 0, 0), this.items.splice.apply(this.items, c))));\n            },\n            markAsRendered: function(a) {\n                this.itemIds = ((this.itemIds || {\n                }));\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.itemIds[b] = 1;\n            },\n            isDuplicate: function(a) {\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                return this.itemIds = ((this.itemIds || {\n                })), !!this.itemIds[b];\n            },\n            allowRerender: function(a) {\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.itemIds = ((this.itemIds || {\n                })), delete this.itemIds[b];\n            },\n            _renderItemHtml: function(a) {\n                function b() {\n                    return ((f.render_withheld && f.render_withheld()));\n                };\n            ;\n                var c = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.markAsRendered(a);\n                var d;\n                ((twttr.is.fn(this.itemViewClass) ? d = this.itemViewClass(a) : d = twttr.views[this.itemViewClass]));\n                var e = a;\n                ((((this.itemForRender && twttr.is.fn(this.itemForRender))) && (e = this.itemForRender.call(this, a))));\n                var f = new d(e);\n                f.query = ((this.params.query || f.query));\n                var g = twttr.views.StreamItem;\n                ((this.itemViewWrapperClass && (g = twttr.views[this.itemViewWrapperClass])));\n                var i = ((this.streamItemClass ? [this.streamItemClass,] : []));\n                if (this.additionalStreamItemClass) {\n                    var j = ((twttr.is.fn(this.additionalStreamItemClass) ? this.additionalStreamItemClass(a) : this.additionalStreamItemClass));\n                    i.push(j);\n                }\n            ;\n            ;\n                if (((((this._expandable && twttr.decider.isExpando())) && !b()))) {\n                    i.push(\"expanding-stream-item\");\n                    if (((((twttr.expando !== !0)) && ((twttr.expando !== \"expando\"))))) {\n                        switch (twttr.expando) {\n                          case \"labels\":\n                            i.push(\"yes-to-labels\");\n                            break;\n                          case \"more\":\n                            i.push(\"more-not-open\");\n                            break;\n                          case \"colorful\":\n                            i.push(\"colorful-links\");\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return ((b() ? i.push(\"withheld-item\") : ((((((f.is_withheld && f.is_withheld())) && f.is_current_user())) && i.push(\"withheld-own-item\"))))), (new g({\n                    item_html: f.html(),\n                    item_id: c,\n                    item_type: this.streamItemType,\n                    item_class: i.join(\" \")\n                })).html();\n            },\n            _renderItemsHtml: function(a) {\n                var b = this, c = [];\n                return $.each(a, function(a, d) {\n                    ((b.isDuplicate(d) || c.push(b._renderItemHtml(d))));\n                }), c.join(\"\");\n            },\n            _renderItems: function(a) {\n                return $(this._renderItemsHtml(a));\n            },\n            remove: function(a) {\n                this.selectedItem(a).remove();\n            },\n            rerenderItem: function(a, b) {\n                this.selectedItem(a).replaceWith(this._renderItemHtml(b));\n            },\n            _showNewItems: function(a) {\n                var b = this.$streamItems();\n                this.beforeShowNewItems(), ((((this.newItemsCount > this.NEW_ITEMS_COUNT_MAX)) && (b.empty(), this.items = this.items.slice(0, this.NEW_ITEMS_COUNT_CUTOFF), this.newItemsCount = this.NEW_ITEMS_COUNT_CUTOFF)));\n                var c = this.items.slice(0, this.newItemsCount), d = this._renderItems(c);\n                ((((a == \"initial\")) ? this.JSBNG__onGotInitialResults(this.items) : ((((((a != \"initial\")) && ((this.newItemsCount > 0)))) && this.JSBNG__onGotNewItems(c))))), b.prepend(d), this.JSBNG__onShowNewItems(d), this.newItemsCount = 0, this.trigger(\"newItemsCountChanged\", [0,]);\n            },\n            _showOldItems: function(a) {\n                var b = this.$streamItems();\n                this.beforeShowOldItems();\n                var c = this.items.slice(((this.items.length - this.oldItemsCount))), d = this._renderItems(c);\n                b.append(d), this.JSBNG__onShowOldItems(d), this.oldItemsCount = 0;\n            },\n            render: function() {\n                this._showNewItems(\"initial\"), this._showOldItems(!0);\n            },\n            isEmpty: function() {\n                return ((this.items.length === 0));\n            },\n            reachedTheEnd: function() {\n                ((this.noMoreOldItems || (this.noMoreOldItems = !0, this.markStreamEnd(), this.hideLoadingSpinner(), this.trigger(\"streamEnd\"))));\n            },\n            markStreamEnd: function() {\n                var a = this;\n                if (this._alreadyMarkedEnd) {\n                    return;\n                }\n            ;\n            ;\n                this._alreadyMarkedEnd = !0, using(twttr.bundleMore, function() {\n                    a.endOfStreamComponent = ((a.isEmpty() ? a._getEmptyStreamComponent() : a._getStreamEndComponent())), ((a.endOfStreamComponent && a.endOfStreamComponent.$node.appendTo(a.$node)));\n                });\n            },\n            switchEndOfStreamMarker: function() {\n                if (this.endOfStreamComponent) {\n                    var a = this._getStreamEndComponent();\n                    ((a && (this.endOfStreamComponent.$node.replaceWith(a.$node), this.endOfStreamComponent = a)));\n                }\n            ;\n            ;\n            },\n            _showError: function(a) {\n                var b = this;\n                using(twttr.bundleMore, function() {\n                    b.hideLoadingSpinner(), ((b._errorComponent && (b._errorComponent.destroy(), delete b._errorComponent)));\n                    var c = b._getStreamErrorComponent(a);\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    c.bind(\"tryAgain\", function(a) {\n                        c.destroy(), delete b._errorComponent, b.getMoreOldItems();\n                    }), b._errorComponent = c, c.$node.appendTo(b.dom());\n                });\n            },\n            _getStreamEndComponent: function() {\n                return new twttr.components.StreamEnd(this._getStreamEndHtml(), this._getStreamEndShowBird());\n            },\n            _getEmptyStreamComponent: function() {\n                return new twttr.components.StreamEnd(this._getEmptyStreamHtml());\n            },\n            _getStreamErrorComponent: function(a) {\n                return ((((a === twttr.streams.DECIDER)) ? new twttr.components.StreamEnd(this._getStreamErrorHtml(a)) : new twttr.components.StreamWhaleEnd(this._getStreamWhaleText())));\n            },\n            _getStreamLoadingComponent: function() {\n                return new twttr.views.StreamLoading;\n            },\n            _getStreamWhaleText: function() {\n                return _(\"Loading seems to be taking a while.\");\n            },\n            _getEmptyStreamHtml: function() {\n            \n            },\n            _getStreamEndHtml: function() {\n                return ((((this.items.length < 20)) ? \"\" : _(\"\\u003Ca href='#' class='back-to-top'\\u003EBack to top &uarr;\\u003C/a\\u003E\")));\n            },\n            _getStreamErrorHtml: function(a) {\n                return _(\"This feature is temporarily unavailable.\");\n            },\n            _getStreamEndShowBird: function() {\n                return !0;\n            },\n            isLoadingMore: function() {\n                this._loadingMoreLock = !0, this.showLoadingSpinner();\n            },\n            showLoadingSpinner: function() {\n                var a = this.dom();\n                ((((((((a.JSBNG__find(\"div.stream-loading\").length === 0)) && !this._alreadyMarkedEnd)) && !this._errorComponent)) && this._getStreamLoadingComponent().render(a, \"append\")));\n            },\n            stream_user_is_current_user: function() {\n                return ((((twttr.currentUser && this.screenName)) && ((twttr.currentUser.screenName === this.screenName))));\n            },\n            doneLoadingMore: function() {\n                this._loadingMoreLock = !1, this.hideLoadingSpinner(), this.trigger(\"doneLoadingMore\");\n            },\n            hideLoadingSpinner: function() {\n                this.dom().JSBNG__find(\"div.stream-loading\").remove();\n            },\n            JSBNG__onGotInitialResults: function(a) {\n                this._scribeResults(\"initial\", a);\n            },\n            JSBNG__onInsertItems: function(a) {\n                this._scribeResults(\"insert\", a);\n            },\n            JSBNG__onGotNewItems: function(a) {\n                this._scribeResults(\"get_newer\", a);\n            },\n            JSBNG__onGotOldItems: function(a) {\n                this._scribeResults(\"get_older\", a);\n            },\n            _scribeResults: function(a, b, c) {\n                (((($.inArray(a, [\"initial\",\"error\",\"insert\",]) == -1)) && this.scribbler.scribe({\n                    component: \"stream\",\n                    action: a\n                }, {\n                    item_count: b.length,\n                    cursor_or_page: this._cursorOrPage()\n                })));\n            },\n            _scribeEmptyResults: function(a, b, c) {\n                var d = this._cursorOrPage();\n                if (((((a == \"error\")) || ((((a == \"initial\")) && !b.length))))) {\n                    var e = {\n                        item_count: 0,\n                        event_value: 0,\n                        referring_event: a\n                    };\n                    ((d && (e.cursor_or_page = d))), ((((((((a == \"error\")) && c)) && c.status_code)) && (e.status_code = c.status_code))), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: ((((a == \"error\")) ? \"error\" : \"no_results\"))\n                    }, e);\n                }\n                 else if (((((a != \"initial\")) && ((a != \"insert\"))))) {\n                    var f = {\n                        item_count: b.length\n                    };\n                    ((d && (f.cursor_or_page = d))), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: a\n                    }, f);\n                }\n                \n            ;\n            ;\n            },\n            _cursorOrPage: function() {\n                return ((((((((this._sinceId || this.cursor)) || ((((this.page && ((this.page > 0)))) && this.page)))) || ((((this._page && ((this._page > 0)))) && this._page)))) || -1));\n            },\n            _registerAddToStreamEvent: function(a, b, c) {\n                var d = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d.addAsNewItem(a), d._showNewItems())));\n                });\n            },\n            _registerRemoveFromStreamEvent: function(a, b, c, d) {\n                var e = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d = ((d || \"id\")), e.remove(a[d]), e.items = twttr.filter(e.items, function(b) {\n                        return ((((b[d] !== a[d])) ? b : null));\n                    }), ((e.isEmpty() && e.reachedTheEnd())))));\n                });\n            },\n            _registerUpdateStreamEvent: function(a, b, c, d) {\n                var e = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d = ((d || \"id\")), e.items = twttr.map(e.items, function(b) {\n                        return ((((b[d] === a[d])) ? a : b));\n                    }), e.rerenderItem(a[((d || \"id\"))], a))));\n                });\n            },\n            _registerEvent: function(a, b, c) {\n                ((this._boundEvents || (this._boundEvents = []))), a.bind(b, c), this._boundEvents.push({\n                    obj: a,\n                    JSBNG__name: b,\n                    cb: c\n                });\n            },\n            unbindEvents: function() {\n                ((this._boundEvents && (twttr.each(this._boundEvents, function(a) {\n                    a.obj.unbind(a.JSBNG__name, a.cb);\n                }), this._boundEvents = [])));\n            },\n            beforeShowNewItems: function() {\n            \n            },\n            beforeShowOldItems: function() {\n            \n            },\n            JSBNG__onShowNewItems: function(a) {\n            \n            },\n            JSBNG__onShowOldItems: function(a) {\n            \n            }\n        });\n        twttr.aug(twttr.streams, {\n            SUCCESS: 1,\n            ERROR: 2,\n            PROTECTED: 3,\n            DECIDER: 4,\n            WHALE: 5,\n            TIMEOUT: 6\n        }), ((twttr.isT1 ? d.methods({\n            _setHeader: null,\n            _expandable: !1,\n            updateHeader: function() {\n                var a = ((this.streamManager && this.streamManager.$headerContainer()));\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                this._updateHeaderFromStream(a);\n            },\n            _updateHeaderFromStream: function(a) {\n            \n            }\n        }) : d.methods({\n            updateHeader: function() {\n                ((this.header || (((this.header = this._getHeaderComponent()) && this.$find(\"div.stream-items\").prepend(this.header.$node.addClass(\"stream-header\"))))));\n            }\n        }))), a(twttr.streams.Stream);\n    });\n});\nprovide(\"scribbles\", function(a) {\n    using().as(function(b) {\n        twttr.augmentString(\"twttr.scribbles\", {\n            logViewProfileDetails: function(a) {\n                var b = $(this), c = {\n                }, d = $(a.target), e = \"view-profile\";\n                ((d.is(\"img\") ? c.target = \"image\" : ((d.is(\"a\") && (c.target = \"link\")))));\n                if (b.is(\"div.dashboard .user-profile-link\")) {\n                    c.component = \"dashboard\", ((b.is(\".new-followers .user-profile-link\") && (c.subcomponent = \"new-followers\")));\n                }\n                 else {\n                    if (b.is(\"div.details-pane .user-profile-link, div.details-pane .twitter-atreply\")) {\n                        c.component = \"details-pane\";\n                        if (b.is(\".related-tweets .user-profile-link, .related-tweets .twitter-atreply\")) {\n                            var f = b.closest(\".tweet\");\n                            twttr.viewHelpers.addRelatedTweetsLogging(f, c, e);\n                        }\n                    ;\n                    ;\n                    }\n                     else ((b.is(\".stream-tweet .user-profile-link, .stream-tweet .twitter-atreply\") ? c.component = \"stream\" : ((b.is(\".twttr-dialog .user-profile-link\") && (c.component = \"dialog\", c.dialog_type = b.closest(\".twttr-dialog\").attr(\"type\"))))));\n                ;\n                }\n            ;\n            ;\n                c.input = \"click\", c.tweet_id = ((b.closest(\".tweet\").attr(\"data-tweet-id\") || \"\")), c.profile_id = ((((b.data(\"user-id\") || b.data(\"screen-name\"))) || b.closest(\".js-profile-popup-actionable\").data(\"user-id\"))), scribble(e, c);\n            }\n        }), a(twttr.scribbles);\n    });\n});\nprovide(\"Cards\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        var c = function(a) {\n            return ((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.photos.length\"))) && !!a.cards.photos.length));\n        }, d = function(a) {\n            var b = 0, c;\n            if (((a.has_embedded_player !== undefined))) {\n                return a.has_embedded_player;\n            }\n        ;\n        ;\n            if (((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.players.length\"))) && !!a.cards.players.length))) {\n                c = a.cards.players.length;\n                for (; ((b < c)); b++) {\n                    a.cards.players[b].players = twttr.filter(a.cards.players[b].players, function(a) {\n                        return ((a && ((a.source_type == \"text/html\"))));\n                    });\n                ;\n                };\n            ;\n                return a.has_embedded_player = !!c, a.has_embedded_player;\n            }\n        ;\n        ;\n            return !1;\n        }, e = function(a) {\n            return ((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.summaries.length\"))) && !!a.cards.summaries.length));\n        }, f = function(a) {\n            return ((twttr.exists(a, \"entities.media.length\") && !!a.entities.media.length));\n        }, g = function(a) {\n            return ((((d(a) || e(a))) || c(a)));\n        }, i = twttr.klass(\"twttr.Cards\").methods({\n            hasPhotos: c,\n            hasPlayers: d,\n            hasSummaries: e,\n            hasCards: g,\n            hasCardPhotoEntities: f\n        });\n        a(i);\n    });\n});\nprovide(\"multiGlobals/client_app_tracking\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        (function() {\n            twttr.Scribbler.clientAppDefaultTerms = function() {\n                var a = {\n                    client: \"web\"\n                }, c = twttr.audit.currentPage();\n                ((c && (a.page = b.util.underscore(c))));\n                var d = twttr.audit.currentAction();\n                return ((d && (a.section = b.util.underscore(d)))), a;\n            }, twttr.Scribbler.clientAppEventNameGenerator = function(a, b) {\n                return b = ((b || twttr.Scribbler.clientAppDefaultTerms())), a = twttr.merge(b, a), [a.client,a.page,a.section,a.component,a.element,a.action,].join(\":\");\n            }, twttr.Scribbler.clientEvent = new twttr.Scribbler({\n            }, {\n                noob_level: function() {\n                    var a = ((twttr.loggedIn ? twttr.helpers.userNoobLevel(twttr.currentUser) : -1));\n                    return ((((a >= 0)) ? a : null));\n                },\n                internal_referer: function() {\n                    return ((((twttr.audit && twttr.audit.path(1))) || null));\n                },\n                referring_event: function(a) {\n                    if (((twttr.isT1 && a))) {\n                        if (((twttr.is.object(a) && ((a[\"action\"] == \"impression\"))))) {\n                            return twttr.clicks.lastClick();\n                        }\n                    ;\n                    ;\n                        if (twttr.is.string(a)) {\n                            var b = a.split(\":\");\n                            if (((b[((b.length - 1))] == \"impression\"))) {\n                                return twttr.clicks.lastClick();\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            }, \"client_event\", twttr.Scribbler.clientAppEventNameGenerator), twttr.Scribbler.getElementEventNameTerms = function(a) {\n                var b = $(a), c = b.closest(\"[data-element-term]\"), d = b.closest(\"[data-component-term]\"), e = b.closest(\"[data-section-term]\"), f = c.attr(\"data-element-term\");\n                componentTerm = d.attr(\"data-component-term\"), sectionTerm = e.attr(\"data-section-term\");\n                var g = {\n                };\n                if (((componentTerm && f))) {\n                    g.component = ((((componentTerm + \"_\")) + f));\n                }\n                 else {\n                    if (((componentTerm || f))) {\n                        g.component = ((componentTerm || f));\n                    }\n                ;\n                }\n            ;\n            ;\n                return ((sectionTerm && (g.section = sectionTerm))), g;\n            }, twttr.Scribbler.clientEvent.spawnWithTerms = function(a, b) {\n                var c = function(b) {\n                    var c = twttr.Scribbler.clientAppDefaultTerms();\n                    return scribeTerms = twttr.merge({\n                    }, b, a), twttr.Scribbler.clientAppEventNameGenerator(scribeTerms, c);\n                }, d = this.spawn(b, c);\n                return d.spawnWithTerms = this.spawnWithTerms, d;\n            }, window.trackClient = twttr.trackClient = function(a, b) {\n                return ((((arguments[1] && ((typeof arguments[1] == \"string\")))) && (arguments[1] = {\n                    context: arguments[1]\n                }))), twttr.Scribbler.clientEvent.scribe.apply(twttr.Scribbler.clientEvent, arguments);\n            }, window.trackElement = twttr.trackElement = function(a, b, c) {\n                ((((typeof b == \"string\")) && (b = {\n                    action: b\n                })));\n                var d = twttr.merge(twttr.Scribbler.getElementEventNameTerms(a), b);\n                ((d.component && trackClient(d, c)));\n            }, window._scribble = function() {\n                ((twttr.decider.isAvailable(\"old_webclient_events\") && twttr.Scribbler.global.scribe.apply(twttr.Scribbler.global, arguments)));\n            };\n        })(), twttr.app.waitForSignal(\"init\", function() {\n            ((twttr.isT1 ? twttr.app.bind(\"streamSwitchedTo\", function(a, b) {\n                var c = {\n                }, d = b.pageNameUnderscore;\n                ((b.addImpressionData && b.addImpressionData(c))), trackClient({\n                    action: \"impression\"\n                }, c);\n            }) : ($(\"#logo\").click(function() {\n                trackClient({\n                    section: \"top_nav\",\n                    component: \"logo\",\n                    action: \"click\"\n                });\n            }), $(\"#global-actions li a\").click(function() {\n                var a = $(this).parent().attr(\"data-global-action\");\n                trackClient({\n                    section: \"top_nav\",\n                    component: ((a + \"_nav\")),\n                    action: \"click\"\n                });\n            })))), $(\"button.js-global-new-tweet,a.js-global-new-tweet\").click(function() {\n                trackClient({\n                    section: \"top_nav\",\n                    component: \"new_tweet_button\",\n                    action: \"click\"\n                });\n            }), ((twttr.decider.isAvailable(\"scribe_general_reliability_events\") && window.JSBNG__setTimeout(function() {\n                twttr.ScribeBuffer.instance.sendReliabilityEvent(function() {\n                    trackClient({\n                        page: \"scribe\",\n                        section: \"reliability\",\n                        component: \"client\",\n                        action: \"impression\"\n                    });\n                });\n            }, 30000)));\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePageDetailsPane\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.streamablePageDetailsPane\", function() {\n            return this.click({\n                \".stream span.js-actions, .stream ul.js-actions\": function(a, b) {\n                    return a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \"div.details-pane div.stream-item\": function(a, b) {\n                    if ($(a.target).is(\".twitter-timeline-link\")) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = b.JSBNG__find(\".tweet\"), d = c.attr(\"data-tweet-id\"), e = {\n                        component: \"details-pane\"\n                    };\n                    ((b.is(\".related-tweets .stream-item\") ? twttr.viewHelpers.addRelatedTweetsLogging(c, e, \"tweet-click\") : ((b.is(\".in-reply-to .stream-item\") && (e.subcomponent = \"in-reply-to\"))))), e.embedded_media_types = c.JSBNG__find(\".icons .media\").map(function(a, b) {\n                        var c = $(b);\n                        return [c.data(\"media-type\"),c.data(\"media-class\"),];\n                    }).get();\n                    var f = c.attr(\"data-impression-id\");\n                    this.loadItemInDetailsPane(d, \"tweet\", {\n                        log: e,\n                        push: !0,\n                        impressionId: f\n                    });\n                },\n                \"div.details-pane .user-detailed-list-item .user-screen-name\": function(a, b) {\n                    var c = parseInt(b.attr(\"data-user-id\"), 10);\n                    return this.loadItemInDetailsPane(c, \"user\", {\n                        push: !0\n                    }), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".stream-tabs .stream-tab \\u003E a, .stream-tabs .dropdown-link .stream-link \\u003E a\": function(a, b) {\n                    var c = b.parent(), d = b.attr(\"href\");\n                    if (((d != \"#\"))) {\n                        var e = twttr.router.findMatchingRoute(d);\n                        if (((((e && e.fn.pageName)) && e.fn.actionName))) {\n                            var f = twttr.util.underscore(e.fn.actionName), g = twttr.util.underscore(e.fn.pageName);\n                            trackClient({\n                                page: g,\n                                section: f,\n                                component: \"stream_nav_tab\",\n                                action: \"click\"\n                            });\n                        }\n                    ;\n                    ;\n                    }\n                     else if (((!c.hasClass(\"stream-tab-lists\") && c.closest(\".stream-tab-lists\").length))) {\n                        var i = ((((twttr.audit.currentPage() == \"JSBNG__home\")) ? \"list_in_home\" : \"lists\"));\n                        trackClient({\n                            section: i,\n                            component: \"stream_nav_tab\",\n                            action: \"create\"\n                        });\n                    }\n                    \n                ;\n                ;\n                },\n                \".stream .stream-item\": function(a, b) {\n                    $eventTarget = $(a.target);\n                    var c = $eventTarget.is(\"div.stream-item a.tweet-timestamp, div.stream-item a.tweet-timestamp *\"), d = $eventTarget.is(\"div.stream-item a.twitter-timeline-link\"), e = $eventTarget.is(\"div.stream-user-buttons *\"), f = $eventTarget.parents(\"div.stream-item\").is(\"div.feedback-shown\"), g = $eventTarget.is(\"div.stream-item a.twitter-timeline-link[data-twitter-media-url=\\\"true\\\"]\"), i = $eventTarget.is(\"div.withheld-item *\"), j = ((b.is(\".js-activity\") && !b.is(\".js-activity-retweet, .js-activity-favorite, .js-activity-reply, .js-activity-mention\")));\n                    if (((((((((((c || ((d && !g)))) || e)) || f)) || j)) || i))) {\n                        return;\n                    }\n                ;\n                ;\n                    this.toggleFocus(b), ((((twttr.decider.isAvailable(\"turkey_prevent_timeline_click\") && g)) && a.preventDefault()));\n                },\n                \".stream-item-activity .user-content-medium\": function(a, b) {\n                    var c = b.parents(\".stream-item\"), d = b.closest(\".sub-stream-item\"), e = ((((c.hasClass(\"focused-stream-item\") && d.hasClass(\"expand-activity-item\"))) && ((this.panes.size() <= 1))));\n                    return ((e || (d.siblings().removeClass(\"expand-activity-item\"), d.addClass(\"expand-activity-item\"), c.removeClass(\"focused-stream-item\")))), this.toggleFocus(c), !1;\n                },\n                \".stream .user-profile-link, .stream .twitter-atreply, div.details-pane .user-profile-link, div.details-pane .twitter-atreply\": function(a, b) {\n                    var c = twttr.helpers.getUserIdentifier(b), d = {\n                    }, e = {\n                        component: \"stream\"\n                    };\n                    d.log = e, ((b.is(\"div.details-pane .user-profile-link, div.details-pane .twitter-atreply\") && (d.push = !0, e.component = \"details-pane\")));\n                    var f = ((b.closest(\".promoted-tweet\").attr(\"data-impression-id\") || b.closest(\".promoted-account\").attr(\"data-impression-id\")));\n                    ((b.is(\"div.details-pane .user-profile-link, .stream .user-profile-link\") && (d.impressionId = f))), ((((twttr.app.isOnPage(\"search\") && b.is(\".stream .user-profile-link, .stream .twitter-atreply\"))) && (d.searchClick = b.closest(\".stream-tweet\")))), twttr.scribbles.logViewProfileDetails.call(b, a);\n                    var g = b.is(\"div.withheld-item *\");\n                    return ((g || this.loadItemInDetailsPane(c, \"user\", d))), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".stream .twitter-hashtag\": function(a, b) {\n                    a.stopPropagation();\n                },\n                \".stream .twitter-place, div.details-pane .twitter-place\": function(a, b) {\n                    var c = b.closest(\".tweet\").attr(\"data-tweet-id\"), d = {\n                        placeId: b.attr(\"data-place-id\")\n                    };\n                    return ((b.is(\"div.details-pane .js-tweets-at-this-place\") && (d.push = !0))), this.loadItemInDetailsPane(c, \"tweet_geo\", d), !1;\n                },\n                \".stream .twitter-listname\": function(a, b) {\n                    return twttr.router.routeTo(twttr.router.lookupAndNormalizeRoute($this.attr(\"href\"))), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".js-tweet-geo-text, div.details-pane .js-tweets-at-this-place\": function(a, b) {\n                    var c = b.attr(\"data-tweet-id\"), d = {\n                        placeId: b.attr(\"data-place-id\")\n                    };\n                    return ((b.is(\"div.details-pane .js-tweets-at-this-place, div.details-pane .tweet-geo-text\") && (d.push = !0))), this.loadItemInDetailsPane(c, \"tweet_geo\", d), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".pane-toolbar a.pane-close\": function(a, b) {\n                    return this.unfocusStreamItem(), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".pane-toolbar a.pane-back\": function(a, b) {\n                    return this.panes.pop(), a.stopPropagation(), a.preventDefault(), !1;\n                }\n            }).JSBNG__focus({\n                \".stream span.js-actions, .stream ul.js-actions\": function(a, b) {\n                    return a.stopPropagation(), !1;\n                }\n            }).methods({\n                toggleFocus: function(a) {\n                    ((((a.hasClass(\"focused-stream-item\") && ((this.panes.size() <= 1)))) ? (this.streamManager.getCurrent().unfocusItem(a), this.unfocusStreamItem()) : (this.streamManager.getCurrent().focusItem(a), this.focusStreamItem(a))));\n                },\n                focusStreamItem: function(a) {\n                    a.addClass(\"focused-stream-item\").siblings().removeClass(\"focused-stream-item\").removeClass(\"light\");\n                    var b, c, d = a.attr(\"data-item-type\"), e = {\n                    };\n                    ((((((((d === \"list\")) || ((d === \"message_thread\")))) || ((d === \"tweet\")))) ? b = a.attr(\"data-item-id\") : ((((d === \"activity\")) ? (((a.is(\".js-activity-reply, .js-activity-mention\") ? c = a.JSBNG__find(\".stream-item-content\") : ((a.is(\".js-activity-retweet, .js-activity-favorite\") ? (c = a.JSBNG__find(\".activity-truncated-tweet .tweet\"), ((c.length || (c = a.JSBNG__find(\".sub-stream-item:not('.sub-stream-item-hidden') .stream-item-content\"))))) : c = a.JSBNG__find(\".expand-activity-item .stream-item-content\"))))), ((c.is(\".tweet\") ? (d = \"tweet\", b = c.attr(\"data-item-id\")) : ((c.is(\".user-content-medium\") && (d = \"user\", b = parseInt(c.attr(\"data-user-id\"), 10)))))), e.streamType = \"activity-stream\", e.itemType = d, e.activityType = a.JSBNG__find(\".stream-item-activity\").attr(\"data-activity-type\"), e.activityId = b) : b = parseInt(a.attr(\"data-item-id\"), 10))))), e.stream = this.streamManager.getCurrent().constructor._name, e.component = \"stream\", e.page_number = this.streamManager.getCurrent()._page;\n                    var f = ((a.JSBNG__find(\".tweet\").attr(\"data-impression-id\") || a.JSBNG__find(\".user-content-medium\").attr(\"data-impression-id\")));\n                    ((((d === \"tweet\")) && (e.embedded_media_types = a.JSBNG__find(\".icons .media\").map(function(a, b) {\n                        return [[b.getAttribute(\"data-media-type\"),b.getAttribute(\"data-media-class\"),],];\n                    }).get()))), a.addClass(\"focused-stream-item\").siblings().removeClass(\"focused-stream-item\"), this.loadItemInDetailsPane(b, d, {\n                        log: e,\n                        impressionId: f,\n                        searchClick: ((((twttr.app.isOnPage(\"search\") && a.is(\".stream .stream-item\"))) ? a.children(\".stream-tweet\") : null))\n                    });\n                    var g = ((this.streamManager && this.streamManager.getCurrent()));\n                    if (g) {\n                        var i = ((((d == \"user\")) ? \"select.user\" : \"select.tweet\"));\n                        g.trigger(i, [a,a,\"select\",]);\n                    }\n                ;\n                ;\n                },\n                unfocusStreamItem: function() {\n                    var a = this.$detailsPane().hasClass(\"opened\");\n                    if (((this.closeDetailsPane() !== !1))) {\n                        var b = this.$node.JSBNG__find(\"div.focused-stream-item\");\n                        this.$node.JSBNG__find(\"div.stream-item\").removeClass(\"focused-stream-item\");\n                        if (a) {\n                            var c = ((this.streamManager && this.streamManager.getCurrent()));\n                            if (c) {\n                                var d = ((((b.attr(\"data-item-type\") == \"user\")) ? \"deselect.user\" : \"deselect.tweet\"));\n                                c.trigger(d, [b,b,\"deselect\",]);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                },\n                loadItemInDetailsPane: function(a, b, c) {\n                    this.yScroll = twttr.$win.scrollTop();\n                    if (!b) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this, e = {\n                    }, c = ((c || {\n                    }));\n                    ((c.log && twttr.merge(e, c.log))), ((((b === \"tweet\")) ? (this.loadTweetInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"user\")) ? (this.loadUserInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"tweet_geo\")) ? (this.loadTweetGeoInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"list\")) ? twttr.router.routeTo(twttr.router.lookupAndNormalizeRoute(a)) : ((((b === \"message_thread\")) && (this.loadMessageThreadInDetailsPane(a, c), this.resizeDetailsPane()))))))))))), ((c.searchClick && twttr.components.pages.Search.addSearchClickLogging(c.searchClick, e))), e.details_type = b, e.item_id = a, e.input = \"click\", scribble(\"load-details-pane\", e), $(\"div.tipsy\").remove();\n                },\n                viewId: function(a, b, c) {\n                    return ((((a + b)) + ((c ? ((\"_\" + c)) : \"\"))));\n                },\n                loadTweetInDetailsPane: function(a, b) {\n                    var c = this, d = b.impressionId, e = this.viewId(\"tweet_pane_\", a, d), f = new twttr.views.DetailsPane(e), g = this.panes.cached(e), i = ((b.push ? this.panes.push(f) : this.panes.reset(f))), j = i.$dom;\n                    ((g ? j.JSBNG__find(\".map_canvas:visible\").trigger(\"refreshMap\") : (this.$find(\".pane-components-inner\").addClass(\"tweet-components\"), using(twttr.bundleMore, function() {\n                        twttr.API.Status.JSBNG__find(a, function(a) {\n                            i._backLabel = _(\"@{{screen_name}}'s Tweet\", {\n                                screen_name: a.user.screenName\n                            }), ((d && (a = twttr.API.util.PromotedStore.getPromotedStatusInstance(a, d), twttr.API.util.PromotedContent.logShowDetails(d))));\n                            var b = c.streamManager.getCurrent();\n                            new twttr.components.Conversation(a, b, function(d) {\n                                d.bind(\"deleted\", function() {\n                                    ((c.panes.contains(i) && (c.panes.remove(i), c.panes.reset(), c.closeDetailsPane())));\n                                });\n                                var e = [], f = j.JSBNG__find(\".component:visible:first\"), g = j.width();\n                                ((((f.length !== 0)) && (g = f.width()))), g -= 55;\n                                var k = new twttr.components.Media(a, g);\n                                e.push(d, new twttr.components.TweetGeoSmall(a), new twttr.components.MachineTranslatedTweet(a)), ((((twttr.decider.isActivityEnabled() && twttr.decider.isAvailable(\"activity_social_context\"))) ? (e.push(new twttr.components.TweetActivity(a)), e.push(new twttr.components.Replies(a, b, d.resultGroups))) : (e.push(new twttr.components.Replies(a, b, d.resultGroups)), e.push(new twttr.components.Retweeters(a, 10))))), e.push(new twttr.components.MentionedInTweet(a)), c.addComponentsToDetailsPane(j, e), k.$node.appendTo(j.JSBNG__find(\"div.js-tweet-media-container\"));\n                            });\n                        });\n                    }))));\n                },\n                loadUserInDetailsPane: function(a, b) {\n                    var c = ((twttr.is.string(a) ? \"user_pane_by_screen_name_\" : \"user_pane_by_id_\")), d = this, e = b.impressionId, f = this.viewId(c, a, e), g = new twttr.views.DetailsPane(f), i = this.panes.cached(f), j = ((b.push ? this.panes.push(g) : this.panes.reset(g))), k = j.$dom;\n                    ((i || (twttr.ui.toggleSpinner(k, !0), using(twttr.bundleMore, function() {\n                        twttr.API.User.JSBNG__find(a, {\n                            success: function(a) {\n                                twttr.ui.toggleSpinner(k), twttr.app.trigger(\"view_profile_pane\", a), j._backLabel = _(\"@{{screen_name}}'s profile\", {\n                                    screen_name: a.screenName\n                                }), ((e && (a = twttr.API.util.PromotedStore.getPromotedUserInstance(a, e)))), d.addComponentsToDetailsPane(k, [new twttr.components.ProfilePane(a),new twttr.components.UserMedia(a, {\n                                    itemWidth: 48,\n                                    itemHeight: 48,\n                                    itemDisplayWidth: 50,\n                                    width: 320,\n                                    noSpacer: !0\n                                }),new twttr.components.RecentTweets(a),]);\n                            },\n                            error: function(a) {\n                                d.addComponentsToDetailsPane(k, [new twttr.components.NoUserExists,]);\n                            }\n                        });\n                    }))));\n                },\n                loadTweetGeoInDetailsPane: function(a, b) {\n                    var c = this, d = this.viewId(\"tweet_geo_pane_\", a, b.placeId), e = new twttr.views.DetailsPane(d), f = this.panes.cached(d), g = ((b.push ? this.panes.push(e) : this.panes.reset(e))), i = g.$dom;\n                    ((f ? i.JSBNG__find(\".map_canvas:visible\").trigger(\"refreshMap\") : using(twttr.bundleMore, function() {\n                        twttr.API.Status.JSBNG__find(a, function(a) {\n                            var d = ((b.placeId || ((a.place ? a.place.id : null))));\n                            g._backLabel = _(\"@{{screen_name}}'s Tweet location\", {\n                                screen_name: a.user.screenName\n                            });\n                            var e = function(b) {\n                                var e = [new twttr.components.TweetGeoBig(a, d),];\n                                ((b && e.push(new twttr.components.PlaceTweets(b)))), c.addComponentsToDetailsPane(i, e);\n                            };\n                            ((d ? ((((a.place && ((a.place.id == d)))) ? e(a.place) : twttr.API.Place.JSBNG__find(d, {\n                                success: function(a) {\n                                    e(a.data());\n                                },\n                                error: function() {\n                                    e();\n                                }\n                            }))) : e()));\n                        });\n                    })));\n                },\n                loadMessageThreadInDetailsPane: function(a, b) {\n                    if (!twttr.loggedIn) {\n                        throw \"Something went wrong. You're not supposed to be able to load a message pane while logged out...\";\n                    }\n                ;\n                ;\n                    var c = this, d = this.viewId(\"message_thread_pane_\", a), e = new twttr.views.DetailsPane(d, {\n                        closable: !1\n                    }), f = c.panes.cached(d), g = c.panes.reset(e), i = g.$dom;\n                    using(twttr.bundleMore, function() {\n                        twttr.messageManager.getThread(a, function(b) {\n                            var d = ((twttr.decider.isAvailable(\"phoenix_use_conversation_endpoint\") ? twttr.components.ConversationThread : twttr.components.MessageThread)), e = new d(b);\n                            g._backLabel = _(\"Conversation with {{screen_name}}\", {\n                                screen_name: b.threadId\n                            });\n                            if (!f) {\n                                var j = new twttr.components.SendMessageBox(a, 522);\n                                j.bind(\"sentMessage\", function(a, b) {\n                                    twttr.messageManager.addMessage(b);\n                                }), j.$node.appendTo(i.JSBNG__find(\".pane-toolbar\"));\n                            }\n                        ;\n                        ;\n                            c.addComponentsToDetailsPane(i, [e,]);\n                        });\n                    });\n                },\n                $detailsPane: function() {\n                    return this.$find(\".details-pane\");\n                },\n                openDetailsPane: function() {\n                    if (this._detailsPaneDisabled()) {\n                        return !1;\n                    }\n                ;\n                ;\n                    var a = this.$detailsPane();\n                    ((a.hasClass(\"opened\") || (a.show(), this._slideDetailsPaneTo(((this.$mainContent.width() - 10))), this.$dashboard.hide(), a.addClass(\"opened\")))), this.repositionDetailsPane(), this.resizeDetailsPane();\n                },\n                _slideDetailsPaneTo: function(a, b) {\n                    this.$detailsPane()[((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"))](((((twttr.i18n && twttr.i18n.rtl)) ? {\n                        right: a\n                    } : {\n                        left: a\n                    })), 250, ((Modernizr.csstransitions ? \"ease-out\" : \"linear\")), b);\n                },\n                closeDetailsPane: function() {\n                    if (((this.isDPLocked === !0))) {\n                        return this.isDPLocked = !1, !1;\n                    }\n                ;\n                ;\n                    if (this._detailsPaneDisabled()) {\n                        return !1;\n                    }\n                ;\n                ;\n                    var a = this.$detailsPane();\n                    ((a.hasClass(\"opened\") && (this.panes.JSBNG__top().hide(), this.$dashboard.show(), this._slideDetailsPaneTo(10, function() {\n                        $(this).hide();\n                    }), a.removeClass(\"opened\"), scribble(\"close-details-pane\", {\n                        input: \"click\",\n                        current_tweet_id: this.streamManager.getCurrent().focusedItemId\n                    }))));\n                },\n                resizeDetailsPane: function() {\n                    var a = this.$detailsPane();\n                    $pageOuter = $(\"#page-outer\"), pagePaddingTop = parseInt($pageOuter.css(\"padding-top\"), 10);\n                    if (((a.length > 0))) {\n                        var b = $(\"#page-container\"), c = $(\"#page-container\").width(), d = ((this.$mainContent ? this.$mainContent.width() : 0)), e = ((c - d)), f = ((twttr.$win.height() - pagePaddingTop)), g = ((((f - a[0].offsetTop)) - 8));\n                        ((this.$mainContent && this.$mainContent.css(\"min-height\", f))), a.height(g), a.width(e), a.JSBNG__find(\".pane-components\").height(((g - a.JSBNG__find(\".inner-pane.active .pane-toolbar\").JSBNG__outerHeight())));\n                    }\n                ;\n                ;\n                },\n                repositionDetailsPane: function() {\n                    if (((!twttr.decider.goodAtCss() || !this.$detailsPaneOuter))) {\n                        return;\n                    }\n                ;\n                ;\n                    if (this.windowHasHorizontalScroll()) {\n                        var a = twttr.$win.scrollTop();\n                        this.$detailsPaneOuter.addClass(\"tracking-vertically\"), this.$detailsPaneOuter.css({\n                            \"margin-top\": a,\n                            JSBNG__top: 0\n                        });\n                    }\n                     else {\n                        var b = this.getTopPositionForDetailsPane();\n                        this.$detailsPaneOuter.removeClass(\"tracking-vertically\"), this.$detailsPaneOuter.css({\n                            \"margin-top\": null,\n                            JSBNG__top: b\n                        });\n                    }\n                ;\n                ;\n                },\n                getTopPositionForDetailsPane: function() {\n                    var a = twttr.$win.scrollTop(), b = parseInt($(\"#page-outer\").css(\"padding-top\"), 10), c = (($(\"#page-container\").position().JSBNG__top - a));\n                    return ((((c < b)) && (c = b))), c;\n                },\n                windowHasHorizontalScroll: function() {\n                    return ((twttr.$win.width() < 1000));\n                },\n                addComponentToDetailsPane: function(a, b, c) {\n                    c = ((c || \"append\")), a.JSBNG__find(\".pane-components-inner\")[c](b.$node);\n                },\n                addComponentsToDetailsPane: function(a, b) {\n                    for (var c = 0; ((c < b.length)); c++) {\n                        this.addComponentToDetailsPane(a, b[c]);\n                    ;\n                    };\n                ;\n                }\n            }).addAfterRender(function() {\n                this.$dashboard = this.$find(\".dashboard\"), this.$mainContent = this.$find(\"div.main-content\"), this.$detailsPaneOuter = this.$find(\"#details-pane-outer\"), this.resizeDetailsPane(), ((this.streamManager || (this.streamManager = new twttr.streams.StreamManager(this.pageNameUnderscore, this.$node), this.streamManager.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    this.hasNewItems(b);\n                })), this.streamManager.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), this.streamManager.bind(\"switchTo\", twttr.bind(this, function(a) {\n                    this.closeDetailsPane();\n                })), ((twttr.decider.isExpando() && this.streamManager.bind(\"doneLoadingMore\", twttr.bind(this, function(a) {\n                    this.$find(\".expanding-stream-item\").removeClass(\"expanding-stream-item\");\n                }))))))), ((this.streamManager.preRendered || this.$node.JSBNG__find(\"div.js-stream-manager-container\").append(this.streamManager.$node))), this.panes = new twttr.ViewStack(this.$detailsPane(), \"append\"), this.trigger(\"streamManagerReady\");\n            }).addOnSwitchTo(function() {\n                ((twttr.decider.isExpando() && ($(\"#page-container\").removeClass(\"expando-container\"), $(\"#page-outer\").removeClass(\"flush-to-top\"))));\n                var a = twttr.audit.trail()[1];\n                ((((a && a.page.match(/userMedia/))) && (this.isDPLocked = !0, ((this.yScroll && twttr.$win.scrollTop(this.yScroll)))))), this.resizeDetailsPane();\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/streamablePageDropdownEdition\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePageDropdownEdition\", function(a) {\n            var b = $(\"html, body\"), c = 8, d = 700, e = 50, f = 30, g = 436, i = 75, j = 105, k = 40, l = 20, m = 40;\n            ((twttr.decider.isAvailable(\"platform_enable_cards\") && (d = 375)));\n            var n = {\n                toggle: function(a, b) {\n                    ((a.is(\".js-original-tweet\") && (b.topLevelExpansion = !0, ((((!b.autoExpanded && ((b.containerClass === \".expanding-stream-item\")))) && (b.fullExpansion = !0))))));\n                    var c = n.expandTweetDom(a, b.containerClass), d = 0;\n                    return ((c.$target.hasClass(\"animating\") ? 0 : (((c.$target.data(\"dropdown.showing\") ? (n.close(c, b), n.scribeClose(c, b.currentStream), d = -1) : ((b.forceClose || (((c.$target.data(\"dropdown.loaded\") ? n.open(c, b) : (n.load(c, b), ((b.autoExpanded && JSBNG__setTimeout(function() {\n                        c.$target.next().addClass(\"after-expanded\");\n                    }, 0)))))), d = 1, n.scribeLoad(c, b.currentStream)))))), ((b.topLevelExpansion ? d : 0)))));\n                },\n                expandTweetDom: function(a, b) {\n                    var c = ((b ? a.closest(b) : a));\n                    return {\n                        $target: c,\n                        $tweet: a,\n                        $expansion: a.parent(),\n                        $ancestors: c.JSBNG__find(\"div.js-tweet-ancestors\"),\n                        $replies: c.JSBNG__find(\"div.js-conversation-replies\")\n                    };\n                },\n                open: function(a, b) {\n                    a.$tweet.JSBNG__find(\"iframe[data-expando-iframe-media-url]\").each(function(a, b) {\n                        var c = b.getAttribute(\"data-expando-iframe-media-url\");\n                        ((!c || (b.src = c)));\n                    }), a.$target.data(\"dropdown.showing\", !0).addClass(\"animating\"), n.enterExpandedState(a.$target, b), n.showHideContent(!1, n.expandTweetDom(a.$tweet, b.containerClass), b), a.$tweet.trigger(\"expanded.tweet\");\n                },\n                close: function(a, b) {\n                    a.$target.data(\"dropdown.showing\", !1).addClass(\"animating\"), n.exitExpandedState(a.$target, b), n.showHideContent(!0, a, b, function() {\n                        a.$target.JSBNG__find(\".opened-tweet\").each(function() {\n                            n.toggle($(this), {\n                                noAnimation: !0,\n                                currentStream: b.currentStream\n                            });\n                        }), a.$tweet.trigger(\"collapsed.tweet\");\n                    });\n                },\n                enterExpandedState: function(a, b) {\n                    a.addClass(\"open\").filter(\".js-stream-item\").animate({\n                        marginTop: ((((a.index() === 0)) ? 0 : c)),\n                        marginBottom: c\n                    }, {\n                        duration: ((b.noAnimation ? 0 : i)),\n                        queue: !1\n                    }).prev().addClass(\"before-expanded\").end().next().addClass(\"after-expanded\"), ((a.hasClass(\"hovered-stream-item\") && a.removeClass(\"hovered-stream-item\").addClass(\"js-had-hovered-stream-item\")));\n                },\n                exitExpandedState: function(a, b) {\n                    a.removeClass(\"open\").filter(\".js-stream-item\").animate({\n                        marginTop: 0,\n                        marginBottom: 0\n                    }, {\n                        duration: ((b.noAnimation ? 0 : i)),\n                        queue: !1,\n                        complete: function() {\n                            a.prev().removeClass(\"before-expanded\").end().next().removeClass(\"after-expanded\"), ((a.hasClass(\"js-had-hovered-stream-item\") && a.removeClass(\"js-had-hovered-stream-item\").addClass(\"hovered-stream-item\")));\n                        }\n                    });\n                },\n                simpleShowHideContent: function(a, b) {\n                    var c = b.children().height();\n                    b.animate({\n                        height: ((a ? 0 : c))\n                    }, {\n                        duration: n.guessGoodSpeed(c)\n                    });\n                },\n                showHideContent: function(a, d, f, g) {\n                    d.$target.addClass(\"animating\"), ((!a && d.$tweet.addClass(\"opened-tweet\")));\n                    var i = ((d.$expansion.data(\"height\") || 0)), j = ((((d.$ancestors.height() || d.$ancestors.data(\"height\"))) || 0)), k = d.$tweet.JSBNG__innerHeight(), l = ((((((d.$replies.height() || d.$replies.data(\"height\"))) || 0)) + k)), m = ((l - i)), o = ((f.noAnimation ? 0 : n.guessGoodSpeed(j, m))), p = twttr.$win.scrollTop(), q = ((d.$target.offset().JSBNG__top - c)), r = ((((p + e)) - q));\n                    ((a || d.$expansion.height(i))), d.$expansion.animate({\n                        height: ((a ? i : l))\n                    }, {\n                        duration: o,\n                        step: function(c) {\n                            var e = ((c - i)), g = ((e / m));\n                            d.$ancestors.height(((j * g))), ((((((((r > 0)) && a)) && !f.noAnimation)) && b.scrollTop(((p - ((r * ((1 - g)))))))));\n                        },\n                        complete: function() {\n                            n.resetEmbeddedContent(d, a), d.$target.removeClass(\"animating\"), ((a && d.$tweet.removeClass(\"opened-tweet\"))), d.$expansion.height(\"auto\"), d.$ancestors.height(\"auto\"), ((g && g()));\n                            var b = d.$tweet.data(\"inline-tweetbox\");\n                            ((((((f.focusOnReply && b)) && !a)) && b.JSBNG__focus()));\n                        }\n                    });\n                },\n                guessGoodSpeed: function() {\n                    var a = Math.max.apply(Math, arguments);\n                    return Math.round(((((358708 * Math.log(a))) * j)));\n                },\n                load: function(a, b) {\n                    a.$target.addClass(\"animating\").data(\"dropdown.loaded\", !0), ((b.tweet ? using(twttr.bundleMore, function() {\n                        n.loadWithTweet(a, b, b.tweet);\n                    }) : twttr.API.Status.JSBNG__find(a.$tweet.attr(\"data-tweet-id\"), function(c) {\n                        n.loadWithTweet(a, b, c);\n                    })));\n                },\n                loadWithTweet: function(a, b, c) {\n                    (new twttr.views.TweetDetails(c)).render(a.$target.JSBNG__find(\"div.js-tweet-details-dropdown\"), \"append\");\n                    var d = a.$tweet.JSBNG__find(\"div.js-tweet-media-container\");\n                    a.$expansion = n.wrapComponents(a, a.$tweet.JSBNG__outerHeight());\n                    var e;\n                    ((twttr.Cards.prototype.hasCardPhotoEntities(c) ? e = n.sumEntityMediaEmbedHeights(c.entities.media) : ((twttr.Cards.prototype.hasCards(c) ? e = n.sumCardMediaHeights(c.cards) : e = n.sumMediaEmbedHeights(a.$tweet.JSBNG__find(\"a.twitter-timeline-link\")))))), ((((e > 0)) ? d.css(\"min-height\", Math.ceil(e)) : d.hide())), n.open(a, b), o.media(c, d), o.translation(c, a.$target.JSBNG__find(\"div.js-machine-translated-tweet-container\"));\n                    var f = ((b.fullExpansion ? 7 : 6));\n                    o.socialProof(c, a.$target.JSBNG__find(\"div.js-tweet-stats-container\"), f), o.geo(c, a.$target.JSBNG__find(\"div.js-tiny-geo\"));\n                    if (((b.fullExpansion && !b.autoExpanded))) {\n                        o.conversation(c, a, b);\n                        var g = a.$tweet.attr(\"data-impression-id\");\n                        ((g && (c = twttr.API.util.PromotedStore.getPromotedStatusInstance(c, g), twttr.API.util.PromotedContent.logShowDetails(g))));\n                    }\n                ;\n                ;\n                },\n                sumCardMediaHeights: function(a) {\n                    var b, c = 0;\n                    return ((((a.photos && (b = a.photos[0]))) ? ((((b.images && b.images.web)) && (c = b.images.web.height))) : ((((a.players && (b = a.players[0]))) ? ((((((b.players && b.players.length)) && b.players[0].height)) && (c = b.players[0].height))) : ((((a.summaries && (b = a.summaries[0]))) && ((((b.images && b.images.web)) ? c = b.images.web.height : c = k)))))))), ((c && (c += k))), ((b.author_user_id_str && (c += l))), ((b.site_user_id_str && (c += m))), c;\n                },\n                sumEntityMediaEmbedHeights: function(a) {\n                    return twttr.reduce(a, 0, function(a, b, c) {\n                        var e, i;\n                        ((((c.type === \"photo\")) ? (e = c.sizes.medium.h, width = c.sizes.medium.w) : (e = c.thumbnails[0].height, width = c.thumbnails[0].width))), ((((width && ((width > g)))) && (e = ((g * ((e / width)))))));\n                        var j = ((e ? ((Math.min(e, d) + f)) : 75));\n                        return ((a + j));\n                    });\n                },\n                sumMediaEmbedHeights: function(a) {\n                    return twttr.reduce(a, 0, function(a, b, c) {\n                        var e = $(c), i = e.data(\"media-type\");\n                        if (i) {\n                            var j = ((e.data(\"media-h\") || i.height)), k = e.data(\"media-w\");\n                            ((((k && ((k > g)))) && (j = ((g * ((j / k)))))));\n                            var l = ((j ? ((Math.min(j, d) + f)) : 75));\n                            return ((a + l));\n                        }\n                    ;\n                    ;\n                        return ((a + 0));\n                    });\n                },\n                wrapComponents: function(a, b) {\n                    var c = $(\"\\u003Cdiv/\\u003E\", {\n                        class: \"expansion-container js-expansion-container\",\n                        height: b,\n                        data: {\n                            height: b\n                        }\n                    });\n                    return a.$tweet.wrap(c), a.$target.JSBNG__find(\"div.js-expansion-container\");\n                },\n                resetEmbeddedContent: function(a, b) {\n                    var c = a.$target.JSBNG__find(\"*[has-playable-media='true'] div.tweet-media\");\n                    ((c.length && ((b ? c.height(c.height()).empty() : c.filter(\":empty\").trigger(\"showMedia\"))))), ((((b && twttr.decider.isAvailable(\"platform_enable_cards\"))) && a.$target.JSBNG__find(\".cards-base.cards-multimedia iframe\").each(function(a, b) {\n                        b.setAttribute(\"data-expando-iframe-media-url\", b.src), b.src = \"\";\n                    })));\n                },\n                scribeLoad: function(a, b) {\n                    var c = a.$tweet.JSBNG__find(\"span.js-icon-container .media\").map(function(a, b) {\n                        return [[b.getAttribute(\"data-media-type\"),b.getAttribute(\"data-media-class\"),],];\n                    }).get();\n                    scribble(\"load-details-pane\", {\n                        component: \"stream\",\n                        details_type: \"tweet\",\n                        item_id: a.$target.attr(\"data-item-id\"),\n                        stream: b.constructor._name,\n                        page_number: b._page,\n                        embedded_media_types: c\n                    }), b.trigger(\"select.tweet\", [a.$target,a.$target,\"select\",]);\n                },\n                scribeClose: function(a, b) {\n                    scribble(\"close-details-pane\", {\n                        input: \"click\",\n                        current_tweet_id: b.focusedItemId\n                    }), b.trigger(\"deselect.tweet\", [a.$target,a.$target,\"deselect\",]);\n                }\n            }, o = {\n                media: function(a, b) {\n                    using(\"components/Media\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new c(a, g, {\n                            afterRender: function(a) {\n                                var c = a.icon();\n                                ((((((c === \"video\")) || ((c === \"song\")))) && b.attr(\"has-playable-media\", !0).show()));\n                            },\n                            whenNotDisplayed: function(a) {\n                                b.css(\"min-height\", 0).show();\n                            }\n                        })).$node.appendTo(b);\n                    });\n                },\n                translation: function(a, b) {\n                    using(\"components/MachineTranslationBackend\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new twttr.components.MachineTranslatedTweet(a)).$node.appendTo(b);\n                    });\n                },\n                conversation: function(a, b, c) {\n                    using(\"components/Conversation\", \"components/Replies\", function(d, e) {\n                        var f;\n                        new d(a, null, function(d) {\n                            new e(a, null, d.resultGroups, function() {\n                                if (b.$expansion.JSBNG__find(\".js-conversation-replies\").length) {\n                                    return;\n                                }\n                            ;\n                            ;\n                                var a = $(\"\\u003Cdiv class='replies js-conversation-replies'\\u003E\\u003C/div\\u003E\").height(0).appendTo(b.$expansion);\n                                this.$node.appendTo(a), f = new twttr.components.InlineReplyBox(b.$tweet, a, this.$node, 421);\n                            });\n                            if (((b.$tweet.data(\"is-reply-to\") && ((b.$target.JSBNG__find(\".js-tweet-ancestors\").length === 0))))) {\n                                b.$target.addClass(\"animating\");\n                                var g = d.$node.JSBNG__find(\".js-tweet-ancestors\");\n                                g.attr(\"data-component-term\", \"conversation\"), g.height(0).prependTo(b.$target);\n                            }\n                        ;\n                        ;\n                            JSBNG__setTimeout(function() {\n                                var a = n.expandTweetDom(b.$tweet, c.containerClass), d = ((!c.noAnimation && b.$target.data(\"dropdown.showing\")));\n                                p(a.$ancestors, d), p(a.$replies, d, function() {\n                                    ((f && (b.$tweet.data(\"inline-tweetbox\", f), ((c.focusOnReply && f.JSBNG__focus())))));\n                                });\n                            }, 0);\n                        });\n                    });\n                },\n                socialProof: function(a, b, c) {\n                    using(\"components/TweetStats\", \"components/Retweeters\", function(d, e) {\n                        var f = (($.trim(b.html()) == \"\"));\n                        if (!f) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var g = ((((((twttr.loggedIn && twttr.decider.isActivityEnabled())) && twttr.decider.isAvailable(\"activity_status_summary\"))) ? d : e));\n                        (new g(a, c, function() {\n                            b.show();\n                        })).$node.appendTo(b);\n                    });\n                },\n                geo: function(a, b) {\n                    using(\"components/TweetGeoSmall\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new c(a)).$node.appendTo(b);\n                    });\n                }\n            }, p = function(a, b, c) {\n                if (!a.length) {\n                    return;\n                }\n            ;\n            ;\n                var d = a.children().height();\n                a.data(\"height\", d), ((b ? a.animate({\n                    height: d\n                }, n.guessGoodSpeed(d), function() {\n                    a.parent().removeClass(\"animating\"), a.height(\"auto\"), ((c && c()));\n                }) : a.height(\"auto\")));\n            };\n            return a.mixin(twttr.mixins.profilePopupActionable).keypress({\n                l: function() {\n                    this.closeAllTweets();\n                }\n            }).click({\n                \"div.js-tiny-geo .map_canvas\": function(a, b) {\n                    a.stopPropagation();\n                },\n                \".js-activity-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b, \".supplement\");\n                },\n                \".expanding-stream-item .js-original-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b, \".expanding-stream-item\");\n                },\n                \".expanding-stream-item .js-expando-link\": function(a, b) {\n                    this.simpleShowHide(b);\n                },\n                \".js-tweet-ancestors .js-stream-tweet, .js-conversation-replies .js-stream-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b);\n                }\n            }).methods({\n                closeAllTweets: function() {\n                    var a = twttr.$win.scrollTop(), c = this.firstVisibleItemBelow(a);\n                    if (c) {\n                        var d = c.offset().JSBNG__top, e = this;\n                        this.$find(\"div.open.expanding-stream-item div.js-original-tweet\").each(function() {\n                            e.showHide($(this), {\n                                containerClass: \".expanding-stream-item\",\n                                noAnimation: !0\n                            });\n                        }), this.$find(\"div.open.expanding-stream-item div.js-expando-link\").each(function() {\n                            e.simpleShowHide($(this));\n                        });\n                        var f = c.offset().JSBNG__top;\n                        b.scrollTop(((a - ((d - f)))));\n                    }\n                ;\n                ;\n                },\n                firstVisibleItemBelow: function(a) {\n                    var b;\n                    return this.$find(\".js-stream-item\").each(function() {\n                        var c = $(this);\n                        if (((c.offset().JSBNG__top >= a))) {\n                            return b = c, !1;\n                        }\n                    ;\n                    ;\n                    }), b;\n                },\n                handleExpandoClick: function(a, b, c, d) {\n                    d = ((d || {\n                    }));\n                    var e = $(a.target).is(\".js-open-close-tweet, .js-open-close-tweet *\");\n                    (($(a.target).hasClass(\"action-reply-container\") && (d.focusOnReply = !0)));\n                    if (((e || !this.shouldPreventClickFrom($(a.target))))) {\n                        var f = twttr.tco.JSBNG__getSelection();\n                        a.preventDefault(), a.stopPropagation();\n                        if (((((e || f.isCollapsed)) || ((f.htmlText === \"\"))))) {\n                            d.containerClass = c, this.showHide(b, d);\n                            var g = \"tweet_anatomy_2_231\";\n                            ((((((!b.is(\".open\") && twttr.isT1)) && twttr.abdecider.choose(g))) && (($(a.target).is(\".open-tweet\") ? twttr.abdecider.track(g, \"open-tweet-open-label\") : (($(a.target).is(\".view-open\") ? twttr.abdecider.track(g, \"open-tweet-view-label\") : twttr.abdecider.track(g, \"open-tweet-whitespace\")))))));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                },\n                shouldPreventClickFrom: function(a) {\n                    var b = ((a.is(\"a, a *, button, button *\") && !a.is(\".js-details *\"))), c = a.is(\"embed,object\");\n                    return ((b || c));\n                },\n                getTweetFromItems: function(a, b) {\n                    var c, d = ((b && b.items));\n                    if (d) {\n                        for (var e = 0, f = d.length; ((e < f)); e++) {\n                            if (((a === d[e].id))) {\n                                c = d[e];\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return c;\n                },\n                simpleShowHide: function(a) {\n                    var b = \".expanding-stream-item\", c = a.closest(b), d = {\n                    }, e = a.closest(\".stream-item\").JSBNG__find(\".js-expando-control-expanded\"), f = e.hasClass(\"show\");\n                    ((f ? (this.updateExpandoControl(!0, e), n.exitExpandedState(c, d), n.simpleShowHideContent(!0, c.JSBNG__find(\"div.js-expando-content\")), a.trigger(\"simpleExpandoContract\"), this.openCount += -1) : (this.updateExpandoControl(!1, e), n.enterExpandedState(c, d), n.simpleShowHideContent(!1, c.JSBNG__find(\"div.js-expando-content\")), a.trigger(\"simpleExpandoExpand\"), this.openCount += 1))), this.showHideCloseAllButton();\n                },\n                showHide: function(a, b) {\n                    b = ((b || {\n                    })), b.currentStream = this.streamManager.getCurrent(), b.tweet = this.getTweetFromItems(a.attr(\"data-tweet-id\"), b.currentStream), this.openCount += n.toggle(a, b), this.showHideCloseAllButton();\n                },\n                toggleFocus: function(a) {\n                    this.showHide(a.JSBNG__find(\".js-original-tweet\"), {\n                        containerClass: \".expanding-stream-item\"\n                    });\n                },\n                showHideCloseAllButton: function() {\n                    ((this.$closer && ((((this.openCount > 0)) ? this.$closer.fadeIn(\"fast\") : this.$closer.fadeOut(\"fast\")))));\n                },\n                updateExpandoControl: function(a, b) {\n                    var c = b.closest(\".stream-item\");\n                    c.JSBNG__find(\".js-expando-control-expanded\").removeClass(((a ? \"show\" : \"hide\"))).addClass(((a ? \"hide\" : \"show\"))), c.JSBNG__find(\".js-expando-control-unexpanded\").removeClass(((a ? \"hide\" : \"show\"))).addClass(((a ? \"show\" : \"hide\")));\n                },\n                resetCloseAllButton: function() {\n                    this.$closer = $(\"a.js-close-all-tweets\"), this.openCount = this.$find(\"div.open\").length, ((((this.openCount > 0)) ? this.$closer.show() : this.$closer.hide()));\n                },\n                dropdown: n,\n                focusStreamItem: twttr.util.noopInT1,\n                unfocusStreamItem: twttr.util.noopInT1,\n                resizeDetailsPane: twttr.util.noopInT1,\n                repositionDetailsPane: twttr.util.noopInT1\n            }).addAfterRender(function() {\n                this.$dashboard = this.$find(\"div.dashboard\"), this.$mainContent = this.$find(\"div.main-content\");\n                var a = this;\n                ((this.streamManager || (this.streamManager = new twttr.streams.StreamManager(this.pageNameUnderscore, this.$node), this.streamManager.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    this.hasNewItems(b);\n                })), this.streamManager.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), this.streamManager.bind(\"switchTo didNotSwitch\", twttr.bind(this, function(b) {\n                    twttr.app.trigger(\"streamSwitchedTo\", [this,]), JSBNG__setTimeout(function() {\n                        a.resetCloseAllButton(), a.$find(\"div.tweet-media\").trigger(\"showMedia\");\n                    }, 0);\n                }))))), ((this.streamManager.preRendered || this.$node.JSBNG__find(\"div.js-stream-manager-container\").append(this.streamManager.$node))), this.panes = [], this.$find(\".stream-item\").addClass(\"expanding-stream-item\"), this.trigger(\"streamManagerReady\");\n            }).addOnSwitchAway(function() {\n                ((this.$closer && this.$closer.hide()));\n            });\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePageWithInlineMedia\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePageWithInlineMedia\", function() {\n            this.methods({\n                addInlineMediaIcons: function(a, b) {\n                    using([twttr.bundleMore,\"media/Iconifier\",], function() {\n                        new twttr.media.Iconifier(a, b);\n                    });\n                }\n            });\n        }), a(twttr.mixins.streamablePageWithInlineMedia);\n    });\n});\nprovide(\"mixins/itemActionableScribing\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.itemActionableScribing\", function(a) {\n            return a.methods({\n                _tweetHasCard: function(a) {\n                    return ((a.hasClass(\"has-cards\") || ((a.JSBNG__find(\".has-cards\").length > 0))));\n                },\n                _getDataFromTweet: function(a) {\n                    var b = {\n                    }, c = a.JSBNG__find(\".cards-base\");\n                    return b.tweetHasCard = c.length, ((b.tweetHasCard && (b.cardType = c.data(\"card-type\"), b.cardUrl = c.data(\"card-url\"), b.publisherUserId = this._getUserIdFromElement(c.JSBNG__find(\".source .js-user-profile-link\")), b.creatorUserId = this._getUserIdFromElement(c.JSBNG__find(\".byline .js-user-profile-link\"))))), b;\n                },\n                _getUserIdFromElement: function(a) {\n                    return ((a.length ? a.attr(\"data-user-id\") : null));\n                },\n                _prepareCustomScribeData: function(a) {\n                    var b = {\n                        associations: {\n                        }\n                    };\n                    return b.associations[2] = {\n                        association_id: a.publisherUserId,\n                        association_type: 3\n                    }, b.associations[3] = {\n                        association_id: a.creatorUserId,\n                        association_type: 3\n                    }, b.message = a.cardUrl, {\n                        scribeData: b\n                    };\n                },\n                _registerTweetActionScribeListeners: function() {\n                    var a = this;\n                    this.bind(\"favorite.tweet unfavorite.tweet retweet.tweet unretweet.tweet delete.tweet reply.tweet dismiss.tweet not_relevant.tweet deselect.tweet permalink_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(e, {\n                            event_info: e\n                        }, f);\n                        if (((((e == \"deselect\")) && a._tweetHasCard(c)))) {\n                            var g = a._getDataFromTweet(c);\n                            a._itemScribe(\"hide\", {\n                                event_info: \"hide\",\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)));\n                        }\n                    ;\n                    ;\n                    }), this.bind(\"select.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c), g = {\n                            event_info: e\n                        };\n                        if (d.JSBNG__find(\".sm-image\").length) {\n                            var i = d.JSBNG__find(\"a[data-expanded-url]\").attr(\"data-expanded-url\");\n                            ((i && (g.url = i)));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(e, g, f);\n                        if (a._tweetHasCard(c)) {\n                            var g = a._getDataFromTweet(c);\n                            a._itemScribe(\"show\", {\n                                event_info: \"show\",\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)));\n                        }\n                    ;\n                    ;\n                    }), this.bind(\"avatar_click.tweet screen_name_click.tweet promoted_badge_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = ((((d.JSBNG__find(\"[data-user-id]\").attr(\"data-user-id\") || d.attr(\"data-user-id\"))) || d.closest(\"[data-user-id]\").attr(\"data-user-id\")));\n                        if (a._tweetHasCard(c)) {\n                            var g = a._getDataFromTweet(c);\n                            ((g.tweetHasCard && a._itemScribe(\"profile_click\", {\n                                event_info: e,\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)))));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(\"profile_click\", {\n                            event_info: e\n                        }, f);\n                    }), this.bind(\"hashtag_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(\"search\", {\n                            event_info: \"hashtag\",\n                            query: d.text()\n                        }, f);\n                    }), this.bind(\"mention_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(\"mention_click\", {\n                            event_info: \"mention\"\n                        }, f);\n                    }), this.bind(\"external_link_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c), g = ((d.attr(\"data-expanded-url\") || d.attr(\"href\"))), i = {\n                            event_info: \"external_link\",\n                            url: g\n                        }, j = d.closest(\".has-cards\").JSBNG__find(\".cards-base\").data(\"card-type\");\n                        ((((((j !== null)) && ((j !== undefined)))) && (i.element = ((((\"platform_\" + j)) + \"_card\"))))), a._itemScribe(\"open_link\", i, f), twttr.externalURLStore.setData(g, f), ((twttr.abdecider.chooseWithoutImpression(\"long_tweet_urls_2_259\") && ((d.attr(\"data-long_tweet_urls_2_259\") ? twttr.abdecider.track(\"long_tweet_urls_2_259\", \"open_link_expanded\") : twttr.abdecider.track(\"long_tweet_urls_2_259\", \"open_link_short\")))));\n                    });\n                },\n                _registerUserActionScribeListeners: function() {\n                    var a = this;\n                    this.bind(\"follow.user unfollow.user follow.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = d.attr(\"data-user-id\");\n                        var g = {\n                            event_info: e\n                        };\n                        if (c.hasClass(\"has-cards\")) {\n                            var i = a._getDataFromTweet(c);\n                            g.element = ((((\"platform_\" + i.cardType)) + \"_card\")), f = twttr.merge(f, a._prepareCustomScribeData(i));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(e, g, f), ((c.attr(\"data-impression-id\") && trackClient({\n                            component: \"promoted_user_recommendations\",\n                            action: e\n                        })));\n                    }), this.bind(\"select.user deselect.user dismiss.user reply.user block.user unblock.user add_to_list.user report_as_spam.user accept.user deny.user dm.user\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(e, {\n                            event_info: e\n                        }, f);\n                    }), this.bind(\"avatar_click.user screen_name_click.user promoted_badge_click.user\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = ((d.JSBNG__find(\"[data-user-id]\").attr(\"data-user-id\") || d.attr(\"data-user-id\"))), a._itemScribe(\"profile_click\", {\n                            event_info: e\n                        }, f), ((c.attr(\"data-impression-id\") && trackClient({\n                            component: \"promoted_user_recommendations\",\n                            action: \"profile_click\"\n                        })));\n                    });\n                },\n                getScribbler: function() {\n                    if (this.scribbler) {\n                        return this.scribbler;\n                    }\n                ;\n                ;\n                    if (this.getStreamManager) {\n                        var a = this.getStreamManager(), b = ((a && a.getCurrent()));\n                        if (((b && b.scribbler))) {\n                            return b.scribbler;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return twttr.Scribbler.clientEvent;\n                },\n                _getScribeComponentName: function() {\n                    return ((this.scribeComponentName ? this.scribeComponentName : ((((this.constructor && this.constructor._name)) ? b.util.underscore(this.constructor._name) : \"\"))));\n                },\n                _itemScribe: function(a, b, c) {\n                    var d = {\n                        component: this._getScribeComponentName(c.targetItem),\n                        action: a\n                    };\n                    ((b.element && (d.element = b.element)));\n                    if (c.targetObj) {\n                        var e = twttr.Scribbler.getElementEventNameTerms(c.targetObj);\n                        ((e.component && (d.component = e.component)));\n                    }\n                ;\n                ;\n                    if (((c.itemType && c.itemId))) {\n                        var f = {\n                        };\n                        f[((c.itemId + \"\"))] = c.itemDetails, c.scribeData.item_details = f;\n                    }\n                ;\n                ;\n                    this.getScribbler().scribe(d, twttr.merge(b, c.scribeData)), ((((((twttr.profileUser && twttr.profileUser.verified)) && ((twttr.app.currentPageName() == \"profile\")))) && twttr.abdecider.track(\"replies_stripped_on_verified_profiles_222\", a))), this._itemDetailsScribe(a, c.itemType, c.itemObj);\n                },\n                _itemDetailsScribe: function(a, b, c) {\n                    var d = \"tweet_anatomy_2_231\";\n                    if (((((((b === \"tweet\")) && twttr.isT1)) && twttr.abdecider.choose(d)))) {\n                        if (((a === \"impression\"))) {\n                            var e = c.attr(\"data-tweet-id\"), f = window.__tweet_anatomy_2_231_impressionSink;\n                            ((f || (f = window.__tweet_anatomy_2_231_impressionSink = [])));\n                            if ((($.inArray(e, f) !== -1))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            f.unshift(e), ((((f.length > 5000)) && (f.length = 5000)));\n                        }\n                    ;\n                    ;\n                        var g = {\n                            hashtag: \".twitter-hashtag\",\n                            link: \".twitter-timeline-link\",\n                            username: \".twitter-atreply\",\n                            photo: \".sm-image\",\n                            video: \".sm-video\",\n                            audio: \".sm-audio\",\n                            geo: \".sm-geo\",\n                            convo: \".sm-convo\",\n                            embed: \".sm-embed\",\n                            summary: \".sm-summary\",\n                            retweet: \".sm-rt\",\n                            reply: \".sm-reply\",\n                            promoted: \".badge-promoted\"\n                        }, i = ((c.JSBNG__find(g.promoted).length ? \"-promoted\" : \"-organic\"));\n                        twttr.abdecider.track(d, ((a + i)));\n                        for (var j in g) {\n                            ((c.JSBNG__find(g[j]).length && twttr.abdecider.track(d, ((((((a + i)) + \"-has-\")) + j)))));\n                        ;\n                        };\n                    ;\n                        $.each(c.JSBNG__find(\".twitter-timeline-link\"), function(b, c) {\n                            var e = ((c.getAttribute(\"data-expanded-url\") || c.href));\n                            ((((e === c.getAttribute(\"data-ultimate-url\"))) ? twttr.abdecider.track(d, ((((a + i)) + \"-has-link-expanded\"))) : twttr.abdecider.track(d, ((((a + i)) + \"-has-link-short\")))));\n                        });\n                    }\n                ;\n                ;\n                },\n                _itemMetadata: function(a) {\n                    var c = this._findOrCurrent(a, \".js-actionable-tweet, .js-actionable-user\"), d = this._closestOrCurrent(c, \"[data-item-type]\"), e = d.attr(\"data-item-type\"), f = {\n                        item_count: 1\n                    }, g = {\n                    }, i, j, k, l;\n                    (((($.inArray(e, [\"tweet\",\"user\",\"activity\",]) == -1)) && ((c.is(\".js-actionable-tweet\") ? e = \"tweet\" : ((c.is(\".js-actionable-user\") && (e = \"user\")))))));\n                    if (d.length) {\n                        switch (e) {\n                          case \"tweet\":\n                            k = !!this._findOrCurrent(c, \".top-tweet\").length, j = this._findOrCurrent(c, \"[data-impression-id]\").attr(\"data-impression-id\");\n                            var m = ((j ? \"promotedTweet\" : ((k ? \"popularTweet\" : \"tweet\"))));\n                            g.item_type = b.constants.clientEvent.itemType[m], i = this._findOrCurrent(c, \"[data-tweet-id]\").attr(\"data-tweet-id\"), ((this.ignoreScribeItemPosition || (g.item_position = this._itemPosition(c, \"tweet\"))));\n                            break;\n                          case \"user\":\n                            j = this._findOrCurrent(d, \"[data-impression-id]\").attr(\"data-impression-id\");\n                            var n = d.attr(\"data-feedback-token\"), m = ((j ? \"promotedUser\" : \"user\"));\n                            g.item_type = b.constants.clientEvent.itemType[m], i = ((d.attr(\"data-item-id\") || d.attr(\"data-user-id\"))), ((this.ignoreScribeItemPosition || (g.item_position = this._itemPosition(c, \"user\")))), ((n && (f.item_names = [n,])));\n                            break;\n                          case \"activity\":\n                            var o = this._activityType(d);\n                            g.item_type = b.constants.clientEvent.itemType.activity, g.item_description = o;\n                            var p = d.attr(\"data-item-id\");\n                            i = ((this._findOrCurrent(d, \"div[data-activity-min-position]\").attr(\"data-activity-min-position\") || p.split(\"_\")[0]));\n                            var q = a.attr(\"data-tweet-id\");\n                            ((q && (g.target_id = q))), f.item_names = [p,];\n                            break;\n                          default:\n                            i = d.attr(\"data-item-id\");\n                        };\n                    ;\n                        ((j && (g.item_token = j))), ((((g.item_description && !f.item_names)) && (f.item_names = [g.item_description,]))), ((i && (f.item_ids = [i,])));\n                    }\n                ;\n                ;\n                    return {\n                        scribeData: f,\n                        itemId: i,\n                        itemType: e,\n                        itemDetails: g,\n                        itemObj: d,\n                        targetObj: a,\n                        impressionId: j,\n                        popular: k\n                    };\n                },\n                _activityType: function(a) {\n                    var b = this._findOrCurrent(a, \".stream-item-activity\").attr(\"data-activity-type\"), c;\n                    return ((b || ((a.is(\".reply\") ? b = \"reply\" : ((a.is(\".mention\") && (b = \"mention\"))))))), b;\n                },\n                MAX_ITEM_POSITION: 40,\n                _itemPosition: function(a, b) {\n                    var c = ((((b == \"tweet\")) ? \"div.js-actionable-tweet\" : \"div.js-actionable-user, li.js-actionable-user\")), d = ((((b == \"tweet\")) ? \"data-tweet-id\" : \"data-user-id\")), e = a.attr(d), f = [];\n                    return this.$node.JSBNG__find(c).each(function(a, b) {\n                        f.push($(b).attr(d));\n                    }), $.inArray(e, twttr.util.arrayUniq(f).slice(0, this.MAX_ITEM_POSITION));\n                },\n                _findOrCurrent: function(a, b) {\n                    return ((a.is(b) ? a : a.JSBNG__find(b)));\n                },\n                _closestOrCurrent: function(a, b) {\n                    var c = ((a.is(b) ? a : a.closest(b)));\n                    return ((c.length ? c : a));\n                }\n            }), a;\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePage\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePage\", function() {\n            this.addViewData(function() {\n                var a = {\n                };\n                return a[((\"active_tab_\" + this._activeTab))] = 1, a;\n            }).addOnSwitchAway(function() {\n                ((this.streamManager && this.streamManager.JSBNG__onSwitchAway()));\n            }).keydown({\n                f: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionFavorite(b.getCurrentlyFocusedItem().JSBNG__find(\".tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                },\n                r: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionReply(b.getCurrentlyFocusedItem().JSBNG__find(\".js-original-tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                },\n                t: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionRetweet(b.getCurrentlyFocusedItem().JSBNG__find(\".tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                }\n            }).keypress({\n                k: function(a) {\n                    this.streamManager.getCurrent().highlightPrevious(), a.preventDefault();\n                },\n                j: function(a) {\n                    this.streamManager.getCurrent().highlightNext(), a.preventDefault();\n                },\n                \"return\": function(a) {\n                    var b = this.streamManager.getCurrent();\n                    if (!b) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.$find(((((\".stream-item[data-item-id=\\\"\" + b.highlightedItemId)) + \"\\\"]\")));\n                    if (((c.length === 0))) {\n                        return;\n                    }\n                ;\n                ;\n                    a.preventDefault(), this.toggleFocus(c);\n                },\n                period: function(a) {\n                    twttr.$win.scrollTop(0);\n                    var b = this.streamManager.getCurrent();\n                    b.fetchTweets(twttr.bind(this, function(a) {\n                        ((((a.newItemsCount > 0)) && (a._showNewItems(), a.restartFetcher())));\n                        var b = a.getFirstItem();\n                        a.highlightItem(b), a.scrollStreamTo(b), twttr.$win.scrollTop(0);\n                    })), twttr.components.JapaneseAd.refreshAds();\n                }\n            }).methods({\n                getStreamManager: function() {\n                    return this.streamManager;\n                },\n                focusStreamTab: function(a) {\n                    var b;\n                    this.$node.JSBNG__find(\"ul.stream-tabs li.stream-tab, ul.stream-subtabs\").removeClass(\"active\"), ((a && (b = ((((((\"ul.stream-tabs li.stream-tab-\" + a)) + \", ul.stream-subtabs-\")) + a)), this.$node.JSBNG__find(b).addClass(\"active\")))), this._activeTab = a, scribble(\"subnav\", {\n                        item: a\n                    });\n                },\n                focusStreamSubtab: function(a) {\n                    var b;\n                    this.$node.JSBNG__find(\"ul.stream-subtabs li.stream-tab\").removeClass(\"active\"), ((a && this.$node.JSBNG__find(((\"ul.stream-subtabs li.stream-subtab-\" + a))).addClass(\"active\"))), this._activeSubtab = a, scribble(\"subsubnav\", {\n                        item: a\n                    });\n                },\n                _detailsPaneDisabled: function() {\n                    return ((!twttr.decider.goodAtCss() || twttr.isT1));\n                }\n            });\n            var a = {\n                Messages: 1,\n                WhoToFollow: 1,\n                SimilarTo: 1,\n                WelcomeLearnFlow: 1\n            };\n            return ((((!twttr.decider.isExpando() || ((this._name in a)))) ? this.mixin(twttr.mixins.streamablePageDetailsPane) : this.mixin(twttr.mixins.streamablePageDropdownEdition)));\n        }), a(twttr.mixins.streamablePage);\n    });\n});\nprovide(\"mixins/userActionableT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.userActionableT1\", function() {\n            return this.methods({\n                getActionableUser: function(a) {\n                    return a.closest(\".js-actionable-user\");\n                },\n                getComboButton: function(a) {\n                    return this.$node.JSBNG__find(((((\".js-follow-combo[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                },\n                getDropdownButton: function(a) {\n                    return this.$node.JSBNG__find(((((\".js-action-profilemenu[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                },\n                getUserId: function(a) {\n                    return twttr.helpers.getUserIdentifier(a);\n                },\n                getUserRelationship: function(a, b) {\n                    var c = this, d = this.getActionableUser(a), e = +d.attr(\"data-user-id\");\n                    if (d.data(\"user\")) {\n                        var f = d.data(\"user\");\n                        this.getRelationship(f, b);\n                    }\n                     else twttr.API.User.JSBNG__find(e, function(a) {\n                        d.data(\"user\", a), c.getRelationship(a, b);\n                    });\n                ;\n                ;\n                },\n                getRelationship: function(a, b) {\n                    if (!twttr.loggedIn) {\n                        var c = {\n                            notifications: !1,\n                            following: !1,\n                            followedBy: !1,\n                            blocking: !1,\n                            followRequestSent: !1,\n                            wantRetweets: !1,\n                            canDM: !1\n                        };\n                        b(c, {\n                            user: a,\n                            id: a.id,\n                            JSBNG__name: a.JSBNG__name,\n                            screen_name: a.screenName,\n                            notifications: c.notifications,\n                            following: c.following,\n                            followed_by: c.followedBy,\n                            blocking: c.blocking,\n                            follow_request_sent: a.followRequestSent,\n                            want_retweets: c.wantRetweets,\n                            can_dm: c.canDM,\n                            reported: !1\n                        });\n                        return;\n                    }\n                ;\n                ;\n                    twttr.currentUser.relationshipWith(a, function(c) {\n                        var d = {\n                            user: a,\n                            id: a.id,\n                            JSBNG__name: a.JSBNG__name,\n                            screen_name: a.screenName,\n                            notifications: c.notifications,\n                            following: c.following,\n                            followed_by: c.followedBy,\n                            blocking: c.blocking,\n                            follow_request_sent: a.followRequestSent,\n                            want_retweets: c.wantRetweets,\n                            can_dm: c.canDM,\n                            reported: !1\n                        };\n                        b(c, d);\n                    });\n                },\n                showFollowOrUnfollow: function(a) {\n                    var b = this;\n                    ((twttr.helpers.isCurrentUser(a) || b.getRelationship(a, function(a, c) {\n                        ((c.followed_by && b.$node.JSBNG__find(\".js-follows-you\").show()));\n                    })));\n                },\n                showMiniSocialProof: function(a) {\n                    var b = this;\n                    ((((twttr.currentUser && !twttr.helpers.isCurrentUser(a))) && twttr.currentUser.followingFollowersOf(a.id, function(c) {\n                        if (c.length()) {\n                            var d = b.makeLongSocialContextHtml(a.screenName, c.toArray());\n                            b.$find(\".js-mini-social-proof-container\").html(d);\n                        }\n                    ;\n                    ;\n                    })));\n                },\n                showUserProfileMenu: function(a) {\n                    var b = this;\n                    $(JSBNG__document).trigger(\"click.button\"), a.addClass(\"open\"), a.closest(\".js-stream-item\").addClass(\"has-follow-dropdown-open\"), $(JSBNG__document).bind(\"click.button\", function() {\n                        b.hideUserProfileMenu(a);\n                    });\n                },\n                hideUserProfileMenu: function(a) {\n                    a.removeClass(\"open\"), a.closest(\".js-stream-item\").removeClass(\"has-follow-dropdown-open\"), $(JSBNG__document).unbind(\"click.button\");\n                },\n                toggleUserProfileMenu: function(a) {\n                    var b = this, c = this.getActionableUser(a), d = +c.attr(\"data-user-id\"), e = this.getDropdownButton(d);\n                    if (c.attr(\"data-dropdown\")) {\n                        ((c.hasClass(\"open\") ? this.hideUserProfileMenu(c) : this.showUserProfileMenu(c)));\n                        return;\n                    }\n                ;\n                ;\n                    this.getUserRelationship(a, function(a, d) {\n                        b.renderUserProfileMenu(c, e, d), b.showUserProfileMenu(c);\n                    });\n                },\n                renderUserProfileMenu: function(a, b, c) {\n                    ((c.want_retweets && a.addClass(\"including\"))), ((((((twttr.currentUser && twttr.currentUser.deviceSetup)) && c.notifications)) ? a.addClass(\"notifying\") : a.removeClass(\"notifying\"))), ((c.blocking && a.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"))), ((c.can_dm && a.addClass(\"can-dm\"))), (new twttr.views.ComboFollowButtonDropdown(c)).render(b, \"append\"), a.attr(\"data-dropdown\", !0);\n                },\n                JSBNG__onUserActionFollowSync: function(a, b) {\n                    var c = this.getComboButton(a);\n                    ((c.length ? this.updateButtonFollow(c, b) : this.updateFollowStateLink(a, !0, b)));\n                },\n                JSBNG__onUserActionFollowSuccess: function(a, b, c) {\n                    var d = this.getActionableUser(c);\n                    this.updateButtonFollow(d, b);\n                },\n                updateButtonFollow: function(a, b) {\n                    ((b ? a.removeClass(\"not-following\").addClass(\"follow-request-sent\") : a.removeClass(\"not-following\").addClass(\"following including\")));\n                },\n                updateFollowStateLink: function(a, b, c) {\n                    if (b) {\n                        var d = ((c ? twttr.views.FollowRequestSentLink : twttr.views.UnfollowLink));\n                    }\n                     else {\n                        var d = twttr.views.FollowLink;\n                    }\n                ;\n                ;\n                    var e = this.$node.JSBNG__find(((((\".js-follow-state .js-link[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                    (new d({\n                        id: a\n                    })).render(e, \"replaceWith\");\n                },\n                JSBNG__onUserActionUnfollowSuccess: function(a, b) {\n                    var c = this.getActionableUser(b);\n                    this.updateButtonUnfollow(c);\n                },\n                JSBNG__onUserActionUnfollowSync: function(a) {\n                    var b = this.getComboButton(a);\n                    ((b.length ? this.updateButtonUnfollow(b) : this.updateFollowStateLink(a, !1)));\n                },\n                updateButtonUnfollow: function(a) {\n                    a.removeClass(\"following follow-request-sent\").addClass(\"not-following\");\n                },\n                updateUserAttributesFromRelationship: function(a) {\n                    ((twttr.decider.isAvailable(\"profile_pane_fresh\") && $.extend(this.user.attributes, {\n                        following: a.following,\n                        blocking: a.blocking,\n                        notifications: a.notifications,\n                        can_dm: a.canDM,\n                        want_retweets: a.wantRetweets\n                    })));\n                },\n                JSBNG__onUserActionFollowError: function(a, b) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                JSBNG__onUserActionUnfollowError: function(a) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                registerFollowAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-follow, .js-action-follow-request\", \"click\", function(b) {\n                        var c = $(this), d = a.getActionableUser(c);\n                        return ((twttr.loggedIn && (d.removeClass(\"not-following\"), ((d.hasClass(\"protected\") ? d.addClass(\"follow-request-sent first-hover\") : d.addClass(\"following including first-hover\")))))), d.JSBNG__one(\"mouseleave\", function() {\n                            d.removeClass(\"first-hover\");\n                        }), a.userActionFollow(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerUnfollowAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-unfollow\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this));\n                        return c.removeClass(\"following follow-request-sent\").addClass(\"not-following\"), a.userActionUnfollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerProfileMenuAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-profilemenu\", \"click\", function(b) {\n                        return a.toggleUserProfileMenu($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerBlockAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-block\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"block\";\n                        return a.markAsPending(c, f), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            var d = \"not-following\";\n                            ((b.following ? d = \"following\" : ((b.followRequestSent && (d = \"follow-request-sent\"))))), b.block({\n                                impression_id: e,\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                timeout: function(a) {\n                                    a.retry();\n                                },\n                                success: function(b) {\n                                    a.trigger(\"block.user\", [c,$(this),\"block\",]), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\");\n                                },\n                                error: function() {\n                                    twttr.showError(_(\"Whoops! We weren't able to block that user. Try again in a minute\")), c.removeClass(\"blocked\").addClass(d);\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerUnblockAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-unblock\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"unblock\";\n                        return a.markAsPending(c, f), c.removeClass(\"blocked\").addClass(\"not-following\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            b.unblock({\n                                impression_id: e,\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.id)) + \"\\\"]\"))).closest(\".stream-item\").show();\n                                },\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                success: function() {\n                                    a.trigger(\"unblock.user\", [c,$(this),\"unblock\",]), c.removeClass(\"blocked\").addClass(\"not-following\");\n                                },\n                                error: function() {\n                                    c.addClass(\"blocked\").removeClass(\"not-following following follow-request-sent\");\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerReportAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-spam\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"report\";\n                        return a.markAsPending(c, f), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            var d = \"not-following\";\n                            ((b.following ? d = \"following\" : ((b.followRequestSent && (d = \"follow-request-sent\"))))), b.report({\n                                impression_id: e,\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.id)) + \"\\\"]\"))).closest(\".stream-item\").hide();\n                                },\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                success: function(d) {\n                                    twttr.showMessage(_(\"You have reported {{screenName}} for spam\", b)), a.trigger(\"report_as_spam.user\", [c,$(this),\"report_as_spam\",]), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\");\n                                },\n                                error: function(a) {\n                                    twttr.errors.showErrorFromResponse(a, \"report\"), c.removeClass(\"blocked\").addClass(d);\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerMentionAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-mention\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(d, function(b) {\n                            (new twttr.widget.TweetDialog({\n                                template: {\n                                    title: ((\"Mention \" + b.screenName))\n                                },\n                                draggable: !0,\n                                defaultContent: ((((\"@\" + b.screenName)) + \" \")),\n                                origin: \"profile-actions-dropdown-mention\"\n                            })).open().JSBNG__focus(), a.trigger(\"reply.user\", [c,$(this),\"reply\",]);\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerAddToListAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-add-to-list\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(d, function(b) {\n                            (new twttr.widget.ListMembershipDialog(b)).open(), a.trigger(\"add_to_list.user\", [c,$(this),\"add_to_list\",]);\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerDeviceNotificationToggle: function() {\n                    var a, b, c, d = this;\n                    this.$node.delegate(\".js-device-notifications\", \"click\", function(e) {\n                        var f = d.getActionableUser($(this)), g = +f.attr(\"data-user-id\"), i = f.hasClass(\"notifying\"), j = ((i ? \"setNotificationsOff\" : \"setNotificationsOn\"));\n                        return twttr.API.User.JSBNG__find(g, function(d) {\n                            if (!twttr.currentUser.deviceSetup) {\n                                ((((!twttr.currentUser.deviceVerified && ((!twttr.currentUser.pushTweetsDecidered || !twttr.currentUser.pushDevice)))) ? (a = {\n                                    title: _(\"Setup mobile notifications\"),\n                                    JSBNG__content: (new twttr.views.PhoneSetupPrompt({\n                                        screen_name: d.screenName,\n                                        ok: _(\"Set up phone\"),\n                                        cancel: _(\"Cancel\")\n                                    })).html()\n                                }, b = twttr.router.devicesPath()) : (a = {\n                                    title: _(\"Enable mobile notifications for Tweets\"),\n                                    JSBNG__content: (new twttr.views.PhoneTweetsOffPrompt({\n                                        screen_name: d.screenName,\n                                        ok: _(\"Enable Tweet notifications\"),\n                                        cancel: _(\"Close\")\n                                    })).html()\n                                }, ((((twttr.currentUser.pushDevice && twttr.currentUser.pushTweetsDecidered)) ? b = twttr.router.pushHelpPath() : b = twttr.router.devicesPath()))))), (new twttr.widget.Prompt({\n                                    modal: !0,\n                                    callback: function(a) {\n                                        ((a && (c = function() {\n                                            twttr.router.routeTo(b);\n                                        }, twttr.API.User.bind(\"subscribe\", c), d.setNotificationsOn())));\n                                    },\n                                    template: a\n                                })).open();\n                                return;\n                            }\n                        ;\n                        ;\n                            d[j](), ((i ? f.removeClass(\"notifying\") : f.addClass(\"notifying\")));\n                        }), e.preventDefault(), e.stopPropagation(), !1;\n                    });\n                },\n                registerRetweetToggle: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-retweet-setting\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.hasClass(\"including\"), f = ((e ? \"setWantRetweetsOff\" : \"setWantRetweetsOn\"));\n                        return twttr.API.User.JSBNG__find(d, function(a) {\n                            a[f](), ((e ? (c.removeClass(\"including\"), twttr.showMessage(_(\"Retweets from @{{screenName}} will no longer appear in your timeline\", a))) : (c.addClass(\"including\"), twttr.showMessage(_(\"Retweets from @{{screenName}} will appear in your timeline\", a)))));\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerDirectMessageAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-direct-message-action\", \"click\", function(b) {\n                        var c = $(this), d = a.getActionableUser(c), e = +d.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(e, function(b) {\n                            twttr.dialogs.dmSingle({\n                                user: {\n                                    screenName: b.screenName,\n                                    user_id: e,\n                                    JSBNG__name: b.attributes.JSBNG__name,\n                                    profile_image_url: b.attributes.profile_image_url\n                                },\n                                origin: \"user-actionable-direct-message\"\n                            }).open(), a.trigger(\"dm.user\", [d,c,\"dm\",]);\n                        }), a.hideUserProfileMenu(d), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerProfileAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"avatar_click.user\", [a.getActionableUser(c),c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"screen_name_click.user\", [a.getActionableUser(c),c,\"screen_name\",]);\n                    }), this.$node.delegate(\".js-action-profile-promoted\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"promoted_badge_click.user\", [a.getActionableUser(c),c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-account-group, .js-mini-profile-user\", \"click\", function(b) {\n                        var c = a.$node.JSBNG__find(\".js-actionable-user\"), d = +c.attr(\"data-user-id\"), e = c.closest(\"[data-impression-id]\").attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(d, e);\n                    });\n                },\n                registerUserActionEvents: function() {\n                    var a = this;\n                    this.registerFollowAction(), this.registerUnfollowAction(), this.registerProfileAction(), this.registerPromotedUserActionEvents(), ((twttr.loggedIn && (this.registerProfileMenuAction(), this.registerBlockAction(), this.registerUnblockAction(), this.registerReportAction(), this.registerMentionAction(), this.registerAddToListAction(), this.registerDeviceNotificationToggle(), this.registerRetweetToggle(), this.registerDirectMessageAction(), this._registerUserActionAPIListeners(), this._registerUserActionScribeListeners())));\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/userActionable\", function(a) {\n    using(((twttr.isT1 ? \"mixins/userActionableT1\" : []))).as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.userActionable\", function(a) {\n            return a.mixin(twttr.mixins.itemActionableScribing, twttr.mixins.pendingActions).methods({\n                userActionFollow: function(a, b) {\n                    var c = this, d = twttr.helpers.getUserId(a), e = a.closest(\".js-actionable-user, .js-actionable-tweet\"), f = ((e.attr(\"data-impression-id\") || e.closest(\"[data-impression-id]\").attr(\"data-impression-id\"))), g = \"follow\";\n                    this.markAsPending(e, g), twttr.API.User.JSBNG__find(d, function(i) {\n                        var j = ((i[\"protected\"] && !i.following));\n                        ((twttr.loggedIn ? (c._updateTwttrPromotedAccount(d, f), i.follow({\n                            complete: function() {\n                                c.markAsComplete(e, g);\n                            },\n                            success: function(f) {\n                                b = ((b || ((e.is(\".js-actionable-tweet\") ? \"follow.tweet\" : \"follow.user\")))), c.trigger(b, [e,a,\"follow\",]);\n                                var g = e.closest(\".js-stream-item\").length;\n                                ((((j && !g)) && twttr.showMessage(_(\"A follow request has been sent to {{user}}.\", {\n                                    user: ((i.JSBNG__name || i.screenName))\n                                })))), c.JSBNG__onUserActionFollowSuccess(d, j, a);\n                            },\n                            error: function(a) {\n                                c.JSBNG__onUserActionFollowError(a, j);\n                            },\n                            impression_id: f\n                        })) : twttr.dialogs.signinOrSignup({\n                            follow: i,\n                            justSignup: !0\n                        }).open()));\n                    });\n                },\n                userActionUnfollow: function(a) {\n                    var b = this, c = twttr.helpers.getUserId(a), d = a.closest(\".js-actionable-user\"), e = ((d.attr(\"data-impression-id\") || d.closest(\"[data-impression-id]\").attr(\"data-impression-id\"))), f = \"unfollow\";\n                    this.markAsPending(d, f), twttr.API.User.JSBNG__find(c, function(g) {\n                        g.unfollow({\n                            complete: function() {\n                                b.markAsComplete(d, f);\n                            },\n                            success: function() {\n                                b._updateTwttrPromotedAccount(c, e), b.trigger(\"unfollow.user\", [d,a,\"unfollow\",]), b.JSBNG__onUserActionUnfollowSuccess(c, a);\n                            },\n                            error: function(a) {\n                                b.JSBNG__onUserActionUnfollowError(a);\n                            },\n                            impression_id: e\n                        });\n                    });\n                },\n                userActionMenu: function(a) {\n                    var b = this, c = twttr.helpers.getUserIdentifier(a);\n                    if (a.attr(\"data-opened\")) {\n                        return;\n                    }\n                ;\n                ;\n                    a.attr(\"data-opened\", !0), twttr.API.User.JSBNG__find(c, function(c) {\n                        twttr.currentUser.relationshipWith(c, twttr.bind(this, function(d) {\n                            var e = {\n                                user: c,\n                                id: c.id,\n                                screen_name: c.screenName,\n                                notifications: d.notifications,\n                                following: d.following,\n                                followed_by: d.followedBy,\n                                blocking: d.blocking,\n                                follow_request_sent: c.followRequestSent,\n                                want_retweets: d.wantRetweets,\n                                reported: !1\n                            };\n                            b.userProfileActionsDropdown = b._getUserActionsDropdown(c, a, e), b.userProfileActionsDropdown.render(a, \"after\").open();\n                        }));\n                    });\n                },\n                JSBNG__onUserActionFollowSync: function(a, b) {\n                    var c = this.$node.JSBNG__find(((((\".js-action-follow[data-user-id='\" + a)) + \"']\"))), d;\n                    ((c.length && (((c.is(\".js-button\") ? d = ((b ? twttr.views.FollowRequestSentButton : twttr.views.UnfollowButton)) : ((c.is(\".js-link\") && (d = ((b ? twttr.views.FollowRequestSentLink : twttr.views.UnfollowLink))))))), this._updateFollowState(a, c, d))));\n                },\n                JSBNG__onUserActionUnfollowSync: function(a) {\n                    var b = this.$node.JSBNG__find(((((\".js-action-unfollow[data-user-id='\" + a)) + \"']\"))), c;\n                    ((b.length && (((b.is(\".js-button\") ? c = twttr.views.FollowButton : ((b.is(\".js-link\") && (c = twttr.views.FollowLink))))), this._updateFollowState(a, b, c))));\n                },\n                _updateFollowState: function(a, b, c) {\n                    ((c && (new c({\n                        id: a\n                    })).render(b, \"replaceWith\")));\n                },\n                _userLinkHtml: function(a) {\n                    return (new twttr.views.UserLink(a)).html();\n                },\n                makeShortSocialContextHtml: function(a, b) {\n                    var c = \"\";\n                    return ((((b.length == 1)) ? c += _(\"Followed by {{{user}}}\", {\n                        user: this._userLinkHtml(b[0])\n                    }) : c += _(\"Followed by {{{user}}} and \\u003Ca href=\\\"{{url}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003Eothers\\u003C/b\\u003E\\u003C/a\\u003E\", {\n                        user: this._userLinkHtml(b[0]),\n                        url: twttr.router.followersYouFollowPath({\n                            screen_name: a\n                        })\n                    }))), c;\n                },\n                makeLongSocialContextHtml: function(a, b) {\n                    var c = \"\";\n                    switch (b.length) {\n                      case 1:\n                        c += _(\"Followed by {{{user}}}.\", {\n                            user: this._userLinkHtml(b[0])\n                        });\n                        break;\n                      case 2:\n                        c += _(\"Followed by {{{first}}} and {{{second}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1])\n                        });\n                        break;\n                      case 3:\n                        c += _(\"Followed by {{{first}}}, {{{second}}} and {{{third}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2])\n                        });\n                        break;\n                      case 4:\n                        c += _(\"Followed by {{{first}}}, {{{second}}}, {{{third}}} and {{{other}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2]),\n                            other: this._userLinkHtml(b[3])\n                        });\n                        break;\n                      default:\n                        c += _(\"Followed by {{{first}}}, {{{second}}}, {{{third}}} and \\u003Ca href=\\\"{{url}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003E{{count}} others\\u003C/b\\u003E\\u003C/a\\u003E.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2]),\n                            count: ((((b.length > 13)) ? \"10+\" : ((b.length - 3)))),\n                            url: twttr.router.followersYouFollowPath({\n                                screen_name: a\n                            })\n                        });\n                    };\n                ;\n                    return c;\n                },\n                makeSocialContextHtml: function(a, b) {\n                    var c = this;\n                    if (a.socialContext) {\n                        var d = a.socialContext, e = a.screenName;\n                    }\n                     else {\n                        var d = a.attributes.connections, e = a.user.screenName;\n                    }\n                ;\n                ;\n                    var f = \"\";\n                    return ((((((!this.screenName && d)) && d.length)) && ((b ? f += this.makeLongSocialContextHtml(e, d) : f += this.makeShortSocialContextHtml(e, d))))), f;\n                },\n                JSBNG__onUserActionFollowSuccess: function(a, b, c) {\n                \n                },\n                JSBNG__onUserActionFollowError: function(a, b) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                JSBNG__onUserActionUnfollowSuccess: function(a, b) {\n                \n                },\n                JSBNG__onUserActionUnfollowError: function(a) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                registerPromotedUserActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-dismiss\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logDismissUser(e), a.trigger(\"dismiss.user\", [d,c,\"dismiss\",]);\n                    }), this.$node.delegate(\".js-actionable-user img.user-profile-link, .js-actionable-user .js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logProfileImageClick(e), a.trigger(\"avatar_click.user\", [d,c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-actionable-user .js-promoted-badge\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logFooterProfileClick(e), a.trigger(\"promoted_badge_click.user\", [d,c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-actionable-user .user-name .user-profile-link, .js-actionable-user .js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logScreenNameClick(e), a.trigger(\"screen_name_click.user\", [d,c,\"screen_name\",]);\n                    });\n                },\n                registerUserActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-follow, .js-actionable-tweet .js-action-follow\", \"click\", function(b) {\n                        return a.userActionFollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-unfollow\", \"click\", function(b) {\n                        return a.userActionUnfollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-profilemenu\", \"click\", function(b) {\n                        return a.userActionMenu($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.registerPromotedUserActionEvents(), this._registerUserActionAPIListeners(), this._registerUserActionScribeListeners();\n                },\n                _registerUserActionAPIListeners: function() {\n                    var a = this;\n                    twttr.API.User.bind(\"follow\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"following\", !0), a.sync(\"followers_count\", ((a.followersCount + 1)));\n                            }), a.JSBNG__onUserActionFollowSync(d);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following\", !1), a.sync(\"followers_count\", ((a.followersCount - 1)));\n                            }), a.JSBNG__onUserActionUnfollowSync(e);\n                        }\n                    }), twttr.API.User.bind(\"follow_request\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"follow_request_sent\", !0);\n                            }), a.JSBNG__onUserActionFollowSync(d, !0);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following_request_sent\", !1);\n                            }), a.JSBNG__onUserActionUnfollowSync(e);\n                        }\n                    }), twttr.API.User.bind(\"unfollow\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"following\", !1), ((a[\"protected\"] || a.sync(\"followers_count\", ((a.followersCount - 1)))));\n                            }), a.JSBNG__onUserActionUnfollowSync(d);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following\", !0), ((a[\"protected\"] || a.sync(\"followers_count\", ((a.followersCount + 1)))));\n                            }), a.JSBNG__onUserActionFollowSync(e);\n                        }\n                    });\n                },\n                _updateTwttrPromotedAccount: function(a, b) {\n                    ((b ? twttr.promotedAccountStore.setAccount(a, b) : twttr.promotedAccountStore.clear()));\n                },\n                _getUserActionsDropdown: function(a, b, c) {\n                    var d = this, e = b.closest(\".js-actionable-user\"), f = [];\n                    return f.push({\n                        label: _(\"Mention {{screen_name}}\", c),\n                        icon: \"mention\",\n                        className: \"js-action-reply\",\n                        handlers: {\n                            click: function() {\n                                (new twttr.widget.TweetDialog({\n                                    template: {\n                                        title: ((\"Mention \" + a.screenName))\n                                    },\n                                    draggable: !0,\n                                    defaultContent: ((((\"@\" + a.screenName)) + \" \")),\n                                    origin: \"profile-actions-dropdown-mention\"\n                                })).open().JSBNG__focus(), d.trigger(\"reply.user\", [e,b,\"reply\",]);\n                            }\n                        }\n                    }), f.push({\n                        label: _(\"Add to list\"),\n                        icon: \"user-list\",\n                        className: \"js-action-addtolist\",\n                        handlers: {\n                            click: function() {\n                                (new twttr.widget.ListMembershipDialog(a)).open(), d.trigger(\"add_to_list.user\", [e,b,\"add_to_list\",]);\n                            }\n                        }\n                    }), ((c.blocking ? f.push({\n                        label: _(\"Unblock {{screen_name}}\", c),\n                        icon: \"block\",\n                        className: \"js-action-unblock\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.unblock({\n                                    before: function() {\n                                        $(((((\".stream .stream-tweet[data-user-id=\\\"\" + a.id)) + \"\\\"]\"))).closest(\".stream-item\").show();\n                                    },\n                                    success: function() {\n                                        d.trigger(\"unblock.user\", [e,b,\"unblock\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }) : f.push({\n                        label: _(\"Block {{screen_name}}\", c),\n                        icon: \"block\",\n                        className: \"js-action-block\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.block({\n                                    timeout: function(a) {\n                                        a.retry();\n                                    },\n                                    error: function() {\n                                        twttr.showError(_(\"Whoops! We weren't able to block that user. Try again in a minute\"));\n                                    },\n                                    success: function(a) {\n                                        d.trigger(\"block.user\", [e,b,\"block\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }))), ((c.blocking || f.push({\n                        label: _(\"Report \\u003Cspan class=\\\"truncate\\\"\\u003E{{screen_name}}\\u003C/span\\u003E for spam\", c),\n                        icon: \"spam\",\n                        className: \"js-action-spam\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.report({\n                                    before: function() {\n                                        $(((((\".stream .stream-tweet[data-user-id=\\\"\" + a.id)) + \"\\\"]\"))).closest(\".stream-item\").hide();\n                                    },\n                                    error: function(a) {\n                                        twttr.errors.showErrorFromResponse(a, \"report\");\n                                    },\n                                    success: function(a) {\n                                        d.trigger(\"report_as_spam.user\", [e,b,\"report_as_spam\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }))), new twttr.control.Dropdown(b, {\n                        itemView: twttr.views.UserDropdownItem,\n                        items: f,\n                        direction: \"right\"\n                    });\n                }\n            }), ((twttr.isT1 && a.mixin(b.mixins.userActionableT1))), a;\n        }), a(twttr.mixins.userActionable);\n    });\n});\nprovide(\"mixins/profilePopupActionable\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.profilePopupActionable\", function() {\n            this.methods({\n                showProfilePopup: function(a) {\n                    using(\"widget/MiniProfileDialog\", function(b) {\n                        (new b(a)).open();\n                    });\n                }\n            }).click({\n                \".user-profile-link,          .js-user-profile-link,          .twitter-atreply,          .js-account-group\": function(a, b) {\n                    var c = this;\n                    if (b.is(\".withheld-item .twitter-atreply\")) {\n                        return !1;\n                    }\n                ;\n                ;\n                    ((b.hasClass(\"js-bubble-event\") || (a.stopPropagation(), a.preventDefault())));\n                    var d = ((((b.data(\"user-id\") || b.attr(\"data-screen-name\"))) || b.closest(\".js-profile-popup-actionable\").data(\"user-id\")));\n                    if (!d) {\n                        ((twttr.development && JSBNG__console.log(\"can't open profile popup: no user identifier found\")));\n                        return;\n                    }\n                ;\n                ;\n                    var e = b.closest(\".js-actionable-tweet, .js-actionable-user\"), f = e.attr(\"data-impression-id\");\n                    e.trigger(((\"profile_popup.\" + ((e.is(\".js-actionable-tweet\") ? \"tweet\" : \"user\"))))), twttr.API.User.JSBNG__find(d, {\n                        success: function(d) {\n                            d = twttr.API.util.PromotedStore.getPromotedUserInstance(d, f), c.showProfilePopup(d), b.data(\"user-id\", d.id), twttr.scribbles.logViewProfileDetails.call(b, a);\n                        },\n                        error: function(a) {\n                            twttr.errors.showErrorFromResponse(a);\n                        }\n                    });\n                }\n            });\n        }), a(twttr.mixins.profilePopupActionable);\n    });\n});\nprovide(\"mixins/listActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.listActionable\", function() {\n            return this.methods({\n                listDeleted: function() {\n                \n                },\n                listUpdated: function() {\n                \n                },\n                _setListFollowing: function(a, b, c) {\n                    var d = ((c ? \"subscribe\" : \"unsubscribe\"));\n                    twttr.API.User.JSBNG__find(a, function(a) {\n                        a.lists.JSBNG__find(b, function(a) {\n                            a[d]({\n                                error: function() {\n                                    ((c ? twttr.showError(_(\"There was an error subscribing to the list\")) : twttr.showError(_(\"There was an error unsubscribing from the list\"))));\n                                }\n                            });\n                        });\n                    });\n                },\n                unfollowList: function(a, b) {\n                    this._setListFollowing(a, parseInt(b, 10), !1);\n                },\n                followList: function(a, b) {\n                    this._setListFollowing(a, parseInt(b, 10), !0);\n                }\n            }).click({\n                \".js-delete-list-action\": function(a, b) {\n                    return (new twttr.widget.Prompt({\n                        modal: !0,\n                        template: {\n                            title: _(\"Are you sure you want to delete this list?\")\n                        },\n                        callback: function(a) {\n                            ((a && twttr.currentUser.lists.JSBNG__find(parseInt(b.attr(\"data-list-id\"), 10), function(a) {\n                                twttr.app.currentPage().send(\"listDeleted\", [a,]), a.destroy({\n                                    error: function() {\n                                        twttr.showError(_(\"There was an error deleting the list\"));\n                                    },\n                                    success: function() {\n                                        twttr.app.currentPage().send(\"listDeleted\", [a,]);\n                                    }\n                                });\n                            })));\n                        }\n                    })).open(), a.stopPropagation(), !1;\n                },\n                \".js-edit-list-action\": function(a, b) {\n                    return twttr.currentUser.lists.JSBNG__find(parseInt(b.attr(\"data-list-id\"), 10), function(a) {\n                        (new twttr.widget.ListDialog({\n                            list: a,\n                            JSBNG__onSuccess: function(a) {\n                                twttr.app.currentPage().send(\"listUpdated\", [a,]);\n                            }\n                        })).open();\n                    }), a.stopPropagation(), !1;\n                },\n                \".js-unfollow-list-action\": function(a, b) {\n                    return this.unfollowList(b.attr(\"data-screen-name\"), parseInt(b.attr(\"data-list-id\"), 10)), a.stopPropagation(), !1;\n                },\n                \".js-follow-list-action\": function(a, b) {\n                    return this.followList(b.attr(\"data-screen-name\"), parseInt(b.attr(\"data-list-id\"), 10)), a.stopPropagation(), !1;\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/tweetActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.tweetActionable\", function(a) {\n            return a.mixin(twttr.mixins.itemActionableScribing, twttr.mixins.pendingActions).methods({\n                deletedTweetCacheDuration: 600000,\n                _updateTweetDisplay: function(a, b) {\n                    var c = this;\n                    ((((b === \"delete\")) ? (twttr.showMessage(_(\"Your tweet has been deleted.\")), c.JSBNG__onTweetActionDelete(a)) : twttr.API.Status.JSBNG__find(a, function(d) {\n                        var e = c.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + a)) + \"]\")));\n                        switch (b) {\n                          case \"favorite\":\n                            d.sync(\"favorited\", !0), e.addClass(\"favorited\");\n                            break;\n                          case \"unfavorite\":\n                            d.sync(\"favorited\", !1), e.removeClass(\"favorited\");\n                            break;\n                          case \"retweet\":\n                            d.sync(\"current_user_retweet\", !0), e.addClass(\"retweeted\");\n                            break;\n                          case \"unretweet\":\n                            d.sync(\"current_user_retweet\", !1), e.removeClass(\"retweeted\");\n                            break;\n                          case \"hide\":\n                            c.JSBNG__onTweetActionHide(a);\n                            break;\n                          case \"show\":\n                            c.JSBNG__onTweetActionShow(a);\n                        };\n                    ;\n                        c.rerenderTweetActionsView(b, d, e);\n                    })));\n                },\n                JSBNG__onTweetActionDelete: function(a) {\n                    this._getActionableTweets(a).remove();\n                },\n                JSBNG__onTweetActionHide: function(a) {\n                    this._getActionableTweets(a).hide();\n                },\n                JSBNG__onTweetActionShow: function(a) {\n                    this._getActionableTweets(a).show();\n                },\n                getTweetId: function(a) {\n                    return a.attr(\"data-tweet-id\");\n                },\n                getScreenName: function(a) {\n                    return a.attr(\"data-screen-name\");\n                },\n                getImpressionId: function(a) {\n                    return a.attr(\"data-impression-id\");\n                },\n                getScribeComponent: function(a) {\n                    return ((a.is(\"div.details-pane .js-actionable-tweet\") ? \"details-pane\" : ((a.is(\"div.stream .js-actionable-tweet\") ? \"stream\" : \"generic-component\"))));\n                },\n                getStreamName: function() {\n                    var a = twttr.app.currentPage(), b = a.getInstanceProperty(\"streamManager\");\n                    return ((b ? b.getCurrent().constructor._name : null));\n                },\n                tweetActionFavorite: function(a, b) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.getTweetId(a), d = a.hasClass(\"favorited\"), e = ((d ? \"unfavorite\" : \"favorite\")), f = this.getImpressionId(a);\n                    twttr.API.Status[e](c, {\n                        impression_id: f,\n                        cacheOptions: {\n                            skipOverwrite: !0\n                        }\n                    });\n                    var g = twttr.app.currentPage().getInstanceProperty(\"streamManager\"), i = {\n                        input: b,\n                        tweet_id: c,\n                        favorited: !d,\n                        component: this.getScribeComponent(a),\n                        stream: ((g && g.getCurrent().constructor._name))\n                    };\n                    ((d ? twttr.viewHelpers.addActivityItemLogging(a, i, \"unfavorite-tweet\") : twttr.viewHelpers.addExtraLogging(a, i, \"favorite-tweet\")));\n                    var j = ((d ? \"unfavorite\" : \"favorite\"));\n                    this.trigger(((j + \".tweet\")), [a,a.JSBNG__find(\"a.js-toggle-fav\"),j,]), _scribble(\"favorite-tweet\", i);\n                },\n                tweetActionRetweet: function(a, b) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.getTweetId(a), d = this.getScreenName(a), e = this.getImpressionId(a), f = a.hasClass(\"retweeted\"), g = this.getScribeComponent(a), i = this.getStreamName(), j = !!a.attr(\"data-protected\");\n                    if (((twttr.helpers.isCurrentUser(d) || ((j && !f))))) {\n                        return;\n                    }\n                ;\n                ;\n                    if (f) {\n                        var k = a.attr(\"data-my-retweet-id\");\n                        ((k && (this.trigger(\"unretweet.tweet\", [a,a.JSBNG__find(\"a.js-toggle-rt\"),\"unretweet\",]), twttr.API.Status.unretweet(k))));\n                    }\n                     else {\n                        var l = this;\n                        using([twttr.bundleMore,\"dialogs\",], function() {\n                            twttr.API.Status.JSBNG__find(c, function(d) {\n                                twttr.dialogs.retweet(c, d.text, function(d) {\n                                    ((d && (twttr.API.Status.retweet(c, {\n                                        impression_id: e\n                                    }), l.trigger(\"retweet.tweet\", [a,a.JSBNG__find(\"a.js-toggle-rt\"),\"retweet\",]), _scribble(\"tweet\", {\n                                        tweet_type: \"retweet\",\n                                        origin: \"tweet-action-retweet\",\n                                        input: b,\n                                        component: g,\n                                        stream: i\n                                    }))));\n                                }).open();\n                            });\n                        });\n                    }\n                ;\n                ;\n                    var m = {\n                        input: b,\n                        tweet_id: c,\n                        component: g,\n                        stream: i\n                    };\n                    twttr.viewHelpers.addExtraLogging(a, m, \"retweet-tweet-opened\"), _scribble(\"retweet-tweet-opened\", m);\n                },\n                tweetActionReply: function(a, b, c) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this.getTweetId(a), e = this.getImpressionId(a), f = this.getScreenName(a), g = this.getScribeComponent(a), i = this.getStreamName(), j = {\n                        $tweet: a,\n                        tweetId: d,\n                        impressionId: e,\n                        screenName: f,\n                        origin: \"tweet-action-reply\",\n                        input: b,\n                        component: g,\n                        stream: i\n                    };\n                    if (!c) {\n                        var k = this;\n                        using([twttr.bundleMore,\"dialogs\",], function() {\n                            var b = twttr.dialogs.reply(j);\n                            b.view.tweetBox.bind(\"sendingTweet\", function(b, c) {\n                                k.trigger(\"reply.tweet\", [a,a.JSBNG__find(\"a.js-action-reply\"),\"reply\",]);\n                            }), b.open();\n                        });\n                    }\n                ;\n                ;\n                    var l = {\n                        input: b,\n                        tweet_id: d,\n                        component: g,\n                        stream: i\n                    };\n                    return twttr.viewHelpers.addExtraLogging(a, l, \"reply-to-tweet-opened\"), _scribble(\"reply-to-tweet-opened\", l), j;\n                },\n                tweetActionDismiss: function(a, b) {\n                    var c = this.getImpressionId(a), d = a.parent(\".js-stream-item\");\n                    ((d.hasClass(\"focused-stream-item\") && twttr.app.currentPage().send(\"closeDetailsPane\"))), d.fadeOut(300, function() {\n                        d.remove();\n                    });\n                    for (var e = 0; ((e < this.items.length)); e++) {\n                        if (((this.items[e].impressionId == c))) {\n                            this.items.splice(e, 1);\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    twttr.API.util.PromotedContent.logDismissOther(c), this.trigger(\"dismiss.tweet\", [a,a.JSBNG__find(\".js-action-dismiss, div.js-action-dismiss\"),\"dismiss\",]), twttr.promotedTweetStore.clear();\n                },\n                tweetActionNotRelevant: function(a) {\n                    var b = {\n                        query: a.JSBNG__find(\"a.js-action-notrel\").attr(\"data-search-query\"),\n                        tweet_id: this.getTweetId(a),\n                        stream_index: String(a.closest(\".stream-item\").parent().JSBNG__find(\".stream-tweet:not([data-promoted=\\\"true\\\"])\").index(a))\n                    };\n                    this.trigger(\"not_relevant.tweet\", [a,a.JSBNG__find(\"a.js-action-notrel\"),\"not_relevant\",]), _scribble(\"not-relevant-tweet\", b);\n                },\n                tweetActionDelete: function(a, b) {\n                    var c = this;\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this.getTweetId(a);\n                    using([twttr.bundleMore,\"widget/Prompt\",], function() {\n                        (new twttr.widget.Prompt({\n                            template: {\n                                title: _(\"Are you sure you want to delete this tweet?\")\n                            },\n                            callback: function(a) {\n                                ((a && twttr.API.Status.JSBNG__find(d).destroy({\n                                    success: function() {\n                                        twttr.app.caches.deletedTweets.set(d, !0, c.deletedTweetCacheDuration);\n                                    },\n                                    error: function(a) {\n                                        twttr.errors.showErrorFromResponse(a, \"delete\");\n                                    }\n                                })));\n                            }\n                        })).open();\n                    }), this.trigger(\"delete.tweet\", [a,a.JSBNG__find(\"a.js-action-del\"),\"delete\",]);\n                    var e = {\n                        input: b,\n                        tweet_id: d,\n                        component: this.getScribeComponent(a)\n                    };\n                    _scribble(\"delete-tweet-opened\", e);\n                },\n                _getActionableTweets: function(a) {\n                    return this.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + a)) + \"]\")));\n                },\n                _getActionableMyRetweets: function(a) {\n                    return this.$find(((((\"div.js-actionable-tweet[data-my-retweet-id=\" + a)) + \"]\")));\n                },\n                _registerTweetActionAPIListeners: function() {\n                    var a = this;\n                    twttr.API.Status.bind(\"favorite\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"favorite\"), a._updateTweetDisplay(d, \"favorite\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"favorite\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"unfavorite\"), twttr.errors.showErrorFromResponse(c, \"favorite\");\n                        }\n                    }), twttr.API.Status.bind(\"unfavorite\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"unfavorite\"), a._updateTweetDisplay(d, \"unfavorite\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"unfavorite\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"favorite\"), twttr.errors.showErrorFromResponse(c, \"unfavorite\");\n                        }\n                    }), twttr.API.Status.bind(\"retweet\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"retweet\"), a._updateTweetDisplay(d, \"retweet\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"retweet\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"unretweet\"), twttr.errors.showErrorFromResponse(c, \"retweet\");\n                        },\n                        success: function(b, c) {\n                            var d = c.retweetingStatus.id, e = c.id;\n                            c.sync(\"current_user_retweet\", {\n                                id: d\n                            }), a.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + e)) + \"]\"))).attr(\"data-my-retweet-id\", d);\n                        }\n                    }), twttr.API.Status.bind(\"unretweet\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].id, e = a._getActionableMyRetweets(d);\n                            a.markAsPending(e, \"unretweet\");\n                            var f = e.attr(\"data-tweet-id\");\n                            a._updateTweetDisplay(f, \"unretweet\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0].id, f = a._getActionableMyRetweets(e);\n                            a.markAsComplete(f, \"unretweet\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].id, f = a._getActionableMyRetweets(e), g = f.attr(\"data-tweet-id\");\n                            a._updateTweetDisplay(g, \"retweet\");\n                        },\n                        success: function(b, c, d) {\n                            var e = c.id, f = c.retweetingStatus.id;\n                            a._updateTweetDisplay(e, \"unretweet\"), a._getActionableTweets(e).attr(\"data-my-retweet-id\", null);\n                        }\n                    }), twttr.API.Status.bind(\"delete\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].id;\n                            a.markAsPending(a._getActionableTweets(d), \"delete\"), a._updateTweetDisplay(d, \"hide\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0].id;\n                            a.markAsComplete(a._getActionableTweets(e), \"delete\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].id;\n                            a._updateTweetDisplay(e, \"show\");\n                        },\n                        success: function(b, c, d) {\n                            var e = c.id;\n                            a._updateTweetDisplay(e, \"delete\");\n                        }\n                    });\n                },\n                registerTweetActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-tweet .js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logProfileImageClick(e))), a.trigger(\"avatar_click.tweet\", [d,c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logScreenNameClick(e))), a.trigger(\"screen_name_click.tweet\", [d,c,\"screen_name\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .js-action-profile-promoted\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logFooterProfileClick(e))), a.trigger(\"promoted_badge_click.tweet\", [d,c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-hashtag\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logHashtagClick(e, c.text()))), a.trigger(\"hashtag_click.tweet\", [d,c,\"hashtag\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-atreply\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logUserMentionClick(e, c.text()))), a.trigger(\"mention_click.tweet\", [d,c,\"mention\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-timeline-link\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logUrlClick(e, c.text()))), a.trigger(\"external_link_click.tweet\", [d,c,\"external_link\",]);\n                    }), this.$node.delegate(\".js-stream-item .js-permalink\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-stream-item\").JSBNG__find(\"div.js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logPermalinkClick(e))), a.trigger(\"permalink_click.tweet\", [d,c,\"permalink\",]);\n                    }), this.$node.delegate(\".js-actions .js-toggle-fav\", \"click\", function(b) {\n                        return ((twttr.loggedIn ? a.tweetActionFavorite($(this).closest(\".js-actionable-tweet\"), \"click\") : twttr.dialogs.signinOrSignup().open())), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-reply\", \"click\", function(b) {\n                        if (twttr.loggedIn) {\n                            var c = $(this).closest(\".js-actionable-tweet\");\n                            if (((((twttr.decider.hasInlineReplies() && c.hasClass(\"original-tweet\"))) && !c.hasClass(\"js-activity-tweet\")))) {\n                                if (!c.hasClass(\"opened-tweet\")) c.JSBNG__find(\".action-reply-container\").trigger(\"click\");\n                                 else {\n                                    var d = c.data(\"inline-tweetbox\");\n                                    ((d && d.JSBNG__focus()));\n                                }\n                            ;\n                            }\n                             else {\n                                a.tweetActionReply(c, \"click\");\n                            }\n                        ;\n                        ;\n                        }\n                         else twttr.dialogs.signinOrSignup().open();\n                    ;\n                    ;\n                        return b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-action-dismiss\", \"click\", function(b) {\n                        return a.tweetActionDismiss($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-del\", \"click\", function(b) {\n                        return a.tweetActionDelete($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-toggle-rt\", \"click\", function(b) {\n                        return ((twttr.loggedIn ? a.tweetActionRetweet($(this).closest(\".js-actionable-tweet\"), \"click\") : twttr.dialogs.signinOrSignup().open())), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-notrel\", \"click\", function(b) {\n                        return a.tweetActionNotRelevant($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this._registerTweetActionAPIListeners(), this._registerTweetActionScribeListeners();\n                }\n            }), ((twttr.isT1 ? this.methods({\n                rerenderTweetActionsView: twttr.util.noopInT1\n            }) : this.methods({\n                rerenderTweetActionsView: function(a, b, c) {\n                    var d = new twttr.views.TweetActions(b);\n                    ((((a === \"unretweet\")) && (d.retweeted = !1))), c.JSBNG__find(\"span.js-actions, ul.js-actions\").replaceWith(d.html());\n                }\n            }))), a;\n        }), a(twttr.mixins.tweetActionable);\n    });\n});\nprovide(\"mixins/pendingActions\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.pendingActions\", function() {\n            function a(a) {\n                var b = a.attr(\"data-pending\");\n                return ((b ? b.split(\" \") : []));\n            };\n        ;\n            function b(a, b) {\n                ((((b.length === 0)) ? a.removeAttr(\"data-pending\") : a.attr(\"data-pending\", b.join(\" \"))));\n            };\n        ;\n            var $ = jQuery;\n            return this.methods({\n                markAsPending: function(c, d) {\n                    var e = a(c);\n                    (((($.inArray(d, e) == -1)) && (e.push(d), b(c, e))));\n                },\n                markAsComplete: function(c, d) {\n                    var e = a(c), f = $.inArray(d, e);\n                    ((((f >= 0)) && (e.splice(f, 1), b(c, e))));\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/i18nTweet\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.i18nTweet\", function() {\n            var a = 419298, b = twttr.constants.regexps.rtlChar, c = /((<a[^>+]+>.+?<\\/a>|[ ^]RT:|:-?[DP\\$\\)\\(])+)/g;\n            this.methods({\n                updateI18nDisplay: function() {\n                    var a = this;\n                    this.$find(\"div.tweet, div.tweet-row\").each(function() {\n                        a.updateRtlDisplay($(this));\n                    });\n                },\n                getMachedRtlChars: function(a) {\n                    return a.match(b);\n                },\n                shouldBeRTL: function(b, c) {\n                    var d = twttr.txt.extractMentions(b).concat(twttr.txt.extractUrls(b)), e = 0;\n                    ((((d.length > 0)) && (e = ((((d.length * 2)) + d.join(\"\").length)))));\n                    var f = ((b.length - e));\n                    return ((((f != 0)) && ((((c.length / f)) > a))));\n                },\n                updateRtlDisplay: function(a) {\n                    var b = this, d = a.JSBNG__find(\"div.js-tweet-text, p.js-tweet-text\");\n                    if (d.hasClass(\"tweet-text-rtl\")) {\n                        return;\n                    }\n                ;\n                ;\n                    var e = this.getMachedRtlChars(d.text());\n                    ((((e != undefined)) && (d.JSBNG__find(\".twitter-hashtag\").each(function() {\n                        var a = $(this).attr(\"title\");\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        ((a.match(twttr.constants.regexps.rtlHashtag) ? $(this).html(((((\"\\u202b\" + $(this).html())) + \"\\u202c\"))) : $(this).html(((((\"\\u202a\" + $(this).html())) + \"\\u202c\")))));\n                    }), ((this.shouldBeRTL(d.text(), e) && (d.addClass(\"tweet-text-rtl\"), d.html(d.html().replace(c, \"\\u200e$1\\u200f\")), d.addClass(\"tweet-rtl\")))))));\n                }\n            });\n        }), a(twttr.mixins.i18nTweet);\n    });\n});\nprovide(\"mixins/i18nTweetBox\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.i18nTweetBox\", function() {\n            this.mixin(twttr.mixins.i18nTweet).methods({\n                registerTextDirEvents: function() {\n                    this.editor.bind(\"didChangeContent\", twttr.bind(this, this._toggleTextDir));\n                },\n                _insertLTRMarker: function(a) {\n                    var b = 0, c = [];\n                    return $(twttr.txt.extractMentionsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[0])), ((((((e.indices[0] === 0)) || ((a[((e.indices[0] - 1))] !== \"\\u200e\")))) && c.push(\"\\u200e\"))), c.push(a.substring(e.indices[0], e.indices[1])), ((((((e.indices[1] === 0)) || ((a[((e.indices[1] + 1))] !== \"\\u200f\")))) && c.push(\"\\u200f\"))), b = e.indices[1];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), b = 0, c.length = 0, $(twttr.txt.extractHashtagsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[0])), ((((!a[((e.indices[0] + 1))].match(twttr.constants.regexps.rtlChar) && ((((e.indices[0] === 0)) || ((a[((e.indices[0] - 1))] !== \"\\u200e\")))))) && c.push(\"\\u200e\"))), b = e.indices[0];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), b = 0, c.length = 0, $(twttr.txt.extractUrlsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[1])), ((((((e.indices[1] !== 0)) && ((a[((e.indices[1] + 1))] !== \"\\u200e\")))) && c.push(\"\\u200e\"))), b = e.indices[1];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), a;\n                },\n                _eraseCheck: function(a) {\n                    if (((this._prev_txt && ((((this._prev_txt.length - a.length)) === 1))))) {\n                        for (i = 0; ((i < this._prev_txt.length)); ++i) {\n                            if (((((this._prev_txt[i] !== a[i])) && ((((this._prev_txt[i] === \"\\u200e\")) || ((this._prev_txt[i] === \"\\u200f\"))))))) {\n                                return ((a.substring(0, ((i - 1))) + a.substr(i)));\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return a;\n                },\n                _markAtmarkLTR: function(a) {\n                    function b(a) {\n                        var b = 0;\n                        if (JSBNG__document.selection) {\n                            var c = JSBNG__document.selection.createRange();\n                            if (((c && ((c.parentElement() === a))))) {\n                                var d = a.value.length, e = a.createTextRange();\n                                e.moveToBookmark(c.getBookmark());\n                                var f = a.createTextRange();\n                                f.collapse(!1), ((((e.compareEndPoints(\"StartToEnd\", f) > -1)) ? b = d : b = -e.moveStart(\"character\", -d)));\n                            }\n                        ;\n                        ;\n                        }\n                         else if (((a.selectionStart || ((a.selectionStart == \"0\"))))) {\n                            b = a.selectionStart;\n                        }\n                        \n                    ;\n                    ;\n                        return b;\n                    };\n                ;\n                    function c(a, b) {\n                        if (a.setSelectionRange) {\n                            a.JSBNG__focus(), a.setSelectionRange(b, b);\n                        }\n                         else {\n                            if (a.createTextRange) {\n                                var c = a.createTextRange();\n                                c.collapse(!0), c.moveEnd(\"character\", b), c.moveStart(\"character\", b), c.select();\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    var d = ((a.parents(\"body\").length !== 0)), e = 0;\n                    ((d && (e = b(a[0]))));\n                    var f = a.val().length, g = this._eraseCheck(a.val()).replace(twttr.constants.regexps.dirMark, \"\");\n                    g = this._insertLTRMarker(g);\n                    if (((d && ((this._prev_txt !== g))))) {\n                        this._prev_txt = g, a.val(g);\n                        var i = ((((e + g.length)) - f));\n                        c(a[0], i);\n                    }\n                ;\n                ;\n                },\n                markPunctuation: function(a, b) {\n                    var c = b.val(), d = c.match(twttr.constants.regexps.rtlChar), e = twttr.isRTL;\n                    ((d ? e = this.shouldBeRTL(c, d) : ((((c.length !== 0)) && (e = !1))))), b.attr(\"dir\", ((e ? \"rtl\" : \"ltr\"))), ((((d && (((($.browser.mozilla || (((($.browser.webkit && a)) && ((a.type === \"keydown\")))))) || (((($.browser.msie && a)) && ((a.type === \"keyup\")))))))) && this._markAtmarkLTR(b)));\n                },\n                _toggleTextDir: function(a, b, c) {\n                    this.markPunctuation(c, this.editor.$editor);\n                }\n            });\n        }), a(twttr.mixins.i18nTweetBox);\n    });\n});\nprovide(\"mixins/promotedTweetStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.promotedTweetStream\", function(a) {\n            return a.methods({\n                hasPromotedContent: function() {\n                    for (var a = 0, b = this.items.length; ((a < b)); a++) {\n                        if (this.items[a].isPromoted()) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    return !1;\n                },\n                logPromotedImpressions: function(a) {\n                    function b(a) {\n                        a.logImpressionIfPromoted();\n                    };\n                ;\n                    ((a.each ? a.each(b) : twttr.each(a, b)));\n                },\n                movePromotedTweetToTop: function() {\n                    var a = this.getMostRecentPromotedTweet();\n                    ((a && (this.removePromotedTweetDOMElements(), this.removePromotedTweetItems(), this.addAsNewItem(a))));\n                },\n                getMostRecentPromotedTweet: function() {\n                    for (var a = this.newItemsCount, b = this.items.length; ((a < b)); a++) {\n                        if (this.items[a].isPromoted()) {\n                            return this.items[a];\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                },\n                promotedTweetIsExpanded: function() {\n                    var a = this.$find(\".promoted-tweet\").closest(\".js-stream-item\");\n                    return a.hasClass(\"open\");\n                },\n                removePromotedTweetDOMElements: function() {\n                    this.$find(\".promoted-tweet\").closest(\".js-stream-item\").remove();\n                },\n                removePromotedTweetItems: function() {\n                    for (var a = this.newItemsCount; ((a < this.items.length)); a++) {\n                        ((this.items[a].isPromoted() && this.items.splice(a, 1)));\n                    ;\n                    };\n                ;\n                }\n            }), a;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/componentEvents\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        var c;\n        twttr.klass.mixin(\"twttr.mixins.componentEvents\", function(a) {\n            return $.each(b.constants.jQueryEvents, function(c, d) {\n                a[d] = function(a) {\n                    return ((twttr.is.inArray(d, [\"keypress\",\"keydown\",\"keyup\",]) && $.each(a, function(b, c) {\n                        a[b] = function(a) {\n                            return ((((((a.ctrlKey || a.metaKey)) || a.altKey)) ? undefined : c.apply(this, arguments)));\n                        };\n                    }))), ((this.prototype.hasOwnProperty(((\"_\" + d))) || ((((this.uberclass && this.uberclass.prototype[((\"_\" + d))])) ? this.prototype[((\"_\" + d))] = b.util.create(this.uberclass.prototype[((\"_\" + d))]) : this.prototype[((\"_\" + d))] = {\n                    })))), twttr.augmentObject(this.prototype[((\"_\" + d))], a), this;\n                };\n            }), a.statics({\n                debugUserEvents: function(a) {\n                    c = ((((typeof a == \"undefined\")) ? !0 : a));\n                }\n            }), a.methods({\n                initComponentEvents: function(a) {\n                    var d = this;\n                    a = ((a || this.$node)), $.each(b.constants.jQueryEvents, function(b, e) {\n                        if (twttr.is.inArray(e, [\"keypress\",\"keydown\",\"keyup\",])) {\n                            return;\n                        }\n                    ;\n                    ;\n                        $.each(((d[((\"_\" + e))] || {\n                        })), function(b, f) {\n                            var g = [b,e,], i = (($.isArray(f) ? f : [f,]));\n                            $.each(i, function(a, f) {\n                                g.push(function(a) {\n                                    ((c && JSBNG__console.log(\"User event fired\", {\n                                        component: d,\n                                        JSBNG__event: e,\n                                        selector: b,\n                                        handler: f\n                                    })));\n                                    if (!a.isImmediatePropagationStopped()) {\n                                        return f.call(d, a, $(this));\n                                    }\n                                ;\n                                ;\n                                });\n                            }), a.delegate.apply(a, g);\n                        });\n                    });\n                }\n            }), a;\n        }), a(twttr.mixins.componentEvents);\n    });\n});\nprovide(\"mixins/protectedUserActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.protectedUserActionable\", function(a) {\n            return a.methods({\n                registerProtectedUserActions: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-deny\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\");\n                        return twttr.currentUser.friends.deny(parseInt(d.attr(\"data-user-id\")), function(b) {\n                            a.trigger(\"deny.user\", [d,c,\"deny\",]), d.parents(\".js-stream-item\").remove();\n                        }), b.stopImmediatePropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-accept\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\");\n                        return twttr.currentUser.friends.accept(parseInt(d.attr(\"data-user-id\")), function(b) {\n                            a.trigger(\"accept.user\", [d,c,\"accept\",]), (new twttr.views.StreamUser(b)).render(d, \"replaceWith\");\n                        }), b.stopImmediatePropagation(), !1;\n                    });\n                }\n            }), a;\n        }), a(twttr.mixins.protectedUserActionable);\n    });\n});\nprovide(\"mixins/serverRenderableObject\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, $) {\n        twttr.klass.mixin(\"twttr.mixins.serverRenderableObject\", function(a) {\n            return a.methods({\n                preRendered: !1,\n                $domNode: function(a) {\n                    return ((this.$node ? this.$node : (((this.isPresentInDom() ? (this.preRendered = !0, this.$node = $(this.selectorAsString())) : (this.preRendered = !1, ((((typeof a == \"function\")) && (a = a.call(this)))), this.$node = $(a), ((((this.$node.length > 1)) && (this.$node = $(\"\\u003Cdiv /\\u003E\").html(a))))))), this.$node)));\n                },\n                domNodeSelector: null,\n                selectorAsString: function() {\n                    return ((((typeof this.domNodeSelector == \"function\")) ? this.domNodeSelector() : this.domNodeSelector));\n                },\n                isPresentInDom: function() {\n                    var a = this.selectorAsString();\n                    return ((a && (($(a).length === 1))));\n                }\n            }), a;\n        }), a(twttr.mixins.serverRenderableObject);\n    });\n});\nprovide(\"mixins/welcomeScribing\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.welcomeScribing\", function(a) {\n            return a.methods({\n                setWelcomeSkipCookie: function() {\n                    twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !1, $.cookie(\"welcome\", \"1\", {\n                        expires: new JSBNG__Date(((+(new JSBNG__Date) + 3600000)))\n                    });\n                },\n                clearWelcomeSkipCookie: function() {\n                    ((twttr.mixins.welcomeScribing._noWelcomeSkipCookie || (twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !0, $.cookie(\"welcome\", null))));\n                },\n                maybeScribeWelcomeSkip: function() {\n                    if (((twttr.mixins.welcomeScribing._noWelcomeSkipCookie || (($.cookie(\"welcome\") != \"1\"))))) {\n                        twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !0;\n                        return;\n                    }\n                ;\n                ;\n                    var a = {\n                        page: \"welcome\",\n                        section: \"finished\",\n                        action: \"skip\"\n                    };\n                    trackClient(a), this.clearWelcomeSkipCookie();\n                }\n            }), a;\n        }), a();\n    });\n});\nprovide(\"mixins/t1/emptyTimelineRecommendations\", function(a) {\n    using().as(function() {\n        twttr.klass.mixin(\"twttr.mixins.emptyTimelineRecommendations\", function() {\n            this.statics({\n                showing: !1\n            }).methods({\n                insertEmptyTimeline: function(a) {\n                    var a = ((a || {\n                    })), b = this;\n                    using([twttr.bundleMore,\"components/t1/EmptyTimelineRecommendations\",], function() {\n                        if (!twttr.decider.isAvailable(\"empty_timeline_recommendations\")) {\n                            return b._dontShowSignalCompleted(b);\n                        }\n                    ;\n                    ;\n                        if (!twttr.util.params().empty_timeline) {\n                            if (((twttr.cache.local.shownWelcomeFlow && ((twttr.currentUser.friendsCount > 0))))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                            if (((twttr.currentUser.friendsCount >= twttr.components.t1.EmptyTimelineRecommendations.avatarLimit))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                            if (((((((((Math.floor((((new JSBNG__Date).getTime() - new JSBNG__Date(twttr.currentUser.createdAt)))) / 86400000)) > 60)) && ((twttr.currentUser.followersCount > 100)))) && ((twttr.currentUser.friendsCount > 0))))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        var c = b.$find(\"#js-empty-timeline-recommendations-module-hook\"), d = b.$find(\".js-stream-manager-container, .js-stream-header\");\n                        c.show(), twttr.mixins.emptyTimelineRecommendations.showing = !0, twttr.router.JSBNG__one(\"routed.EmptyTimelineRecommendations\", function(a, b) {\n                            ((((e === b.JSBNG__name)) ? twttr.router.JSBNG__one(\"routed.EmptyTimelineRecommendations\", arguments.callee) : (c.hide(), d.show())));\n                        });\n                        var e = twttr.router.getCurrentRoute().JSBNG__name;\n                        if (((c.JSBNG__find(\".js-empty-timeline\").size() > 0))) {\n                            b.signal(\"emptyTimelineModuleLogicCompleted\");\n                            return;\n                        }\n                    ;\n                    ;\n                        var f = new twttr.components.t1.EmptyTimelineRecommendations({\n                            scribeComponentName: \"empty_timeline_recommendations\"\n                        });\n                        c.html(f.$node), f.trigger(\"addedToPage\"), ((((typeof a.JSBNG__onDestroyCb == \"function\")) && f.bind(\"destroyed\", a.JSBNG__onDestroyCb)));\n                        var g = {\n                            success: function() {\n                                var c = b.streamManager.streams.current;\n                                ((a.reloadStream && c.trigger(\"reloadCurrentStream\", c.constructor))), d.show();\n                            }\n                        };\n                        twttr.API.User.bind(\"follow.EmptyTimelineRecommendations\", g);\n                        var g = {\n                            success: function() {\n                                var c = b.streamManager.streams.current;\n                                ((a.reloadStream && c.trigger(\"reloadCurrentStream\", c.constructor))), ((((twttr.currentUser.friendsCount === 0)) && d.hide()));\n                            }\n                        };\n                        twttr.API.User.bind(\"unfollow.EmptyTimelineRecommendations\", g), b.signal(\"emptyTimelineModuleLogicCompleted\");\n                    });\n                },\n                _dontShowSignalCompleted: function(a) {\n                    twttr.mixins.emptyTimelineRecommendations.showing = !1, a.signal(\"emptyTimelineModuleLogicCompleted\");\n                }\n            });\n        }), a(twttr.mixins.emptyTimelineRecommendations);\n    });\n});\nprovide(\"lib/natcompare\", function(a) {\n    using().as(function(b) {\n        var c = twttr.augmentString(\"twttr.natcompare\", function() {\n            var a = function(a) {\n                var b;\n                return b = a.charCodeAt(0), ((((b <= 32)) ? !0 : !1));\n            }, b = function(a) {\n                var b;\n                return b = a.charCodeAt(0), ((((((b >= 48)) && ((b <= 57)))) ? !0 : !1));\n            }, c = function(a, c) {\n                var d = 0, e = 0, f = 0, g, i;\n                for (; ; e++, f++) {\n                    g = a.charAt(e), i = c.charAt(f);\n                    if (((!b(g) && !b(i)))) {\n                        return d;\n                    }\n                ;\n                ;\n                    if (!b(g)) {\n                        return -1;\n                    }\n                ;\n                ;\n                    if (!b(i)) {\n                        return 1;\n                    }\n                ;\n                ;\n                    ((((g < i)) ? ((((d == 0)) && (d = -1))) : ((((((g > i)) && ((d == 0)))) && (d = 1)))));\n                };\n            ;\n            };\n            return function(d, e) {\n                ((((typeof d == \"number\")) && (d = d.toString()))), ((((typeof e == \"number\")) && (e = e.toString())));\n                var f = 0, g = 0, i = 0, j = 0, k, l, m;\n                for (; ; ) {\n                    i = j = 0, k = d.charAt(f), l = e.charAt(g);\n                    while (((a(k) || ((k == \"0\"))))) {\n                        ((((k == \"0\")) ? i++ : i = 0)), k = d.charAt(++f);\n                    ;\n                    };\n                ;\n                    while (((a(l) || ((l == \"0\"))))) {\n                        ((((l == \"0\")) ? j++ : j = 0)), l = e.charAt(++g);\n                    ;\n                    };\n                ;\n                    if (((((b(k) && b(l))) && (((m = c(d.substring(f), e.substring(g))) != 0))))) {\n                        return m;\n                    }\n                ;\n                ;\n                    if (((((k == 0)) && ((l == 0))))) {\n                        return ((i - j));\n                    }\n                ;\n                ;\n                    if (((k < l))) {\n                        return -1;\n                    }\n                ;\n                ;\n                    if (((k > l))) {\n                        return 1;\n                    }\n                ;\n                ;\n                    ++f, ++g;\n                };\n            ;\n            };\n        }());\n        twttr.augmentString(\"twttr.util.natcompare\", c), a(c);\n    });\n});\nprovide(\"$lib/twitter-text-1.5.0.js\", function(a) {\n    if (((((typeof window == \"undefined\")) || ((window === null))))) {\n        window = {\n            twttr: {\n            }\n        };\n    }\n;\n;\n    ((((window.twttr == null)) && (window.twttr = {\n    })));\n    if (((((typeof twttr == \"undefined\")) || ((twttr === null))))) {\n        twttr = {\n        };\n    }\n;\n;\n    (function() {\n        function a(a, b) {\n            return b = ((b || \"\")), ((((typeof a != \"string\")) && (((((a.global && ((b.indexOf(\"g\") < 0)))) && (b += \"g\"))), ((((a.ignoreCase && ((b.indexOf(\"i\") < 0)))) && (b += \"i\"))), ((((a.multiline && ((b.indexOf(\"m\") < 0)))) && (b += \"m\"))), a = a.source))), new RegExp(a.replace(/#\\{(\\w+)\\}/g, function(a, b) {\n                var c = ((twttr.txt.regexen[b] || \"\"));\n                return ((((typeof c != \"string\")) && (c = c.source))), c;\n            }), b);\n        };\n    ;\n        function b(a, b) {\n            return a.replace(/#\\{(\\w+)\\}/g, function(a, c) {\n                return ((b[c] || \"\"));\n            });\n        };\n    ;\n        function c(a, b, c) {\n            var d = String.fromCharCode(b);\n            return ((((c !== b)) && (d += ((\"-\" + String.fromCharCode(c)))))), a.push(d), a;\n        };\n    ;\n        function d(a) {\n            var b = {\n            };\n            for (var c in a) {\n                ((a.hasOwnProperty(c) && (b[c] = a[c])));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function e(a, b, c) {\n            return ((c ? ((!a || ((a.match(b) && ((RegExp[\"$&\"] === a)))))) : ((((((typeof a == \"string\")) && a.match(b))) && ((RegExp[\"$&\"] === a))))));\n        };\n    ;\n        twttr.txt = {\n        }, twttr.txt.regexen = {\n        };\n        var f = {\n            \"&\": \"&amp;\",\n            \"\\u003E\": \"&gt;\",\n            \"\\u003C\": \"&lt;\",\n            \"\\\"\": \"&quot;\",\n            \"'\": \"&#39;\"\n        };\n        twttr.txt.htmlEscape = function(a) {\n            return ((a && a.replace(/[&\"'><]/g, function(a) {\n                return f[a];\n            })));\n        }, twttr.txt.regexSupplant = a, twttr.txt.stringSupplant = b, twttr.txt.addCharsToCharClass = c;\n        var g = String.fromCharCode, i = [g(32),g(133),g(160),g(5760),g(6158),g(8232),g(8233),g(8239),g(8287),g(12288),];\n        c(i, 9, 13), c(i, 8192, 8202);\n        var j = [g(65534),g(65279),g(65535),];\n        c(j, 8234, 8238), twttr.txt.regexen.spaces_group = a(i.join(\"\")), twttr.txt.regexen.spaces = a(((((\"[\" + i.join(\"\"))) + \"]\"))), twttr.txt.regexen.invalid_chars_group = a(j.join(\"\")), twttr.txt.regexen.punct = /\\!'#%&'\\(\\)*\\+,\\\\\\-\\.\\/:;<=>\\?@\\[\\]\\^_{|}~\\$/;\n        var k = [];\n        c(k, 1024, 1279), c(k, 1280, 1319), c(k, 11744, 11775), c(k, 42560, 42655), c(k, 1425, 1471), c(k, 1473, 1474), c(k, 1476, 1477), c(k, 1479, 1479), c(k, 1488, 1514), c(k, 1520, 1524), c(k, 64274, 64296), c(k, 64298, 64310), c(k, 64312, 64316), c(k, 64318, 64318), c(k, 64320, 64321), c(k, 64323, 64324), c(k, 64326, 64335), c(k, 1552, 1562), c(k, 1568, 1631), c(k, 1646, 1747), c(k, 1749, 1756), c(k, 1758, 1768), c(k, 1770, 1775), c(k, 1786, 1788), c(k, 1791, 1791), c(k, 1872, 1919), c(k, 2208, 2208), c(k, 2210, 2220), c(k, 2276, 2302), c(k, 64336, 64433), c(k, 64467, 64829), c(k, 64848, 64911), c(k, 64914, 64967), c(k, 65008, 65019), c(k, 65136, 65140), c(k, 65142, 65276), c(k, 8204, 8204), c(k, 3585, 3642), c(k, 3648, 3662), c(k, 4352, 4607), c(k, 12592, 12677), c(k, 43360, 43391), c(k, 44032, 55215), c(k, 55216, 55295), c(k, 65441, 65500), c(k, 12449, 12538), c(k, 12540, 12542), c(k, 65382, 65439), c(k, 65392, 65392), c(k, 65296, 65305), c(k, 65313, 65338), c(k, 65345, 65370), c(k, 12353, 12438), c(k, 12441, 12446), c(k, 13312, 19903), c(k, 19968, 40959), c(k, 173824, 177983), c(k, 177984, 178207), c(k, 194560, 195103), c(k, 12291, 12291), c(k, 12293, 12293), c(k, 12347, 12347), twttr.txt.regexen.nonLatinHashtagChars = a(k.join(\"\"));\n        var l = [];\n        c(l, 192, 214), c(l, 216, 246), c(l, 248, 255), c(l, 256, 591), c(l, 595, 596), c(l, 598, 599), c(l, 601, 601), c(l, 603, 603), c(l, 611, 611), c(l, 616, 616), c(l, 623, 623), c(l, 626, 626), c(l, 649, 649), c(l, 651, 651), c(l, 699, 699), c(l, 768, 879), c(l, 7680, 7935), twttr.txt.regexen.latinAccentChars = a(l.join(\"\")), twttr.txt.regexen.hashSigns = /[#＃]/, twttr.txt.regexen.hashtagAlpha = a(/[a-z_#{latinAccentChars}#{nonLatinHashtagChars}]/i), twttr.txt.regexen.hashtagAlphaNumeric = a(/[a-z0-9_#{latinAccentChars}#{nonLatinHashtagChars}]/i), twttr.txt.regexen.endHashtagMatch = a(/^(?:#{hashSigns}|:\\/\\/)/), twttr.txt.regexen.hashtagBoundary = a(/(?:^|$|[^&a-z0-9_#{latinAccentChars}#{nonLatinHashtagChars}])/), twttr.txt.regexen.validHashtag = a(/(#{hashtagBoundary})(#{hashSigns})(#{hashtagAlphaNumeric}*#{hashtagAlpha}#{hashtagAlphaNumeric}*)/gi), twttr.txt.regexen.validMentionPrecedingChars = /(?:^|[^a-zA-Z0-9_!#$%&*@＠]|RT:?)/, twttr.txt.regexen.atSigns = /[@＠]/, twttr.txt.regexen.validMentionOrList = a(\"(#{validMentionPrecedingChars})(#{atSigns})([a-zA-Z0-9_]{1,20})(/[a-zA-Z][a-zA-Z0-9_-]{0,24})?\", \"g\"), twttr.txt.regexen.validReply = a(/^(?:#{spaces})*#{atSigns}([a-zA-Z0-9_]{1,20})/), twttr.txt.regexen.endMentionMatch = a(/^(?:#{atSigns}|[#{latinAccentChars}]|:\\/\\/)/), twttr.txt.regexen.validUrlPrecedingChars = a(/(?:[^A-Za-z0-9@＠$#＃#{invalid_chars_group}]|^)/), twttr.txt.regexen.invalidUrlWithoutProtocolPrecedingChars = /[-_.\\/]$/, twttr.txt.regexen.invalidDomainChars = b(\"#{punct}#{spaces_group}#{invalid_chars_group}\", twttr.txt.regexen), twttr.txt.regexen.validDomainChars = a(/[^#{invalidDomainChars}]/), twttr.txt.regexen.validSubdomain = a(/(?:(?:#{validDomainChars}(?:[_-]|#{validDomainChars})*)?#{validDomainChars}\\.)/), twttr.txt.regexen.validDomainName = a(/(?:(?:#{validDomainChars}(?:-|#{validDomainChars})*)?#{validDomainChars}\\.)/), twttr.txt.regexen.validGTLD = a(/(?:(?:aero|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|xxx)(?=[^0-9a-zA-Z]|$))/), twttr.txt.regexen.validCCTLD = a(/(?:(?:ac|ad|ae|af|ag|ai|al|am|an|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bm|bn|bo|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cs|cu|cv|cx|cy|cz|dd|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|eu|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|su|sv|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tp|tr|tt|tv|tw|tz|ua|ug|uk|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw)(?=[^0-9a-zA-Z]|$))/), twttr.txt.regexen.validPunycode = a(/(?:xn--[0-9a-z]+)/), twttr.txt.regexen.validDomain = a(/(?:#{validSubdomain}*#{validDomainName}(?:#{validGTLD}|#{validCCTLD}|#{validPunycode}))/), twttr.txt.regexen.validAsciiDomain = a(/(?:(?:[a-z0-9#{latinAccentChars}]+)\\.)+(?:#{validGTLD}|#{validCCTLD}|#{validPunycode})/gi), twttr.txt.regexen.invalidShortDomain = a(/^#{validDomainName}#{validCCTLD}$/), twttr.txt.regexen.validPortNumber = a(/[0-9]+/), twttr.txt.regexen.validGeneralUrlPathChars = a(/[a-z0-9!\\*';:=\\+,\\.\\$\\/%#\\[\\]\\-_~|&#{latinAccentChars}]/i), twttr.txt.regexen.validUrlBalancedParens = a(/\\(#{validGeneralUrlPathChars}+\\)/i), twttr.txt.regexen.validUrlPathEndingChars = a(/[\\+\\-a-z0-9=_#\\/#{latinAccentChars}]|(?:#{validUrlBalancedParens})/i), twttr.txt.regexen.validUrlPath = a(\"(?:(?:#{validGeneralUrlPathChars}*(?:#{validUrlBalancedParens}#{validGeneralUrlPathChars}*)*#{validUrlPathEndingChars})|(?:@#{validGeneralUrlPathChars}+/))\", \"i\"), twttr.txt.regexen.validUrlQueryChars = /[a-z0-9!?\\*'\\(\\);:&=\\+\\$\\/%#\\[\\]\\-_\\.,~|]/i, twttr.txt.regexen.validUrlQueryEndingChars = /[a-z0-9_&=#\\/]/i, twttr.txt.regexen.extractUrl = a(\"((#{validUrlPrecedingChars})((https?:\\\\/\\\\/)?(#{validDomain})(?::(#{validPortNumber}))?(\\\\/#{validUrlPath}*)?(\\\\?#{validUrlQueryChars}*#{validUrlQueryEndingChars})?))\", \"gi\"), twttr.txt.regexen.validTcoUrl = /^https?:\\/\\/t\\.co\\/[a-z0-9]+/i, twttr.txt.regexen.cashtag = /[a-z]{1,6}(?:[._][a-z]{1,2})?/i, twttr.txt.regexen.validCashtag = a(\"(?:^|#{spaces})\\\\$(#{cashtag})(?=$|\\\\s|[#{punct}])\", \"gi\"), twttr.txt.regexen.validateUrlUnreserved = /[a-z0-9\\-._~]/i, twttr.txt.regexen.validateUrlPctEncoded = /(?:%[0-9a-f]{2})/i, twttr.txt.regexen.validateUrlSubDelims = /[!$&'()*+,;=]/i, twttr.txt.regexen.validateUrlPchar = a(\"(?:#{validateUrlUnreserved}|#{validateUrlPctEncoded}|#{validateUrlSubDelims}|[:|@])\", \"i\"), twttr.txt.regexen.validateUrlScheme = /(?:[a-z][a-z0-9+\\-.]*)/i, twttr.txt.regexen.validateUrlUserinfo = a(\"(?:#{validateUrlUnreserved}|#{validateUrlPctEncoded}|#{validateUrlSubDelims}|:)*\", \"i\"), twttr.txt.regexen.validateUrlDecOctet = /(?:[0-9]|(?:[1-9][0-9])|(?:1[0-9]{2})|(?:2[0-4][0-9])|(?:25[0-5]))/i, twttr.txt.regexen.validateUrlIpv4 = a(/(?:#{validateUrlDecOctet}(?:\\.#{validateUrlDecOctet}){3})/i), twttr.txt.regexen.validateUrlIpv6 = /(?:\\[[a-f0-9:\\.]+\\])/i, twttr.txt.regexen.validateUrlIp = a(\"(?:#{validateUrlIpv4}|#{validateUrlIpv6})\", \"i\"), twttr.txt.regexen.validateUrlSubDomainSegment = /(?:[a-z0-9](?:[a-z0-9_\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomainSegment = /(?:[a-z0-9](?:[a-z0-9\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomainTld = /(?:[a-z](?:[a-z0-9\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomain = a(/(?:(?:#{validateUrlSubDomainSegment]}\\.)*(?:#{validateUrlDomainSegment]}\\.)#{validateUrlDomainTld})/i), twttr.txt.regexen.validateUrlHost = a(\"(?:#{validateUrlIp}|#{validateUrlDomain})\", \"i\"), twttr.txt.regexen.validateUrlUnicodeSubDomainSegment = /(?:(?:[a-z0-9]|[^\\u0000-\\u007f])(?:(?:[a-z0-9_\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomainSegment = /(?:(?:[a-z0-9]|[^\\u0000-\\u007f])(?:(?:[a-z0-9\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomainTld = /(?:(?:[a-z]|[^\\u0000-\\u007f])(?:(?:[a-z0-9\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomain = a(/(?:(?:#{validateUrlUnicodeSubDomainSegment}\\.)*(?:#{validateUrlUnicodeDomainSegment}\\.)#{validateUrlUnicodeDomainTld})/i), twttr.txt.regexen.validateUrlUnicodeHost = a(\"(?:#{validateUrlIp}|#{validateUrlUnicodeDomain})\", \"i\"), twttr.txt.regexen.validateUrlPort = /[0-9]{1,5}/, twttr.txt.regexen.validateUrlUnicodeAuthority = a(\"(?:(#{validateUrlUserinfo})@)?(#{validateUrlUnicodeHost})(?::(#{validateUrlPort}))?\", \"i\"), twttr.txt.regexen.validateUrlAuthority = a(\"(?:(#{validateUrlUserinfo})@)?(#{validateUrlHost})(?::(#{validateUrlPort}))?\", \"i\"), twttr.txt.regexen.validateUrlPath = a(/(\\/#{validateUrlPchar}*)*/i), twttr.txt.regexen.validateUrlQuery = a(/(#{validateUrlPchar}|\\/|\\?)*/i), twttr.txt.regexen.validateUrlFragment = a(/(#{validateUrlPchar}|\\/|\\?)*/i), twttr.txt.regexen.validateUrlUnencoded = a(\"^(?:([^:/?#]+):\\\\/\\\\/)?([^/?#]*)([^?#]*)(?:\\\\?([^#]*))?(?:#(.*))?$\", \"i\");\n        var m = \"tweet-url list-slug\", n = \"tweet-url username\", o = \"tweet-url hashtag\", p = \"tweet-url cashtag\", q = {\n            urlClass: !0,\n            listClass: !0,\n            usernameClass: !0,\n            hashtagClass: !0,\n            cashtagClass: !0,\n            usernameUrlBase: !0,\n            listUrlBase: !0,\n            hashtagUrlBase: !0,\n            cashtagUrlBase: !0,\n            usernameUrlBlock: !0,\n            listUrlBlock: !0,\n            hashtagUrlBlock: !0,\n            linkUrlBlock: !0,\n            usernameIncludeSymbol: !0,\n            suppressLists: !0,\n            suppressNoFollow: !0,\n            suppressDataScreenName: !0,\n            urlEntities: !0,\n            symbolTag: !0,\n            textWithSymbolTag: !0,\n            urlTarget: !0,\n            invisibleTagAttrs: !0,\n            linkAttributeBlock: !0,\n            linkTextBlock: !0\n        }, r = {\n            disabled: !0,\n            readonly: !0,\n            multiple: !0,\n            checked: !0\n        };\n        twttr.txt.tagAttrs = function(a) {\n            var b = \"\";\n            for (var c in a) {\n                var d = a[c];\n                ((r[c] && (d = ((d ? c : null)))));\n                if (((d == null))) {\n                    continue;\n                }\n            ;\n            ;\n                b += ((((((((\" \" + twttr.txt.htmlEscape(c))) + \"=\\\"\")) + twttr.txt.htmlEscape(d.toString()))) + \"\\\"\"));\n            };\n        ;\n            return b;\n        }, twttr.txt.linkToText = function(a, c, d, e) {\n            ((e.suppressNoFollow || (d.rel = \"nofollow\"))), ((e.linkAttributeBlock && e.linkAttributeBlock(a, d))), ((e.linkTextBlock && (c = e.linkTextBlock(a, c))));\n            var f = {\n                text: c,\n                attr: twttr.txt.tagAttrs(d)\n            };\n            return b(\"\\u003Ca#{attr}\\u003E#{text}\\u003C/a\\u003E\", f);\n        }, twttr.txt.linkToTextWithSymbol = function(a, b, c, d, e) {\n            var f = ((e.symbolTag ? ((((((((((((\"\\u003C\" + e.symbolTag)) + \"\\u003E\")) + b)) + \"\\u003C/\")) + e.symbolTag)) + \"\\u003E\")) : b));\n            c = twttr.txt.htmlEscape(c);\n            var g = ((e.textWithSymbolTag ? ((((((((((((\"\\u003C\" + e.textWithSymbolTag)) + \"\\u003E\")) + c)) + \"\\u003C/\")) + e.textWithSymbolTag)) + \"\\u003E\")) : c));\n            return ((((e.usernameIncludeSymbol || !b.match(twttr.txt.regexen.atSigns))) ? twttr.txt.linkToText(a, ((f + g)), d, e) : ((f + twttr.txt.linkToText(a, g, d, e)))));\n        }, twttr.txt.linkToHashtag = function(a, b, c) {\n            var e = b.substring(a.indices[0], ((a.indices[0] + 1))), f = twttr.txt.htmlEscape(a.hashtag), g = d(((c.htmlAttrs || {\n            })));\n            return g.href = ((c.hashtagUrlBase + encodeURIComponent(f))), g.title = ((\"#\" + f)), g[\"class\"] = c.hashtagClass, twttr.txt.linkToTextWithSymbol(a, e, f, g, c);\n        }, twttr.txt.linkToCashtag = function(a, b, c) {\n            var e = twttr.txt.htmlEscape(a.cashtag), f = d(((c.htmlAttrs || {\n            })));\n            return f.href = ((c.cashtagUrlBase + e)), f.title = ((\"$\" + e)), f[\"class\"] = c.cashtagClass, twttr.txt.linkToTextWithSymbol(a, \"$\", e, f, c);\n        }, twttr.txt.linkToMentionAndList = function(a, b, c) {\n            var e = b.substring(a.indices[0], ((a.indices[0] + 1))), f = twttr.txt.htmlEscape(a.screenName), g = twttr.txt.htmlEscape(a.listSlug), i = ((a.listSlug && !c.suppressLists)), j = d(((c.htmlAttrs || {\n            })));\n            return j[\"class\"] = ((i ? c.listClass : c.usernameClass)), j.href = ((i ? ((((c.listUrlBase + f)) + g)) : ((c.usernameUrlBase + f)))), ((((!i && !c.suppressDataScreenName)) && (j[\"data-screen-name\"] = f))), twttr.txt.linkToTextWithSymbol(a, e, ((i ? ((f + g)) : f)), j, c);\n        }, twttr.txt.linkToUrl = function(a, b, c) {\n            var e = a.url, f = e, g = twttr.txt.htmlEscape(f), i = ((((c.urlEntities && c.urlEntities[e])) || a));\n            ((i.display_url && (g = twttr.txt.linkTextWithEntity(i, c))));\n            var j = d(((c.htmlAttrs || {\n            })));\n            return j.href = e, ((c.urlClass && (j[\"class\"] = c.urlClass))), ((c.urlTarget && (j.target = c.urlTarget))), ((((!c.title && i.display_url)) && (j.title = i.expanded_url))), twttr.txt.linkToText(a, g, j, c);\n        }, twttr.txt.linkTextWithEntity = function(a, c) {\n            var d = a.display_url, e = a.expanded_url, f = d.replace(/…/g, \"\");\n            if (((e.indexOf(f) != -1))) {\n                var g = e.indexOf(f), i = {\n                    displayUrlSansEllipses: f,\n                    beforeDisplayUrl: e.substr(0, g),\n                    afterDisplayUrl: e.substr(((g + f.length))),\n                    precedingEllipsis: ((d.match(/^…/) ? \"\\u2026\" : \"\")),\n                    followingEllipsis: ((d.match(/…$/) ? \"\\u2026\" : \"\"))\n                };\n                for (var j in i) {\n                    ((i.hasOwnProperty(j) && (i[j] = twttr.txt.htmlEscape(i[j]))));\n                ;\n                };\n            ;\n                return i.invisible = c.invisibleTagAttrs, b(\"\\u003Cspan class='tco-ellipsis'\\u003E#{precedingEllipsis}\\u003Cspan #{invisible}\\u003E&nbsp;\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan #{invisible}\\u003E#{beforeDisplayUrl}\\u003C/span\\u003E\\u003Cspan class='js-display-url'\\u003E#{displayUrlSansEllipses}\\u003C/span\\u003E\\u003Cspan #{invisible}\\u003E#{afterDisplayUrl}\\u003C/span\\u003E\\u003Cspan class='tco-ellipsis'\\u003E\\u003Cspan #{invisible}\\u003E&nbsp;\\u003C/span\\u003E#{followingEllipsis}\\u003C/span\\u003E\", i);\n            }\n        ;\n        ;\n            return d;\n        }, twttr.txt.autoLinkEntities = function(a, b, c) {\n            c = d(((c || {\n            }))), c.hashtagClass = ((c.hashtagClass || o)), c.hashtagUrlBase = ((c.hashtagUrlBase || \"https://twitter.com/#!/search?q=%23\")), c.cashtagClass = ((c.cashtagClass || p)), c.cashtagUrlBase = ((c.cashtagUrlBase || \"https://twitter.com/#!/search?q=%24\")), c.listClass = ((c.listClass || m)), c.usernameClass = ((c.usernameClass || n)), c.usernameUrlBase = ((c.usernameUrlBase || \"https://twitter.com/\")), c.listUrlBase = ((c.listUrlBase || \"https://twitter.com/\")), c.htmlAttrs = twttr.txt.extractHtmlAttrsFromOptions(c), c.invisibleTagAttrs = ((c.invisibleTagAttrs || \"style='position:absolute;left:-9999px;'\"));\n            var e, f, g;\n            if (c.urlEntities) {\n                e = {\n                };\n                for (f = 0, g = c.urlEntities.length; ((f < g)); f++) {\n                    e[c.urlEntities[f].url] = c.urlEntities[f];\n                ;\n                };\n            ;\n                c.urlEntities = e;\n            }\n        ;\n        ;\n            var i = \"\", j = 0;\n            b.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            for (var f = 0; ((f < b.length)); f++) {\n                var k = b[f];\n                i += a.substring(j, k.indices[0]), ((k.url ? i += twttr.txt.linkToUrl(k, a, c) : ((k.hashtag ? i += twttr.txt.linkToHashtag(k, a, c) : ((k.screenName ? i += twttr.txt.linkToMentionAndList(k, a, c) : ((k.cashtag && (i += twttr.txt.linkToCashtag(k, a, c)))))))))), j = k.indices[1];\n            };\n        ;\n            return i += a.substring(j, a.length), i;\n        }, twttr.txt.autoLinkWithJSON = function(a, b, c) {\n            var d = [];\n            for (var e in b) {\n                d = d.concat(b[e]);\n            ;\n            };\n        ;\n            for (var f = 0; ((f < d.length)); f++) {\n                entity = d[f], ((entity.screen_name ? entity.screenName = entity.screen_name : ((entity.text && (entity.hashtag = entity.text)))));\n            ;\n            };\n        ;\n            return twttr.txt.modifyIndicesFromUnicodeToUTF16(a, d), twttr.txt.autoLinkEntities(a, d, c);\n        }, twttr.txt.extractHtmlAttrsFromOptions = function(a) {\n            var b = {\n            };\n            for (var c in a) {\n                var d = a[c];\n                if (q[c]) {\n                    continue;\n                }\n            ;\n            ;\n                ((r[c] && (d = ((d ? c : null)))));\n                if (((d == null))) {\n                    continue;\n                }\n            ;\n            ;\n                b[c] = d;\n            };\n        ;\n            return b;\n        }, twttr.txt.autoLink = function(a, b) {\n            var c = twttr.txt.extractEntitiesWithIndices(a, {\n                extractUrlWithoutProtocol: !1\n            });\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkUsernamesOrLists = function(a, b) {\n            var c = twttr.txt.extractMentionsOrListsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkHashtags = function(a, b) {\n            var c = twttr.txt.extractHashtagsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkCashtags = function(a, b) {\n            var c = twttr.txt.extractCashtagsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkUrlsCustom = function(a, b) {\n            var c = twttr.txt.extractUrlsWithIndices(a, {\n                extractUrlWithoutProtocol: !1\n            });\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.removeOverlappingEntities = function(a) {\n            a.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            var b = a[0];\n            for (var c = 1; ((c < a.length)); c++) {\n                ((((b.indices[1] > a[c].indices[0])) ? (a.splice(c, 1), c--) : b = a[c]));\n            ;\n            };\n        ;\n        }, twttr.txt.extractEntitiesWithIndices = function(a, b) {\n            var c = twttr.txt.extractUrlsWithIndices(a, b).concat(twttr.txt.extractMentionsOrListsWithIndices(a)).concat(twttr.txt.extractHashtagsWithIndices(a, {\n                checkUrlOverlap: !1\n            })).concat(twttr.txt.extractCashtagsWithIndices(a));\n            return ((((c.length == 0)) ? [] : (twttr.txt.removeOverlappingEntities(c), c)));\n        }, twttr.txt.extractMentions = function(a) {\n            var b = [], c = twttr.txt.extractMentionsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                var e = c[d].screenName;\n                b.push(e);\n            };\n        ;\n            return b;\n        }, twttr.txt.extractMentionsWithIndices = function(a) {\n            var b = [], c = twttr.txt.extractMentionsOrListsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                mentionOrList = c[d], ((((mentionOrList.listSlug == \"\")) && b.push({\n                    screenName: mentionOrList.screenName,\n                    indices: mentionOrList.indices\n                })));\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractMentionsOrListsWithIndices = function(a) {\n            if (((!a || !a.match(twttr.txt.regexen.atSigns)))) {\n                return [];\n            }\n        ;\n        ;\n            var b = [], c = 0;\n            return a.replace(twttr.txt.regexen.validMentionOrList, function(d, e, f, g, i, j, k) {\n                var l = k.slice(((j + d.length)));\n                if (!l.match(twttr.txt.regexen.endMentionMatch)) {\n                    i = ((i || \"\"));\n                    var m = a.indexOf(((((f + g)) + i)), c);\n                    c = ((((((m + g.length)) + i.length)) + 1)), b.push({\n                        screenName: g,\n                        listSlug: i,\n                        indices: [m,c,]\n                    });\n                }\n            ;\n            ;\n            }), b;\n        }, twttr.txt.extractReplies = function(a) {\n            if (!a) {\n                return null;\n            }\n        ;\n        ;\n            var b = a.match(twttr.txt.regexen.validReply);\n            return ((((!b || RegExp.rightContext.match(twttr.txt.regexen.endMentionMatch))) ? null : b[1]));\n        }, twttr.txt.extractUrls = function(a, b) {\n            var c = [], d = twttr.txt.extractUrlsWithIndices(a, b);\n            for (var e = 0; ((e < d.length)); e++) {\n                c.push(d[e].url);\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.extractUrlsWithIndices = function(a, b) {\n            ((b || (b = {\n                extractUrlsWithoutProtocol: !0\n            })));\n            if (((!a || ((b.extractUrlsWithoutProtocol ? !a.match(/\\./) : !a.match(/:/)))))) {\n                return [];\n            }\n        ;\n        ;\n            var c = [];\n            while (twttr.txt.regexen.extractUrl.exec(a)) {\n                var d = RegExp.$2, e = RegExp.$3, f = RegExp.$4, g = RegExp.$5, i = RegExp.$7, j = twttr.txt.regexen.extractUrl.lastIndex, k = ((j - e.length));\n                if (!f) {\n                    if (((!b.extractUrlsWithoutProtocol || d.match(twttr.txt.regexen.invalidUrlWithoutProtocolPrecedingChars)))) {\n                        continue;\n                    }\n                ;\n                ;\n                    var l = null, m = !1, n = 0;\n                    g.replace(twttr.txt.regexen.validAsciiDomain, function(a) {\n                        var b = g.indexOf(a, n);\n                        n = ((b + a.length)), l = {\n                            url: a,\n                            indices: [((k + b)),((k + n)),]\n                        }, m = a.match(twttr.txt.regexen.invalidShortDomain), ((m || c.push(l)));\n                    });\n                    if (((l == null))) {\n                        continue;\n                    }\n                ;\n                ;\n                    ((i && (((m && c.push(l))), l.url = e.replace(g, l.url), l.indices[1] = j)));\n                }\n                 else ((e.match(twttr.txt.regexen.validTcoUrl) && (e = RegExp.lastMatch, j = ((k + e.length))))), c.push({\n                    url: e,\n                    indices: [k,j,]\n                });\n            ;\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.extractHashtags = function(a) {\n            var b = [], c = twttr.txt.extractHashtagsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                b.push(c[d].hashtag);\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractHashtagsWithIndices = function(a, b) {\n            ((b || (b = {\n                checkUrlOverlap: !0\n            })));\n            if (((!a || !a.match(twttr.txt.regexen.hashSigns)))) {\n                return [];\n            }\n        ;\n        ;\n            var c = [], d = 0;\n            a.replace(twttr.txt.regexen.validHashtag, function(b, e, f, g, i, j) {\n                var k = j.slice(((i + b.length)));\n                if (k.match(twttr.txt.regexen.endHashtagMatch)) {\n                    return;\n                }\n            ;\n            ;\n                var l = a.indexOf(((f + g)), d);\n                d = ((((l + g.length)) + 1)), c.push({\n                    hashtag: g,\n                    indices: [l,d,]\n                });\n            });\n            if (b.checkUrlOverlap) {\n                var e = twttr.txt.extractUrlsWithIndices(a);\n                if (((e.length > 0))) {\n                    var f = c.concat(e);\n                    twttr.txt.removeOverlappingEntities(f), c = [];\n                    for (var g = 0; ((g < f.length)); g++) {\n                        ((f[g].hashtag && c.push(f[g])));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return c;\n        }, twttr.txt.extractCashtags = function(a) {\n            var b = [], c = twttr.txt.extractCashtagsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                b.push(c[d].cashtag);\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractCashtagsWithIndices = function(a) {\n            if (((!a || ((a.indexOf(\"$\") == -1))))) {\n                return [];\n            }\n        ;\n        ;\n            var b = [], c = 0;\n            return a.replace(twttr.txt.regexen.validCashtag, function(d, e, f, g) {\n                var i = a.indexOf(((\"$\" + e)), c);\n                c = ((((i + e.length)) + 1)), b.push({\n                    cashtag: e,\n                    indices: [i,c,]\n                });\n            }), b;\n        }, twttr.txt.modifyIndicesFromUnicodeToUTF16 = function(a, b) {\n            twttr.txt.convertUnicodeIndices(a, b, !1);\n        }, twttr.txt.modifyIndicesFromUTF16ToUnicode = function(a, b) {\n            twttr.txt.convertUnicodeIndices(a, b, !0);\n        }, twttr.txt.convertUnicodeIndices = function(a, b, c) {\n            if (((b.length == 0))) {\n                return;\n            }\n        ;\n        ;\n            var d = 0, e = 0;\n            b.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            var f = 0, g = b[0];\n            while (((d < a.length))) {\n                if (((g.indices[0] == ((c ? d : e))))) {\n                    var i = ((g.indices[1] - g.indices[0]));\n                    g.indices[0] = ((c ? e : d)), g.indices[1] = ((g.indices[0] + i)), f++;\n                    if (((f == b.length))) {\n                        break;\n                    }\n                ;\n                ;\n                    g = b[f];\n                }\n            ;\n            ;\n                var j = a.charCodeAt(d);\n                ((((((((55296 <= j)) && ((j <= 56319)))) && ((d < ((a.length - 1)))))) && (j = a.charCodeAt(((d + 1))), ((((((56320 <= j)) && ((j <= 57343)))) && d++))))), e++, d++;\n            };\n        ;\n        }, twttr.txt.splitTags = function(a) {\n            var b = a.split(\"\\u003C\"), c, d = [], e;\n            for (var f = 0; ((f < b.length)); f += 1) {\n                e = b[f];\n                if (!e) d.push(\"\");\n                 else {\n                    c = e.split(\"\\u003E\");\n                    for (var g = 0; ((g < c.length)); g += 1) {\n                        d.push(c[g]);\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return d;\n        }, twttr.txt.hitHighlight = function(a, b, c) {\n            var d = \"em\";\n            b = ((b || [])), c = ((c || {\n            }));\n            if (((b.length === 0))) {\n                return a;\n            }\n        ;\n        ;\n            var e = ((c.tag || d)), f = [((((\"\\u003C\" + e)) + \"\\u003E\")),((((\"\\u003C/\" + e)) + \"\\u003E\")),], g = twttr.txt.splitTags(a), i, j, k = \"\", l = 0, m = g[0], n = 0, o = 0, p = !1, q = m, r = [], s, t, u, v, w;\n            for (i = 0; ((i < b.length)); i += 1) {\n                for (j = 0; ((j < b[i].length)); j += 1) {\n                    r.push(b[i][j]);\n                ;\n                };\n            ;\n            };\n        ;\n            for (s = 0; ((s < r.length)); s += 1) {\n                t = r[s], u = f[((s % 2))], v = !1;\n                while (((((m != null)) && ((t >= ((n + m.length))))))) {\n                    k += q.slice(o), ((((p && ((t === ((n + q.length)))))) && (k += u, v = !0))), ((g[((l + 1))] && (k += ((((\"\\u003C\" + g[((l + 1))])) + \"\\u003E\"))))), n += q.length, o = 0, l += 2, m = g[l], q = m, p = !1;\n                ;\n                };\n            ;\n                ((((!v && ((m != null)))) ? (w = ((t - n)), k += ((q.slice(o, w) + u)), o = w, ((((((s % 2)) === 0)) ? p = !0 : p = !1))) : ((v || (v = !0, k += u)))));\n            };\n        ;\n            if (((m != null))) {\n                ((((o < q.length)) && (k += q.slice(o))));\n                for (s = ((l + 1)); ((s < g.length)); s += 1) {\n                    k += ((((((s % 2)) === 0)) ? g[s] : ((((\"\\u003C\" + g[s])) + \"\\u003E\"))));\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return k;\n        };\n        var s = 140, t = [g(65534),g(65279),g(65535),g(8234),g(8235),g(8236),g(8237),g(8238),];\n        twttr.txt.getTweetLength = function(a, b) {\n            ((b || (b = {\n                short_url_length: 20,\n                short_url_length_https: 21\n            })));\n            var c = a.length, d = twttr.txt.extractUrlsWithIndices(a);\n            for (var e = 0; ((e < d.length)); e++) {\n                c += ((d[e].indices[0] - d[e].indices[1])), ((d[e].url.toLowerCase().match(/^https:\\/\\//) ? c += b.short_url_length_https : c += b.short_url_length));\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.isInvalidTweet = function(a) {\n            if (!a) {\n                return \"empty\";\n            }\n        ;\n        ;\n            if (((twttr.txt.getTweetLength(a) > s))) {\n                return \"too_long\";\n            }\n        ;\n        ;\n            for (var b = 0; ((b < t.length)); b++) {\n                if (((a.indexOf(t[b]) >= 0))) {\n                    return \"invalid_characters\";\n                }\n            ;\n            ;\n            };\n        ;\n            return !1;\n        }, twttr.txt.isValidTweetText = function(a) {\n            return !twttr.txt.isInvalidTweet(a);\n        }, twttr.txt.isValidUsername = function(a) {\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var b = twttr.txt.extractMentions(a);\n            return ((((b.length === 1)) && ((b[0] === a.slice(1)))));\n        };\n        var u = a(/^#{validMentionOrList}$/);\n        twttr.txt.isValidList = function(a) {\n            var b = a.match(u);\n            return ((((!!b && ((b[1] == \"\")))) && !!b[4]));\n        }, twttr.txt.isValidHashtag = function(a) {\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var b = twttr.txt.extractHashtags(a);\n            return ((((b.length === 1)) && ((b[0] === a.slice(1)))));\n        }, twttr.txt.isValidUrl = function(a, b, c) {\n            ((((b == null)) && (b = !0))), ((((c == null)) && (c = !0)));\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var d = a.match(twttr.txt.regexen.validateUrlUnencoded);\n            if (((!d || ((d[0] !== a))))) {\n                return !1;\n            }\n        ;\n        ;\n            var f = d[1], g = d[2], i = d[3], j = d[4], k = d[5];\n            return ((((((((((!c || ((e(f, twttr.txt.regexen.validateUrlScheme) && f.match(/^https?$/i))))) && e(i, twttr.txt.regexen.validateUrlPath))) && e(j, twttr.txt.regexen.validateUrlQuery, !0))) && e(k, twttr.txt.regexen.validateUrlFragment, !0))) ? ((((b && e(g, twttr.txt.regexen.validateUrlUnicodeAuthority))) || ((!b && e(g, twttr.txt.regexen.validateUrlAuthority))))) : !1));\n        }, ((((((typeof module != \"undefined\")) && module.exports)) && (module.exports = twttr.txt)));\n    })(), a();\n});\nprovide(\"setup\", function(a) {\n    using(\"util\").as(function(b) {\n        ((twttr.is.nil($.cookie(\"js\")) && $.cookie(\"js\", 1, {\n            expires: 30,\n            path: \"/\"\n        }))), twttr.setup = function(a) {\n            function c() {\n                var a = [\"webkit\",\"mozilla\",\"JSBNG__opera\",\"msie\",];\n                for (var b = 0; ((b < a.length)); b++) {\n                    if ($.browser[a[b]]) {\n                        return a[b];\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            $(\"body\").addClass(c()), ((twttr.hoversInCss || $(\".js-hover\").live(\"mouseenter mouseleave\", function(a) {\n                $(this).toggleClass(\"hover\", ((a.type == \"mouseenter\")));\n            }))), ((twttr.currentUser ? twttr.caches.User = new twttr.cache.local.User(twttr.currentUser.screenName) : twttr.caches.User = new twttr.cache.local.User($.cookie(\"guest_id\")))), twttr.app.init(a), twttr.$win = $(window), twttr.$doc = $(JSBNG__document), twttr.provide(\"twttr.$elements\", {\n                page: $(\"#page-outer\")\n            }), twttr.windowHeight = twttr.$win.height(), twttr[\"interface\"].setup(), twttr.ui.loadBar(), twttr.search.setup(), twttr.API.globalEvents.bind(\"rate_limited\", function(a) {\n                twttr.errors.showErrorFromCode(twttr.constants.errorCodes.dailyLimit);\n            }), twttr.API.globalEvents.bind(\"unknown_error\", function(a) {\n                twttr.errors.showErrorFromResponse({\n                });\n            }), using(twttr.bundleMore, function() {\n                var a = $(\"div.welcome-banner-outer\");\n                if (((a.length > 0))) {\n                    var b = twttr.banners.welcomeToPhoenix();\n                    b.bind(\"JSBNG__closed\", function() {\n                        $.cookie(((\"show_phx_welcome_\" + twttr.currentUser.id)), null);\n                    }), a.remove(), b.insert();\n                }\n            ;\n            ;\n                var c = $(\"div.became-user-banner-outer\");\n                ((((c.length > 0)) && (c.remove(), twttr.banners.becameUser().insert())));\n                var d = $(\"div.top-bar-inside,div.banner div.banner-inside\");\n                ((twttr.isT1 || twttr.$win.JSBNG__scroll(function() {\n                    d.css(\"left\", -twttr.$win.scrollLeft());\n                })));\n            }), twttr.router.bind(\"routed\", function(a, b) {\n                twttr.$win.scrollTop(0);\n            }), twttr.router.bind(\"urlChanged\", function(a, b) {\n                twttr.trackPageView(b.JSBNG__name);\n            }), twttr.router.bind(\"routeNotFound\", function() {\n                twttr.app.switchToPage(\"404\").send(\"notFound\");\n            }), twttr.router.startRouting(), ((twttr.decider.isInfiniteScroll() && b.util.lazyBind(window, \"JSBNG__scroll\", function(a) {\n                if (((((twttr.widget && twttr.widget.Dialog)) && twttr.widget.Dialog.currentModal))) {\n                    return;\n                }\n            ;\n            ;\n                var b = twttr.app.currentPage();\n                b.send(\"scrollEnd\", [twttr.$win.scrollTop(),]), ((((Math.abs(((((twttr.$doc.scrollTop() + twttr.windowHeight)) - twttr.$doc.height()))) < 500)) && b.send(\"getStreamManager\", function(a) {\n                    ((((a && !a.noInfiniteScroll)) && a.getMoreOldItems(function(a) {\n                        _scribble(\"stream-scrolled\", {\n                            page: a._page,\n                            stream: a._cacheKey,\n                            focused_tweet_id: ((a.focusedItemId || \"\"))\n                        });\n                    })));\n                })));\n            }))), ((twttr.isT1 || b.util.lazyBind(window, \"JSBNG__scroll\", function(a) {\n                twttr.app.currentPage().send(\"repositionDetailsPane\");\n            }, 100))), b.util.lazyBind(window, \"resize\", function(a) {\n                var b = twttr.app.currentPage();\n                twttr.windowHeight = twttr.$win.height(), ((b && b.send(\"resizeDetailsPane\"))), twttr.windowHeight = twttr.$win.height();\n            }), ((twttr.isT1 && using(\"idleDetector\", function(a) {\n                a({\n                    wait: 300000\n                });\n            }))), function() {\n                function a() {\n                    var a = $(this), b = parseInt(a.attr(\"data-time\"), 10);\n                    if (((((d - b)) > 86400000))) a.removeClass(\"_timestamp\").addClass(\"_old-timestamp\");\n                     else {\n                        var c = twttr.helpers.timeAgo(b, JSON.parse(((a.attr(\"data-long-form\") || \"false\"))), JSON.parse(((a.attr(\"data-include-sec\") || \"false\"))));\n                        ((((c !== a.text())) && a.text(c)));\n                    }\n                ;\n                ;\n                };\n            ;\n                function b() {\n                    var e = twttr.app.currentPage(), f = ((twttr.isT1 && twttr.at(\"widget.Dialog.currentModal\", twttr)));\n                    d = +(new JSBNG__Date), ((e && e.$find(((((\"span._timestamp[data-time$=\\\"\" + c)) + \"000\\\"]\"))).each(a))), ((f && f.$find(((((\"span._timestamp[data-time$=\\\"\" + c)) + \"000\\\"]\"))).each(a)));\n                    var g = ((+(new JSBNG__Date) - d));\n                    c++, c %= 10, JSBNG__setTimeout(b, 2000);\n                };\n            ;\n                var c = 0, d;\n                JSBNG__setTimeout(b, 2000);\n            }(), using([twttr.bundleMore,\"components/Autocomplete\",], function() {\n                twttr.API.User.bind(\"follow acceptFollow\", function(a, b) {\n                    twttr.currentUser.sync(\"friendsCount\", ++twttr.currentUser.friendsCount), twttr.components.Autocomplete.getAutocompletedUsers(function() {\n                        twttr.components.Autocomplete.addToList([b.id,b.screenName,b.JSBNG__name,b.profileImageUrl,]);\n                    }), $(JSBNG__document).trigger(\"currentUserUpdated\");\n                });\n            }), twttr.API.User.bind(\"unfollow\", function(a, b) {\n                twttr.currentUser.sync(\"friendsCount\", Math.max(--twttr.currentUser.friendsCount, 0)), $(JSBNG__document).trigger(\"currentUserUpdated\");\n            });\n            var d = $(\"#loading_indicator_container\");\n            d.fadeOut(\"fast\", function() {\n                d.remove(), JSBNG__document.body.style.overflow = \"\";\n            });\n        }, twttr.showError = function(a) {\n            return twttr.openMessageDrawer(a, \"error\");\n        }, twttr.showMessage = function(a, b) {\n            var c = twttr.openMessageDrawer(a, \"message\", {\n                close_button: !!b\n            });\n            ((((c && !b)) && JSBNG__setTimeout(function() {\n                c.$dom.css(\"opacity\", 1).animate({\n                    opacity: 0\n                }, 1000, function() {\n                    c.$dom.remove(), twttr.views.MessageDrawer.isOpen = !1;\n                });\n            }, 2000)));\n        }, function() {\n            var a = {\n                close_button: !0\n            };\n            twttr.openMessageDrawer = function(b, c, d) {\n                d = twttr.merge({\n                }, a, ((d || {\n                }))), d.text = b, d.type = c, twttr.views.MessageDrawer.close();\n                var e = new twttr.views.MessageDrawer(d);\n                return e.render(\"#message-drawer\", \"append\"), twttr.views.MessageDrawer.isOpen = !0, e;\n            };\n        }(), twttr.messageNotification = function(a) {\n            var b = new twttr.views.MessageNotification({\n                message: a.attributes\n            }), c = a.senderScreenName, d = a.id;\n            $(\"#message-notifications\").append(b.$html());\n            var e = $(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification\")));\n            e.bind(\"click\", function() {\n                var a = $(this);\n                a.unbind(), a.JSBNG__find(\".message-notification-reply-box\").show();\n                var b = new twttr.Editor(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification  .message-notification-reply-editor\")), function() {\n                    var a = this;\n                    this.JSBNG__focus(), this.height(36), $(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification .message-notification-reply-button\"))).click(function() {\n                        e.html(\"Sent!\"), JSBNG__setTimeout(function() {\n                            e.remove();\n                        }, 2000), twttr.API.DirectMessage.send(c, a.JSBNG__content());\n                    });\n                });\n            });\n        }, twttr.provide(\"twttr.ui\", {\n            toggleSpinner: function(a, b) {\n                if (b) {\n                    var c = $(((((\"\\u003Cdiv class=\\\"loading-spinner\\\"\\u003E\\u003Cimg src=\\\"/phoenix/img/loader.gif\\\" alt=\\\"\" + _(\"Loading\"))) + \"\\\"/\\u003E\\u003C/div\\u003E\"))).appendTo(a);\n                }\n                 else {\n                    $(a).JSBNG__find(\"div.loading-spinner\").remove();\n                }\n            ;\n            ;\n            },\n            loadBar: function() {\n                var a = $(\"#global-actions\");\n                a.JSBNG__find(\"a\").not(\".js-dropdown-toggle\").each(function() {\n                    $(this).attr(\"href\", twttr.router.lookupAndNormalizeRoute($(this).attr(\"href\")));\n                }), ((twttr.loggedIn && a.delegate(\"a\", \"mousedown\", function(a) {\n                    var b = $(this);\n                    scribble(\"globalnav\", {\n                        input: \"click\",\n                        JSBNG__name: b.text(),\n                        href: b.attr(\"href\")\n                    });\n                })));\n            }\n        }), a(twttr.setup);\n    });\n});\nprovide(\"search\", function(a) {\n    using().as(function(b) {\n        twttr.search = {\n            setup: function() {\n                var a = this;\n                this.$searchQuery = $(\"#search-query\"), ((Modernizr.input.placeholder || (this.$searchQuery.bind({\n                    JSBNG__focus: function() {\n                        a.hidePlaceholder($(this));\n                    },\n                    JSBNG__blur: function() {\n                        a.showPlaceholder($(this));\n                    }\n                }), ((this.$searchQuery[0].hasFocus ? this.$searchQuery.addClass(\"focused\") : this.$searchQuery.JSBNG__blur()))))), ((twttr.isT1 ? (twttr.app.bind(\"switchToPage\", function(b, c) {\n                    a.updatePlaceholder(c);\n                }), this.attachTypeahead(), this.registerSearchInputEvents(), ((twttr.loggedIn && this.setupSavedSearches()))) : this.setupFocusP1()));\n            },\n            setupSavedSearches: function() {\n                if (!twttr.loggedIn) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                this.updateSavedSearches(), twttr.API.SavedSearch.bind(\"create delete\", function() {\n                    a.updateSavedSearches();\n                });\n            },\n            updateSavedSearches: function() {\n                var a = this;\n                twttr.currentUser.savedSearches(function(b) {\n                    ((((b.length() > 0)) ? (a.savedSearches = b, $(\".global-nav .js-search-form\").addClass(\"has-saved-searches\")) : $(\".global-nav .js-search-form\").removeClass(\"has-saved-searches\")));\n                });\n            },\n            updatePlaceholder: function(a) {\n                switch (a) {\n                  case \"connect\":\n                    this.setPlaceholder(_(\"Enter an @name or full name\"));\n                    break;\n                  case \"discover\":\n                    this.setPlaceholder(_(\"Enter a #hashtag or keyword\"));\n                    break;\n                  default:\n                    this.setPlaceholder();\n                };\n            ;\n            },\n            setPlaceholder: function(a) {\n                a = ((a || _(\"Search\"))), this.$searchQuery.attr(\"placeholder\", a), ((((!Modernizr.input.placeholder && this.$searchQuery.data(\"placeholding\"))) && this.$searchQuery.val(this.$searchQuery.attr(\"placeholder\")))), $(JSBNG__document).trigger(\"searchPlaceholderUpdate\", [a,]), this.$searchQuery.JSBNG__blur();\n            },\n            hidePlaceholder: function(a) {\n                ((a.data(\"placeholding\") && (a.val(\"\"), a.data(\"placeholding\", !1))));\n            },\n            showPlaceholder: function(a) {\n                ((((!a.data(\"placeholding\") && ((a.val() === \"\")))) && (a.data(\"placeholding\", !0), a.val(a.attr(\"placeholder\")))));\n            },\n            attachTypeahead: function() {\n                var a = this;\n                using(twttr.bundleMore, function() {\n                    a.$typeahead = new twttr.components.GlobalNavTypeahead;\n                });\n            },\n            queryWasEntered: function() {\n                return ((((this.$searchQuery.val() !== this.$searchQuery.attr(\"placeholder\"))) && ((this.$searchQuery.val() !== \"\"))));\n            },\n            setupFocusP1: function() {\n                var a = this;\n                this.$searchQuery.bind({\n                    JSBNG__focus: function() {\n                        $(this).addClass(\"focused\").select().closest(\"form\").addClass(\"focused\");\n                    },\n                    JSBNG__blur: function() {\n                        $(this).removeClass(\"focused\").closest(\"form\").removeClass(\"focused\");\n                    }\n                });\n            },\n            clear: function() {\n                this.focusQuery(\"\").JSBNG__blur();\n            },\n            isSavedSearch: function(a) {\n                if (!this.savedSearches) {\n                    return !1;\n                }\n            ;\n            ;\n                var b = this.savedSearches.filter(function(b) {\n                    return ((b.query === a));\n                });\n                return ((b.length() ? b.first() : !1));\n            },\n            setLastQuerySource: function(a) {\n                twttr.app.caches.searchQuerySource.set(\"source\", a, 60000);\n            },\n            getLastQuerySource: function() {\n                var a = twttr.app.caches.searchQuerySource.get(\"source\");\n                return ((a || twttr.search.searchQuerySource.UNKNOWN));\n            },\n            registerSearchInputEvents: function() {\n                var a = this;\n                $(\"span.js-search-action\").bind({\n                    mouseenter: function() {\n                        a.mouseOverMagnifying = !0;\n                    },\n                    mouseleave: function() {\n                        a.mouseOverMagnifying = !1;\n                    },\n                    click: function() {\n                        ((((!a.$searchQuery.data(\"placeholding\") && a.$searchQuery.val())) ? (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch(), a.$searchQuery.JSBNG__blur(), twttr.widget.Dialog.trigger(\"close\")) : a.$searchQuery.JSBNG__focus()));\n                    }\n                }), this.$searchQuery.bind(\"JSBNG__focus\", function(b) {\n                    a.$searchQuery.addClass(\"JSBNG__focus\"), a.$searchQuery.siblings(\"#search-query-hint\").addClass(\"JSBNG__focus\"), a.$searchQuery.parent(\".js-search-form\").addClass(\"JSBNG__focus\");\n                }), this.$searchQuery.bind(\"JSBNG__blur\", function(b) {\n                    ((((!a.mouseOverMagnifying && !a.mouseIsOverTypeaheadDropdown())) && (a.$searchQuery.removeClass(\"JSBNG__focus\"), a.$searchQuery.siblings(\"#search-query-hint\").removeClass(\"JSBNG__focus\"), a.$searchQuery.parent(\".js-search-form\").removeClass(\"JSBNG__focus\"))));\n                });\n            },\n            mouseIsOverTypeaheadDropdown: function() {\n                return ((this.$typeahead && this.$typeahead.mouseOverDropDown));\n            },\n            focusQuery: function(a) {\n                return ((((!this.$searchQuery[0].hasFocus && !twttr.isT1)) && this.$searchQuery.JSBNG__focus())), ((twttr.is.def(a) && this.$searchQuery.val(a))), this.$searchQuery;\n            },\n            doSearch: function(a) {\n                var b = this.focusQuery(a).val();\n                if (b) {\n                    trackClient({\n                        section: \"top_nav\",\n                        component: \"searchbox\",\n                        action: \"search\"\n                    }, {\n                        query: b\n                    });\n                    var c = twttr.router.getCurrentRoute().JSBNG__name, d = ((twttr.isT1 && ((((twttr.app.currentPageName() == \"Connect\")) || ((c == \"userSearch\")))))), e = ((twttr.isT1 && ((c == \"searchTimeline\")))), f = ((twttr.isT1 && ((c == \"searchRealtime\"))));\n                    ((d ? twttr.router.routeTo(twttr.router.userSearchPath({\n                        query: b\n                    })) : ((e ? twttr.router.routeTo(twttr.router.searchTimelinePath({\n                        query: b\n                    })) : ((f ? twttr.router.routeTo(twttr.router.searchRealtimePath({\n                        query: b\n                    })) : twttr.router.routeTo(twttr.router.searchResultsPath({\n                        query: b\n                    }))))))));\n                }\n                 else this.$searchQuery.JSBNG__blur();\n            ;\n            ;\n            },\n            latestQuery: \"\",\n            formifyLatestQuery: function(a) {\n                var b = jQuery.trim(this.latestQuery).replace(/\\s+/, \" \");\n                if (b) {\n                    if (a.is(\".advanced-search form\")) {\n                        var c, d = /(|#|\\-|@|\\w+:|OR |AND )?\\\"([^\\\"]+)\\\"/i, e = function(b, c) {\n                            var d = {\n                                \"#\": \"tag\",\n                                \"-\": \"nots\",\n                                \"@\": \"ref\",\n                                \"to:\": \"to\",\n                                \"from:\": \"from\",\n                                \"near:\": \"near\",\n                                or: \"ors\",\n                                and: \"ands\"\n                            }, e = ((b ? d[jQuery.trim(b).toLowerCase()] : \"phrase\"));\n                            if (e) {\n                                var f = a.JSBNG__find(((((\"input[name=\" + e)) + \"]\"))), g = f.val();\n                                f.val(((((g ? ((g + \" \")) : \"\")) + c)));\n                            }\n                        ;\n                        ;\n                        };\n                        while (c = d.exec(b)) {\n                            ((((c && c[2])) && e(c[1], c[2]))), b = b.replace(c[0], \"\");\n                        ;\n                        };\n                    ;\n                        twttr.each(b.split(\" \"), function(b, d, f) {\n                            switch (b.toLowerCase()) {\n                              case \":)\":\n                            \n                              case \":(\":\n                            \n                              case \"?\":\n                                a.JSBNG__find(((((\"input[value=\\\"\" + b)) + \"\\\"]\"))).attr(\"checked\", \"checked\");\n                                break;\n                              case \"include:retweets\":\n                                a.JSBNG__find(\"input[name=include]\").attr(\"checked\", \"checked\");\n                                break;\n                              case \"\":\n                            \n                              case \"or\":\n                            \n                              case \"and\":\n                                break;\n                              default:\n                                c = /^(#|\\-|@|to:|from:|near:)(.*)/i.exec(b);\n                                if (((c && c[2]))) {\n                                    e(c[1], c[2]);\n                                    break;\n                                }\n                            ;\n                            ;\n                                c = /^within:(\\d+)(mi|km)*/i.exec(b);\n                                if (c) {\n                                    var g = a.JSBNG__find(\"select[name=within]\");\n                                    ((g.JSBNG__find(((((\"option[value=\" + c[1])) + \"]\"))) && g.val(c[1]))), ((c[2].match(/km/i) && a.JSBNG__find(\"input[name=units]\").each(function() {\n                                        var a = $(this);\n                                        a.attr(\"checked\", ((((a.val() == \"km\")) ? \"checked\" : \"\")));\n                                    })));\n                                    break;\n                                }\n                            ;\n                            ;\n                                c = /^lang:(\\w+)/i.exec(b);\n                                if (c) {\n                                    var i = a.JSBNG__find(\"select[name=lang]\");\n                                    ((i.JSBNG__find(((((\"option[value=\" + c[1])) + \"]\"))) && i.val(c[1])));\n                                    break;\n                                }\n                            ;\n                            ;\n                                ((((d && f[((d - 1))].match(/OR/i))) ? e(\"or\", b) : e(\"and\", b)));\n                            };\n                        ;\n                        });\n                    }\n                     else a.JSBNG__find(\"input[name=q]\").val(((b || \"\")));\n                ;\n                }\n            ;\n            ;\n            },\n            serializeAdvancedForm: function(a) {\n                var b = a.serializeArray(), c = [];\n                for (var d in b) {\n                    var e = b[d], f = jQuery.trim(e.value);\n                    if (!f) {\n                        continue;\n                    }\n                ;\n                ;\n                    switch (e.JSBNG__name) {\n                      case \"attd\":\n                    \n                      case \"ands\":\n                        c.push(f);\n                        break;\n                      case \"ors\":\n                        c.push(f.split(\" \").join(\" OR \"));\n                        break;\n                      case \"phrase\":\n                        c.push(((((\"\\\"\" + f)) + \"\\\"\")));\n                        break;\n                      case \"nots\":\n                        c.push(((\"-\" + f.split(\" \").join(\" -\"))));\n                        break;\n                      case \"tag\":\n                        c.push(((\"#\" + f.replace(/#+/g, \"\").split(\" \").join(\" OR #\"))));\n                        break;\n                      case \"from\":\n                        c.push(((\"from:\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR from:\"))));\n                        break;\n                      case \"to\":\n                        c.push(((\"to:\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR to:\"))));\n                        break;\n                      case \"ref\":\n                        c.push(((\"@\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR @\"))));\n                        break;\n                      case \"near\":\n                        c.push(((((((((\"near:\\\"\" + f)) + \"\\\" within:\")) + a.JSBNG__find(\"select[name=within]\").val())) + a.JSBNG__find(\"input:radio[name=units]:checked\").val())));\n                        break;\n                      case \"include\":\n                        c.push(\"include:retweets\");\n                        break;\n                      case \"lang\":\n                        ((((f !== \"all\")) && c.push(((\"lang:\" + f)))));\n                    };\n                ;\n                };\n            ;\n                return c.join(\" \");\n            },\n            searchQuerySource: {\n                UNKNOWN: \"unknown\",\n                TYPED_QUERY: \"typed_query\",\n                HASHTAG: \"hashtag_click\",\n                TREND: \"trend_click\",\n                SAVED_SEARCH: \"saved_search_click\",\n                TYPEAHEAD: \"typeahead_click\",\n                SPELLING_CORRECTION: \"spelling_correction_click\",\n                RELATED_QUERY: \"related_query_click\"\n            },\n            urlParamQuerySource: {\n                UNKNOWN: \"unkn\",\n                TYPED_QUERY: \"typd\",\n                HASHTAG: \"hash\",\n                TREND: \"tren\",\n                SAVED_SEARCH: \"savs\",\n                TYPEAHEAD: \"tyah\",\n                SPELLING_CORRECTION: \"corr\",\n                RELATED_QUERY: \"rela\"\n            }\n        }, a(twttr.search);\n    });\n});\nprovide(\"helpers\", function(a) {\n    using(\"_\", \"util\", \"constants\", \"errors\").as(function(b, _) {\n        twttr.helpers = {\n            timeStrings: function() {\n                if (((twttr.at(\"QUnit\") || !twttr.helpers.timeStrings.memo))) {\n                    twttr.helpers.timeStrings.memo = {\n                        words: {\n                            longForm: {\n                                singular: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{one}} second ago\"),\n                                    minutes: _(\"{{one}} minute ago\"),\n                                    hours: _(\"{{one}} hour ago\"),\n                                    days: _(\"{{one}} day ago\")\n                                },\n                                plural: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{plural_number}} seconds ago\"),\n                                    minutes: _(\"{{plural_number}} minutes ago\"),\n                                    hours: _(\"{{plural_number}} hours ago\"),\n                                    days: _(\"{{plural_number}} days ago\")\n                                }\n                            },\n                            shortForm: {\n                                allCounts: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{number}}s\"),\n                                    minutes: _(\"{{number}}m\"),\n                                    hours: _(\"{{number}}h\"),\n                                    days: _(\"{{number}}d\")\n                                }\n                            }\n                        },\n                        dates: {\n                            months: [_(\"Jan\"),_(\"Feb\"),_(\"Mar\"),_(\"Apr\"),_(\"May\"),_(\"Jun\"),_(\"Jul\"),_(\"Aug\"),_(\"Sep\"),_(\"Oct\"),_(\"Nov\"),_(\"Dec\"),],\n                            dates: [_(\"1st\"),_(\"2nd\"),_(\"3rd\"),_(\"4th\"),_(\"5th\"),_(\"6th\"),_(\"7th\"),_(\"8th\"),_(\"9th\"),_(\"10th\"),_(\"11th\"),_(\"12th\"),_(\"13th\"),_(\"14th\"),_(\"15th\"),_(\"16th\"),_(\"17th\"),_(\"18th\"),_(\"19th\"),_(\"20th\"),_(\"21st\"),_(\"22nd\"),_(\"23rd\"),_(\"24th\"),_(\"25th\"),_(\"26th\"),_(\"27th\"),_(\"28th\"),_(\"29th\"),_(\"30th\"),_(\"31st\"),]\n                        }\n                    };\n                }\n            ;\n            ;\n                return twttr.helpers.timeStrings.memo;\n            },\n            resolveHexColor: function(a) {\n                function b(a) {\n                    return parseInt(((a + a)).slice(0, 2), 16);\n                };\n            ;\n                if (((((!a || !a.match(/^#?([0-9A-F]{6}|[0-9A-F]{3})$/i))) || !RegExp.$1))) {\n                    return;\n                }\n            ;\n            ;\n                return RegExp.$1.match(/(..?)(..?)(..?)/), [b(RegExp.$1),b(RegExp.$2),b(RegExp.$3),];\n            },\n            hexToRGBA: function(a, b) {\n                var c = this.resolveHexColor(a);\n                if (!c) {\n                    return;\n                }\n            ;\n            ;\n                return c.push(((b || \"1\"))), ((((\"rgba(\" + c.join(\",\"))) + \")\"));\n            },\n            blendHexColor: function(a, b, c) {\n                var d = this.resolveHexColor(a), e = this.resolveHexColor(b), f = ((1 - c));\n                if (((!d || !e))) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.map(d, function(a, b) {\n                    var d = e[b], g = Math.floor(((((a * c)) + ((d * f)))));\n                    return ((g + 256)).toString(16).slice(1);\n                }).join(\"\").toUpperCase();\n            },\n            sanitizeCssColor: function(a) {\n                if (((a && a.match(/^[0-9a-f]{3,6}$/i)))) {\n                    return a;\n                }\n            ;\n            ;\n            },\n            parseDateString: function(a) {\n                var b = new JSBNG__Date(a);\n                return (((($.browser.msie && a)) && (b = new JSBNG__Date(JSBNG__Date.parse(a.replace(/( \\+)/, \" UTC$1\")))))), +b;\n            },\n            prettyTime: function(a, b) {\n                var c = twttr.helpers.timeStrings(), d = new JSBNG__Date(a), e = {\n                    year4: d.getFullYear().toString(),\n                    year: d.getFullYear().toString().slice(2),\n                    month: c.dates.months[d.getMonth()],\n                    day: d.getDate(),\n                    hours24: d.getHours(),\n                    hours12: ((((d.getHours() % 12)) || 12)),\n                    minutes: d.getMinutes().toString().replace(/^(\\d)$/, \"0$1\"),\n                    amPm: ((((d.getHours() < 12)) ? _(\"AM\") : _(\"PM\"))),\n                    date: c.dates.dates[((d.getDate() - 1))]\n                };\n                return ((((twttr.isT1 && !b)) ? _(\"{{hours12}}:{{minutes}} {{amPm}} - {{day}} {{month}} {{year}}\", e) : _(\"{{hours12}}:{{minutes}} {{amPm}}, {{month}} {{date}}\", e)));\n            },\n            timeAgo: function(a, b, c, d) {\n                ((((twttr.decider.isExpando() && !d)) && (b = !1)));\n                var e = twttr.helpers.timeStrings(), f = e.words[((b ? \"longForm\" : \"shortForm\"))], g = new JSBNG__Date, i = new JSBNG__Date(a), j = ((g - i)), k = 1000, l = ((k * 60)), m = ((l * 60)), n = ((m * 24)), o = ((n * 7)), p, q, r;\n                return ((((isNaN(j) || ((j < 0)))) ? \"\" : (((((j < ((k * 3)))) ? (p = \"\", q = \"now\", c = !1) : ((((j < l)) ? (p = Math.floor(((j / k))), q = \"seconds\", c = !1) : ((((j < m)) ? (p = Math.floor(((j / l))), q = \"minutes\", c = !1) : ((((j < n)) ? (p = Math.floor(((j / m))), q = \"hours\", c = !1) : ((((j < ((n * 365)))) ? r = _(\"{{date}} {{month}}\", {\n                    date: i.getDate(),\n                    month: e.dates.months[i.getMonth()]\n                }) : r = _(\"{{date}} {{month}} {{year}}\", {\n                    date: i.getDate(),\n                    month: e.dates.months[i.getMonth()],\n                    year: i.getFullYear().toString().slice(2),\n                    year4: i.getFullYear().toString()\n                }))))))))))), ((r || (((f.allCounts ? f = f.allCounts : ((((p === 1)) ? f = f.singular : f = f.plural)))), r = Mustache.to_html(f[q], {\n                    JSBNG__one: p,\n                    number: p,\n                    plural_number: p\n                })))), ((c && (r += ((\" \" + _(\"at {{time}}\", {\n                    time: i.toTimeString().split(\":\").slice(0, 2).join(\":\")\n                })))))), r)));\n            },\n            timeAgoRounded: function(a) {\n                var b = new JSBNG__Date, c = new JSBNG__Date(a), d = ((b - c)), e = 1000, f = ((e * 60)), g = ((f * 60)), i = ((g * 24)), j = ((i * 7)), k = ((i * 30)), l = ((i * 365)), m;\n                return ((((isNaN(d) || ((d < 0)))) ? \"\" : (((((d <= ((f * 5)))) ? m = _(\"5 minutes\") : ((((d <= ((f * 15)))) ? m = _(\"15 minutes\") : ((((d <= ((f * 30)))) ? m = _(\"30 minutes\") : ((((d <= ((f * 45)))) ? m = _(\"45 minutes\") : ((((d <= g)) ? m = _(\"1 hour\") : ((((d <= ((g * 12)))) ? m = ((Math.floor(((d / g))) + _(\" hours\"))) : ((((d < ((g * 24)))) ? m = _(\"over 12 hours\") : ((((d <= ((i * 2)))) ? m = _(\"yesterday\") : ((((d <= ((i * 14)))) ? m = ((Math.floor(((d / i))) + _(\" days\"))) : ((((d < k)) ? m = _(\"over 2 weeks\") : ((((d < ((k * 2)))) ? m = _(\"over 1 month\") : ((((d < ((k * 3)))) ? m = _(\"over 2 months\") : ((((d < l)) ? m = _(\"over 6 months\") : ((((d < ((l * 2)))) ? m = _(\"over 1 year\") : m = _(\"over 2 years\"))))))))))))))))))))))))))))), m)));\n            },\n            transformProfileImageUrl: function(a, b) {\n                if (!twttr.is.string(a)) {\n                    return a;\n                }\n            ;\n            ;\n                ((((!b && a.match(/default_profile_\\d_normal.png$/))) && (b = \"bigger\")));\n                var c = /_normal(\\..*)?$/i;\n                return ((b ? a.replace(c, ((((\"_\" + b)) + \"$1\"))) : a.replace(c, \"$1\")));\n            },\n            isCurrentUser: function(a) {\n                return ((twttr.currentUser ? ((twttr.is.string(a) ? ((twttr.currentUser.screenName === a)) : ((twttr.is.object(a) ? ((a.id === twttr.currentUser.id)) : ((twttr.currentUser.id === a)))))) : !1));\n            },\n            isProfileUser: function() {\n                return ((twttr.profileUser && twttr.helpers.isCurrentUser(twttr.profileUser)));\n            },\n            userNoobLevel: function(a) {\n                var c = parseInt(twttr.Router.getCurrentQueryStringParams().nooblevel, 10);\n                if (!isNaN(c)) {\n                    return twttr.caches.User.set(\"noobLevel\", c), c;\n                }\n            ;\n            ;\n                var d = twttr.caches.User.get(\"noobLevel\");\n                if (((d < 0))) {\n                    return d;\n                }\n            ;\n            ;\n                var e = b.constants.noob;\n                return a = ((a || twttr.currentUser)), ((((a && twttr.decider.isAvailable(\"flock\"))) ? ((((a.statusesCount == 0)) ? ((((a.followersCount > 49)) ? e.notNoob : ((((a.friendsCount === 0)) ? ((a.followersCount ? e.invited : e.total)) : ((((a.followersCount || ((a.friendsCount > 9)))) ? e.silent : e.friendless)))))) : ((((((a.friendsCount > 9)) || ((((a.friendsCount === 0)) && ((a.followersCount > 49)))))) ? e.notNoob : ((((a.friendsCount === 0)) ? ((a.followersCount ? e.popular : e.talking)) : ((a.followersCount ? e.struggling : e.lonely)))))))) : e.notNoob));\n            },\n            canViewUser: function(a) {\n                return ((((((!a[\"protected\"] || a.following)) || this.isCurrentUser(a))) || ((twttr.is.def(twttr.isAdmin) && twttr.isAdmin))));\n            },\n            truncate: function(a, b, c) {\n                c = ((c || \"&hellip;\"));\n                var d = $(\"\\u003Cdiv/\\u003E\").html(c).text().length;\n                return ((((a.length > b)) && (a = ((a.slice(0, ((b - d))) + c))))), a;\n            },\n            displayUrl: function() {\n                var a = /^www\\./;\n                return function(c, d) {\n                    d = ((d || 16));\n                    var e = new b.util.Location(c), f = e.hostname.replace(a, \"\");\n                    ((((((e.port != 80)) && ((e.port != 443)))) && (f += ((\":\" + e.port)))));\n                    var g = ((((e.pathname + e.search)) + e.hash));\n                    return ((f + twttr.helpers.truncate(g, d, \"\\u2026\")));\n                };\n            }(),\n            getUserId: function(a) {\n                var b = parseInt(a.attr(\"data-user-id\"), 10);\n                return ((isNaN(b) ? 0 : b));\n            },\n            getUserIdentifier: function(a) {\n                var b = twttr.helpers.getUserId(a), c = a.attr(\"data-screen-name\");\n                return ((((((!b && !c)) && a.attr(\"hash\"))) && (c = twttr.router.findMatchingRoute(a.attr(\"hash\")).args.screen_name))), ((b || c));\n            },\n            parseEmailAddress: function(a) {\n                var c = b.constants.regexps.email.exec(a.replace(/^\\s+|\\s+$/g, \"\"));\n                return ((c ? c[0] : null));\n            },\n            extractEmailAddresses: function(a) {\n                return ((((a.indexOf(\"\\u003C\") == -1)) ? twttr.filter(twttr.map(a.split(\",\"), twttr.helpers.parseEmailAddress), function(a) {\n                    return !twttr.is.nil(a);\n                }) : [a,]));\n            },\n            handlePopupLinks: function(a) {\n                a.JSBNG__find(\".js-popup\").click(function(a) {\n                    a.preventDefault(), a.stopPropagation();\n                    var b = $(this);\n                    window.open(b.attr(\"href\"), ((b.attr(\"JSBNG__name\") || \"twttr_popup\")), b.attr(\"data-popup\"));\n                });\n            },\n            addFormEvents: function(a, c, d) {\n                d = ((d || {\n                })), a.bind(\"submit\", function(b) {\n                    if (a.hasClass(\"submitting\")) {\n                        b.preventDefault();\n                        return;\n                    }\n                ;\n                ;\n                    if (c) {\n                        b.preventDefault();\n                        var d = {\n                        };\n                        $.each($(this).serializeArray(), function() {\n                            ((d[this.JSBNG__name] ? (((d[this.JSBNG__name].push || (d[this.JSBNG__name] = [d[this.JSBNG__name],]))), d[this.JSBNG__name].push(((this.value || \"\")))) : d[this.JSBNG__name] = ((this.value || \"\"))));\n                        }), c.call(this, b, d);\n                    }\n                ;\n                ;\n                }).bind(\"keydown keypress\", function(c) {\n                    if (((c.ctrlKey || ((c.which == b.constants.keyCodes.escape))))) {\n                        return;\n                    }\n                ;\n                ;\n                    c.stopPropagation(), ((((((c.which == b.constants.keyCodes.enter)) && !$(c.target).is(\"textarea, [autocomplete=\\\"on\\\"]\"))) && (c.preventDefault(), c.target.JSBNG__blur(), a.submit())));\n                }), a.JSBNG__find(((((d.submitSelector || \"div.button.submit\")) + \", .js-submit\"))).attr(\"tabindex\", 0).click(function() {\n                    a.submit();\n                }), a.JSBNG__find(\"input:text, textarea\").bind(\"keydown\", function(a) {\n                    if (((a.which == b.constants.keyCodes.escape))) {\n                        this.JSBNG__blur();\n                        return;\n                    }\n                ;\n                ;\n                }).each(function() {\n                    var a = $(this), b = a.attr(\"placeholder\");\n                    if (((b && !Modernizr.input.placeholder))) {\n                        var c = !1;\n                        a.JSBNG__focus(function() {\n                            ((c && (a.val(\"\"), c = !1))), a.addClass(\"js-focused\").removeClass(\"js-placeholded placeholded\").select();\n                        }).JSBNG__blur(function() {\n                            ((((!c && ((a.val() === \"\")))) && (c = !0, a.val(b), a.addClass(\"js-placeholded placeholded\")))), a.removeClass(\"js-focused\");\n                        }), JSBNG__setTimeout(function() {\n                            a.JSBNG__blur();\n                        }, 0);\n                    }\n                ;\n                ;\n                });\n            },\n            addHoldingInputEvents: function(a) {\n                a.JSBNG__find(\"div.holding, div.placeholding-input\").each(function() {\n                    var a = $(this), b = a.JSBNG__find(\"input\");\n                    a.JSBNG__find(\"span\").click(function() {\n                        b.JSBNG__focus();\n                    }), b.JSBNG__blur(function() {\n                        ((b.val().length || a.removeClass(\"hasome\")));\n                    }), b.keydown(function(c) {\n                        JSBNG__setTimeout(function() {\n                            ((((((c && ((c.keyCode == 8)))) || b.val().length)) ? a.addClass(\"hasome\") : a.removeClass(\"hasome\")));\n                        }, 0);\n                    });\n                }), ((twttr.helpers._holdingInterval || (twttr.helpers._holdingInterval = window.JSBNG__setInterval(function() {\n                    $(\"form div.holding, form div.placeholding-input\").each(function() {\n                        var a = $(this), b = a.JSBNG__find(\"input\");\n                        ((((b.val() && b.val().length)) && a.addClass(\"hasome\")));\n                    });\n                }, 1111))));\n            },\n            chainAnimate: function(a, b, c, d) {\n                var e = 0;\n                (function() {\n                    var f = c[e++];\n                    if (twttr.is.def(f)) {\n                        var g = {\n                        };\n                        g[b] = f, a.animate(g, ((d || 100)), arguments.callee);\n                    }\n                ;\n                ;\n                })();\n            },\n            isModifier: function(a) {\n                return !!((((((a.shiftKey || a.metaKey)) || a.ctrlKey)) || a.altKey));\n            },\n            isTextOverflowEllipsisSupported: function() {\n                return ((\"textOverflow\" in $(\"\\u003Cdiv\\u003E\")[0].style));\n            },\n            ellipsify: function(a, b, c, d, e) {\n                if (c) {\n                    $(a).ellipsis(d, e);\n                    return;\n                }\n            ;\n            ;\n                return ((twttr.helpers.isTextOverflowEllipsisSupported() ? !1 : ($(a).each(function() {\n                    var a = $(this), c;\n                    if (a.hasClass(\"ellipsify-container\")) {\n                        if (!b) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                        c = a.JSBNG__find(\"span.ellip-content\"), ((c.length && a.html(c.html())));\n                    }\n                ;\n                ;\n                    a.addClass(\"ellipsify-container\").wrapInner($(\"\\u003Cspan\\u003E\").addClass(\"ellip-content\")), c = a.JSBNG__find(\"span.ellip-content\");\n                    if (((c.width() > a.width()))) {\n                        var d = $(\"\\u003Cdiv class=\\\"ellip\\\"\\u003E&hellip;\\u003C/div\\u003E\");\n                        a.append(d), c.width(((a.width() - d.width()))).css(\"margin-right\", d.width());\n                    }\n                ;\n                ;\n                }), !0)));\n            },\n            showErrorFromResponse: function(a, b) {\n                return twttr.errors.showErrorFromResponse(a, b);\n            }\n        }, a(twttr.helpers);\n    });\n});\nprovide(\"errors\", function(a) {\n    using(\"constants\").as(function(b) {\n        function c(a, b, c) {\n            return {\n                regex: a,\n                errorCode: b,\n                requestRegex: c\n            };\n        };\n    ;\n        var d = [c(/not following/, b.constants.errorCodes.notFollowing),c(/duplicate|already said that/, b.constants.errorCodes.duplicateTweet),c(/malware/, b.constants.errorCodes.malwareTweet),c(/daily|only send so many/, b.constants.errorCodes.dailyLimit),c(/140/, b.constants.errorCodes.tooLongTweet),c(/(this account|User) has been suspended/, b.constants.errorCodes.otherUserSuspended),c(/suspend/, b.constants.errorCodes.suspended),c(/photo/, b.constants.errorCodes.photoTimeout),c(/unable to follow more people/, b.constants.errorCodes.followingLimitReached),c(/blocked from following/, b.constants.errorCodes.blockedFromFollowing),c(/list's name.+25 characters/, b.constants.errorCodes.tooLongListName),c(/list's description.+100 characters/, b.constants.errorCodes.tooLongListDescription),c(/list's name.+start with a letter/, b.constants.errorCodes.noLetterStartListName),c(/Not found/, b.constants.errorCodes.tweetNotFound, /statuses\\/retweet/),c(/No status found/, b.constants.errorCodes.tweetNotFound),c(/Not found/, b.constants.errorCodes.userNotFound),];\n        twttr.errors = {\n            errorCodeFromResponse: function(a) {\n                var c, e, f, g = ((((a.response && ((a.response.error || ((a.response.errors && a.response.errors[0].message)))))) || null));\n                if (g) {\n                    for (c = 0, e = d.length; ((c < e)); c++) {\n                        f = d[c];\n                        if (((f.regex.test(g) && ((!f.requestRegex || f.requestRegex.test(a.response.request)))))) {\n                            return f.errorCode;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((((a.JSBNG__status === 403)) ? b.constants.errorCodes.permission : b.constants.errorCodes.whale));\n            },\n            showErrorFromResponse: function(a, b) {\n                var c = twttr.errors.errorCodeFromResponse(a);\n                return twttr.errors.showErrorFromCode(c, b);\n            },\n            showErrorFromCode: function(a, b) {\n                var c = twttr.errors.getViewForErrorCode(a, b);\n                return twttr.showError(c.html()), a;\n            },\n            getViewForErrorCode: function(a, b) {\n                var c = ((twttr.views[a] || twttr.views.DefaultErrorMessage));\n                if (((!b || !/^(dm|(re)?tweet|(un)?follow|(un)?block|report|delete|(un)?favorite)$/.test(b)))) {\n                    b = \"generic\";\n                }\n            ;\n            ;\n                var d = {\n                };\n                return d[((\"is_\" + b))] = !0, new c(d);\n            }\n        }, a(twttr.errors);\n    });\n});\nprovide(\"viewHelpers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.viewHelpers = {\n            addRelatedTweetsLogging: function(a, b, c) {\n                b.subcomponent = \"related-tweets\";\n                var d;\n                if (((a && (d = a.closest(\".related-tweets\")).length))) {\n                    var e = a.attr(\"data-tweet-id\");\n                    b.related_tweet_info = {\n                        impression_id: d.attr(\"data-related-impression-id\"),\n                        group_name: d.attr(\"data-related-group-name\"),\n                        annotations: d.attr(\"data-related-annotations\"),\n                        tweet_id: ((e ? e : \"0\"))\n                    };\n                    var f = d.attr(\"data-ab-data-bucket\");\n                    if (f) {\n                        var g = {\n                            bucket: f,\n                            experiment_key: d.attr(\"data-ab-data-experiment-key\"),\n                            version: d.attr(\"data-ab-data-version\")\n                        };\n                        scribble(c, g, \"www_ab_testing\");\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            addActivityItemLogging: function(a, b, c, d) {\n                b.streamType = \"activity-stream\", b.activityId = a.closest(\".stream-item\").attr(\"data-item-id\");\n            },\n            addExtraLogging: function(a, b, c) {\n                var d = a.closest(\".stream-tweet\"), e = twttr.app.currentPage();\n                ((((twttr.app.isOnPage(\"search\") && d.is(\".stream .stream-tweet\"))) ? using([twttr.bundleMore,\"components/pages/Search\",], function() {\n                    twttr.components.pages.Search.addSearchClickLogging(d, b);\n                }) : ((d.is(\"div.details-pane .related-tweets .stream-tweet\") ? twttr.viewHelpers.addRelatedTweetsLogging(d, b, c) : e.send(\"getStreamManager\", function(a) {\n                    if (a) {\n                        var e = a.getCurrent();\n                        using([twttr.bundleMore,\"streams/ActivityStream\",], function() {\n                            ((((e instanceof twttr.streams.ActivityStream)) && twttr.viewHelpers.addActivityItemLogging(d, b, c, e)));\n                        });\n                    }\n                ;\n                ;\n                })))));\n            }\n        }, a(twttr.viewHelpers);\n    });\n});\nprovide(\"components/Base\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.components\"), twttr.klass.component = function(a, b) {\n            return twttr.klass(a, b).subclassOf(twttr.components.Base);\n        }, twttr.deprecateAccess(twttr.klass, \"component\", {\n            replacement: \"twttr.klass(...).subclassOf(twttr.components.Base)\",\n            now: 1313800194870,\n            daysRemaining: 30\n        }), $.fn.component = function() {\n            var a = $(this), b = a.parent();\n            return ((a.data(\"component\") || ((b.length && b.component()))));\n        }, twttr.klass(\"twttr.components.Base\", function() {\n            var a = ((!this.constructor._deciderKey || twttr.decider.isAvailable(this.constructor._deciderKey)));\n            ((((this.constructor._baseView && a)) ? this.$node = (new this.constructor._baseView(this.constructor._baseViewOptions)).$html() : this.$node = ((this.$node || $(\"\\u003Cdiv/\\u003E\").addClass(\"component\"))))), this.$node.addClass(\"component\").data(\"component\", this);\n            if (!a) {\n                ((this._decideredOff && this._decideredOff()));\n                return;\n            }\n        ;\n        ;\n            ((this.constructor._initializer && this.constructor._initializer.apply(this, arguments)));\n            if (twttr.isT1) {\n                var c = this.scribeComponentName;\n                ((c || ((((this.constructor && this.constructor._name)) && (c = b.util.underscore(this.constructor._name)))))), ((c && this.$node.attr(\"data-component-term\", c)));\n            }\n        ;\n        ;\n            this.initComponentEvents();\n        }).statics({\n            initializer: function(a) {\n                return a._owner = this, this._initializer = a, this;\n            },\n            destructor: function(a) {\n                return this._destructor = a, this;\n            },\n            deciderKey: function(a) {\n                return this._deciderKey = a, this;\n            },\n            setBaseView: function(a, b) {\n                return this._baseView = a, this._baseViewOptions = b, this;\n            },\n            setBaseViewOptions: function(a) {\n                return this._baseViewOptions = a, this;\n            }\n        }).mixin(twttr.mixins.componentEvents).methods(twttr.EventProvider).methods({\n            hasRendered: function() {\n                this._hasRendered = !0, ((((!this.noSpacer && !twttr.isT1)) && this.$node.append(\"\\u003Chr class='component-spacer' /\\u003E\")));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            _superInitializer: function() {\n                var a = arguments.callee.caller._owner;\n                if (a) {\n                    var b = a.uberclass._initializer;\n                    ((b && b.apply(this, arguments)));\n                }\n            ;\n            ;\n            },\n            destroy: function() {\n                ((this.constructor._destructor && this.constructor._destructor.apply(this))), this.$node.remove(), this.trigger(\"destroyed\"), ((this._boundEvents && (twttr.each(this._boundEvents, function(a) {\n                    a.obj.unbind(a.JSBNG__name, a.cb);\n                }), this._boundEvents = []))), this.unbind();\n            },\n            _registerEvent: function(a, b, c) {\n                ((this._boundEvents || (this._boundEvents = []))), a.bind(b, c), this._boundEvents.push({\n                    obj: a,\n                    JSBNG__name: b,\n                    cb: c\n                });\n            }\n        }), a(twttr.components.Base);\n    });\n});\nprovide(\"idleDetector\", function(a) {\n    function b() {\n        var a = (new JSBNG__Date).getTime();\n        ((((!j && ((((a - k)) > g)))) && ($(JSBNG__document).trigger(\"inactive\"), JSBNG__clearInterval(l), j = !0)));\n    };\n;\n    function c() {\n        $(JSBNG__document).off(\".idleDetect\"), JSBNG__clearInterval(l), k = (new JSBNG__Date).getTime(), JSBNG__setTimeout(d, i), ((j && ($(JSBNG__document).trigger(\"active\"), j = !1)));\n    };\n;\n    function d() {\n        k = (new JSBNG__Date).getTime(), l = JSBNG__setInterval(b, i), $(JSBNG__document).JSBNG__on(m, c);\n    };\n;\n    function e() {\n        j = !0, $(JSBNG__document).off(\".idleDetect\"), JSBNG__clearInterval(l);\n    };\n;\n    function f(a) {\n        return a = $.extend({\n        }, {\n            wait: 300000,\n            heartBeat: 1000\n        }, a), g = a.wait, i = a.heartBeat, d(), {\n            deactivate: e\n        };\n    };\n;\n    var g, i, j = !0, k = 0, l = 0, m = \"mousemove.idleDetect keydown.idleDetect DOMMouseScroll.idleDetect mousewheel.idleDetect mousedown.idleDetect touchstart.idleDetect touchmove.idleDetect\";\n    a(f);\n});\nprovide(\"interface\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.Interface\").mixin(twttr.mixins.i18nTweetBox).methods({\n            enableRtl: function() {\n                twttr.i18n.rtl = !0, JSBNG__document.body.dir = \"rtl\";\n            },\n            setup: function() {\n                $(JSBNG__document).delegate(\"a[data-send-impression-cookie]\", \"click\", function(a) {\n                    var b = a.currentTarget;\n                    if (((((((!b || ((b.hostname != window.JSBNG__location.hostname)))) || !b.pathname)) || ((b.pathname.indexOf(\"/#!/\") == 0))))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = $(b), d = c.closest(\"[data-impression-cookie]\").attr(\"data-impression-cookie\");\n                    if (!d) {\n                        return;\n                    }\n                ;\n                ;\n                    var e = new JSBNG__Date, f = 60000, g = new JSBNG__Date(((e.getTime() + f)));\n                    $.cookie(\"ic\", d, {\n                        expires: g\n                    });\n                }), $(\"a[href$='#']\").live(\"click\", function(a) {\n                    a.preventDefault();\n                }), $(\".user-profile-link\").live(\"click\", twttr.scribbles.logViewProfileDetails), $(\"a[href^='/']\").live(\"click\", function(a) {\n                    if (((((((a.which == 1)) && !a.metaKey)) && !a.shiftKey))) {\n                        var b = $(this), c = b.attr(\"href\"), d = b.attr(\"target\");\n                        twttr.search.setLastQuerySource(((twttr.isT1 ? $(a.currentTarget).data(\"query-source\") : null)));\n                        if (((d && twttr.router.shouldRedirectTo(c)))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        return twttr.router.routeTo(c), a.preventDefault(), !1;\n                    }\n                ;\n                ;\n                }), ((((((twttr.isT1 && twttr.i18n)) && $(\"body\").hasClass(\"rtl\"))) && this.enableRtl())), $(\"li.user-thumb-list-member img\").tipsy({\n                    live: !0,\n                    gravity: \"s\"\n                }), ((twttr.isT1 ? ($(\"div.promoted-account a.js-promoted-badge, div.promoted-account small.js-disclosure, div.promoted-tweet span.js-disclosure\").tipsy({\n                    live: !0,\n                    gravity: \"n\",\n                    delayIn: 500\n                }), $(\"li.promoted-trend span.js-disclosure\").tipsy({\n                    live: !0,\n                    gravity: \"s\",\n                    delayIn: 500\n                })) : ($(\"div.promoted-account a.icon-link, div.promoted-tweet a.icon-link, li.promoted-account a.icon-link\").tipsy({\n                    live: !0,\n                    gravity: \"n\",\n                    delayIn: 500\n                }), $(\"li.promoted-trend span.icon-link\").tipsy({\n                    live: !0,\n                    gravity: \"s\",\n                    delayIn: 500\n                }), $(\"form.js-search-form .js-search-action\").click(function(a) {\n                    $(\"form.js-search-form\").submit();\n                })))), $(\"div.tweet a.twitter-timeline-link\").live(\"mousedown\", function() {\n                    var a = $(this), b = {\n                    };\n                    ((a.is(\"div.dashboard a\") ? b.component = \"dashboard\" : ((a.is(\"div.details-pane a\") ? b.component = \"details-pane\" : ((a.is(\".stream-tweet a\") ? b.component = \"stream\" : ((a.is(\".twttr-dialog a\") && (b.component = \"dialog\", b.dialog_type = a.closest(\".twttr-dialog\").attr(\"type\")))))))))), twttr.viewHelpers.addExtraLogging(a, b, \"tweet-link\"), b.tweet_id = a.closest(\".tweet\").attr(\"data-tweet-id\"), b.input = \"click\", b.href = a.attr(\"href\"), b.text = a.text(), scribble(\"tweet-link\", b);\n                }), $(\"a.media-attribution-link\").live(\"mousedown\", function(a) {\n                    scribble(\"follow-attribution-link\", {\n                        component: \"inline-media\",\n                        input: \"click\",\n                        type: $(this).attr(\"data-media-type\")\n                    });\n                }), $(\"a.inline-media-image\").live(\"mousedown\", function(a) {\n                    scribble(\"open-inline-media-photo\", {\n                        component: \"inline-media\",\n                        input: \"click\",\n                        type: $(this).attr(\"data-media-type\")\n                    });\n                }), $(\"button.js-global-new-tweet,a.js-global-new-tweet\").click(function(a) {\n                    a.stopPropagation(), a.preventDefault(), using([twttr.bundleMore,\"widget/TweetDialog\",], function() {\n                        (new twttr.widget.TweetDialog({\n                            draggable: !0,\n                            template: {\n                                title: _(\"What&#8217;s happening?\")\n                            },\n                            enableDraft: \"global-tweetbox\",\n                            origin: \"new-tweet-titlebar-button\"\n                        })).open().JSBNG__focus();\n                    });\n                }).tipsy({\n                    gravity: \"n\",\n                    offset: 6\n                }), twttr.helpers.ellipsify($(\"#screen-name\")), $(\"a.js-close-all-tweets\").click(function() {\n                    $(\".tipsy\").remove(), twttr.app.currentPage().send(\"closeAllTweets\");\n                }).tipsy({\n                    gravity: \"ne\",\n                    delayIn: 500\n                }), $(\"form.js-search-form\").submit(function(a) {\n                    var b = $(\"#search-query\");\n                    ((b.val() && (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch()))), a.preventDefault();\n                }), $(\"#message-drawer\").delegate(\".dismiss\", \"click\", function() {\n                    return twttr.views.MessageDrawer.close(), !1;\n                }), $(\"#message-drawer\").delegate(\".js-reload\", \"click\", function() {\n                    return window.JSBNG__location.reload(), !1;\n                }), $(\"a.js-signout-button\").click(function(a) {\n                    a.preventDefault(), twttr.cache.LocalProvider.clearAll(), ((window.JSBNG__localStorage && JSBNG__localStorage.clear())), trackClient({\n                        component: \"topnav\",\n                        action: \"logout\"\n                    }), ((twttr.decider.isAvailable(\"scribe_logout_reliability_events\") && ($(\"#signout-form .js-reliability-event\").attr(\"value\", \"true\"), trackClient({\n                        page: \"logout\",\n                        section: \"reliability\",\n                        component: \"client\",\n                        action: \"impression\"\n                    })))), $(\"#signout-form\").submit();\n                }), $(\"a.back-to-top\").live(\"click\", function(a) {\n                    return $(window).scrollTop(0), a.preventDefault(), !1;\n                }), $(\"a.sms-codes-link\").live(\"click\", function(a) {\n                    twttr.dialogs.smsCodes().open();\n                }), $(\"a.use-old-twitter\").live(\"click\", function(a) {\n                    $.cookie(((\"phx_seen_dialog-\" + twttr.currentUser.id)), null);\n                }), ((twttr.isT1 || $(\".contributor-account-link\").each(function(a) {\n                    var b = $(this), c = b.attr(\"data-profile-image-url\");\n                    ((c && (((((((window.JSBNG__location.protocol === \"https:\")) && twttr.cdnBase)) && (c = twttr.assets.getPathFromAbsoluteURL(c, {\n                        isSSL: !0,\n                        isVersioned: !1\n                    })))), b.JSBNG__find(\"img\").attr(\"src\", c))));\n                })));\n                var a = this;\n                $(\"#search-query\").bind(\"keyup keypress keydown\", function(b) {\n                    if (b.ctrlKey) {\n                        return;\n                    }\n                ;\n                ;\n                    a.markPunctuation(b, $(this)), b.stopPropagation();\n                });\n                var c = ((parseInt(b.util.params($.cookie(\"twll\")).l, 10) || 0));\n                twttr.verifySession = function() {\n                    var a = ((parseInt(b.util.params($.cookie(\"twll\")).l, 10) || 0));\n                    ((((a !== c)) && window.JSBNG__location.reload(!0)));\n                }, window.JSBNG__setInterval(function() {\n                    twttr.verifySession();\n                }, b.constants.sessionPollInterval), (($.browser.msie ? JSBNG__document.JSBNG__onfocusout = function() {\n                    twttr.verifySession(), twttr.externalURLStore.scribeFocusAfterClick();\n                } : $(window).JSBNG__focus(function() {\n                    twttr.verifySession(), twttr.externalURLStore.scribeFocusAfterClick();\n                }))), $(window).scrollTop(0);\n            }\n        }), twttr[\"interface\"] = new twttr.Interface, a(twttr[\"interface\"]);\n    });\n});\nprovide(\"run/topbarDropdown\", function(a) {\n    using().as(function(b) {\n        function c() {\n            if (((twttr.loggedIn && twttr.decider.isAvailable(\"api_verify_credentials_counts\")))) {\n                var a = $(\".dropdown-menu li[data-name='lists']\"), b = twttr.currentUser.counts.lists, c = function() {\n                    ((twttr.currentUser.hasLists() || a.hide()));\n                };\n                c(), twttr.API.List.bind(\"create follow\", function(c) {\n                    ((((c.type == \"create\")) ? b.owned += 1 : b.subscribed += 1)), a.show();\n                }), twttr.API.List.bind(\"delete unfollow\", function(a) {\n                    ((((a.type == \"delete\")) ? b.owned -= 1 : b.subscribed -= 1)), c();\n                });\n            }\n        ;\n        ;\n        };\n    ;\n        $(JSBNG__document).ready(function() {\n            function a() {\n                return ((twttr.app && twttr.app.isOnPage(\"login\")));\n            };\n        ;\n            var b = $(\".js-session\"), d = ((twttr.isT1 ? \"open\" : \"active\"));\n            b.click(function() {\n                ((a() ? twttr.router.routeTo(twttr.router.signupPath()) : (b.toggleClass(d), ((((!twttr.loggedIn && b.hasClass(d))) && b.JSBNG__find(\".username input\").JSBNG__focus())))));\n            }), $(JSBNG__document).bind(\"click\", function(a) {\n                var c = b.get(0);\n                ((((((c && ((a.target !== c)))) && !$.contains(c, a.target))) && b.removeClass(d)));\n            }).bind(\"keydown\", function(a) {\n                ((((a.keyCode === 27)) && b.removeClass(d)));\n            });\n            if (twttr.isT1) {\n                var e = $(\"li.js-language-dropdown\");\n                e.click(function(a) {\n                    e.toggleClass(\"open\"), a.preventDefault();\n                }), e.JSBNG__find(\".js-language-link\").bind(\"click\", function(a) {\n                    var b = e.JSBNG__find(\"form\");\n                    b.JSBNG__find(\"input[name=\\\"lang\\\"]\").val($(this).attr(\"data-lang-code\")), b.JSBNG__find(\"input[name=\\\"redirect\\\"]\").val(window.JSBNG__location.href), b.submit(), a.preventDefault(), a.stopPropagation();\n                });\n                var f = $(\"li.js-country-dropdown\");\n                f.click(function(a) {\n                    f.toggleClass(\"open\"), a.preventDefault();\n                }), f.JSBNG__find(\".js-country-link\").bind(\"click\", function(a) {\n                    var b = $(this);\n                    twttr.countryCode = b.attr(\"data-country-code\"), $.cookie(\"co\", twttr.countryCode, {\n                        domain: \".twitter.com\",\n                        path: \"/\",\n                        expires: 3650\n                    }), a.preventDefault(), a.stopPropagation(), JSBNG__location.reload();\n                }), $(\"a.js-dm-dialog\").click(function(a) {\n                    using([twttr.bundleMore,\"components/t1/DirectMessageDialog\",], function(a, b) {\n                        (new b).open();\n                    }), b.removeClass(d), a.stopPropagation(), a.preventDefault();\n                }), $(JSBNG__document).bind(\"click\", function(a) {\n                    var b = e.get(0);\n                    ((((((b && ((a.target !== b)))) && !$.contains(b, a.target))) && e.removeClass(d)));\n                    var c = f.get(0);\n                    ((((((c && ((a.target !== c)))) && !$.contains(c, a.target))) && f.removeClass(d)));\n                }).bind(\"keydown\", function(a) {\n                    ((((a.keyCode === 27)) && e.removeClass(d)));\n                }), c();\n            }\n        ;\n        ;\n            if (!twttr.loggedIn) {\n                $(\"#session \\u003E a\").attr(\"href\", \"#\");\n                var g = $(\"#signin-dropdown form\"), i = g.JSBNG__find(\"input\");\n                g.bind(\"click\", function(a) {\n                    a.stopPropagation();\n                }), g.bind(\"submit\", function(a) {\n                    if (twttr.app) {\n                        var b = ((twttr.app.isOnPage(\"mobile_gallery\") ? \"/\" : twttr.Router.getCurrentPath()));\n                        $(this).JSBNG__find(\"input[name=redirect_after_login]\").val(b);\n                    }\n                ;\n                ;\n                }), ((((JSBNG__navigator.userAgent.toLowerCase().indexOf(\"JSBNG__chrome\") > -1)) && i.each(function() {\n                    if (this.type.match(/text|password/)) {\n                        var a = $(this);\n                        a.clone().appendTo(a.parent()), a.remove();\n                    }\n                ;\n                ;\n                }))), ((twttr.helpers && twttr.helpers.addFormEvents(g))), i.bind(\"JSBNG__focus\", function() {\n                    ((a() ? twttr.app.currentPage().$find(\".username input\").JSBNG__focus() : b.addClass(d)));\n                });\n            }\n        ;\n        ;\n        }), a();\n    });\n});\nprovide(\"tco\", function(a) {\n    using().as(function(b) {\n        twttr.app.waitForSignal(\"init\", function() {\n            $(JSBNG__document.body).bind(\"copy\", twttr.bind(twttr.tco, twttr.tco.JSBNG__onCopy)), $(JSBNG__document.body).bind(\"aftercopy\", twttr.bind(twttr.tco, twttr.tco.JSBNG__onAfterCopy));\n        }), twttr.provide(\"twttr.tco\"), twttr.tco = {\n            shouldRefreshSelection: function() {\n                return !$.browser.msie;\n            },\n            JSBNG__onCopy: function(a) {\n                var b = twttr.tco.JSBNG__getSelection(), c;\n                ((this.shouldRefreshSelection() && (c = this.getCurrentRange())));\n                var d = ((b.anchorNode ? twttr.tco.nearestCommonAncestor(b.anchorNode, b.focusNode) : a.target));\n                if (!this.displayToTco(d)) {\n                    return;\n                }\n            ;\n            ;\n                window.JSBNG__setTimeout(function() {\n                    $(JSBNG__document.body).trigger(\"aftercopy\", [d,c,]);\n                }, 0);\n            },\n            linksForTarget: function(a) {\n                var b = $(a).JSBNG__find(\"a.twitter-timeline-link\");\n                return ((((a.tagName.toLowerCase() === \"a\")) && b.push(a))), b;\n            },\n            nearestCommonAncestor: function(a, b) {\n                if (((a == b))) {\n                    return a.parentNode;\n                }\n            ;\n            ;\n                var c = $.makeArray($(a).parents()).reverse().concat(a), d = $.makeArray($(b).parents()).reverse().concat(b), e = 0;\n                while (((c[e] == d[e]))) {\n                    e++;\n                ;\n                };\n            ;\n                return c[((e - 1))];\n            },\n            isFirstChild: function(a, b) {\n                while (((a != b))) {\n                    if (((a != a.parentNode.childNodes[0]))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    a = a.parentNode;\n                };\n            ;\n                return !0;\n            },\n            isLastChild: function(a, b) {\n                while (((a != b))) {\n                    var c = a.parentNode.childNodes;\n                    if (((a != c[((c.length - 1))]))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    a = a.parentNode;\n                };\n            ;\n                return !0;\n            },\n            displayToTco: function(a) {\n                var b = this, c = !1, d = twttr.tco.getCurrentRange(), e = ((d.focusNode ? $(d.focusNode).text().length : undefined)), f = twttr.tco.linksForTarget(a);\n                return $(f).each(function(a, f) {\n                    var g = $(f), i = g.attr(\"data-expanded-url\");\n                    if (!i) {\n                        return;\n                    }\n                ;\n                ;\n                    var j = ((d.focusNode && !!$(f).has(d.focusNode).length));\n                    if (j) {\n                        var k = twttr.tco.isFirstChild(d.focusNode, f), l = twttr.tco.isLastChild(d.focusNode, f), m = ((((k && ((d.focusOffset == 0)))) || ((l && ((d.focusOffset == e))))));\n                        if (!m) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ((((g.text().indexOf(\"pic.twitter.com/\") === 0)) && (i = g.attr(\"href\").replace(/t\\.co/, \"pic.twitter.com\")))), g.data(\"original-child-nodes\", $.map(f.childNodes, function(a) {\n                        return a;\n                    })), g.empty(), g.text(i), ((((j && ((d.focusOffset > 0)))) && b.adjustTextSelectionEndpoint())), c = !0;\n                }), c;\n            },\n            tcoToDisplay: function(a) {\n                var b = twttr.tco.linksForTarget(a);\n                $(b).each(function(a, b) {\n                    var c = $(b), d = c.data(\"original-child-nodes\");\n                    ((d && (c.empty().append(d), c.data(\"original-child-nodes\", null))));\n                });\n            },\n            getCurrentRange: function() {\n                var a = twttr.tco.JSBNG__getSelection();\n                return {\n                    anchorNode: a.anchorNode,\n                    anchorOffset: a.anchorOffset,\n                    focusNode: a.focusNode,\n                    focusOffset: a.focusOffset\n                };\n            },\n            JSBNG__onAfterCopy: function(a, b, c) {\n                this.tcoToDisplay(b), ((c && this.updateSelection(c)));\n            },\n            adjustTextSelectionEndpoint: function() {\n                var a = twttr.tco.JSBNG__getSelection(), b = JSBNG__document.createRange(), c = ((((a.focusNode.nodeType == 3)) ? a.focusNode.length : a.focusNode.childNodes.length));\n                b.setStart(a.anchorNode, a.anchorOffset), b.setEnd(a.focusNode, c), a.removeAllRanges(), a.addRange(b);\n            },\n            JSBNG__getSelection: function() {\n                return ((window.JSBNG__getSelection ? window.JSBNG__getSelection() : JSBNG__document.selection.createRange()));\n            },\n            updateSelection: function(a) {\n                var b = twttr.tco.JSBNG__getSelection(), c = JSBNG__document.createRange();\n                c.setStart(a.anchorNode, a.anchorOffset), c.setEnd(a.focusNode, a.focusOffset), ((((((((((c.startOffset === c.endOffset)) && ((c.anchorNode === c.focusNode)))) && ((c.anchorNode !== a.anchorNode)))) && ((c.focusNode !== a.focusNode)))) && (c.setStart(a.focusNode, a.focusOffset), c.setEnd(a.anchorNode, a.anchorOffset)))), b.removeAllRanges(), b.addRange(c);\n            }\n        }, a(twttr.tco);\n    });\n});\nprovide(\"streams/TweetStream\", function(a) {\n    using().as(function(b) {\n        var c = {\n            ACTIVE: 30000,\n            INACTIVE: 90000\n        }, d = c.ACTIVE;\n        $(window).JSBNG__focus(function() {\n            d = c.ACTIVE;\n        }), $(window).JSBNG__blur(function() {\n            d = c.INACTIVE;\n        }), twttr.tweetStream = function(a, b) {\n            ((b || (b = function() {\n                twttr.streams.TweetStream.apply(this, arguments);\n            })));\n            var c = twttr.stream(a, b);\n            return c.subclassOf(twttr.streams.TweetStream), c.prototype._updateMethod = function() {\n            \n            }, c.update = function(a) {\n                return this.prototype._updateMethod = a, this;\n            }, c.every = function(a) {\n                return this.prototype._interval = ((a * 1000)), this;\n            }, c.setTitle = function(a) {\n                return this.prototype._setTitle = a, this;\n            }, c.deciderKey = function(a) {\n                return c._deciderKey = a, c;\n            }, c.pollingDeciderKey = function(a) {\n                return c._pollingDeciderKey = a, c;\n            }, c;\n        }, twttr.klass(\"twttr.streams.TweetStream\", function() {\n            var a = this;\n            twttr.streams.Stream.apply(this, arguments), twttr.API.User.bind(\"block\", function(b, c) {\n                a.blockTweetsBy(c);\n            }), twttr.API.User.bind(\"unblock\", function(b, c) {\n                a.blockTweetsBy(c, !0);\n            }), this.bind(\"didTweet\", function(b, c) {\n                a.fetchTweets(function(a) {\n                    a.render();\n                });\n            }), this.registerTweetActionEvents(), this.registerUserActionEvents(), this.updateI18nDisplay(), this.periodicUpdater = null, this.scribbler = twttr.Scribbler.clientEvent;\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.tweetActionable, twttr.mixins.i18nTweet, twttr.mixins.userActionable, twttr.mixins.promotedTweetStream, twttr.mixins.streamablePageWithInlineMedia).methods(twttr.EventProvider).methods({\n            itemViewClass: \"StreamTweet\",\n            streamItemType: \"tweet\",\n            _expandable: !0\n        }).methods({\n            _fetchCount: function() {\n            \n            },\n            _fetchMoreCount: function() {\n                return 20;\n            },\n            convertToStatus: function(a) {\n                return new twttr.API.Status(a);\n            },\n            afterFirstSwitchingTo: function(a) {\n                var b = this, c = new JSBNG__Date;\n                ((this._attachedTweetBarEvent || (this._attachedTweetBarEvent = !0, this.dom().delegate(\".js-new-tweets-bar\", \"click\", function() {\n                    b._showNewItems();\n                })))), this.startPeriodicFetcher(), this._loadedStreamOnce = !0;\n                if (this.preRendered) {\n                    ((twttr.bootTimings && (twttr.bootTimings.add(\"tweets_visible\", twttr.tweetsVisibleTime), twttr.bootTimings.done()))), (((($(this.streamManagerDomNodeSelector).JSBNG__find(\"div.stream-end\").length == 1)) && (this._alreadyMarkedEnd = !0))), this.items = [], this.itemIds = {\n                    };\n                    var d = this.$node.JSBNG__find(\"div.js-stream-tweet, div.stream-tweet\"), e = twttr.promotedTweetStore.getTweetInfo();\n                    storedPromotedTweetId = null, ((((e && e.data.promoted_status)) ? storedPromotedTweetId = e.data.promoted_status.id_str : ((e && (storedPromotedTweetId = e.data.id_str))))), d.each(function(a, c) {\n                        var f = $(c), g, i, j, k, l, m, n;\n                        g = JSON.parse(f.attr(\"data-status\"));\n                        if (((storedPromotedTweetId === g.id_str))) {\n                            g = e.data, i = g.promoted_content.impression_id, f.attr(\"data-impression-id\", i);\n                            var o = ((g.id_str + \"-promoted\"));\n                            f.parent().attr(\"data-item-id\", o).attr(\"id\", ((\"stream-item-tweet-\" + o)));\n                        }\n                         else ((f.attr(\"data-impression-id\") && (k = d[((a + 1))], ((k && (l = $(k).attr(\"data-tweet-id\"), j = !!f.JSBNG__find(\"i.badge-political\").length, twttr.promotedTweetStore.setTweetInfo(l, g, j)))))));\n                    ;\n                    ;\n                        n = b.convertToStatus(g), m = new twttr.views.StreamTweet(n), m.wakeUp(), b.items.push(n), b.markAsRendered(n);\n                    }), ((((this.items.length == 0)) && (this.noMoreOldItems = !0))), this.updateI18nDisplay(), this.wokeUp(), this.JSBNG__onGotInitialResults(this.items), this._updateSinceId(this.items), this.logPromotedImpressions(this.items), this.addInlineMediaIcons(this.$node, function() {\n                        b._scribeTweetImpressions();\n                    }), using(\"\\u003EallCodeLoaded\", function() {\n                        b.addActivityByFriendsToTweets(b.items);\n                    });\n                }\n                 else this.isLoadingMore(), this.fetchTweets(!0, function(c, d) {\n                    c.render(), ((twttr.tweetsVisibleTime || (twttr.tweetsVisibleTime = new JSBNG__Date))), ((twttr.bootTimings && (twttr.bootTimings.add(\"tweets_visible\"), twttr.bootTimings.done()))), ((twttr.util.params().show_time && twttr.showMessage(((((\"Stream loaded at \" + ((((+(new JSBNG__Date) - JSBNG__document.startTime)) / 1000)))) + \"s\"))))), c.doneLoadingMore(), ((((d !== twttr.streams.SUCCESS)) ? b._showError(d) : b.fetchUntilScreenIsFull())), ((a ? a() : $.noop)), b._scribeTweetImpressions();\n                });\n            ;\n            ;\n            },\n            fetchUntilScreenIsFull: function() {\n                var a = this;\n                ((((((!this.noMoreOldItems && this._isInDOM())) && this._shorterThanWindow())) && this.getMoreOldItems(function(b, c) {\n                    ((((c !== twttr.streams.SUCCESS)) ? a._showError(c) : a.fetchUntilScreenIsFull()));\n                })));\n            },\n            _isInDOM: function() {\n                return jQuery.contains(JSBNG__document.body, this.$node[0]);\n            },\n            _shorterThanWindow: function() {\n                return ((this.$node.height() < twttr.windowHeight));\n            },\n            afterSwitchingToAgain: function(a) {\n                this.fetchTweets(twttr.bind(this, function(b) {\n                    var c = this.newItemsCount;\n                    ((((this.newItemsCount > 0)) && this._showNewItems())), this.restartFetcher();\n                    if (!twttr.isT1) {\n                        var d = this.getFirstItem();\n                        this.highlightItem(d);\n                    }\n                ;\n                ;\n                    ((a ? a() : $.noop));\n                }));\n            },\n            _getStreamWhaleText: function() {\n                return _(\"Loading Tweets seems to be taking a while.\");\n            },\n            streamItemId: function(a) {\n                return ((a.impressionId ? ((a.id + \"-promoted\")) : a.id));\n            },\n            blockTweetsBy: function(a, b) {\n                var c = ((((this.constructor._name === \"User\")) && ((this.screenName === a.screenName)))), d = ((this.constructor._name === \"Search\"));\n                if (((c || d))) {\n                    return;\n                }\n            ;\n            ;\n                var e = this.$find(((((\".stream-item [data-screen-name=\\\"\" + a.screenName)) + \"\\\"]\"))).parent();\n                e[((b ? \"addClass\" : \"removeClass\"))](\"blocked\");\n            },\n            JSBNG__onTweetActionDelete: function(a) {\n                this.remove(a);\n                for (var b = 0; ((b < this.items.length)); b++) {\n                    ((((this.items[b].id === a)) && this.items.splice(b, 1)));\n                ;\n                };\n            ;\n            },\n            JSBNG__onTweetActionHide: function(a) {\n                this.selectedItem(a).hide();\n            },\n            JSBNG__onTweetActionShow: function(a) {\n                this.selectedItem(a).show();\n            },\n            beforeShowNewItems: function() {\n                var a;\n                ((this.keepPromotedTweetsAtTop ? a = this.$find(\".js-original-tweet:not(.promoted-tweet)\").first().closest(\".js-stream-item\") : a = this.$find(\".js-stream-item\").first())), this.$find(\".last-new-tweet\").removeClass(\"last-new-tweet\"), a.addClass(\"first-old-tweet\");\n                if (a.hasClass(\"expanding-stream-item\")) {\n                    var b = a.css(\"margin-bottom\");\n                    ((b && a.css(\"margin-top\", b)));\n                }\n            ;\n            ;\n            },\n            separateOldAndNewTweets: function() {\n                var a = this.$find(\".first-old-tweet\").removeClass(\"first-old-tweet\").first(), b = a.prev().addClass(\"last-new-tweet\");\n                ((a.is(\".expanding-stream-item.open\") && b.addClass(\"before-expanded\")));\n            },\n            JSBNG__onShowNewItems: function(a) {\n                this.updateI18nDisplay();\n                var b = this;\n                this.addInlineMediaIcons(a, function() {\n                    b._scribeTweetImpressions();\n                }), this.separateOldAndNewTweets(), this.$find(\".js-new-tweets-bar\").remove();\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this.updateI18nDisplay();\n                var b = this;\n                this.addInlineMediaIcons(a, function() {\n                    b._scribeTweetImpressions();\n                });\n            },\n            addActivityByFriendsToTweets: function(a) {\n                if (((((!twttr.currentUser || !twttr.decider.isActivityEnabled())) || !twttr.decider.isAvailable(\"activity_social_context\")))) {\n                    return;\n                }\n            ;\n            ;\n                var b = this, c = {\n                }, d = {\n                };\n                return $.each(a, function(a, b) {\n                    c[b.id] = {\n                        retweeters: [],\n                        favoriters: []\n                    }, ((b.wasRetweeted && (c[b.id].retweeters.push(b.retweetingStatus.user), d[b.retweetingStatus.user.id] = !0)));\n                }), this.activityByFriendIntersection(a, c, d);\n            },\n            activityByFriendIntersection: function(a, b, c) {\n                var d = this;\n                this.loadFriends(function(e) {\n                    var f = {\n                    }, g = {\n                    };\n                    $.each(a, function(a, b) {\n                        if (!b.activities) {\n                            return;\n                        }\n                    ;\n                    ;\n                        $.each(b.activities.favoriters, function(a, c) {\n                            if (!e[c]) {\n                                return;\n                            }\n                        ;\n                        ;\n                            ((g[c] || (g[c] = []))), g[c].push(b.id);\n                        }), $.each(b.activities.retweeters, function(a, d) {\n                            if (((!e[d] || c[d]))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            ((f[d] || (f[d] = []))), f[d].push(b.id);\n                        });\n                    });\n                    var i = twttr.util.arrayUniq(twttr.util.objKeys(g).concat(twttr.util.objKeys(f))).slice(0, twttr.constants.users.maxLookupSize);\n                    twttr.API.User.findAll(i, {\n                        stringifiedIds: !0,\n                        success: function(a) {\n                            a.each(function(a) {\n                                faves = g[a.id], retweets = f[a.id], ((faves && $.each(faves, function(c, d) {\n                                    b[d].favoriters.push(a);\n                                }))), ((retweets && $.each(retweets, function(c, d) {\n                                    b[d].retweeters.push(a);\n                                })));\n                            }), d.appendActivities(b);\n                        },\n                        error: function() {\n                            d.appendActivities(b);\n                        }\n                    });\n                });\n            },\n            appendActivities: function(a) {\n                for (tweetId in a) {\n                    var b = a[tweetId], c = this.$node.JSBNG__find(((((\".stream-item[data-item-id='\" + tweetId)) + \"']\")));\n                    ((b.retweeters.length && (new twttr.views.StreamActivity({\n                        items: b.retweeters,\n                        item_type: \"retweets\"\n                    })).render(c.JSBNG__find(\".tweet-activity-retweets\"), \"html\"))), ((((!b.retweeters.length && b.favoriters.length)) && (new twttr.views.StreamActivity({\n                        items: b.favoriters,\n                        item_type: \"favorites\"\n                    })).render(c.JSBNG__find(\".tweet-activity-favorites\"), \"html\")));\n                };\n            ;\n            },\n            loadFriends: function() {\n                var a;\n                return function(b) {\n                    if (a) {\n                        return b(a);\n                    }\n                ;\n                ;\n                    twttr.currentUser.friendIds(function(c) {\n                        a = twttr.inject(c, {\n                        }, function(a, b, c) {\n                            return a[c] = !0, a;\n                        }), b(a);\n                    });\n                };\n            }(),\n            JSBNG__onGotInitialResults: function(a) {\n                var b = a.slice(this.newItemsCount);\n                twttr.streams.Stream.prototype.JSBNG__onGotInitialResults.apply(this, arguments), this.addActivityByFriendsToTweets(b);\n            },\n            JSBNG__onGotNewItems: function(a) {\n                twttr.streams.Stream.prototype.JSBNG__onGotNewItems.apply(this, arguments), this.addActivityByFriendsToTweets(a);\n            },\n            JSBNG__onGotOldItems: function(a) {\n                twttr.streams.Stream.prototype.JSBNG__onGotOldItems.apply(this, arguments), this.addActivityByFriendsToTweets(a);\n            },\n            _scribeTweetImpressions: function() {\n                var a = this;\n                ((twttr.abdecider.chooseWithoutImpression(\"tweet_anatomy_2_231\") && a.$node.JSBNG__find(\"div.js-stream-tweet\").each(function(b, c) {\n                    c = $(c), ((c.height() && a._itemDetailsScribe(\"impression\", \"tweet\", c)));\n                })));\n            },\n            _scribeResults: function(a, b, c) {\n                this._scribeEmptyResults(a, b, c);\n                if (b.length) {\n                    var d = [], e;\n                    twttr.each(b, function(a, b) {\n                        var c;\n                        d.push(a.id), ((((a.isPromoted && a.isPromoted())) ? c = {\n                            item_type: twttr.constants.clientEvent.itemType.promotedTweet,\n                            item_token: a.impressionId\n                        } : ((((a.resultCategory == \"popular\")) && (c = {\n                            item_type: twttr.constants.clientEvent.itemType.popularTweet\n                        }))))), ((c && (e = ((e || {\n                        })), c.item_position = b, e[a.id] = c)));\n                    }), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"results\"\n                    }, {\n                        item_ids: d,\n                        item_count: d.length,\n                        event_value: d.length,\n                        cursor_or_page: this._sinceId,\n                        item_details: e,\n                        referring_event: a\n                    });\n                }\n            ;\n            ;\n            },\n            beforeSwitchingAway: function() {\n                this.stopPeriodicFetcher(), this.trigger(\"switchingAway\");\n            },\n            _fetchItems: function(a) {\n                this.fetchTweets(!0, a);\n            },\n            fetchTweets: function(a, b, c) {\n                ((twttr.is.fn(a) && (c = b, b = a, a = !1)));\n                if (((this.preRendered && this._alreadyMarkedEnd))) {\n                    b(this, twttr.streams.SUCCESS);\n                    return;\n                }\n            ;\n            ;\n                if (((!twttr.decider.isAvailable(\"tweet_streams\") || ((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))))) {\n                    b(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var d = this, e = twttr.audit.trail(), f = ((a ? this._optionsForOld(b) : this._optionsForNew(b)));\n                c = ((c || {\n                })), f = twttr.merge(c, f), ((twttr.decider.isAvailable(\"platform_enable_cards\") && (f.include_cards = 1))), f.include_entities = 1, f.include_available_features = 1, f.contributor_details = ((!e[1] || ((e[1].page !== \"welcome\")))), this._updateMethod(f, this.params, b);\n            },\n            _idForTweet: function(a) {\n                return ((a.wasRetweeted ? a.retweetingStatus.id : a.id));\n            },\n            _optionsForNew: function(a) {\n                var b = this, c = {\n                    success: function(c) {\n                        ((((c instanceof twttr.API.util.BaseCollection)) && (c = c.array))), c = b.cleanStream(c);\n                        var d = !b.items.length;\n                        b.unshift(c), b._updateSinceId(c), ((((d && b.items.length)) && b.switchEndOfStreamMarker())), ((a && a(b, twttr.streams.SUCCESS)));\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR))), b._scribeResults(\"error\", [], {\n                            status_code: c.JSBNG__status\n                        });\n                    }\n                };\n                return ((this.items.length && (c.since_id = this._sinceId))), c;\n            },\n            _updateSinceId: function(a) {\n                ((twttr.is.array(a) || (a = Array.prototype.slice.call(arguments))));\n                for (var b = 0; ((b < a.length)); b++) {\n                    var c = a[b], d = this._idForTweet(c);\n                    if (((!c.isPromoted() && ((c.resultCategory !== \"popular\"))))) {\n                        ((((twttr.natcompare(d, ((this._sinceId || \"0\"))) > 0)) && (this._sinceId = d)));\n                        return;\n                    }\n                ;\n                ;\n                };\n            ;\n            },\n            _streamMaxId: function() {\n                for (var a = ((this.items.length - 1)); ((a >= 0)); a--) {\n                    if (!this.items[a].isPromoted()) {\n                        return this._idForTweet(this.items[a]);\n                    }\n                ;\n                ;\n                };\n            ;\n            },\n            cleanStream: function(a) {\n                return a = this._filterMutedUsers(a), a = this._filterDeletedTweets(a), a = this._filterOutRetweets(a), a;\n            },\n            _filterOutRetweets: function(a) {\n                return ((twttr.currentUser ? twttr.filter(a, function(a) {\n                    return ((a.wasRetweeted ? a : a));\n                }) : a));\n            },\n            _filterMutedUsers: function(a) {\n                ((twttr.decider.isAvailable(\"muteUsers\") || a));\n                if (((twttr.currentUser && ((this.constructor._name == \"Home\"))))) {\n                    var b = twttr.caches.User.get(\"muted\");\n                    a = twttr.filter(a, function(a) {\n                        if (((((!twttr.is.def(b) || ((a.wasRetweeted && !twttr.is.def(b[a.retweetingStatus.user.id]))))) || ((!a.wasRetweeted && !twttr.is.def(b[a.user.id])))))) {\n                            return a;\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                return a;\n            },\n            _filterDeletedTweets: function(a) {\n                return twttr.filter(a, function(a) {\n                    if (!twttr.app.caches.deletedTweets.get(a.id)) {\n                        return a;\n                    }\n                ;\n                ;\n                });\n            },\n            _optionsForOld: function(a) {\n                var b = this, c = {\n                    success: function(d) {\n                        ((((d instanceof twttr.API.util.BaseCollection)) && (d = d.array))), ((c.max_id && (d = twttr.filter(d, function(a) {\n                            return ((a.id !== c.max_id));\n                        })))), d = b.cleanStream(d), b.push(d), b._updateSinceId(d), ((d.length || b.reachedTheEnd())), ((a && a(b, twttr.streams.SUCCESS)));\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                    },\n                    timeout: function(a) {\n                        a.retry();\n                    },\n                    cancel: function() {\n                        a(b, twttr.streams.TIMEOUT);\n                    }\n                };\n                return ((this.items.length ? (c.max_id = this._streamMaxId(), c.count = ((this._fetchMoreCount() + 1))) : ((this._fetchCount() && (c.count = this._fetchCount()))))), c;\n            },\n            _getInterval: function() {\n                return d;\n            },\n            startPeriodicFetcher: function() {\n                if (((((this.periodicUpdater || !twttr.decider.isAvailable(\"tweet_streams_polling\"))) || ((this.constructor._pollingDeciderKey && !twttr.decider.isAvailable(this.constructor._pollingDeciderKey)))))) {\n                    return;\n                }\n            ;\n            ;\n                this.periodicUpdater = JSBNG__setTimeout(twttr.bind(this, this.fetchNewTweetsThenPoll), this._getInterval());\n            },\n            fetchNewTweetsThenPoll: function() {\n                var a = {\n                    headers: {\n                        \"X-Twitter-Polling\": !0\n                    },\n                    interval: this._getInterval()\n                };\n                this.fetchTweets(twttr.bind(this, function(a) {\n                    var b = a.newItemsCount;\n                    ((((b > 0)) && (this.showNewTweetsBar(b), this.trigger(\"newTweets\", [a,b,]))));\n                }), a), this.restartFetcher();\n            },\n            stopPeriodicFetcher: function() {\n                ((this.periodicUpdater && (JSBNG__clearTimeout(this.periodicUpdater), this.periodicUpdater = null)));\n            },\n            restartFetcher: function() {\n                this.stopPeriodicFetcher(), this.startPeriodicFetcher();\n            },\n            addInlineMediaIcons: function(a, b) {\n                using([twttr.bundleMore,\"media/Iconifier\",], function() {\n                    new twttr.media.Iconifier(a, b);\n                }), using([twttr.bundleMore,\"stork\",], function() {\n                    if (a) {\n                        var b = a.JSBNG__find(\".js-stream-items\");\n                        ((b.length || (b = a.closest(\".js-stream-items\")))), twttr.stork.storkifyTweets(b);\n                    }\n                ;\n                ;\n                });\n            },\n            showNewTweetsBar: function(a) {\n                var b = this.$find(\".js-new-tweets-bar\"), c = (new twttr.views.NewTweetsBar({\n                    count: a,\n                    is_tweet: !0\n                })).$html();\n                ((((b.length > 0)) ? ((twttr.isT1 ? b.parent() : b)).replaceWith(c) : c.hide().prependTo(this.dom()).slideDown()));\n            },\n            screen_name: function() {\n                return this.params.screenName;\n            },\n            _getUserStreamErrorComponent: function(a) {\n                return this.wokeUp(), ((((a === twttr.streams.PROTECTED)) ? new twttr.components.ProtectedUser({\n                    screen_name: this.params.screenName\n                }) : this.constructor.uber._getStreamErrorComponent.apply(this, arguments)));\n            },\n            wokeUp: function() {\n                signal(\"\\u003EwokeUp\");\n            }\n        }), a(twttr.streams.TweetStream);\n    });\n});\nprovide(\"streams/Home\", function(a) {\n    using().as(function(b) {\n        twttr.tweetStream(\"twttr.streams.Home\", function() {\n            var a = this;\n            twttr.streams.TweetStream.apply(this, arguments), this.unbind(\"didTweet\"), this.bind(\"didTweet\", function(b, c) {\n                a.fetchTweets(function(b, d) {\n                    if (((((d != twttr.streams.WHALE)) && ((d != twttr.streams.ERROR))))) {\n                        a.insertTweetIfNotPresent(c);\n                        var e = a.$node.JSBNG__find(\".js-stream-item:first\"), f = ((e.length > 0)), g = ((f && e.position().JSBNG__top));\n                        b._showNewItems(\"insert\");\n                        if (f) {\n                            var i = e.position().JSBNG__top, j = twttr.$win.scrollTop();\n                            $(\"html, body\").scrollTop(((j + ((i - g)))));\n                        }\n                    ;\n                    ;\n                        b._showOldItems(!0);\n                    }\n                ;\n                ;\n                });\n            });\n        }).update(function(a, b, c) {\n            a.pc = !0, twttr.currentUser.homeTimeline(a);\n        }).methods({\n            JSBNG__onShowNewItems: function(a) {\n                this.constructor.uber.JSBNG__onShowNewItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(0, this.newItemsCount));\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this.constructor.uber.JSBNG__onShowOldItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(((this.items.length - this.oldItemsCount)))), ((twttr.streams.Home.scribeTweetDensity && (this._scribeTweetDensity(a), twttr.streams.Home.scribeTweetDensity = !1)));\n            },\n            _scribeTweetDensity: function(a) {\n                var b = a.JSBNG__find(\".js-stream-tweet\"), c = {\n                };\n                if (((b.length < 10))) {\n                    return;\n                }\n            ;\n            ;\n                for (var d = 0; ((d < 10)); ++d) {\n                    var e = b.eq(d), f = e.attr(\"data-user-id\");\n                    ((c[f] ? c[f]++ : c[f] = 1));\n                };\n            ;\n                var g = 0, i = null, j = 0, k = 0;\n                $.each(c, function(a, b) {\n                    ((((b > g)) && (g = b, i = a))), j += ((b * ((b - 1))));\n                    var c = ((b / 10));\n                    k += ((c * Math.log(((1 / c)))));\n                });\n                var l = ((1 - ((j / 90))));\n                k /= Math.log(10), scribble(\"welcome-timeline-stats\", {\n                    density: g,\n                    density_leader: i,\n                    diversity: l,\n                    entropy: k\n                });\n            },\n            _fetchCount: function() {\n                return null;\n            },\n            _fetchMoreCount: function() {\n                return 20;\n            },\n            _getStreamEndComponent: function() {\n                return this.constructor.uber._getStreamEndComponent.apply(this, arguments);\n            },\n            insertTweetIfNotPresent: function(a) {\n                ((((a instanceof twttr.API.Status)) || (a = new twttr.API.Status(a))));\n                var b = this.cleanStream([a,]);\n                if (((b && !this.hasTweet(a)))) {\n                    var c = this.insertionIndexOfTweet(a);\n                    this.splice(c, b), this.newItemsCount++, ((((c == 0)) && this._updateSinceId(b))), this.JSBNG__onInsertItems(b);\n                }\n            ;\n            ;\n            },\n            hasTweet: function(a) {\n                for (var b = 0, c = this.items.length; ((b < c)); b++) {\n                    if (((this.items[b].id == a.id))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            insertionIndexOfTweet: function(a) {\n                for (var b = 0, c = this.items.length; ((b < c)); b++) {\n                    if (!this.items[b].isPromoted()) {\n                        var d = a.id, e = this.items[b].id;\n                        if (((twttr.natcompare(d, e) >= 0))) {\n                            return b;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return b;\n            }\n        }).deciderKey(\"tweet_stream_home\").pollingDeciderKey(\"tweet_stream_home_polling\"), ((twttr.isT1 ? twttr.streams.Home.methods({\n            _setTitle: function(a) {\n                a(_(\"Tweets\"));\n            },\n            _getEmptyStreamHtml: function() {\n                return (new twttr.views.EmptyTimelineMessage).html();\n            }\n        }) : twttr.streams.Home.methods({\n            _getEmptyStreamComponent: function() {\n                var a = new twttr.components.EmptyHome, b = \"newItemsCountChanged.EmptyHomeComponent\", c = this;\n                return this.bind(b, function(d, e) {\n                    ((((!e && !c.isEmpty())) && (a.destroy(), c.unbind(b), c._alreadyMarkedEnd = !1, c.markStreamEnd())));\n                }), a;\n            }\n        }))), a();\n    });\n});\nprovide(\"streams/StreamManager\", function(a) {\n    using(\"_\", \"mixins/serverRenderableObject\").as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.StreamManager\", function(a, b) {\n            var c = this, d = \"\";\n            if (a) {\n                var e = ((a + \"-stream-manager\"));\n                d = ((((\" id=\\\"\" + e)) + \"\\\"\")), this.domNodeSelector = ((\"#\" + e));\n            }\n        ;\n        ;\n            this.$node = this.$domNode(((((\"\\u003Cdiv class=\\\"js-stream-manager\\\" \" + d)) + \"\\u003E\\u003Cdiv class=\\\"stream-title\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stream-container\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"))), this.$page = ((b || $())), ((twttr.decider.isInfiniteScroll() || (this.$moreButton = (new twttr.views.MoreButton).$html().appendTo(this.$node).click(function(a) {\n                c.getMoreOldItems(function(a) {\n                    scribble(\"stream-more-button\", {\n                        page: a._cacheKey,\n                        stream: a._cacheKey,\n                        focused_tweet_id: ((a.focusedItemId || \"\"))\n                    });\n                }), a.stopPropagation(), a.preventDefault();\n            })))), this.resetCache(), ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"route_timing\") || twttr.util.params().routetimer)))) && (c.bind(\"switchingToStream didNotSwitch\", function(a, b) {\n                twttr.RouteTimer.streamSwitch(b);\n            }), c.bind(\"afterSwitchingTo\", function(a, b, c) {\n                twttr.RouteTimer.streamAfterSwitch(b, c);\n            })))), ((window.ttft && c.bind(\"afterSwitchingTo\", function() {\n                window.ttft.clientRendered(twttr.app.currentPageName());\n            })));\n        }).statics({\n            cacheKeyForStream: function(a) {\n                return a._cacheKey;\n            },\n            cacheKeyForStreamClass: function(a, b) {\n                var c = a._name;\n                if (((b && !$.isEmptyObject(b)))) {\n                    var d = twttr.filter(b, function(a, b) {\n                        return ((!twttr.is.fn(b) && !twttr.is.object(b)));\n                    });\n                    c += JSON.stringify(d);\n                }\n            ;\n            ;\n                return encodeURIComponent(c);\n            }\n        }).methods(twttr.EventProvider).mixin(c).methods({\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            getCurrent: function() {\n                return this.streams.current;\n            },\n            setCurrent: function(a) {\n                this.streams.current = a;\n            },\n            getStream: function(a, b) {\n                var c = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b);\n                return this.streams[c];\n            },\n            JSBNG__onSwitchAway: function() {\n                var a = this.getCurrent();\n                ((a && a.beforeSwitchingAway()));\n            },\n            switchOut: function() {\n                var a = this.getCurrent();\n                ((a && (a.beforeSwitchingAway(), a.dom().detach()))), this.$headerContainer().empty(), this.titleContainer().empty();\n            },\n            switchTo: function(a, b, c) {\n                var d = null;\n                ((((b && ((b.initialItems !== undefined)))) && (d = b.initialItems, delete b.initialItems)));\n                var e = this, f = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b), g = this.getCurrent(), i, j = !1, k = function(a) {\n                    return function() {\n                        e.trigger(\"afterSwitchingTo\", [a,j,]), ((c && c.apply(this, arguments)));\n                    };\n                };\n                _scribble(\"stream-view\", {\n                    stream_name: a._name\n                }), b = ((b || {\n                }));\n                if (g) {\n                    var l = twttr.streams.StreamManager.cacheKeyForStream(g);\n                    if (((l === f))) {\n                        return this.trigger(\"didNotSwitch\", g), j = !0, g.afterSwitchingToAgain(k(g)), g;\n                    }\n                ;\n                ;\n                    this.switchOut();\n                }\n            ;\n            ;\n                this.trigger(\"switchTo\"), ((((this.streams[f] && ((!d || b.cacheWithInitialItems)))) ? (i = this.streams[f], j = !0) : (i = new a(b, d, this), i._cacheKey = f, i.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    ((((i === this.getCurrent())) && this.trigger(\"newItemsCountChanged\", [b,])));\n                })), i.bind(\"reloadCurrentStream\", twttr.bind(this, function(a, b) {\n                    i.unbindEvents(), this.clearFromCache(b), this.$node.JSBNG__find(\"div.stream-container\").empty(), delete this.streams.current, this.switchTo(b);\n                })), i.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), ((i._shouldCache && (this.streams[f] = i))), i.bind(\"governmentSearch\", function(a, b) {\n                    twttr.router.routeTo(twttr.router.governmentSearchByZipPath({\n                        zipCode: b\n                    }));\n                })))), this.trigger(\"switchingToStream\", i);\n                var m = this.$node.JSBNG__find(\"div.stream-container\");\n                ((((m.has(i.$node).length === 0)) && m.prepend(i.$node))), this.setHeader(i, b);\n                if (e.$moreButton) {\n                    function n() {\n                        e.$moreButton.toggle(((!i._alreadyMarkedEnd && !i._errorComponent)));\n                    };\n                ;\n                    i.bind(\"streamEnd doneLoadingMore\", n), n();\n                }\n            ;\n            ;\n                return i.bind(\"doneLoadingMore\", function() {\n                    e.trigger(\"doneLoadingMore\");\n                }), this.setCurrent(i), this.trigger(\"newItemsCountChanged\", [i.newItemsCount,]), ((j ? i.afterSwitchingToAgain(k(i)) : i.afterFirstSwitchingTo(k(i)))), ((twttr.decider.isInfiniteScroll() && i.showLoadingSpinner())), ((((((this.preRendered && !i.preRendered)) && !twttr.app.fullyLoaded())) && signal(\"\\u003EwokeUp\"))), i;\n            },\n            setTitle: function(a) {\n                var b = this.titleContainer();\n                b.empty(), a._setTitle(twttr.bind(this, function(a) {\n                    if (!a) {\n                        return;\n                    }\n                ;\n                ;\n                    this.setTitleHTML(a);\n                }));\n            },\n            getMoreOldItems: function(a) {\n                ((this.getCurrent() && this.getCurrent().getMoreOldItems(a)));\n            },\n            resetCache: function() {\n                this.streams = {\n                }, this.setCurrent(null);\n            },\n            $headerContainer: function() {\n                return this.$page.JSBNG__find(\"div.js-stream-header\");\n            },\n            titleContainer: function() {\n                return ((twttr.isT1 ? this.$page.JSBNG__find(\".js-stream-title\") : this.$node.JSBNG__find(\"div.stream-title\")));\n            },\n            clearFromCache: function(a, b) {\n                b = ((b || {\n                }));\n                var c = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b);\n                this.clearKeyFromCache(c);\n            },\n            clearKeyFromCache: function(a) {\n                delete this.streams[a];\n            }\n        });\n        ((twttr.isT1 ? d.methods({\n            setHeader: function(a, b) {\n                if (a._setHeader) {\n                    var c = this;\n                    using(twttr.bundleMore, function() {\n                        a._setHeader(twttr.bind(c, function(d) {\n                            c.renderHeader(a, b, d);\n                        }), b);\n                    });\n                }\n                 else this.renderHeader(a, b, (new twttr.views.StreamHeader(b)).$html());\n            ;\n            ;\n            },\n            renderHeader: function(a, b, c) {\n                this.setHeaderHTML(c), this.setTitle(a), this.setViewToggler(a, b), this.setHeaderButton(a, b);\n            },\n            setHeaderHTML: function(a) {\n                this.$headerContainer().html(a);\n            },\n            setTitleHTML: function(a) {\n                var b = this.titleContainer();\n                ((b && b.html(a)));\n            },\n            setViewToggler: function(a, b) {\n                $viewTogglerContainer = this.$page.JSBNG__find(\"small.js-view-toggler\");\n                if (!$viewTogglerContainer) {\n                    return;\n                }\n            ;\n            ;\n                $viewTogglerContainer.empty(), ((a._setViewToggler && using(twttr.bundleMore, function() {\n                    a._setViewToggler(twttr.bind(this, function(a) {\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        a.render($viewTogglerContainer);\n                    }), b);\n                })));\n            },\n            setHeaderButton: function(a, b) {\n                $headerButtonContainer = this.$page.JSBNG__find(\"span.js-header-button-container\");\n                if (!$headerButtonContainer) {\n                    return;\n                }\n            ;\n            ;\n                $headerButtonContainer.empty(), ((a._setHeaderButton && using(twttr.bundleMore, function() {\n                    a._setHeaderButton(twttr.bind(this, function(a) {\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        a.render($headerButtonContainer);\n                    }), b);\n                })));\n            }\n        }) : d.methods({\n            setHeader: function(a, b) {\n                this.setTitle(a);\n            },\n            setTitleHTML: function(a) {\n                this.titleContainer().html(((((\"\\u003Ch2\\u003E\" + a)) + \"\\u003C/h2\\u003E\")));\n            },\n            setViewToggler: twttr.util.noopInP1,\n            setHeaderButton: twttr.util.noopInP1\n        }))), a(d);\n    });\n});\nprovide(\"view\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.augmentString(\"twttr.views\", {\n            makeDefaultViews: function(a) {\n                twttr.map(a, function(a, c) {\n                    var d = b.util.capitalize(b.util.camelize(c));\n                    twttr.views[d] = ((twttr.views[d] || twttr.view(((\"twttr.views.\" + d)))));\n                }), signal(\"\\u003EdefaultViews\");\n            }\n        }), twttr.view = function(a, b) {\n            ((b || (b = function() {\n                twttr.views.Base.apply(this, arguments);\n            }))), ((((twttr.development && twttr.at(a))) && JSBNG__console.error(\"twttr.view duplicate definition of:\", a)));\n            var c = twttr.klass(a, b);\n            return c.subclassOf(twttr.views.Base), c.template = function(a) {\n                return this._template = a, this;\n            }, twttr.view._setDefaultTemplate(c, a), c._partials = twttr.templates, c;\n        }, twttr.view._setDefaultTemplate = function(a, c) {\n            a.template(twttr.templates[b.util.underscore(c.split(\".\")[2]).toLowerCase()]);\n        }, twttr.klass(\"twttr.ViewStack\", function(a, b) {\n            this.$referenceNode = $(a), this.operation = ((b || \"append\")), this._cache = {\n            }, this._stack = [];\n        }).methods({\n            cached: function(a) {\n                return ((twttr.is.string(a) || (a = a.viewId))), twttr.is.def(this._cache[a]);\n            },\n            size: function() {\n                return this._stack.length;\n            },\n            contains: function(a) {\n                return twttr.is.inArray(a, this._stack);\n            },\n            remove: function(a) {\n                delete this._cache[a.viewId];\n            },\n            JSBNG__top: function(a) {\n                return this._stack[((((this._stack.length - 1)) - ((a || 0))))];\n            },\n            push: function(a) {\n                var b = this.JSBNG__top();\n                return ((((b && b._backLabel)) && (a._backLabel = b._backLabel, b.hide()))), ((this.cached(a) ? (a = this._cache[a.viewId], this._stack.push(a)) : (this._cache[a.viewId] = a, a._viewstack = this, this._stack.push(a), a.render(this.$referenceNode, this.operation)))), a.show(), a;\n            },\n            pop: function(a) {\n                var b = this._stack.pop(), c = this._stack[((this._stack.length - 1))];\n                return ((b && b.hide())), ((((c && !a)) && c.show())), ((b ? b : null));\n            },\n            reset: function(a) {\n                while (this.pop()) {\n                ;\n                };\n            ;\n                if (a) {\n                    return this.push(a);\n                }\n            ;\n            ;\n            }\n        }), a(twttr.view);\n    });\n});\nprovide(\"urlResolver\", function(a) {\n    using().as(function(b) {\n        twttr.augmentString(\"twttr.urlResolver\", function() {\n            var a = {\n            };\n            return {\n                expand: function(b, c) {\n                    var d, e = {\n                    }, f = [];\n                    if (((twttr.decider.isAvailable(\"phoenix_url_resolver\") && twttr.is.array(b)))) {\n                        for (var g = 0, i = b.length; ((g < i)); ++g) {\n                            var j = b[g];\n                            (((d = a[j]) ? e[j] = d : f.push(j)));\n                        };\n                    ;\n                        ((((f.length === 0)) ? c(e) : twttr.API.Urls.resolve(f, function(b) {\n                            $.each(b, function(b, c) {\n                                a[b] = e[b] = c;\n                            }), c(e);\n                        })));\n                    }\n                ;\n                ;\n                }\n            };\n        }()), a(twttr.urlResolver);\n    });\n});\nprovide(\"multiGlobals/core_views\", function(exports) {\n    using(\"util\").as(function(phx) {\n        var logContext = phx.util.params().log_context;\n        twttr.view(\"twttr.views.Base\", function(a, b) {\n            ((twttr.is.string(a) ? (this.viewId = a, this.obj = b) : (this.obj = a, this.viewId = null)));\n            var c = twttr.audit.currentPage();\n            ((c && (this[((((\"in_\" + c)) + \"_page\"))] = !0)));\n            var d = twttr.audit.currentAction();\n            ((d && (this.actionName = twttr.util.underscore(d), this[((((\"in_\" + this.actionName)) + \"_action\"))] = !0)));\n            if (!this.obj) {\n                return;\n            }\n        ;\n        ;\n            this.originalObject = this.obj, this.attach(this.obj);\n        }).statics({\n            formatDeciderMethodName: function(a) {\n                return twttr.util.underscore(((\"\" + a)).replace(/[^A-Z0-9]/gi, \"_\"));\n            },\n            _addBucketTestMethod: function(a, b, c) {\n                var d = ((((b + \"_\")) + this.formatDeciderMethodName(c)));\n                ((((c && !this.prototype[d])) && this.method(d, function() {\n                    return ((c == twttr.abdecider.choose(a)));\n                })));\n            },\n            addABTestMethods: function(a, b, c) {\n                var d = ((\"abtest_\" + this.formatDeciderMethodName(a)));\n                ((this.prototype[d] || this.method(d, function() {\n                    return !!twttr.abdecider.choose(a);\n                })));\n                var e = ((d + \"_any_bucket\"));\n                ((this.prototype[e] || this.method(e, function() {\n                    var b = twttr.abdecider.choose(a);\n                    return ((!!b && ((b != \"control\"))));\n                })));\n                if (c) {\n                    for (var f = 0; ((f < c.length)); f++) {\n                        this._addBucketTestMethod(a, d, c[f]);\n                    ;\n                    };\n                }\n                 else {\n                    this._addBucketTestMethod(a, d, b);\n                }\n            ;\n            ;\n            },\n            addDeciderMethod: function(a) {\n                this.method(((\"decider_\" + twttr.util.underscore(a))), function() {\n                    return twttr.decider.isAvailable(a);\n                });\n            },\n            JSBNG__onDeciderKeyChange: function(a, b) {\n                twttr.views.Base.addDeciderMethod(b.key);\n            },\n            JSBNG__onABTestKeyChange: function(a, b) {\n                ((b.current && twttr.views.Base.addABTestMethods(b.key, b.current.bucket, b.current.bucket_names)));\n            }\n        }).methods({\n            anatomy_world: function() {\n                return !1;\n            },\n            anatomy_world_with_expand: function() {\n                return !1;\n            },\n            change_german_verbs: function() {\n                return ((((((twttr.isT1 && twttr.currentUser)) && ((new JSBNG__Date(2012, 6, 3) < new JSBNG__Date(twttr.currentUser.createdAt))))) && ((twttr.abdecider.choose(\"change_deutsch_verbs_229\") === \"change_verbs\"))));\n            },\n            australian_fav_to_like: function() {\n                var a = ((((twttr.isT1 && twttr.currentUser)) && twttr.abdecider.chooseWithoutImpression(\"rename_favorite_australia_334\"))), b = ((((a === \"fav_to_like_australia\")) || ((((a === \"fav_to_like_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt)))))));\n                return ((((b || ((a === \"control\")))) && twttr.abdecider.choose(\"rename_favorite_australia_334\"))), b;\n            },\n            australian_fav_to_star: function() {\n                var a = ((((twttr.isT1 && twttr.currentUser)) && twttr.abdecider.chooseWithoutImpression(\"rename_favorite_australia_334\"))), b = ((((a === \"fav_to_star_australia\")) || ((((a === \"fav_to_star_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt)))))));\n                return ((((b || ((a === \"control\")))) && twttr.abdecider.choose(\"rename_favorite_australia_334\"))), b;\n            },\n            \"debugger\": function() {\n                return ((twttr.development && eval(\"debugger;\"))), \"\";\n            },\n            languages: function() {\n                return twttr.languages;\n            },\n            languages_by_own: function() {\n                return twttr.languages.sort(function(a, b) {\n                    var c = a.JSBNG__name.toLowerCase(), d = b.JSBNG__name.toLowerCase();\n                    return ((((c < d)) ? -1 : ((((c === d)) ? 0 : 1))));\n                });\n            },\n            coerce_native_media_to_cards: function() {\n                return twttr.decider.isAvailable(\"platform_coerce_native_media_to_cards\");\n            },\n            media_cards_enabled: function() {\n                return ((twttr.isT1 && twttr.decider.isAvailable(\"platform_enable_cards\")));\n            },\n            render: function(a, b) {\n                this.selector = a, this.operation = ((b || \"html\"));\n                try {\n                    this.$dom = $(this.html());\n                } catch (c) {\n                    if (((!c.message || ((c.message.indexOf(\"Syntax error, unrecognized expression\") != 0))))) {\n                        throw c;\n                    }\n                ;\n                ;\n                    this.$dom = $(\"\");\n                };\n            ;\n                return $(this.selector)[this.operation](this.$dom), this.afterRender(this.$dom), this.$dom;\n            },\n            attach: function(a) {\n                if (((twttr.API.Base && ((a instanceof twttr.API.Base))))) {\n                    throw new Error(((((\"You failed to subclass BaseAPI with this view (\" + this.constructor._name)) + \"), so we're about to clobber all your favorite properties.  Subclass twttr.views.BaseAPI!\")));\n                }\n            ;\n            ;\n                for (var b in a) {\n                    this[b] = a[b];\n                ;\n                };\n            ;\n            },\n            hide: function() {\n                this.$dom.hide(), this.$dom.addClass(\"inactive\").removeClass(\"active\");\n            },\n            show: function() {\n                this.$dom.show(), this.$dom.addClass(\"active\").removeClass(\"inactive\");\n            },\n            refresh: function() {\n                this.$dom = $(this.html(!0)), $(this.selector)[this.operation](this.$dom);\n            },\n            html: function(a) {\n                if (((!a && this._html))) {\n                    return this._html;\n                }\n            ;\n            ;\n                if (!twttr.is.def(this.constructor._template)) {\n                    return JSBNG__console.log(\"Missing template file: \", this, this.constructor._name), \"\";\n                }\n            ;\n            ;\n                if (((((logContext == \"\")) || ((logContext == this.constructor._name))))) {\n                    try {\n                        var b = JSON.stringify(this.obj, null, 2);\n                    } catch (c) {\n                        var b = c.toString();\n                    };\n                ;\n                    JSBNG__console.log(\"View inputs to\", ((this.constructor._name + \":\")), {\n                        originalObject: this,\n                        stringified: b\n                    });\n                }\n            ;\n            ;\n                var d = [this.constructor._template,this,];\n                ((this.constructor._partials && d.push(this.constructor._partials)));\n                try {\n                    this._html = Mustache.to_html.apply(Mustache, d);\n                } catch (c) {\n                    if (c.message) {\n                        throw ((twttr.development && JSBNG__console.error(((\"Error rendering \" + this.constructor._name)), c.message))), c;\n                    }\n                ;\n                ;\n                };\n            ;\n                return this.afterHtml(this._html), this._html;\n            },\n            $html: function(a) {\n                return $(this.html());\n            },\n            rendering_on_server: !1,\n            swift: !1,\n            afterHtml: function(a) {\n            \n            },\n            afterRender: function(a) {\n            \n            },\n            subview: function(a, b) {\n                return this[a] = b, this;\n            },\n            logged_in: function() {\n                return !!twttr.currentUser;\n            },\n            is_ssl: function() {\n                return ((twttr.proto == \"https\"));\n            },\n            is_mobile: function() {\n                return !!twttr.isMobile;\n            },\n            t1_actions_eligible: function() {\n                return twttr.t1_actions_eligible;\n            },\n            form_authenticity_token: function() {\n                return twttr.anywhere.api.config.postAuthenticityToken;\n            },\n            plural_rules: {\n                r0: function() {\n                    return \"other\";\n                },\n                r1: function(a) {\n                    return ((((a === 1)) ? \"JSBNG__one\" : \"other\"));\n                },\n                r2: function(a) {\n                    return ((((a <= 1)) ? \"JSBNG__one\" : \"other\"));\n                },\n                r3: function(a) {\n                    if (((parseInt(a) === a))) {\n                        switch (((a % 10))) {\n                          case 1:\n                            if (((a === 11))) {\n                                break;\n                            }\n                        ;\n                        ;\n                            return \"JSBNG__one\";\n                          case 2:\n                        \n                          case 3:\n                        \n                          case 4:\n                            if (((((a >= 12)) && ((a <= 14))))) {\n                                break;\n                            }\n                        ;\n                        ;\n                            return \"few\";\n                        };\n                    ;\n                        return \"many\";\n                    }\n                ;\n                ;\n                    return \"other\";\n                },\n                r4: function(a) {\n                    switch (a) {\n                      case 0:\n                        return \"zero\";\n                      case 1:\n                        return \"JSBNG__one\";\n                      case 2:\n                        return \"two\";\n                      default:\n                        var b = ((a % 100));\n                        return ((((b >= 11)) ? \"many\" : ((((((b >= 3)) && ((b <= 10)))) ? \"few\" : \"other\"))));\n                    };\n                ;\n                }\n            },\n            lang_to_rule: {\n                ar: \"r4\",\n                da: \"r1\",\n                de: \"r1\",\n                en: \"r1\",\n                es: \"r1\",\n                fa: \"r0\",\n                fil: \"r2\",\n                fr: \"r2\",\n                he: \"r1\",\n                hi: \"r2\",\n                hu: \"r0\",\n                id: \"r0\",\n                it: \"r1\",\n                ja: \"r0\",\n                ko: \"r0\",\n                msa: \"r0\",\n                nl: \"r1\",\n                pt: \"r1\",\n                ru: \"r3\",\n                sv: \"r1\",\n                tr: \"r0\",\n                ur: \"r1\",\n                \"zh-cn\": \"r0\",\n                \"zh-tw\": \"r0\"\n            },\n            lookup_missing_property: function(a, b) {\n                var c = a.lastIndexOf(\"_\");\n                if (((c !== -1))) {\n                    var d = a.substring(((c + 1)));\n                    switch (d) {\n                      case \"zero\":\n                    \n                      case \"JSBNG__one\":\n                    \n                      case \"two\":\n                    \n                      case \"few\":\n                    \n                      case \"many\":\n                    \n                      case \"other\":\n                        var e = a.substring(0, c);\n                        if (((e in b))) {\n                            function f(a) {\n                                return ((((a || ((a === !1)))) || ((a === 0))));\n                            };\n                        ;\n                            var g = this.plural_rules[((this.lang_to_rule[twttr.pageLocale] || \"r0\"))];\n                            function i() {\n                                var a;\n                                return ((f(this[e]) && (a = this[e]))), ((((typeof a == \"function\")) && (a = a.apply(this)))), ((d === g(a)));\n                            };\n                        ;\n                            var j = null;\n                            ((Object.getPrototypeOf ? j = Object.getPrototypeOf(b) : ((b.__proto__ && (j = b.__proto__)))));\n                            if (((!j || ((j === Object.prototype))))) {\n                                j = b;\n                            }\n                        ;\n                        ;\n                            return j[a] = i, i.apply(b);\n                        }\n                    ;\n                    ;\n                        break;\n                      default:\n                    \n                    };\n                ;\n                }\n            ;\n            ;\n                return undefined;\n            },\n            render_page_content: !0\n        }), function() {\n            for (var a in twttr.decider.features()) {\n                twttr.views.Base.addDeciderMethod(a);\n            ;\n            };\n        ;\n            var b = twttr.abdecider.experiments();\n            for (var c in b) {\n                var d = b[c];\n                ((((d && d.bucket)) && twttr.views.Base.addABTestMethods(c, d.bucket, d.bucket_names)));\n            };\n        ;\n        }(), twttr.decider.bind(\"keyChanged\", twttr.views.Base.JSBNG__onDeciderKeyChange), twttr.abdecider.bind(\"keyChanged\", twttr.views.Base.JSBNG__onABTestKeyChange), twttr.view(\"twttr.views.BaseAPI\").methods({\n            attach: function(a) {\n                var b = ((a.attributes || a));\n                for (var c in b) {\n                    this[c] = b[c];\n                ;\n                };\n            ;\n            }\n        }), twttr.view(\"twttr.views.UserLink\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.BaseTweet\", function() {\n            twttr.views.BaseAPI.apply(this, arguments), this.user = new twttr.views.BaseUser({\n                attributes: this.user\n            });\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.userActionable).methods({\n            impression_cookie: function() {\n                if (!this.impression_id) {\n                    return;\n                }\n            ;\n            ;\n                var a = [];\n                return JSON.stringify([this.id,this.impression_id,this.disclosure_type,this.disclosure_text,a,]);\n            },\n            full_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp(), !0);\n            },\n            short_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp());\n            },\n            explicit_timestamp: function() {\n                return twttr.helpers.prettyTime(this.actual_timestamp());\n            },\n            actual_timestamp: function() {\n                return twttr.helpers.parseDateString(this.created_at);\n            },\n            linkified_text: function() {\n                if (!this.text) {\n                    return \"\";\n                }\n            ;\n            ;\n                var a = this.text;\n                return ((((this.is_withheld() && this.is_current_user())) && (a = this.withheld_text))), a = twttr.util.linkify(a, {\n                    nofollow: !0\n                }), a = twttr.util.linkifyEntities(a, this), ((this.render_withheld() && ((this.is_withheld_copyright() ? a += ((((((((\"  \\u003Ca href=\\\"\" + twttr.router.withheldCopyrightHelpPath())) + \"\\\" target=\\\"_blank\\\"\\u003E\")) + _(\"Learn more\"))) + \"\\u003C/a\\u003E\")) : a += ((((((((\"  \\u003Ca href=\\\"\" + twttr.router.withheldHelpPath())) + \"\\\" target=\\\"_blank\\\"\\u003E\")) + _(\"Learn more\"))) + \"\\u003C/a\\u003E\")))))), ((this.query ? twttr.util.queryHighlight(this.query, a) : a));\n            },\n            is_withheld: function() {\n                return ((this.is_tweet_withheld() || this.is_user_withheld()));\n            },\n            is_tweet_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"JSBNG__status\"))));\n            },\n            is_user_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\"))));\n            },\n            is_withheld_copyright: function() {\n                return ((this.is_tweet_withheld_copyright() || this.is_user_withheld_copyright()));\n            },\n            is_tweet_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"JSBNG__status\")))) && !!this.withheld_copyright));\n            },\n            is_user_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\")))) && !!this.withheld_copyright));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            is_current_user_withheld: function() {\n                return ((this.is_withheld() && this.is_current_user()));\n            },\n            render_withheld: function() {\n                return ((this.is_withheld() && !this.is_current_user()));\n            },\n            is_top_tweet: function() {\n                return ((this.result_category === \"popular\"));\n            },\n            is_sponsored: function() {\n                return !!this.impression_id;\n            },\n            tweet_impression_id: function() {\n                return ((this.impression_id ? Mustache.to_html(\"data-impression-id=\\\"{{id}}\\\" \", {\n                    id: this.impression_id\n                }) : \"\"));\n            },\n            promoted_badge_class: function() {\n                return ((\"badge-\" + ((this.disclosure_type || \"promoted\"))));\n            },\n            social_context: function() {\n                if (((this.socialContext && this.socialContext.length))) {\n                    this.user.socialContext = this.socialContext, this.user.screenName = this.user.screen_name;\n                    var a = this.makeSocialContextHtml(this.user, !1);\n                    return _(\"\\u003Cspan class=\\\"icon-link social-context\\\"\\u003E{{{social_context}}}\\u003C/span\\u003E\", {\n                        social_context: a\n                    });\n                }\n            ;\n            ;\n                return \"\";\n            },\n            has_native_media: function() {\n                return twttr.Cards.prototype.hasCardPhotoEntities(this);\n            },\n            has_visible_cards: function() {\n                return twttr.Cards.prototype.hasCards(this);\n            },\n            advertiser_name: function() {\n                return ((this.was_retweeted ? this.retweeting_status.user.JSBNG__name : this.user.JSBNG__name));\n            },\n            allowed_to_retweet: function() {\n                return ((!this.user[\"protected\"] && !twttr.helpers.isCurrentUser(this.user)));\n            },\n            retweet_count_text: function() {\n                var a = this.retweet_count;\n                return ((((a === 1)) ? _(\"{{retweet_count}} Retweet\", {\n                    retweet_count: a\n                }) : _(\"{{retweet_count}} Retweets\", {\n                    retweet_count: twttr.util.formatNumber(a, twttr.pageLocale)\n                })));\n            },\n            activity_count: function(a) {\n                var b = ((((this.activities && this.activities[a])) && ((this.activities[a] !== \"0\"))));\n                return ((b ? ((((\"(\" + this.activities[a])) + \")\")) : \"\"));\n            },\n            favoriter_count: function() {\n                return this.activity_count(\"favoriters_count\");\n            },\n            retweeter_count: function() {\n                return this.activity_count(\"retweeters_count\");\n            },\n            has_retweet_count: function() {\n                return ((this.retweet_count > 0));\n            },\n            replier_count: function() {\n                return this.activity_count(\"repliers_count\");\n            },\n            is_retweeted_by_current_user: function() {\n                return !!this.current_user_retweet;\n            },\n            is_my_tweet: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            show_trashcan: function() {\n                return ((twttr.helpers.isCurrentUser(this.user) || ((twttr.admin && twttr.admin.showTrashcan()))));\n            },\n            show_not_relevant_action: function() {\n                return ((twttr.decider.isAvailable(\"phoenix_search_relevance_not_relevant_action\") && ((this.result_category === \"relevance\"))));\n            },\n            contributor: function() {\n                return ((this.contributors ? this.contributors[0] : null));\n            },\n            can_view: function() {\n                return this.user.can_view();\n            },\n            retweet_source_screen_name_link: function() {\n                if (this.retweeting_status) {\n                    var a = this.retweeting_status.text.match(/^RT @?([0-9A-Za-z_]*):/).pop();\n                    return Mustache.to_html(\"\\u003Ca href='{{path}}' class='latest-status-retweeted-user'\\u003E{{screen_name}}\\u003C/a\\u003E\", {\n                        path: twttr.router.profilePath({\n                            screen_name: a\n                        }),\n                        screen_name: a\n                    });\n                }\n            ;\n            ;\n            },\n            css_classes: function() {\n                var a = \"\";\n                return $.each({\n                    is_top_tweet: \"top-tweet\",\n                    is_sponsored: \"promoted-tweet\",\n                    current_user_retweet: \"retweeted\",\n                    favorited: \"favorited\"\n                }, twttr.bind(this, function(b, c) {\n                    if (((twttr.is.fn(this[b]) ? this[b]() : this[b]))) {\n                        a += ((c + \" \"));\n                    }\n                ;\n                ;\n                })), a;\n            },\n            permalink_path: function() {\n                return twttr.router.permalinkPath({\n                    screen_name: this.user.screen_name,\n                    id: this.id\n                });\n            },\n            embed_dialog_permalink_path: function() {\n                return twttr.router.embedDialogPermalinkPath({\n                    screen_name: this.user.screen_name,\n                    id: this.id\n                });\n            },\n            place_path: function() {\n                return twttr.router.placePath({\n                    place_id: this.place.id\n                });\n            },\n            truncated_text: function() {\n                return twttr.helpers.truncate(this.text, 50);\n            },\n            can_expand: function() {\n                return twttr.decider.isExpando();\n            },\n            in_reply_to_path: function() {\n                return twttr.router.permalinkPath({\n                    screen_name: this.in_reply_to_screen_name,\n                    id: this.in_reply_to_status_id\n                });\n            },\n            in_reply_to_name: function() {\n                var a = this.in_reply_to_screen_name, b = ((this.entities && this.entities.user_mentions));\n                if (b) {\n                    for (var c = 0, d = b.length; ((c < d)); c++) {\n                        if (((b[c].screen_name === a))) {\n                            return b[c].JSBNG__name;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((\"@\" + a));\n            }\n        }), twttr.view(\"twttr.views.BaseUser\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.i18nTweet).methods({\n            defaultAvatarRegEx: /default_profile_\\d/,\n            defaultAvatar: function(a) {\n                return ((((this.profile_image_url.match(this.defaultAvatarRegEx) && this.is_current_user())) ? ((a ? twttr.assets.path(\"/images/default_profile_add_photo.png\") : twttr.router.settingsProfilePath())) : !1));\n            },\n            raw_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url)));\n            },\n            bigger_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"bigger\")));\n            },\n            mini_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"mini\")));\n            },\n            reasonably_small_profile_image_url: function() {\n                return ((this.defaultAvatar(!0) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"reasonably_small\")));\n            },\n            right_image_size: function() {\n                return twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"bigger\");\n            },\n            account_profile_image_path: function() {\n                return ((\"/account/profile_image/\" + this.screen_name));\n            },\n            description_is_rtl: function() {\n                if (!this.description) {\n                    return !1;\n                }\n            ;\n            ;\n                var a = this.getMachedRtlChars(this.description);\n                return ((a && this.shouldBeRTL(this.description, a)));\n            },\n            linkified_description: function() {\n                var a = this.description;\n                ((((this.is_withheld() && this.is_current_user())) && (a = this.withheld_description)));\n                if (!a) {\n                    return \"\";\n                }\n            ;\n            ;\n                var b = twttr.util.linkifyEntities(twttr.util.linkify(a, {\n                    nofollow: !0\n                }), this);\n                return ((this.query ? twttr.util.queryHighlight(this.query, b) : b));\n            },\n            display_url_or_url: function() {\n                return ((this.url ? twttr.txt.htmlEscape(((this.display_url || this.url))) : \"\"));\n            },\n            is_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\"))));\n            },\n            is_current_user_withheld: function() {\n                return ((this.is_withheld() && this.is_current_user()));\n            },\n            is_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\")))) && !!this.withheld_copyright));\n            },\n            is_current_user_withheld_copyright: function() {\n                return ((this.is_withheld_copyright() && this.is_current_user()));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(this.id);\n            },\n            can_view: function() {\n                return twttr.helpers.canViewUser(this);\n            },\n            is_sponsored: function() {\n                return !!this.promoted_content;\n            },\n            promoted_badge_class: function() {\n                return ((\"badge-\" + ((this.promoted_content.disclosure_type || \"promoted\"))));\n            },\n            translation_tool_path: function() {\n                return ((twttr.decider.isAvailable(\"i18n_new_translation_center\") ? \"http://translate.twttr.com\" : this.translate_path()));\n            },\n            account_impression_id: function() {\n                var a = this.promoted_content;\n                return ((a ? Mustache.to_html(\"data-impression-id='{{id}}' \", {\n                    id: a.impression_id\n                }) : \"\"));\n            },\n            feedback_token: function() {\n                return ((this.feedback ? Mustache.to_html(\"data-feedback-token='{{feedback}}' \", {\n                    feedback: this.feedback\n                }) : \"\"));\n            },\n            mini_profile_image_url: function() {\n                return twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"mini\");\n            }\n        }), twttr.view(\"twttr.views.StreamTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).mixin(twttr.mixins.serverRenderableObject).methods({\n            wakeUp: function() {\n                this.initDomNode();\n                var a = this.$node.children().remove();\n                this.$node.html(twttr.views.BaseTweet.prototype.html.call(this, !0)), ((this.render_withheld() && this.$node.addClass(\"withheld-item\")));\n                var b = $(\"\\u003Cdiv style=\\\"display:none;\\\" class=\\\"js-old-content\\\" /\\u003E\").append(a);\n                this.$node.append(b);\n                var c = b[0];\n                using(\"\\u003EactionQueueEmpty\", function() {\n                    c.parentNode.removeChild(c);\n                });\n            },\n            initDomNode: function() {\n                if (this.$node) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                this.$node = this.$domNode(function() {\n                    return twttr.views.BaseTweet.prototype.html.apply(a, arguments);\n                });\n            },\n            html: function(a) {\n                return ((a && (this.$node = null))), this.initDomNode(), ((this.preRendered ? this.$node.html() : twttr.views.Base.prototype.html.apply(this, arguments)));\n            },\n            domNodeSelector: function() {\n                var a = this.id;\n                return ((this.impression_id && (a += \"-promoted\"))), ((\"#stream-item-tweet-\" + a));\n            }\n        }), twttr.view(\"twttr.views.TweetActions\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.TweetDogear\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.DetailsPane\").methods({\n            closable: !0,\n            back_label: function() {\n                return this._backLabel;\n            },\n            popable: function() {\n                return ((this._viewstack && ((this._viewstack.size() > 1))));\n            },\n            hide: function() {\n                this.$dom.addClass(\"inactive\").removeClass(\"active\"), this.$dom.JSBNG__find(\"div.tweet-media\").trigger(\"hideMedia\"), this.$dom = this.$dom.detach();\n            },\n            show: function() {\n                $(this.selector)[this.operation](this.$dom), this.$dom.JSBNG__find(\"div.tweet-media\").trigger(\"showMedia\"), this.$dom.addClass(\"active\").removeClass(\"inactive\");\n            }\n        }), twttr.view(\"twttr.views.MessageDrawer\").statics({\n            isOpen: !1,\n            close: function() {\n                twttr.views.MessageDrawer.isOpen = !1, $(\"#message-drawer .message\").remove();\n            }\n        }), twttr.view(\"twttr.views.UserCss\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n            var a = [\"profile_background_color\",\"profile_text_color\",\"profile_link_color\",\"profile_sidebar_fill_color\",];\n            for (var b = 0; ((b < a.length)); b++) {\n                this[a[b]] = twttr.helpers.sanitizeCssColor(this[a[b]]);\n            ;\n            };\n        ;\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            rgba_sidebar_color: function() {\n                if (!this.profile_sidebar_fill_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_sidebar_fill_color, \"0.9\");\n            },\n            rgba_tweet_background_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.1\");\n            },\n            rgba_tweet_border_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.15\");\n            },\n            rgba_newtweets_background_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.2\");\n            },\n            rgba_newtweets_border_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.25\");\n            },\n            rgba_text_color: function() {\n                if (!this.profile_text_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_text_color, \"0.6\");\n            },\n            profile_pretty_link_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.blendHexColor(this.profile_link_color, \"FFF\", 535648);\n            },\n            profile_pretty_link_sidebar_color: function() {\n                if (((!this.profile_link_color || !this.profile_sidebar_fill_color))) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.blendHexColor(this.profile_link_color, this.profile_sidebar_fill_color, 535858);\n            }\n        }), twttr.view(\"twttr.views.UserCssP1\", function() {\n            twttr.views.UserCss.apply(this, arguments);\n        }).subclassOf(twttr.views.UserCss), twttr.view(\"twttr.views.UserCssT1\", function(a) {\n            twttr.inputUser = a, twttr.views.UserCss.apply(this, arguments);\n        }).subclassOf(twttr.views.UserCss).methods({\n            style_namespace: function() {\n                return ((this.screen_name ? this.screen_name : \"twttr\"));\n            },\n            has_hovers_in_css: function() {\n                return !!twttr.hasHoversInCss;\n            },\n            colon_hover: function() {\n                return ((twttr.hasHoversInCss ? \":hover\" : \"\"));\n            }\n        }), twttr.view(\"twttr.views.BgImgCss\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.BaseStats\", function(a) {\n            twttr.views.BaseUser.apply(this, arguments), ((a.JSBNG__status && (this.JSBNG__status = new twttr.views.BaseTweet(a.JSBNG__status), this.JSBNG__status.user = this)));\n        }).subclassOf(twttr.views.BaseUser).methods({\n            statuses_count_commaized: function() {\n                return phx.util.formatNumber(this.statuses_count, twttr.pageLocale);\n            },\n            following_nobody: function(a) {\n                return ((this.friends_count === 0));\n            },\n            friends_count_commaized: function() {\n                return ((((this.screen_name === \"toptweets\")) ? _(\"everyone!\") : phx.util.formatNumber(this.friends_count, twttr.pageLocale)));\n            },\n            followers_count_commaized: function() {\n                return phx.util.formatNumber(this.followers_count, twttr.pageLocale);\n            },\n            favorites_count_commaized: function() {\n                return ((((this.favourites_count && ((parseInt(this.favourites_count, 10) > 0)))) ? phx.util.formatNumber(this.favourites_count, twttr.pageLocale) : 0));\n            },\n            listed_count_commaized: function() {\n                return ((((this.listed_count && ((parseInt(this.listed_count, 10) > 0)))) ? phx.util.formatNumber(this.listed_count, twttr.pageLocale) : 0));\n            },\n            can_view: function() {\n                return twttr.helpers.canViewUser(this);\n            },\n            source_impression_id: function() {\n                var a = this.impression_id;\n                return ((a ? Mustache.to_html(\"data-impression-id=\\\"{{id}}\\\" \", {\n                    id: a\n                }) : \"\"));\n            },\n            translator_profile_path: function() {\n                return ((twttr.decider.isAvailable(\"i18n_new_translation_center\") ? ((((this.translation_tool_path() + \"/user/\")) + this.screen_name)) : this.translation_tool_path()));\n            }\n        }), twttr.view(\"twttr.views.MessageNotification\").statics({\n            isOpen: !1,\n            close: function() {\n                twttr.views.MessageNotification.isOpen = !1, $(\"#message-notification .notification\").remove();\n            }\n        }), twttr.view(\"twttr.views.StreamActivity\").statics({\n            maxItems: 2,\n            sentences: {\n                favorites: [_(\"Favorited by {{{screen_name_0}}}\"),_(\"Favorited by {{{screen_name_0}}} and {{{screen_name_1}}}\"),],\n                retweets: [_(\"Retweeted by {{{screen_name_0}}}\"),_(\"Retweeted by {{{screen_name_0}}} and {{{screen_name_1}}}\"),]\n            }\n        }).methods({\n            sentence: function() {\n                var a = this.constructor.sentences[this.item_type], b = this.items.slice(0, this.constructor.maxItems);\n                return ((((!b.length || !a)) ? \"\" : Mustache.to_html(a[((b.length - 1))], twttr.inject(b, {\n                }, function(a, b, c) {\n                    return a[((\"screen_name_\" + b))] = (new twttr.views.UserLink(c.attributes)).html(), a;\n                }))));\n            }\n        }), exports();\n    });\n});\nprovide(\"multiGlobals/core_views_t1\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.view(\"twttr.views.StreamTweeter\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), a();\n    });\n});\nprovide(\"router_t1\", function(a) {\n    using(\"util\", \"\\u003EdeciderFeaturesFromBootstrap\").as(function(b) {\n        function c(a) {\n            function b(b) {\n                var d = twttr.app.switchToPage(a);\n                ((((d && c)) && d.send(c, Array.prototype.slice.apply(arguments))));\n            };\n        ;\n            var c;\n            return b.action = function(a) {\n                return this.actionName = c = a, b;\n            }, b.pageName = a, b;\n        };\n    ;\n        function d(a, b, c) {\n            m(((\"hashbang\" + twttr.util.capitalize(a))), ((\"/#!\" + b)), function() {\n                twttr.themes.loadLoadingTheme(), twttr.Router.performRedirect(((c || b)));\n            });\n        };\n    ;\n        function e(a, b) {\n            d(a, b), m(a, b, $.noop);\n        };\n    ;\n        function f(a, b) {\n            var c = ((((twttr.isLocalhost ? \"\" : ((\"https://\" + JSBNG__location.hostname)))) + b));\n            d(a, b, c), n(a, c);\n        };\n    ;\n        function g(a, b, c, d, e) {\n            var f = ((i(d) ? e : b));\n            twttr.router.swiftRoutes[a] = {\n                decider: d,\n                path: e\n            }, m(a, f, c);\n        };\n    ;\n        function i(a) {\n            var b = twttr.util.params(window.JSBNG__location.search);\n            return ((twttr.is.def(b.render_on_server) ? ((((b[\"render_on_server\"] == \"1\")) || ((b[\"render_on_server\"] == \"true\")))) : twttr.decider.isAvailable(a)));\n        };\n    ;\n        function j(a) {\n            return ((twttr.loggedIn ? a.loggedIn : ((a.loggedOut || k()))));\n        };\n    ;\n        function k() {\n            return ((twttr.ScribeBuffer && twttr.ScribeBuffer.instance.send())), c(\"Login\").action(\"loginRequired\");\n        };\n    ;\n        function l() {\n            var a = twttr.router.shouldRedirectToCanonicalUrl(twttr.router.getCurrentRoute());\n            if (a) {\n                return twttr.router.routingEnabled = !1, window.JSBNG__location.replace(a), !0;\n            }\n        ;\n        ;\n        };\n    ;\n        twttr.router = new twttr.Router;\n        var m = twttr.bind(twttr.router, twttr.router.route), n = twttr.bind(twttr.router, twttr.router.staticRoute), o = twttr.bind(twttr.router, twttr.router.redirectRoute);\n        twttr.router.bind(\"routeAdded\", function(a, c, d) {\n            twttr.views.Base.method(b.util.underscore(c), function() {\n                return d(this);\n            });\n        }), e(\"about\", \"/about\"), e(\"jobs\", \"/jobs\"), e(\"tos\", \"/tos\"), e(\"privacy\", \"/privacy\"), e(\"deactivated\", \"/account/deactivated\"), e(\"deactivate\", \"/account/deactivate\"), e(\"suspendedHelp\", \"/account/suspended_help\"), e(\"suspended\", \"/suspended\"), e(\"settings\", \"/settings/account\"), e(\"design\", \"/settings/design\"), e(\"settingsProfile\", \"/settings/profile\"), e(\"devices\", \"/devices\"), e(\"invitationEmailPreview\", \"/invitations/email_preview\"), e(\"campaigns\", \"/account/campaigns\"), e(\"resources\", \"/about/resources\"), e(\"translate\", \"/translate\"), e(\"whatsNew\", \"/newtwitter\"), e(\"changeLocale\", \"/sessions/change_locale\"), e(\"resendPassword\", \"/account/resend_password\"), e(\"mobileComplete\", \"/account/complete\"), e(\"turnPhxOff\", \"/account/use_phx?setting=false&format=html\"), e(\"mobileGallery\", \"/download\"), o(\"terms\", \"/#!/terms\", \"tos\"), o(\"admin\", \"/#!/admin\", \"JSBNG__home\"), f(\"sessions\", \"/sessions?phx=1\"), f(\"signup\", \"/signup\"), g(\"login\", \"/#!/login\", c(\"login\").action(\"index\"), \"swift_login\", \"/login\"), g(\"sessionsNew\", \"/#!/sessions/new\", c(\"login\").action(\"index\"), \"swift_login\", \"/sessions/new\"), g(\"loginRedirect\", \"/#!/login/redirect/:redirect_after_login\", c(\"login\").action(\"index\"), \"swift_login\", \"/login?redirect_after_login=:redirect_after_login\"), g(\"loginError\", \"/#!/login/:error\", c(\"login\").action(\"error\"), \"swift_login\", \"/login/:error\"), m(\"logout\", \"/#!/logout\", c(\"logout\").action(\"index\")), e(\"logout_action\", \"/logout\"), n(\"support\", \"//support.twitter.com\"), n(\"blog\", twttr.localize({\n            ja: \"http://blog.jp.twitter.com\",\n            es: \"http://blog.es.twitter.com\",\n            fr: \"http://blog.fr.twitter.com\",\n            de: \"http://blog.de.twitter.com\",\n            pt: \"http://blog.pt.twitter.com\",\n            ko: \"http://blog.kr.twitter.com\",\n            it: \"http://blog.it.twitter.com\",\n            ru: \"http://blog.ru.twitter.com\"\n        }, \"http://blog.twitter.com\")), n(\"JSBNG__status\", twttr.localize({\n            ja: \"http://status.twitter.jp\"\n        }, \"http://status.twitter.com\")), n(\"developers\", \"//dev.twitter.com\"), n(\"businesses\", ((((\"//business.twitter.com/index_\" + twttr.pageLocale)) + \".html\"))), n(\"advertisers\", ((((\"//business.twitter.com/\" + twttr.pageLocale)) + \"/advertise/start\"))), n(\"partnerships\", \"http://media.twitter.com\"), n(\"helpPromotedTweets\", \"//support.twitter.com/articles/142101\"), n(\"helpPromotedAccounts\", \"//support.twitter.com/articles/282154\"), n(\"helpPromotedTrends\", \"//support.twitter.com/articles/282142\"), n(\"spamLearnMore\", \"//support.twitter.com/articles/64986-how-to-report-spam-on-twitter\"), n(\"malwareLearnMore\", \"//support.twitter.com/articles/90491-my-website-is-being-flagged-as-malware-or-spam\"), n(\"suspendedLearnMore\", \"//support.twitter.com/articles/15790-my-account-is-suspended\"), n(\"dailyLimitLearnMore\", \"//support.twitter.com/articles/15364-about-twitter-limits-update-api-dm-and-following\"), n(\"savedSearchesHelp\", \"//support.twitter.com/articles/96646-how-to-save-searches\"), n(\"listsHelp\", \"//support.twitter.com/articles/76460-how-to-use-twitter-lists\"), n(\"emailHelp\", \"//support.twitter.com/articles/82050-i-m-having-trouble-confirming-my-email\"), n(\"changeEmail\", \"//twitter.com/settings/account?change_email=true\"), n(\"mobile\", \"//mobile.twitter.com\"), n(\"mobileHelp\", \"//support.twitter.com/groups/34-mobile\"), n(\"mobileHelpFaq\", \"//support.twitter.com/groups/34-mobile/topics/123-getting-started/articles/14014-twitter-phone-faqs\"), n(\"shortCodeHelp\", \"//support.twitter.com/articles/14226-how-to-find-your-twitter-short-code\"), n(\"smsHelp\", \"//support.twitter.com/articles/14020-about-twitter-sms-commands\"), n(\"pushHelp\", \"//support.twitter.com/articles/20169887\"), n(\"helpDiscovery\", \"//support.twitter.com/articles/14022\"), n(\"analytics\", \"//analytics.twitter.com/\"), n(\"turkeySupport\", \"https://support.twitter.com/articles/20156423\"), n(\"flagTurkeySupport\", \"https://support.twitter.com/articles/20069937\"), n(\"twirefoxSupport\", \"https://support.twitter.com/articles/20167003-about-firefox-with-twitter\"), n(\"tweetIntent\", \"https://twitter.com/share\"), n(\"withheldCopyrightHelp\", \"https://support.twitter.com/articles/15795\"), n(\"withheldHelp\", \"https://support.twitter.com/articles/20169222\"), n(\"followLimitReachedLearnMore\", \"https://support.twitter.com/articles/66885\"), n(\"blockedFromFollowingLearnMore\", \"https://support.twitter.com/articles/117063\"), n(\"listNameErrorLearnMore\", \"https://support.twitter.com/articles/20169276\"), n(\"cookiePersonalizationLearnMore\", \"https://support.twitter.com/articles/20169421\"), n(\"embedDocumentation\", \"//dev.twitter.com/docs/embedded-tweets\"), n(\"directMessageLearnMore\", \"http://support.twitter.com/groups/31-twitter-basics/topics/109-tweets-messages/articles/14606-what-is-a-direct-message-dm\"), g(\"JSBNG__home\", \"/#!/\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"JSBNG__home\"),\n            loggedOut: c(\"front\").action(\"index\")\n        }), \"swift_home_timeline\", \"/\"), g(\"homeIndex\", \"/#!/\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"JSBNG__home\"),\n            loggedOut: c(\"front\").action(\"index\")\n        }), \"swift_home_timeline\", \"/\"), m(\"savedSearches\", \"/#!/saved-search\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"savedSearches\")\n        })), g(\"listsFollowingYou\", \"/#!/lists/memberships\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"memberships\")\n        }), \"swift_lists\", \"/lists/memberships\"), g(\"listsYouFollow\", \"/#!/lists/subscriptions\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"subscriptions\")\n        }), \"swift_lists\", \"/lists/subscriptions\"), m(\"messages\", \"/#!/messages\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"messageCreate\", \"/#!/messages/create/:screen_name\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"inbox\", \"/#!/inbox\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"sent\", \"/#!/sent\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"createDm\", \"/#!/direct_messages/create/:screen_name\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        }));\n        if (((twttr.griffin && twttr.griffin.current))) {\n            for (var p = 0; ((p < twttr.griffin.current.length)); p++) {\n                var q = twttr.griffin.current[p];\n                e(((q + \"Static\")), ((\"/hashtag/\" + q))), o(q, ((\"/#\" + q)), ((q + \"Static\")));\n            };\n        ;\n            m(\"searchNoReroute\", \"/#!/search/:query/show\", c(\"search\").action(\"searchShow\")), m(\"eventsGrid\", \"/#!/hashtag/:query/grid/:mode\", c(\"eventsMediaGallery\").action(\"grid\")), m(\"eventsSlideshow\", \"/#!/hashtag/:query/slideshow/:mode\", c(\"eventsMediaGallery\").action(\"slideshow\"));\n        }\n    ;\n    ;\n        o(\"retweetsByOthers\", \"/#!/retweets_by_others\", \"connect\"), o(\"retweetsOfMine\", \"/#!/retweeted_of_mine\", \"connect\"), m(\"rateLimit\", \"/#!/twttr/rate_limit\", c(\"rateLimit\").action(\"tooMuch\")), g(\"discover\", \"/#!/i/discover\", j({\n            loggedIn: c(\"discover\").action(\"discover\")\n        }), \"swift_discover\", \"/i/discover\"), m(\"networkActivity\", \"/#!/activity\", j({\n            loggedIn: c(\"discover\").action(\"networkActivity\")\n        })), m(\"whoToFollow\", \"/#!/who_to_follow\", j({\n            loggedIn: c(\"discover\").action(\"suggestions\")\n        })), m(\"whoToFollowSuggestions\", \"/#!/who_to_follow/suggestions\", j({\n            loggedIn: c(\"discover\").action(\"suggestions\")\n        })), m(\"whoToFollowSuggestionsSearch\", \"/#!/who_to_follow/suggestions/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"suggestions_search\")\n        })), m(\"whoToFollowSuggestionsSearchForm\", \"/#!/who_to_follow/suggestions/search/\", j({\n            loggedIn: c(\"discover\").action(\"suggestions_search\")\n        })), m(\"whoToFollowLifeline\", \"/#!/who_to_follow/lifeline\", j({\n            loggedIn: c(\"discover\").action(\"lifeline\")\n        })), m(\"whoToFollowLifelineSearch\", \"/#!/who_to_follow/lifeline/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"lifeline_search\")\n        })), m(\"whoToFollowImport\", \"/#!/who_to_follow/import\", j({\n            loggedIn: c(\"discover\").action(\"find_friends\")\n        })), m(\"whoToFollowImportMatches\", \"/#!/who_to_follow/matches\", j({\n            loggedIn: c(\"discover\").action(\"matches\")\n        })), m(\"whoToFollowImportSearch\", \"/#!/who_to_follow/import/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"find_friends_search\")\n        })), m(\"whoToFollowImportSearchForm\", \"/#!/who_to_follow/import/search/\", j({\n            loggedIn: c(\"discover\").action(\"find_friends_search\")\n        })), m(\"whoToFollowInterests\", \"/#!/who_to_follow/interests\", j({\n            loggedIn: c(\"discover\").action(\"interests\")\n        })), m(\"whoToFollowInterestsSearch\", \"/#!/who_to_follow/interests/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"interests_search\")\n        })), m(\"whoToFollowInterestsSearchForm\", \"/#!/who_to_follow/interests/search\", j({\n            loggedIn: c(\"discover\").action(\"interests_search\")\n        })), m(\"whoToFollowInterestsCategory\", \"/#!/who_to_follow/interests/:category\", j({\n            loggedIn: c(\"discover\").action(\"category\")\n        })), m(\"governmentSearchByZip\", \"/#!/who_to_follow/government_by_zip/:zipCode\", j({\n            loggedIn: c(\"discover\").action(\"government_by_zip\")\n        })), m(\"personalizationPreview\", \"/#!/who_to_follow/web_personalized\", c(\"WebPersonalizationPreview\").action(\"preview\")), g(\"searchHome\", \"/#!/search-home\", c(\"searchHome\").action(\"index\"), \"swift_search\", \"/search-home\"), g(\"searchAdvanced\", \"/#!/search-advanced\", c(\"searchHome\").action(\"advanced\"), \"swift_search\", \"/search-advanced\"), g(\"formSearchResults\", \"/#!/search\", c(\"search\").action(\"search\"), \"swift_search\", \"/search\"), g(\"searchResults\", \"/#!/search/:query\", c(\"search\").action(\"search\"), \"swift_search\", \"/search/:query\"), m(\"searchRealtime\", \"/#!/search/realtime/:query\", c(\"search\").action(\"realtime\")), m(\"searchTimeline\", \"/#!/search/timeline/:query\", c(\"search\").action(\"timeline\")), m(\"userSearch\", \"/#!/search/users/:query\", c(\"search\").action(\"people\")), m(\"savedSearch\", \"/#!/saved-search/:query\", c(\"search\").action(\"search\")), m(\"searchFacetsGrid\", \"/#!/search/:query/grid/:mode\", c(\"facetsMediaGallery\").action(\"grid\")), m(\"searchFacetsSlideshow\", \"/#!/search/:query/slideshow/:mode\", c(\"facetsMediaGallery\").action(\"slideshow\")), m(\"searchFacetsGridDefault\", \"/#!/search/:query/grid\", c(\"facetsMediaGallery\").action(\"grid\")), m(\"searchFacetsSlideshowDefault\", \"/#!/search/:query/slideshow\", c(\"facetsMediaGallery\").action(\"slideshow\")), m(\"place\", \"/#!/places/:place_id\", c(\"PlaceT1\").action(\"tweets\")), m(\"trends\", \"/#!/trends\", c(\"trends\").action(\"trends\")), g(\"connect\", \"/#!/i/connect\", j({\n            loggedIn: c(\"Connect\").action(\"connect\")\n        }), \"swift_interactions\", \"/i/connect\"), g(\"mentions\", \"/#!/mentions\", j({\n            loggedIn: c(\"Connect\").action(\"mentions\")\n        }), \"swift_mentions\", \"/mentions\"), g(\"replies\", \"/#!/replies\", j({\n            loggedIn: c(\"Connect\").action(\"mentions\")\n        }), \"swift_mentions\", \"/replies\"), g(\"permalink\", \"/#!/:screen_name/status/:id\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id\"), g(\"permalinkOld\", \"/#!/:screen_name/statuses/:id\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/statuses/:id\"), g(\"photoPermalink\", \"/#!/:screen_name/status/:id/photo/:photo_index\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id/photo/:photo_index\"), g(\"bigPhotoPermalink\", \"/#!/:screen_name/status/:id/photo/:photo_index/large\", c(\"bigPhotoPermalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id/photo/:photo_index/large\"), m(\"embedDialogPermalink\", \"/#!/:screen_name/status/:id/embed\", c(\"permalink\").action(\"permalinkWithEmbedDialog\")), m(\"welcome\", \"/#!/welcome\", j({\n            loggedIn: c(\"welcome\").action(\"welcome\")\n        })), m(\"welcomeSearch\", \"/#!/welcome/search/:query\", j({\n            loggedIn: c(\"welcome\").action(\"search\")\n        })), m(\"welcomeSearchTop\", \"/#!/welcome/search_top/:query\", j({\n            loggedIn: c(\"welcome\").action(\"searchTop\")\n        })), m(\"welcomeSearchForm\", \"/#!/welcome/search\", j({\n            loggedIn: c(\"welcome\").action(\"search\")\n        })), m(\"welcomeLifelineSearch\", \"/#!/welcome/lifeline/search/:query\", j({\n            loggedIn: c(\"welcome\").action(\"searchByZipcode\")\n        })), m(\"welcomeIntro\", \"/#!/welcome/intro\", j({\n            loggedIn: c(\"welcome\").action(\"intro\")\n        })), m(\"welcomeInterests\", \"/#!/welcome/interests\", j({\n            loggedIn: c(\"welcome\").action(\"interests\")\n        })), m(\"welcomeLifeline\", \"/#!/welcome/lifeline\", j({\n            loggedIn: c(\"welcome\").action(\"lifeline\")\n        })), m(\"welcomeInterestsCategory\", \"/#!/welcome/interests/:category\", j({\n            loggedIn: c(\"welcome\").action(\"category\")\n        })), m(\"welcomeImport\", \"/#!/welcome/import\", j({\n            loggedIn: c(\"welcome\").action(\"import\")\n        })), m(\"welcomeImportMatches\", \"/#!/welcome/matches\", j({\n            loggedIn: c(\"welcome\").action(\"matches\")\n        })), m(\"welcomeRecommendations\", \"/#!/welcome/recommendations\", j({\n            loggedIn: c(\"welcome\").action(\"recommendations\")\n        })), m(\"welcomeResurrect\", \"/#!/welcome/return\", j({\n            loggedIn: c(\"welcome\").action(\"resurrect\")\n        })), m(\"welcomeProfile\", \"/#!/welcome/profile\", j({\n            loggedIn: c(\"welcome\").action(\"profile\")\n        })), m(\"welcomeTweets\", \"/#!/welcome/tweets\", j({\n            loggedIn: c(\"welcome\").action(\"tweets\")\n        })), m(\"welcomePreview\", \"/#!/welcome/preview\", j({\n            loggedIn: c(\"welcome\").action(\"preview\")\n        })), m(\"welcomeEdit\", \"/#!/welcome/edit\", j({\n            loggedIn: c(\"welcome\").action(\"edit\")\n        })), g(\"followers\", \"/#!/followers\", j({\n            loggedIn: c(\"profile\").action(\"followers\")\n        }), \"swift_followers\", \"/followers\"), g(\"following\", \"/#!/following\", j({\n            loggedIn: c(\"profile\").action(\"following\")\n        }), \"swift_following\", \"/following\"), g(\"favorites\", \"/#!/favorites\", j({\n            loggedIn: c(\"profile\").action(\"favorites\")\n        }), \"swift_favorites\", \"/favorites\"), g(\"friends\", \"/#!/friends\", j({\n            loggedIn: c(\"profile\").action(\"following\")\n        }), \"swift_following\", \"/following\"), g(\"lists\", \"/#!/lists\", j({\n            loggedIn: c(\"profile\").action(\"lists\")\n        }), \"swift_lists\", \"/lists\"), g(\"followersYouFollow\", \"/#!/:screen_name/followers_you_follow\", c(\"profile\").action(\"followersYouFollow\"), \"swift_followers_you_follow\", \"/:screen_name/followers_you_follow\"), g(\"memberships\", \"/#!/:screen_name/lists/memberships\", c(\"profile\").action(\"memberships\"), \"swift_lists\", \"/:screen_name/lists/memberships\"), g(\"subscriptions\", \"/#!/:screen_name/lists\", c(\"profile\").action(\"allLists\"), \"swift_lists\", \"/:screen_name/lists\"), g(\"profile\", \"/#!/:screen_name\", c(\"profile\").action(\"profile\"), \"swift_profile\", \"/:screen_name\"), g(\"profileWithReplies\", \"/#!/:screen_name/with_replies\", c(\"profile\").action(\"with_replies\"), \"swift_profile\", \"/:screen_name/with_replies\"), g(\"userFavorites\", \"/#!/:screen_name/favorites\", c(\"profile\").action(\"favorites\"), \"swift_favorites\", \"/:screen_name/favorites\"), g(\"userFollowers\", \"/#!/:screen_name/followers\", c(\"profile\").action(\"followers\"), \"swift_followers\", \"/:screen_name/followers\"), m(\"userMediaGrid\", \"/#!/:screen_name/media/grid\", c(\"userMediaGallery\").action(\"grid\")), m(\"userMediaSlideshow\", \"/#!/:screen_name/media/slideshow\", c(\"userMediaGallery\").action(\"slideshow\")), g(\"userFollowing\", \"/#!/:screen_name/following\", c(\"profile\").action(\"following\"), \"swift_following\", \"/:screen_name/following\"), g(\"userLists\", \"/#!/:screen_name/userlists\", c(\"profile\").action(\"lists\"), \"swift_lists\", \"/:screen_name/userlists\"), g(\"followerRequests\", \"/#!/:screen_name/follower_requests\", c(\"profile\").action(\"followerRequests\"), \"swift_follower_requests\", \"/:screen_name/follower_requests\"), g(\"similarTo\", \"/#!/similar_to/:screen_name\", c(\"profile\").action(\"similarTo\"), \"swift_similar_to\", \"/similar_to/:screen_name\"), m(\"userList\", \"/#!/:screen_name/:list_slug\", c(\"list\").action(\"list\")), m(\"listMembers\", \"/#!/:screen_name/:list_slug/members\", c(\"list\").action(\"members\")), m(\"listSubscribers\", \"/#!/:screen_name/:list_slug/subscribers\", c(\"list\").action(\"followers\")), ((l() || (twttr.router.bind(\"routeFollowed\", l), a())));\n    });\n});\nprovide(\"audit\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.AuditTrail\", function() {\n            this.array = [];\n        }).methods({\n            MAX_LENGTH: 20,\n            add: function(a) {\n                this.array.unshift(a), ((((this.array.length > this.MAX_LENGTH)) && (this.array = this.array.slice(0, this.MAX_LENGTH))));\n            },\n            trail: function() {\n                return this.array;\n            },\n            currentPage: function() {\n                return this.page(0);\n            },\n            currentAction: function() {\n                return this.action(0);\n            },\n            currentPath: function() {\n                return this.path(0);\n            },\n            page: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].page));\n            },\n            action: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].action));\n            },\n            path: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].path));\n            },\n            _routes: function() {\n                return twttr.filter(this.array, function(a, b) {\n                    return ((a.type === \"route\"));\n                });\n            }\n        }), twttr.audit = new twttr.AuditTrail, twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n            var d = b.fn.pageName;\n            twttr.audit.add({\n                action: b.fn.actionName,\n                page: d,\n                path: c,\n                type: \"route\"\n            }), ((window.JSBNG__sessionStorage && JSBNG__sessionStorage.setItem(\"ScribeTransport.internal_referer\", c)));\n            var e = $(\"#doc\").removeClass();\n            ((d && e.addClass(((\"route-\" + d.replace(/_/g, \"-\"))))));\n        }), a(twttr.audit);\n    });\n});\nprovide(\"multiGlobals/ClickTrail\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.ClickTrail\", function() {\n            this.array = [];\n        }).methods({\n            MAX_LENGTH: 5,\n            add: function(a) {\n                this.array.unshift(a), ((((this.array.length > this.MAX_LENGTH)) && (this.array = this.array.slice(0, this.MAX_LENGTH))));\n            },\n            lastClick: function() {\n                if (this.array.length) {\n                    return this.array[0].eventName;\n                }\n            ;\n            ;\n            },\n            trail: function() {\n                return this.array;\n            }\n        }), twttr.clicks = new twttr.ClickTrail, twttr.app.waitForSignal(\"init\", function() {\n            $(\"body\").mousedown(function(a) {\n                var c = $(a.target), d = c.closest(\"[data-element-term]\"), e = c.closest(\"[data-component-term]\"), f = c.closest(\"[data-section-term]\"), g = twttr.Scribbler.getElementEventNameTerms(c), i = twttr.audit.currentPage(), j = c.closest(\"[href]\").attr(\"href\");\n                ((g.section || (g.section = b.util.underscore(twttr.audit.currentAction())))), ((((((g.component && g.section)) && i)) && (g.client = \"web\", g.page = b.util.underscore(i), g.action = \"JSBNG__navigate\", twttr.clicks.add({\n                    eventName: twttr.Scribbler.clientAppEventNameGenerator(g),\n                    eventTerms: g,\n                    path: j,\n                    target: c\n                }))));\n            }), twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n                var d = twttr.clicks.trail()[0];\n                ((((d && ((d.path == c)))) && trackClient(d.eventTerms, {\n                    url: c\n                })));\n            });\n        }), a(twttr.clicks);\n    });\n});\nprovide(\"run/defaultViews\", function(a) {\n    using().as(function(b) {\n        using(\"\\u003Epayload\", function() {\n            ((twttr.payload.conditionalTemplates && ($.each(twttr.payload.conditionalTemplates, function(a, b) {\n                twttr.templates[a] = b;\n            }), twttr.views.makeDefaultViews(twttr.templates))));\n        }), twttr.views.makeDefaultViews(twttr.templates), a();\n    });\n});\nprovide(\"TrendLocations\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.TrendLocations\", function(a) {\n            this.getLocation(a);\n        }).statics({\n            LOGGED_OUT_TREND_LOCATION_COOKIE: \"trend_location\",\n            install: function(a) {\n                ((twttr.trendLocations ? twttr.trendLocations.getLocation(a) : twttr.trendLocations = new twttr.TrendLocations(a)));\n            }\n        }).methods({\n            getLocation: function(a) {\n                var b = this;\n                twttr.API.Trend.locations({\n                    lang: twttr.pageLocale,\n                    success: function(c) {\n                        b.all = c;\n                        if (twttr.currentUser) twttr.currentUser.trendLocation().first(function(c) {\n                            ((c ? b.current = c : b.current = b.worldwide())), a(b.current);\n                        });\n                         else {\n                            var d = parseInt($.cookie(b.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE), 10);\n                            b.current = ((b.locationForWoeid(d) || b.worldwide())), a(b.current);\n                        }\n                    ;\n                    ;\n                    }\n                });\n            },\n            allLocations: function() {\n                return this.all.array;\n            },\n            ancestorsOf: function(a) {\n                if (!a.parentid) {\n                    return [];\n                }\n            ;\n            ;\n                var b = this.locationForWoeid(a.parentid);\n                return [b,].concat(this.ancestorsOf(b));\n            },\n            withAncestorsOf: function(a) {\n                return [a,].concat(this.ancestorsOf(a));\n            },\n            currentAncestors: function() {\n                return this.ancestorsOf(this.current);\n            },\n            withCurrentAncestors: function() {\n                return this.withAncestorsOf(this.current);\n            },\n            withFilterAncestors: function() {\n                return this.withAncestorsOf(this.currentFilter());\n            },\n            childrenOf: function(a) {\n                return twttr.filter(this.allLocations(), function(b) {\n                    return ((b.parentid === a.woeid));\n                });\n            },\n            currentChildren: function() {\n                return ((this.current.isPersonalized ? this.childrenOf(this.currentFilter(this.worldwide())) : this.childrenOf(this.currentFilter())));\n            },\n            locationForWoeid: function(a) {\n                return ((a ? twttr.filter(this.allLocations(), function(b) {\n                    return ((b.woeid == a));\n                })[0] : null));\n            },\n            locationsForWoeids: function(a) {\n                var b = this;\n                return twttr.map(a, function(a) {\n                    return b.locationForWoeid(a);\n                });\n            },\n            worldwide: function() {\n                return this.locationForWoeid(1);\n            },\n            currentFilter: function(a) {\n                var c = ((a || this.current));\n                return ((((((c.placeType.code === b.constants.placeTypes.city)) || ((this.childrenOf(c).length === 0)))) ? this._currentFilterWoeid = c.parentid : this._currentFilterWoeid = c.woeid)), this.locationForWoeid(this._currentFilterWoeid);\n            },\n            setPersonalized: function(a) {\n                this.current = $.extend(this.current, {\n                    isPersonalized: a\n                });\n            },\n            setCurrent: function(a) {\n                this.current = ((this.locationForWoeid(a.woeid) || this.current)), this.setPersonalized(a.isPersonalized), ((twttr.currentUser ? twttr.currentUser.setTrendLocation(a.woeid, a.isPersonalized) : (twttr.API.CurrentUser.trigger(\"changedLocation_success\"), $.cookie(this.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE, a.woeid)))), scribble(\"switch-trend-location\", {\n                    woeid: a.woeid,\n                    input: \"click\",\n                    origin: a.origin\n                });\n            }\n        }), a(twttr.TrendLocations);\n    });\n});\nprovide(\"mixins/sideNavigationT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(function() {\n            this.methods({\n                selectCurrentSideNav: function() {\n                    this.selectSideNav(twttr.router.getCurrentRoute().JSBNG__name);\n                },\n                selectSideNav: function(a) {\n                    var b = this.$find(((((\"li.js-sidenav-link[data-name='\" + a)) + \"']\")));\n                    this.$find(\"li.js-sidenav-link\").removeClass(\"active\"), ((b.length && b.addClass(\"active\")));\n                },\n                setSideNavBadge: function(a, b) {\n                    var c = $(JSBNG__document).JSBNG__find(((((\"li.js-sidenav-link a[href='\" + a)) + \"']\")));\n                    c.JSBNG__find(\"[class=\\\"unread\\\"]\").remove(), ((b && c.append(\"\\u003Ci class=\\\"unread\\\"\\u003E\\u003Ci\\u003E\")));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/PagePromise\", function(a) {\n    using(\"mixins/serverRenderableObject\").as(function(b, c) {\n        twttr.klass(\"twttr.PagePromise\", function(a) {\n            this._queue = [], this._unavailableQueue = [], this._isUnavailable = !1, this._name = a, this.pageNodeId = ((\"page-node-\" + twttr.util.underscore(a))), this.$node = this.$domNode(\"\\u003Cdiv/\\u003E\");\n        }).mixin(c).methods({\n            domNodeSelector: function() {\n                return ((\"#\" + this.pageNodeId));\n            },\n            build: function() {\n                var a = this, b = twttr.components.pages[this._name];\n                ((b ? a._build(a._name) : using(twttr.bundleMore, function() {\n                    a._build(a._name);\n                })));\n            },\n            send: function(a, b, c, d) {\n                ((((typeof b == \"function\")) && (error = c, c = b, b = [])));\n                var e = {\n                    JSBNG__name: a,\n                    args: b,\n                    cb: c,\n                    missing: d\n                };\n                ((this._instance ? this._execute(e) : this._enqueue(e)));\n            },\n            getInstanceProperty: function(a) {\n                if (((this._instance && this._instance[a]))) {\n                    return this._instance[a];\n                }\n            ;\n            ;\n            },\n            bind: function() {\n                this.send(\"bind\", Array.prototype.slice.apply(arguments));\n            },\n            JSBNG__one: function() {\n                this.send(\"JSBNG__one\", Array.prototype.slice.apply(arguments));\n            },\n            trigger: function() {\n                this.send(\"trigger\", Array.prototype.slice.apply(arguments));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, ((arguments || [])));\n            },\n            _build: function(a) {\n                var b = twttr.components.pages[a];\n                ((b ? (this._instance = new b(this.$node, this.preRendered), ((b.isAvailable() ? this._flush() : this._unavailable()))) : this._unavailable()));\n            },\n            whenUnavailable: function(a) {\n                ((this._isUnavailable ? a() : this._unavailableQueue.push(a)));\n            },\n            _unavailable: function() {\n                this._isUnavailable = !0;\n                for (var a = 0; ((a < this._unavailableQueue.length)); a++) {\n                    this._unavailableQueue[a].call(null);\n                ;\n                };\n            ;\n                this._unavailableQueue = [];\n            },\n            _enqueue: function(a) {\n                this._queue.push(a);\n            },\n            _execute: function(a) {\n                var b = this._instance[a.JSBNG__name];\n                if (b) {\n                    var c = b.apply(this._instance, ((a.args || [])));\n                    ((a.cb && a.cb.call(null, c)));\n                }\n                 else ((a.missing && a.missing.apply(null)));\n            ;\n            ;\n            },\n            _flush: function() {\n                for (var a = 0; ((a < this._queue.length)); a++) {\n                    this._execute(this._queue[a]);\n                ;\n                };\n            ;\n                this._queue = [];\n            }\n        }), a();\n    });\n});\nprovide(\"components/Page\", function(a) {\n    using(((twttr.isT1 ? \"mixins/sideNavigationT1\" : \"mixins/sideNavigationP1\")), \"util\", \"constants\", \"mixins/serverRenderableObject\").as(function(b, c) {\n        twttr.klass(\"twttr.components.Page\", function(a, b) {\n            var c = this._namespace.match(/\\.([^.]+)$/)[1];\n            this.pageNameUnderscore = twttr.util.underscore(c), this.$node = ((a || this.$domNode(\"\\u003Cdiv/\\u003E\"))), this.preRendered = !!b, ((b || signal(\"\\u003EwokeUp\"))), this._isOpen = !1, this.initComponentEvents();\n        }).statics({\n            view: function(a) {\n                return this.prototype._View = a, this;\n            },\n            containerCssClass: function(a) {\n                return this._containerCssClass = a, this;\n            },\n            deciderKey: function(a) {\n                return this._deciderKey = a, this;\n            },\n            isAvailable: function() {\n                return ((!this._deciderKey || twttr.decider.isAvailable(this._deciderKey)));\n            }\n        }).mixin(twttr.mixins.componentEvents).methods(twttr.EventProvider).mixin(b.mixins.serverRenderableObject).methods({\n            _isActive: function() {\n                return ((twttr.app.currentPageName().toLowerCase() === this.constructor._name.toLowerCase()));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            keyevent: function(a, c) {\n                if (twttr.helpers.isModifier(a)) {\n                    return;\n                }\n            ;\n            ;\n                var d;\n                ((((a.keyCode === b.constants.keyCodes.esc)) ? d = \"esc\" : ((((a.keyCode === b.constants.keyCodes.enter)) ? d = \"return\" : ((((a.which === b.constants.which.period)) ? d = \"period\" : ((((a.keyCode === b.constants.keyCodes.leftArrow)) ? d = \"left\" : ((((a.keyCode === b.constants.keyCodes.rightArrow)) ? d = \"right\" : ((((a.keyCode === b.constants.keyCodes.upArrow)) ? d = \"up\" : ((((a.keyCode === b.constants.keyCodes.downArrow)) ? d = \"down\" : d = String.fromCharCode(a.which).toLowerCase()))))))))))))));\n                if (((((((this[((\"_\" + c))] && this[((\"_\" + c))][d])) && ((((a.which < 111)) || ((a.which > 118)))))) && !twttr.shortcuts.currentKey))) {\n                    return this[((\"_\" + c))][d].call(this, a);\n                }\n            ;\n            ;\n            },\n            render: function(a) {\n                this.beforeRender();\n                var b = $.extend(this.viewData(), a);\n                return ((this.preRendered || (this.$node.empty(), ((((twttr.development && !this._View)) && JSBNG__console.log(((\"Missing view for page \" + this.constructor.JSBNG__name))))), this.$node.html((new this._View(b)).html())))), this.afterRender(), this.trigger(\"rendered\", [this,]), this;\n            },\n            JSBNG__onkeydown: function(a) {\n                this.keyevent(a, \"keydown\");\n            },\n            JSBNG__onkeypress: function(a) {\n                this.keyevent(a, \"keypress\");\n            },\n            JSBNG__onkeyup: function(a) {\n                this.keyevent(a, \"keyup\");\n            },\n            addContainerComponent: function(a, b, c) {\n                ((((c == null)) ? a.append(b.$node) : ((twttr.is.number(c) ? a.children(((((\":nth-child(\" + c)) + \")\"))).before(b.$node) : a[c](b.$node))))), b.bind(\"notRendered\", twttr.bind(this, function(a) {\n                    this.componentNotRendered(b, a);\n                })), b.trigger(\"addedToPage\", [b,]);\n            },\n            addTopContentComponent: function(a, b) {\n                ((this.$topContent || (this.$topContent = this.$find(\"div.js-content-top\")))), this.addContainerComponent(this.$topContent, a, b);\n            },\n            addDashboardComponent: function(a, b) {\n                ((this.$dashboard || (this.$dashboard = this.$find(\".dashboard\")))), ((a && this.addContainerComponent(this.$dashboard, a, b)));\n            },\n            addDashboardComponents: function(a) {\n                var b = this;\n                twttr.each(a, function(a) {\n                    b.addDashboardComponent(a);\n                });\n            },\n            componentNotRendered: function(a, b) {\n            \n            },\n            updatePageTitle: function(a) {\n                ((twttr.isPreflight && (a = ((\"PREFLIGHT :: \" + a))))), this._pageTitle = a, ((this._isActive() && (JSBNG__document.title = a)));\n            },\n            hasNewItems: function(a) {\n                ((a ? ($(\"#global-actions .active\").addClass(\"new\"), JSBNG__document.title = ((((((\"(\" + a)) + \") \")) + this._pageTitle))) : ($(\"#global-actions .active\").removeClass(\"new\"), JSBNG__document.title = this._pageTitle)));\n            },\n            shouldAutoRender: function() {\n                return !this.noAutoRender;\n            },\n            addImpressionData: function(a) {\n            \n            }\n        }), twttr.klass.page = function(a, b) {\n            return twttr.klass(a, b).subclassOf(twttr.components.Page);\n        }, $.each([\"beforeRender\",\"afterRender\",\"JSBNG__onFirstSwitch\",\"viewData\",\"JSBNG__onSwitchAway\",\"JSBNG__onSwitchTo\",], function(a, b) {\n            var c = ((b.charAt(0).toUpperCase() + b.slice(1))), d = ((\"_\" + b));\n            twttr.components.Page[((\"add\" + c))] = function(a) {\n                var b = [], c = this.prototype[d];\n                if (c) {\n                    for (var e = 0; ((e < c.length)); e++) {\n                        b.push(c[e]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return b.push(a), this.prototype[d] = b, this;\n            }, twttr.components.Page.prototype[b] = function() {\n                var a = this, b = {\n                };\n                return $.each(((this[d] || [])), function(c, d) {\n                    twttr.aug(b, d.call(a));\n                }), b;\n            };\n        }), twttr.components.Page.addOnSwitchTo(function() {\n            ((this.constructor._containerCssClass && $(\"#page-container\").addClass(this.constructor._containerCssClass)));\n        }).addOnSwitchAway(function() {\n            ((this.constructor._containerCssClass && $(\"#page-container\").removeClass(this.constructor._containerCssClass))), $(\"div.tipsy\").remove();\n        }).addBeforeRender(function() {\n            $(\"div.tipsy\").remove();\n        }).addAfterRender(function() {\n            this.$topContent = this.$find(\"div.js-content-top\"), $(\"div.tipsy\").remove();\n        }).addBeforeRender(function() {\n            twttr.isRendering = ((twttr.is.def(twttr.isRendering) ? ((twttr.isRendering + 1)) : 1));\n        }).addAfterRender(function() {\n            twttr.isRendering = ((twttr.is.def(twttr.isRendering) ? ((twttr.isRendering - 1)) : 0));\n        }).addAfterRender(function() {\n            ((((twttr.currentUser && twttr.currentUser.facebookProfileId)) && window.JSBNG__setTimeout(function() {\n                if ((($(\"#facebook-token\").length == 0))) {\n                    var a = $(\"\\u003Ciframe style=\\\"display: none\\\"/\\u003E\");\n                    a.attr(\"src\", ((\"/settings/facebook/token?profile_id=\" + twttr.currentUser.facebookProfileId))), $(\"body\").append(a);\n                }\n            ;\n            ;\n            }, 3000)));\n        }).mixin(twttr.mixins.listActionable, c).click({\n            \"[data-modal='list-new']\": function(a, b) {\n                (new twttr.widget.ListDialog({\n                })).open(), trackElement(b, \"click\");\n            }\n        }), a(twttr.components.Page);\n    });\n});\nprovide(\"components/pages/mixins/homeT1\", function(a) {\n    using(\"util\", \"mixins/t1/emptyTimelineRecommendations\").as(function(b, c, d) {\n        var e = twttr.klass.mixin(\"twttr.components.pages.mixins.homeT1\", function() {\n            this.view(twttr.views.Page), this.methods({\n                insertTweetbox: twttr.util.noopInT1,\n                insertPromptbirdPrompt: function() {\n                    var a = this;\n                    using([twttr.bundleMore,\"promptbird\",]).as(function(a) {\n                        var b = a.promptbird.getPrompt();\n                        if (!b) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var c = a.promptbird.renderComponentFromPrompt(b);\n                        if (!c) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = ((((\"#js-promptbird-\" + b.JSBNG__prompt.format.replace(/_/g, \"-\"))) + \"-hook\"));\n                        $(d).html(c.$node);\n                    });\n                },\n                selectDashboardComponents: function() {\n                    return this.trendsComponent = new twttr.components.Trends, [new twttr.components.PromptbirdDashboardPlaceholder,new twttr.components.t1.dashboard.MiniHomeProfile(!0),((twttr.at(\"twttr.currentUser.protected\") && new twttr.components.FollowerRequestLink)),new twttr.components.JapaneseAd,new twttr.components.UserRecommendations({\n                        showLinks: twttr.decider.isAvailable(\"wtf_home_timeline_show_links\")\n                    }),this.trendsComponent,new twttr.components.Footer,];\n                },\n                getTweetBoxOptions: function() {\n                    return {\n                        condensedContent: _(\"Compose new Tweet...\"),\n                        autocompleteSuggestionLimit: ((twttr.isT1 ? 5 : 10))\n                    };\n                },\n                JSBNG__home: function(a, b) {\n                    var c = this, e = twttr.util.params().badLinkRecipient;\n                    ((((e && !this.warnedOfBadLink)) && (this.warnedOfBadLink = !0, twttr.API.User.JSBNG__find(+e, function(a) {\n                        twttr.showError(_(\"Sorry, you must be logged in as @{{screenName}} to use this link!\", a));\n                    })))), this.selectCurrentSideNav(), this.insertEmptyTimeline({\n                        reloadStream: !0,\n                        JSBNG__onDestroyCb: function() {\n                            c.trigger(\"emptyTimelineModuleDestroyed\");\n                        }\n                    }), this.waitForSignal(\"emptyTimelineModuleLogicCompleted\", function() {\n                        var a = c.$find(\".component[data-component-term=\\\"user_recommendations\\\"]\"), b = function() {\n                            ((((a.length === 1)) && ((d.showing ? a.hide() : a.show()))));\n                        };\n                        b(), c.bind(\"emptyTimelineModuleDestroyed\", function() {\n                            b();\n                        });\n                    }), this.loadPage(_(\"Twitter / Home\"), \"JSBNG__home\", \"Home\"), this.insertPromptbirdPrompt(), this._maybeShowReplyDialog(b);\n                },\n                networkActivity: function(a) {\n                    this.selectCurrentSideNav(), this.loadPage(_(\"Twitter / Activity\"), \"activity\", \"ActivityByNetworkStream\");\n                },\n                memberships: function(a) {\n                    var b = this;\n                    this.selectSideNav(\"lists\"), this.loadPage(_(\"Twitter / Lists following you\"), \"listFollowingYou\", \"Memberships\", {\n                        screenName: twttr.currentUser.screenName\n                    });\n                },\n                subscriptions: function(a) {\n                    var b = this;\n                    this.selectSideNav(\"lists\"), this.loadPage(_(\"Twitter / Lists you follow\"), \"listYouFollow\", \"AllSubscriptions\", {\n                        screenName: twttr.currentUser.screenName\n                    });\n                },\n                messages: function(a) {\n                    var b = this;\n                    using([twttr.bundleMore,\"components/t1/DirectMessageDialog\",], function(c, d) {\n                        b.JSBNG__home(a), ((a.screen_name ? (new d(twttr.widget.DirectMessageDialog.views.conversation, a.screen_name)).open() : (new d).open()));\n                    });\n                },\n                savedSearches: function(a) {\n                    this.selectCurrentSideNav(), this.loadPage(_(\"Twitter / Saved Searches\"), \"savedSearches\", \"SavedSearches\");\n                }\n            });\n        });\n        a(e);\n    });\n});\nprovide(\"components/pages/Home\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"components/pages/mixins/homeT1\" : \"components/pages/mixins/homeP1\")), ((twttr.isT1 ? \"mixins/t1/emptyTimelineRecommendations\" : \"mixins/emptyTimelineRecommendations\")), \"util\", \"constants\").as(function(b, _, c, d) {\n        var e = twttr.klass(\"twttr.components.pages.Home\").subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage, twttr.mixins.welcomeScribing, d).view(twttr.views.HomePage).containerCssClass(\"home-container\").addOnSwitchTo(function() {\n            var a = this;\n            using([twttr.bundleMore,\"TweetBox\",], function() {\n                ((a._hasRendered && a.insertTweetbox())), twttr.TweetBox.bind(\"tweetSuccess\", function(b, c) {\n                    var d = a.streamManager.getCurrent().trigger(\"didTweet\", [c,]);\n                });\n            });\n            var b = twttr.currentUser.states;\n            if (((((b && b.pending_email)) && !$.cookie(\"abtest_email_verification_18\")))) {\n                var c = twttr.abdecider.choose(\"email_verification-18\", !0);\n                ((((c && ((c != \"control\")))) && using([twttr.bundleMore,\"dialogs\",], function() {\n                    twttr.dialogs.verifyEmail(c).open();\n                })));\n            }\n        ;\n        ;\n            ((this.scrollTop && twttr.$win.scrollTop(this.scrollTop))), $(\".promptbird\").show(), this.maybeScribeWelcomeSkip();\n        }).addOnSwitchAway(function() {\n            using([twttr.bundleMore,\"TweetBox\",], function() {\n                twttr.TweetBox.unbind(\"tweetSuccess\");\n            }), $(\".promptbird\").hide();\n        }).addViewData(function() {\n            return {\n                current_user_screen_name: twttr.currentUser.screenName\n            };\n        }).methods({\n            loadPage: function(a, b, c, d) {\n                function e() {\n                    f.streamManager.switchTo(twttr.streams[c], ((d || {\n                    })));\n                };\n            ;\n                var f = this;\n                this.updatePageTitle(a), twttr.themes.loadCurrentUserStyle(), ((twttr.streams[c] ? e() : (this.streamManager.switchOut(), using(twttr.bundleMore, function() {\n                    e();\n                })))), ((b && (this.focusStreamTab(b), ((((((((b == \"JSBNG__home\")) && ((twttr.currentUser.friendsCount == 0)))) && ((twttr.abdecider.choose(\"show_wtf_recs_in_timeline_105\", true) == \"show_wtf\")))) && this.$find(\".stream-tab.stream-tab-home.active a\").text(\"Who To Follow\")))))), this.unfocusStreamItem(), ((twttr.components.JapaneseAd && twttr.components.JapaneseAd.refreshAds())), ((twttr.isT1 || trackClient({\n                    action: \"impression\"\n                })));\n            },\n            shouldShowSubtabs: function() {\n                return window.JSBNG__location.search.match(/subtabs\\=1/);\n            },\n            componentNotRendered: function(a, b) {\n                ((((a._namespace == \"twttr.components.UserRecommendations\")) && this.$dashboard.JSBNG__find(\"div.trends-inner\").addClass(\"wide-trends\")));\n            },\n            JSBNG__onFirstSwitch: function() {\n                using([twttr.bundleMore,\"photo/turkey\",], function() {\n                    ((twttr.decider.isAvailable(\"turkey\") && twttr.turkey.showFirstTimeTurkey()));\n                });\n            },\n            getTweetbox: function() {\n                return this.tweetBox;\n            },\n            _maybeShowReplyDialog: function(a) {\n                ((((((a && a.in_reply_to_status_id)) && a.screen_name)) && (defaultContent = ((a.JSBNG__status || \"\")), using([twttr.bundleMore,\"dialogs\",], function() {\n                    twttr.dialogs.reply({\n                        tweetId: a.in_reply_to_status_id,\n                        screenName: a.screen_name,\n                        dataFields: {\n                            defaultContent: defaultContent,\n                            multiple: ((defaultContent.split(/@/).length > 2))\n                        }\n                    }).open();\n                }), (($.browser.msie || window.JSBNG__location.replace(twttr.router.homePath()))))));\n            },\n            insertPromptbirdPrompt: function() {\n                var a = this;\n                using([twttr.bundleMore,\"promptbird\",]).as(function(b) {\n                    var c = twttr.promptbird.getPrompt();\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = twttr.promptbird.renderComponentFromPrompt(c);\n                    if (!d) {\n                        return;\n                    }\n                ;\n                ;\n                    switch (c.JSBNG__prompt.format) {\n                      case \"dashboard_narrow\":\n                        a.addDashboardComponent(d, 1);\n                        break;\n                      case \"below_black_bar\":\n                        ((a._isActive() && twttr.app.addComponentToAppBody(d)));\n                    };\n                ;\n                });\n            },\n            scrollEnd: function(a) {\n                this.scrollTop = a, ((((((a > 100)) && twttr.components.pages.Home.scribeScroll)) && (trackClient({\n                    action: \"JSBNG__scroll\"\n                }), twttr.components.pages.Home.scribeScroll = !1)));\n            }\n        }).addAfterRender(function() {\n            var a = this;\n            this._hasRendered = !0, using([twttr.bundleMore,\"TweetBox\",], function() {\n                a.insertTweetbox();\n            }), using(twttr.bundleMore, function() {\n                ((a.preRendered && a.$find(\"div.dashboard, section.dashboard\").empty())), a.addDashboardComponents(a.selectDashboardComponents()), a.signal(\"dashboardComponentsAdded\");\n            }), this.waitForSignal(\"dashboardComponentsAdded\", function() {\n                a.insertPromptbirdPrompt();\n            });\n        }).click({\n            \".done-right\": function(a, b) {\n                ((((twttr.currentUser.friendsCount > 0)) ? (twttr.abdecider.track(\"show_wtf_recs_in_timeline_105\", \"User clicked done button and is following accounts\"), window.JSBNG__location = \"/\") : (twttr.abdecider.track(\"show_wtf_recs_in_timeline_105\", \"User clicked done button and is not following any accounts\"), this.$find(\".stream-tab.stream-tab-home.active a\").text(\"Timeline\"), this.$find(\".stream-title\").css(\"border-bottom\", \"none\"), this.loadPage(_(\"Twitter / Home\"), \"JSBNG__home\", \"Home\"))));\n            }\n        });\n        e.mixin(c), a(e);\n    });\n});\nprovide(\"themes\", function(a) {\n    using().as(function(b) {\n        twttr.themes = {\n            loadUserStyleFor: function(a) {\n                ((twttr.helpers.isCurrentUser(a) && (a = twttr.currentUser)));\n                if (((a && !this._hasBrokenDefaults(a)))) {\n                    this._setTheme(((\"user-style-\" + a.screenName)));\n                    if ((($(((\"style#user-style-\" + a.screenName))).length === 0))) {\n                        $(\"head style.js-user-style\").remove();\n                        var b = ((twttr.isT1 ? twttr.views.UserCssT1 : twttr.views.UserCssP1));\n                        (new b(a)).render(\"head\", \"append\");\n                    }\n                ;\n                ;\n                    (((($(((((\"style#user-style-\" + a.screenName)) + \"-bg-img\"))).length === 0)) && ($(\"head style.js-user-style-bg-img\").remove(), (new twttr.views.BgImgCss(a)).render(\"head\", \"append\"))));\n                }\n                 else this.loadDefaultTheme();\n            ;\n            ;\n            },\n            loadCurrentUserStyle: function() {\n                this.loadUserStyleFor(twttr.currentUser);\n            },\n            loadDefaultTheme: function() {\n                ((twttr.isT1 ? this._setTheme(\"default-theme\") : this._setTheme(\"user-style-twttr\")));\n            },\n            loadFrontPageTheme: function() {\n                this._setTheme(\"front-page\");\n            },\n            loadLoadingTheme: function() {\n                this._setTheme(\"loading-body\");\n            },\n            clear: function() {\n                this._setTheme(!1);\n            },\n            _setTheme: function(a) {\n                var b = $(\"body\");\n                this._clearExistingTheme(), ((a && b.addClass(a)));\n            },\n            _brokenTheme: {\n                profileBackgroundColor: \"9ae4e8\",\n                profileBackgroundImageUrl: /\\/images\\/themes\\/theme1\\/bg.png$/i,\n                profileBackgroundTile: !1,\n                profileLinkColor: \"0000ff\",\n                profileSidebarBorderColor: \"87bc44\",\n                profileSidebarFillColor: \"e0ff92\",\n                profileTextColor: \"000000\",\n                profileUseBackgroundImage: !0\n            },\n            _hasBrokenDefaults: function(a) {\n                for (var b in this._brokenTheme) {\n                    var c = this._brokenTheme[b], d = a[b], e = !1;\n                    ((twttr.is.regex(c) ? e = !!d.match(c) : e = ((c === d))));\n                    if (!e) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            _clearExistingTheme: function() {\n                var a = $(\"body\");\n                $(\"style[id^=user-style]\").each(function() {\n                    a.removeClass(this.id);\n                }), a.removeClass(\"loading-body front-page default-theme\"), ((twttr.isT1 || a.removeClass(\"static-page user-style-twttr\")));\n            }\n        }, ((twttr.isT1 || twttr.aug(twttr.themes, {\n            loadStaticPageTheme: function() {\n                this._setTheme(\"static-page\");\n            }\n        }))), a(twttr.themes);\n    });\n});\nprovide(\"Profiler\", function(a) {\n    using(\"util\").as(function(b) {\n        var c = 0, d = b.util.params().profiling, e = twttr.klass(\"twttr.Profiler\", function(a) {\n            if (!e.isEnabled()) {\n                this.waypoint = $.noop, this.waitFor = $.noop, this.done = $.noop, this.addBeforeScribbleFilter = $.noop, this.doneAfterCallback = function(a) {\n                    return a;\n                };\n                return;\n            }\n        ;\n        ;\n            this.id = ++c, this.description = a, this.pendingProfilers = 0, this.subProfilers = [], this.startTime = new JSBNG__Date, this.endTime = null, this.isDone = !1, this.isComplete = !1, this.runawayProfilerTimeout = JSBNG__setTimeout(twttr.bind(this, this._giveUp), e.timeoutAfter), this.timedOut = !1, this.timedOutSubProfilers = [], this.beforeScribbleFilters = [], this.profilerType = e.types.GENERIC, ((d && JSBNG__console.log(\"%s started\", this.description)));\n        }).methods(twttr.EventProvider).statics({\n            isEnabled: function() {\n                return ((!!twttr.payload.profiling || !!d));\n            },\n            logPreviousEvent: function(a, b, c) {\n                var d = new e(a);\n                d.addBeforeScribbleFilter(function(a) {\n                    return a.start_time_ms = b, a.end_time_ms = c, a.duration_ms = ((c - b)), a;\n                }), d.done();\n            },\n            logDataSet: function(a, b, c) {\n                var d = new e(a);\n                d.startTime = b, $.each(c, function(a, b) {\n                    d.waypoint(b.JSBNG__name, b.timestamp);\n                }), d.done();\n            },\n            timeoutAfter: 15000,\n            types: {\n                GENERIC: 0,\n                FIRST_PAGE_LOAD: 1\n            }\n        }).methods({\n            addBeforeScribbleFilter: function(a) {\n                this.beforeScribbleFilters.push(a);\n            },\n            doneAfterCallback: function(a) {\n                var b = this, c = function(a) {\n                    return function() {\n                        ((twttr.is.fn(a) || JSBNG__console.warn(\"Invalid call to doneAfterCallback\")));\n                        var c = a.apply(this, arguments);\n                        return b.done(), c;\n                    };\n                };\n                return ((twttr.is.fn(a) ? c(a) : (a.cancel = ((a.cancel || $.noop)), a.cancel = c(a.cancel), a.complete = ((a.complete || $.noop)), a.complete = c(a.complete), a)));\n            },\n            waitFor: function() {\n                ((this.isDone && JSBNG__console.warn(\".waitFor called on a profiler that's already complete\", this)));\n                var a = this;\n                $(arguments).each(function(b, c) {\n                    if (((!c || !((c instanceof e))))) {\n                        if (!twttr.is.def(c.profiler)) {\n                            JSBNG__console.error(\"Non-profiler passed in, and it doesn't have a .profiler property\");\n                            return;\n                        }\n                    ;\n                    ;\n                        c = c.profiler;\n                    }\n                ;\n                ;\n                    if (c.isComplete) {\n                        return;\n                    }\n                ;\n                ;\n                    ((d && JSBNG__console.log(\"%s waiting for %o\", a.description, c))), a.pendingProfilers++, a.subProfilers.push(c), c.bind(\"complete\", function(b, c, e) {\n                        ((d && ((e ? JSBNG__console.log(\"%s noticed that %o timed out\", a.description, c) : JSBNG__console.log(\"%s noticed that %o finished\", a.description, c))))), a.pendingProfilers--, ((e && a.timedOutSubProfilers.push(c))), ((((((a.pendingProfilers === 0)) && a.isDone)) && a._complete()));\n                    });\n                });\n            },\n            done: function() {\n                if (this.isDone) {\n                    return;\n                }\n            ;\n            ;\n                ((d && JSBNG__console.log(\"%s is done\", this.description))), this.isDone = !0, JSBNG__clearTimeout(this.runawayProfilerTimeout), this.runawayProfilerTimeout = null, ((((((this.pendingProfilers === 0)) && !this.isComplete)) && this._complete()));\n            },\n            _complete: function() {\n                ((d && JSBNG__console.log(\"%s is complete\", this.description))), this.isComplete = !0, this.endTime = new JSBNG__Date, this.waypoint(\"complete\"), this.trigger(\"complete\", [this,this.timedOut,]);\n            },\n            _giveUp: function() {\n                JSBNG__console.warn(\"Runaway profiler detected!\", this), this.timedOut = !0, this.done();\n            },\n            waypoint: function(a, c) {\n                c = ((c || new JSBNG__Date));\n                var e = {\n                    profiler_type: this.profilerType,\n                    product: \"webclient\",\n                    start_time_ms: twttr.appStartTime,\n                    impression_id: ((((twttr.session && twttr.session.impressionId)) ? twttr.session.impressionId.toString() : null)),\n                    id: this.id,\n                    description: this.description\n                };\n                ((this.isComplete ? (e.end_time_ms = this.endTime.getTime(), e.duration_ms = ((this.endTime - this.startTime))) : (e.waypoint_time_ms = c.getTime(), e.duration_ms = ((e.waypoint_time_ms - this.startTime)), e.waypoint_key = a))), ((this.timedOut && (e.timed_out = !0)));\n                var f = this;\n                $.each([\"subProfilers\",\"timedOutSubProfilers\",], function(a, c) {\n                    ((((f[c].length > 0)) && (e[b.util.underscore(c)] = twttr.map(f[c], function(a) {\n                        return a.description;\n                    }))));\n                }), $.each(this.beforeScribbleFilters, function(a, b) {\n                    e = b.call(f, e);\n                }), scribble(\"profiler_waypoint\", e, \"perftown\"), ((d && ((this.isComplete ? JSBNG__console.log(\"%s: complete after %d ms; data %o\", this.description, e.duration_ms, e) : JSBNG__console.log(\"%s: %s waypoint after %d ms; data %o\", this.description, a, ((e.waypoint_time_ms - this.startTime)), e)))));\n            }\n        });\n        e.verboseProfiling = d, a(e);\n    });\n});\nprovide(\"RouteTimer\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.RouteTimer\", {\n            previousRoute: null,\n            previousPath: null,\n            trackedRoute: null,\n            trackedPath: null,\n            trackedStream: null,\n            trackAjax: !1,\n            prestreamAjaxCount: 0,\n            poststreamAjax: {\n            },\n            routeTiming: {\n            },\n            timeoutId: 0,\n            routeStart: function(a, b) {\n                var c = this;\n                this.routeTiming.next_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset(), this.previousRoute = ((this.trackedRoute || a)), this.previousPath = ((this.trackedPath || b)), this.trackedRoute = a, this.trackedPath = b, this.trackedStream = null, this.routeTiming.start_time = (new JSBNG__Date).getTime(), this.timeoutId = window.JSBNG__setTimeout(function() {\n                    c._scribeResultsAndReset();\n                }, 20000);\n            },\n            streamSwitch: function(a) {\n                var b = this, c = twttr.router.getCurrentRoute(), d = twttr.Router.getCurrentPath();\n                if (((((((!this.routeTiming.start_time || !this._routesEqual(c, this.trackedRoute))) || ((d !== this.trackedPath)))) || ((this._routesEqual(this.previousRoute, this.trackedRoute) && ((this.previousPath === this.trackedPath))))))) {\n                    this._reset();\n                    return;\n                }\n            ;\n            ;\n                this.routeTiming.stream_switch_time = (new JSBNG__Date).getTime(), this.trackedStream = a;\n            },\n            streamAfterSwitch: function(a, b) {\n                ((((((this.trackedStream === a)) && this.routeTiming.stream_switch_time)) ? (this.routeTiming.stream_complete_time = (new JSBNG__Date).getTime(), this.routeTiming.cached = b, this._startAjaxTracking()) : this._reset()));\n            },\n            JSBNG__onAjaxComplete: function(a, b) {\n                if (((!this.trackAjax || ((this.prestreamAjaxCount == 0))))) {\n                    return;\n                }\n            ;\n            ;\n                if (((b && ((b.url in this.poststreamAjax))))) {\n                    for (i = 0; ((i < this.poststreamAjax[b.url].length)); i++) {\n                        if (((b === this.poststreamAjax[b.url][i]))) {\n                            this.poststreamAjax[b.url].splice(i, 1);\n                            return;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                this.prestreamAjaxCount--;\n                if (((((this.prestreamAjaxCount == 0)) || (($.active == 0))))) {\n                    this.trackAjax = !1, this.routeTiming.ajax_complete_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset();\n                }\n            ;\n            ;\n            },\n            JSBNG__onAjaxSend: function(a, b) {\n                ((((((this.trackAjax && b)) && b.url)) && (((this.poststreamAjax[b.url] || (this.poststreamAjax[b.url] = []))), this.poststreamAjax[b.url].push(b))));\n            },\n            _scribeResultsAndReset: function() {\n                var a = this;\n                if (this.routeTiming) {\n                    var c = !0;\n                    $.each([\"start_time\",\"stream_switch_time\",\"stream_complete_time\",\"cached\",], function(b, d) {\n                        ((((d in a.routeTiming)) || (c = !1)));\n                    }), ((c && (((b.util.params().routetimer && twttr.showMessage(((((((((((((((\"switch: \" + ((this.routeTiming.stream_switch_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Estream: \")) + ((this.routeTiming.stream_complete_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Eajax: \")) + ((this.routeTiming.ajax_complete_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Ecached: \")) + this.routeTiming.cached)), !0))), scribble(\"route_time\", $.extend({\n                        source_page: this.previousRoute.fn.pageName,\n                        source_action: this.previousRoute.fn.actionName,\n                        source_path: this.previousPath,\n                        dest_page: this.trackedRoute.fn.pageName,\n                        dest_action: this.trackedRoute.fn.actionName,\n                        dest_path: this.trackedPath\n                    }, this.routeTiming), \"route_timing\"))));\n                }\n            ;\n            ;\n                this._reset();\n            },\n            _startAjaxTracking: function() {\n                var a = this;\n                this.routeTiming.ajax_count = this.prestreamAjaxCount = $.active, ((((this.prestreamAjaxCount == 0)) ? (this.routeTiming.ajax_complete_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset()) : this.trackAjax = !0));\n            },\n            _routesEqual: function(a, b) {\n                return ((((a.JSBNG__name === b.JSBNG__name)) && ((a.path === b.path))));\n            },\n            _reset: function() {\n                this.routeTiming = {\n                }, this.trackAjax = !1, this.prestreamAjaxCount = 0, this.poststreamAjax = {\n                }, ((this.timeoutId && window.JSBNG__clearTimeout(this.timeoutId))), this.timeoutId = 0;\n            }\n        }), ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"route_timing\") || b.util.params().routetimer)))) && (twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n            twttr.RouteTimer.routeStart(b, c);\n        }), $(JSBNG__document).ajaxComplete(function(a, b, c) {\n            twttr.RouteTimer.JSBNG__onAjaxComplete(b, c);\n        }), $(JSBNG__document).ajaxSend(function(a, b, c) {\n            twttr.RouteTimer.JSBNG__onAjaxSend(b, c);\n        })))), a(twttr.RouteTimer);\n    });\n});\nprovide(\"bundle/t1-core\", function(a) {\n    using([\"$lib/jquery-1.7.1.js\",\"libwrap/jquery\",\"$lib/json2.js\",\"libwrap/json\",\"$lib/hogan.js\",\"libwrap/hogan\",\"run/base\",\"_\",\"/account/templates_t1_core.js\",\"EventProvider\",\"bluejs/init\",\"bluejs/config/endpoints\",\"bluejs/util/request_helpers\",\"bluejs/util/local_storage_cache\",\"bluejs/util/object_cache\",\"bluejs/util/request_cache\",\"bluejs/util/helpers\",\"bluejs/util/model\",\"bluejs/util/remote_request\",\"bluejs/util/base_collection\",\"bluejs/mixins/status_actions\",\"bluejs/mixins/phoenix/user\",\"bluejs/mixins/phoenix/current_user\",\"bluejs/mixins/phoenix/status\",\"bluejs/mixins/phoenix/rate_user_recommendation\",\"bluejs/models/base\",\"bluejs/models/user\",\"bluejs/models/direct_message\",\"bluejs/models/saved_search\",\"bluejs/models/list\",\"bluejs/models/location\",\"bluejs/models/trend\",\"bluejs/models/status\",\"bluejs/models/promptbird\",\"bluejs/models/search_result\",\"bluejs/models/place\",\"bluejs/models/user_recommendation\",\"bluejs/models/suggestion_category\",\"bluejs/models/related_tweets\",\"bluejs/models/related_result\",\"bluejs/util/promoted_content\",\"bluejs/models/address_book\",\"bluejs/models/promo\",\"bluejs/models/urls\",\"bluejs/models/blob\",\"bluejs/models/device\",\"bluejs/models/search\",\"bluejs/models/conversation\",\"bluejs/models/activity\",\"bluejs/models/topic_story\",\"bluejs/models/news_article\",\"bluejs/models/news_story\",\"bluejs/models/user_story\",\"bluejs/models/tweet_story\",\"bluejs/models/story\",\"bluejs/models/search_story\",\"bluejs/models/stories\",\"bluejs/models/discovery\",\"bluejs/models/sports_story\",\"bluejs/models/soccer_events\",\"bluejs/models/us_political_rep\",\"bluejs/models/social_proof\",\"bluejs/models/referenced_by\",\"extendAPI\",\"bluejs/api\",\"$lib/jquery.color.js\",\"$lib/modernizr-1.5.js\",\"$lib/jquery.hashchange.js\",\"$lib/jquery.cookie.js\",\"$lib/jquery.tipsy.js\",\"$lib/jquery.cssanimation.js\",\"div\",\"util\",\"constants\",\"cache\",\"singletons/namespaced_store\",\"singletons/promoted_account_store\",\"singletons/promoted_tweet_store\",\"decider\",\"multiGlobals/scribble\",\"abdecider\",\"app\",\"singletons/external_url_store\",\"singletons/Router\",\"streams/Stream\",\"scribbles\",\"Cards\",\"multiGlobals/client_app_tracking\",\"mixins/streamablePageDetailsPane\",\"mixins/streamablePageDropdownEdition\",\"mixins/streamablePageWithInlineMedia\",\"mixins/itemActionableScribing\",\"mixins/streamablePage\",\"mixins/userActionableT1\",\"mixins/userActionable\",\"mixins/profilePopupActionable\",\"mixins/listActionable\",\"mixins/tweetActionable\",\"mixins/pendingActions\",\"mixins/i18nTweet\",\"mixins/i18nTweetBox\",\"mixins/promotedTweetStream\",\"mixins/componentEvents\",\"mixins/protectedUserActionable\",\"mixins/serverRenderableObject\",\"mixins/welcomeScribing\",\"mixins/t1/emptyTimelineRecommendations\",\"lib/natcompare\",\"$lib/twitter-text-1.5.0.js\",\"setup\",\"search\",\"helpers\",\"errors\",\"viewHelpers\",\"components/Base\",\"idleDetector\",\"interface\",\"run/topbarDropdown\",\"tco\",\"streams/TweetStream\",\"streams/Home\",\"streams/StreamManager\",\"view\",\"urlResolver\",\"multiGlobals/core_views\",\"multiGlobals/core_views_t1\",\"router_t1\",\"audit\",\"multiGlobals/ClickTrail\",\"run/defaultViews\",\"TrendLocations\",\"mixins/sideNavigationT1\",\"components/PagePromise\",\"components/Page\",\"components/pages/mixins/homeT1\",\"components/pages/Home\",\"themes\",\"Profiler\",\"RouteTimer\",], function() {\n        a();\n    });\n});");
// 9496
geval("provide(\"/account/templates_t1_more.js\", function(exports) {\n    if (!twttr.isMockview) {\n        var __hogan_opts = {\n            sectionTags: [{\n                o: \"_i\",\n                c: \"i\"\n            },],\n            disableLambda: true\n        };\n        twttr.provide(\"twttr.templates\", {\n            \"404_page\": \"\\u003Cdiv class=\\\"content-narrow\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"error-page error-404 clearfix\\\"\\u003E\\u000a    {{#render_page_content}}\\u000a      \\u003Ch1 class=\\\"heading\\\"\\u003ESorry, that page doesn\\u2019t exist!\\u003C/h1\\u003E\\u000a      \\u003Cform class=\\\"inline-form user-search-form\\\" method=\\\"GET\\\" action=\\\"{{who_to_follow_search_form_path}}\\\"\\u003E\\u000a        \\u003Cp class=\\\"lead\\\"\\u003ESearch for a username, first or last name:\\u003C/p\\u003E\\u000a        \\u003Cinput class=\\\"input-large user-search-query\\\" type=\\\"text\\\" name=\\\"q\\\" id=\\\"fof-user-search-field\\\" /\\u003E\\u000a        \\u003Cbutton class=\\\"btn\\\" type=\\\"submit\\\"\\u003ESearch\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cp\\u003E\\u003Ca href=\\\"{{home_path}}\\\"\\u003E&larr; Go to the homepage\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    {{/render_page_content}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            \"500_page\": \"\\u003Cdiv class=\\\"content-narrow\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"error-page error-500 clearfix\\\"\\u003E\\u000a    {{#render_page_content}}\\u000a      \\u003Ch1 class=\\\"heading\\\"\\u003ESomething is technically wrong.\\u003C/h1\\u003E\\u000a      \\u003Cp class=\\\"lead\\\"\\u003EThanks for noticing&mdash;we're going to fix it up and have things back to normal soon.\\u003C/p\\u003E\\u000a      \\u003Cp\\u003E\\u003Ca href=\\\"{{home_path}}\\\"\\u003E&larr; Go to the homepage\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    {{/render_page_content}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            mobile_complete: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"mobile-complete-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003ESign up to use Twitter on the web.\\u003C/h1\\u003E\\u000a    \\u003Cform action=\\\"{{mobile_complete_path}}\\\" class=\\\"mobile-complete\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"address\\\" class=\\\"control-label\\\"\\u003EEnter your phone number:\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" id=\\\"address\\\" name=\\\"address\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" id=\\\"account_request_verification_code_submit\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/groups/34-apps-sms-and-mobile/topics/123-mobile-basics/articles/95277-which-twitter-account-is-my-mobile-phone-associated-with\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mobile_sms_complete: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"mobile-complete-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003ESign up to use Twitter on the web.\\u003C/h1\\u003E\\u000a    \\u003Cp\\u003EOn your phone, send \\u003Cstrong\\u003E{{start_command}}\\u003C/strong\\u003E to \\u003Cstrong\\u003E{{device_address}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a    \\u003Cp\\u003EFollow the instructions sent to your phone. Once you are finished, click continue.\\u003C/p\\u003E\\u000a    \\u003Cform action=\\\"{{mobile_sms_complete_path}}\\\" class=\\\"mobile-complete\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"address\\\", value=\\\"{{device}}\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" id=\\\"mobile_sms_complete_submit\\\"\\u003EContinue\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/groups/34-apps-sms-and-mobile/topics/123-mobile-basics/articles/95277-which-twitter-account-is-my-mobile-phone-associated-with\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mobile_verify: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"mobile-complete-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EWe've sent a verification code to your phone.\\u003C/h1\\u003E\\u000a    \\u003Cdiv class=\\\"verify-device-token\\\"\\u003E\\u000a      When you receive the code, type it in the box below. If you don't recieve the code in a few minutes, try\\u000a      \\u003Cform action=\\\"{{mobile_verify_path}}\\\" method=\\\"post\\\" class=\\\"link-form\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"send_again\\\" value=\\\"true\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"address\\\" value=\\\"{{device}}\\\" %\\u003E\\u000a        \\u003Cbutton id=\\\"resend_token\\\" class=\\\"btn-link\\\"\\u003Eresending your request\\u003C/button\\u003E.\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cform action=\\\"{{mobile_verify_path}}\\\" class=\\\"mobile-complete\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"address\\\" value=\\\"{{device}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Clabel for=\\\"verification_code\\\" class=\\\"control-label\\\"\\u003EEnter your verification code:\\u003C/label\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" id=\\\"verification_code\\\" name=\\\"device[verification_code]\\\" class=\\\"input-small\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" id=\\\"mobile_verify_submit\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/groups/34-apps-sms-and-mobile/topics/123-mobile-basics/articles/95277-which-twitter-account-is-my-mobile-phone-associated-with\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            password_reset: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EChoose your new password.\\u003C/h2\\u003E\\u000a    \\u003Cform action=\\\"{{accounts_path}}\\\" id=\\\"password-reset-form\\\" class=\\\"clearfix resend-password js-resend-password\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"email\\\" value=\\\"{{email_address}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"id\\\" value={{user_id}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"token\\\" value=\\\"{{token}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"reset_type\\\" value=\\\"{{reset_type}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      {{\\u003E shared/password}}\\u000a      \\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"btn primary-btn\\\" id=\\\"password_change_submit\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            password_reset_sent: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EWe've sent password reset instructions to your email address.\\u003C/h1\\u003E\\u000a    If you don't receive instructions within a minute or two, check your email's spam and junk filters, or try \\u003Ca href=\\\"{{resend_password_path}}\\\"\\u003Eresending your request\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/articles/15365?utm_source=15365&utm_medium=website&utm_campaign=inproduct\\\"\\u003EPlease contact Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            password_reset_type: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EChoose your password reset option.\\u003C/h1\\u003E\\u000a    Twitter can send password reset instructions to your email address or the phone number associated with your account.\\u000a    \\u003Cform action=\\\"{{password_reset_type_path}}\\\" class=\\\"resend-password\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" id=\\\"screen_name\\\" name=\\\"screen_name\\\" value=\\\"{{username}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" id=\\\"email_submit\\\" name=\\\"email_submit\\\" class=\\\"submit btn primary-btn\\\"\\u003EReset via email\\u003C/button\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" id=\\\"device_submit\\\" name=\\\"device_submit\\\" class=\\\"submit btn primary-btn\\\"\\u003EReset via phone\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/articles/14663#SMSreset?utm_source=14663&utm_medium=website&utm_campaign=inproduct\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            resend_password: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EForgot your password?\\u003C/h1\\u003E\\u000a    \\u003Cform action=\\\"{{accounts_path}}\\\" id=\\\"resend_password_form\\\" class=\\\"clearfix resend-password js-resend-password\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\" id=\\\"email_or_phone_fieldset\\\"\\u003E\\u000a        \\u003Clabel for=\\\"email_or_phone\\\" class=\\\"control-label\\\"\\u003EEnter your email address or phone number:\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" id=\\\"email_or_phone\\\" name=\\\"email_or_phone\\\" autocomplete=\\\"on\\\"\\u003E\\u000a          \\u003Cspan id=\\\"email_or_phone_notification\\\" class=\\\"help-inline notification\\\"\\u003E\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cdiv class=\\\"separator\\\"\\u003E\\u000a        &mdash;OR&mdash;\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\" id=\\\"screen_name_fieldset\\\"\\u003E\\u000a        \\u003Clabel for=\\\"screen_name\\\" class=\\\"control-label\\\"\\u003EEnter your username:\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cspan class=\\\"input-prepend\\\"\\u003E\\u000a            \\u003Cspan class=\\\"add-on\\\"\\u003E\\u003Ci class=\\\"tweet-at\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" id=\\\"screen_name\\\" name=\\\"screen_name\\\" autocomplete=\\\"on\\\" class=\\\"username-prepended-input\\\"\\u003E\\u000a          \\u003C/span\\u003E\\u000a          \\u003Cspan id=\\\"screen_name_notification\\\" class=\\\"help-inline notification notification-prepended\\\"\\u003E\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" id=\\\"lookup_user\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a      {{^no_captcha}}\\u000a        {{\\u003Edialogs/captcha_dialog}}\\u000a      {{/no_captcha}}\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/articles/14663#SMSreset?utm_source=14663&utm_medium=website&utm_campaign=inproduct\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            verify_device_token: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EWe've sent a password reset code to your phone.\\u003C/h1\\u003E\\u000a    \\u003Cdiv class=\\\"verify-device-token\\\"\\u003E\\u000a      When you receive the code, type it in the box below. If you don't receive the code within a few minutes, try\\u000a      \\u003Cform action=\\\"/account/password_reset_type?device_submit=true&device_resend=true\\\" method=\\\"post\\\" class=\\\"link-form\\\"\\u003E\\u003Cbutton id=\\\"resend_token\\\" class=\\\"btn-link\\\"\\u003Eresending your request\\u003C/button\\u003E.\\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u003C/form\\u003E\\u000a      {{#can_reset_password_by_email}}\\u000a      You can also\\u000a      \\u003Cform action=\\\"/account/password_reset_type?email_submit=true\\\" method=\\\"post\\\" class=\\\"link-form\\\"\\u003E\\u003Cbutton id=\\\"resend_email\\\" class=\\\"btn-link\\\"\\u003Ereset your password via email\\u003C/button\\u003E.\\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u003C/form\\u003E\\u000a      {{/can_reset_password_by_email}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cform action=\\\"{{verify_device_token_path}}\\\" id=\\\"verify-device-token-form\\\" class=\\\"clearfix resend-password js-resend-password\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" id=\\\"screen_name\\\" name=\\\"screen_name\\\" value=\\\"{{username}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"token\\\" class=\\\"control-label\\\"\\u003EEnter your reset code:\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" id=\\\"token\\\" name=\\\"token\\\" class=\\\"input-small\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" id=\\\"verify_token_submit\\\" class=\\\"btn primary-btn\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/articles/15365?utm_source=15365&utm_medium=website&utm_campaign=inproduct\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            verify_personal_information: \"\\u003Cdiv class=\\\"page-canvas route-resend-password\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"resend-password-wrapper\\\"\\u003E\\u000a    \\u003Ch1\\u003EVerify your personal information.\\u003C/h1\\u003E\\u000a    \\u003Cform action=\\\"{{verify_personal_information_path}}\\\" id=\\\"verify-personal-information-form\\\" class=\\\"clearfix resend-password js-resend-password\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        {{#has_valid_phone_number}}\\u000a          \\u003Clabel for=\\\"phone\\\" class=\\\"control-label\\\"\\u003EEnter phone number:\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" id=\\\"phone\\\" name=\\\"phone\\\" autocomplete=\\\"on\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a        {{/has_valid_phone_number}}\\u000a        {{^has_valid_phone_number}}\\u000a          \\u003Clabel for=\\\"email\\\" class=\\\"control-label\\\"\\u003EEnter email address:\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" id=\\\"email\\\" name=\\\"email\\\" autocomplete=\\\"on\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a        {{/has_valid_phone_number}}\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" id=\\\"lookup_user\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"contact-support\\\"\\u003E\\u000a    Need help? \\u003Ca href=\\\"https://support.twitter.com/articles/14663#SMSreset?utm_source=14663&utm_medium=website&utm_campaign=inproduct\\\"\\u003EPlease contact Twitter Support\\u003C/a\\u003E.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_item: \"\\u003Cdiv class=\\\"stream-item-content clearfix stream-item-activity stream-item-{{event}} {{#is_your_activity}}stream-item-activity-me{{/is_your_activity}}{{^is_your_activity}}stream-item-activity-network{{/is_your_activity}}\\\"\\u000a     data-activity-type=\\\"{{event}}\\\"\\u000a     data-activity-min-position=\\\"{{min_position}}\\\"\\u000a     data-activity-max-position=\\\"{{max_position}}\\\"\\u003E\\u000a\\u000a     \\u003Cdiv class=\\\"stream-item-activity-header\\\"\\u003E\\u000a       \\u003Cdiv class=\\\"activity-additional-info\\\"\\u003E\\u000a         {{^is_your_activity}}\\u000a           {{#has_hidden_supplements}}\\u000a             \\u003Ca href=\\\"#\\\" class=\\\"view-all-supplements show\\\"\\u003E{{{view_all_supplements_sentence}}}\\u003C/a\\u003E\\u000a           {{/has_hidden_supplements}}\\u000a         {{/is_your_activity}}\\u000a\\u000a         \\u003Cdiv class=\\\"activity-timestamp\\\"\\u003E\\u000a            \\u003Cspan class=\\\"_timestamp\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{full_timestamp}}\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a       \\u003C/div\\u003E\\u000a\\u000a       \\u003Cdiv class=\\\"stream-item-activity-line js-actionable-user {{#is_your_activity}}stream-item-activity-line-me{{/is_your_activity}}{{^is_your_activity}}stream-item-activity-line-network{{/is_your_activity}}\\\"\\u003E\\u000a         {{#should_show_first_actor}}\\u000a           {{#first_actor}}\\u000a             {{\\u003Euser_image_16}}\\u000a           {{/first_actor}}\\u000a         {{/should_show_first_actor}}\\u000a\\u000a         {{{activity_line}}}\\u000a\\u000a         \\u003Cb class=\\\"activity-type\\\"\\u003E\\u003Ci class=\\\"{{icon_class}}\\\"\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a       \\u003C/div\\u003E\\u000a     \\u003C/div\\u003E\\u000a\\u000a     {{#should_show_truncated_tweet}}\\u000a       \\u003Cdiv class=\\\"activity-truncated-tweet\\\"\\u003E\\u000a         {{{truncated_tweet}}}\\u000a       \\u003C/div\\u003E\\u000a     {{/should_show_truncated_tweet}}\\u000a\\u000a     \\u003Cdiv class=\\\"activity-supplement {{#has_hidden_supplements}} has-hidden-supplements{{/has_hidden_supplements}}{{#user_supplement_and_count_greater_than_two}}follow-more-than-two{{/user_supplement_and_count_greater_than_two}}{{#user_supplement_and_count_exactly_two}}follow-exactly-two{{/user_supplement_and_count_exactly_two}}\\\"\\u003E\\u000a       {{{activity_supplement}}}\\u000a\\u000a       {{#has_secondary_supplement}}\\u000a         \\u003Cdiv class=\\\"activity-secondary-supplement\\\"\\u003E\\u000a           {{{activity_secondary_supplement}}}\\u000a         \\u003C/div\\u003E\\u000a       {{/has_secondary_supplement}}\\u000a     \\u003C/div\\u003E\\u000a\\u000a     {{#is_your_activity}}\\u000a       {{#has_hidden_supplements}}\\u000a        \\u003Ca class=\\\"view-all-supplements show\\\" href=\\\"#\\\"\\u003E{{{view_all_supplements_sentence}}}\\u003C/a\\u003E\\u000a       {{/has_hidden_supplements}}\\u000a     {{/is_your_activity}}\\u000a\\u003C/div\\u003E\",\n            activity_item_content: \"{{#activity_item_view}}\\u000a\\u000a  {{#is_favorite}}\\u000a    {{\\u003Eactivities/activity_item_favorite}}\\u000a  {{/is_favorite}}\\u000a\\u000a  {{#is_follow}}\\u000a    {{\\u003Eactivities/activity_item_follow}}\\u000a  {{/is_follow}}\\u000a\\u000a  {{#is_list_add}}\\u000a    {{\\u003Eactivities/activity_item_list_add}}\\u000a  {{/is_list_add}}\\u000a\\u000a  {{#is_mention}}\\u000a    {{\\u003Eactivities/activity_item_mention}}\\u000a  {{/is_mention}}\\u000a\\u000a  {{#is_reply}}\\u000a    {{\\u003Eactivities/activity_item_reply}}\\u000a  {{/is_reply}}\\u000a\\u000a  {{#is_retweet}}\\u000a    {{\\u003Eactivities/activity_item_retweet}}\\u000a  {{/is_retweet}}\\u000a\\u000a{{/activity_item_view}}\",\n            activity_item_favorite: \"\\u003Cdiv class=\\\"stream-item-activity-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"activity-additional-info\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"activity-timestamp\\\"\\u003E\\u000a      \\u003Cspan class=\\\"_timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{short_timestamp}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-activity-line js-actionable-user stream-item-activity-line-me\\\"\\u003E\\u000a\\u000a    {{#sources_1}}\\u000a      {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} favorited your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} favorited your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_like}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} liked your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} liked your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} starred your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} starred your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}\\u000a    {{/sources_1}}\\u000a    {{#sources_2}}\\u000a      {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} favorited your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} favorited your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_like}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} liked your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} liked your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} starred your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} starred your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}\\u000a    {{/sources_2}}\\u000a    {{#sources_3}}\\u000a      {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} favorited your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} favorited your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_like}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} liked your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} liked your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} starred your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} starred your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}\\u000a    {{/sources_3}}\\u000a    {{#sources_more}}\\u000a      {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others favorited your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others favorited your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_like}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others liked your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others liked your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_like}}\\u000a      {{#australian_fav_to_star}}\\u000a        \\u000a          {{#targets_count_one}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others starred your Tweet{{/targets_count_one}}\\u000a          {{#targets_count_other}}{{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others starred your Tweets{{/targets_count_other}}\\u000a        \\u000a      {{/australian_fav_to_star}}\\u000a    {{/sources_more}}\\u000a\\u000a    \\u003Cb class=\\\"activity-type\\\"\\u003E\\u003Ci class=\\\"{{icon_class}}\\\"\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"activity-truncated-tweet\\\"\\u003E\\u000a  {{#target_0}}\\u000a    {{\\u003Elatest_tweet}}\\u000a  {{/target_0}}\\u000a\\u003Cdiv class=\\\"activity-supplement{{#targets_more_than_1}} has-hidden-supplements{{/targets_more_than_1}}\\\"\\u003E\\u000a  {{#sources_limited}}\\u000a    {{#targets_1}}\\u000a      {{\\u003Euser_avatar_link_24}}\\u000a    {{/targets_1}}\\u000a    {{#targets_more_than_1}}\\u000a      {{#target_1_to_limit}}\\u000a        {{\\u003Elatest_tweet}}\\u000a      {{/target_1_to_limit}}\\u000a    {{/targets_more_than_1}}\\u000a  {{/sources_limited}}\\u000a\\u003C/div\\u003E\\u000a{{#targets_more_than_1}}\\u000a  \\u003Cbutton type=\\\"button\\\" class=\\\"btn-link view-all-supplements show\\\"\\u003E\\u000a    \\u003Cspan class=\\\"show-text\\\"\\u003E\\u000a      \\u000a        {{#targets_less_1_one}}1 other favorite{{/targets_less_1_one}}\\u000a        {{#targets_less_1_other}}{{targets_less_1}} other favorites{{/targets_less_1_other}}\\u000a      \\u000a    \\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"hide-text\\\"\\u003EHide other favorites\\u003C/span\\u003E\\u000a  \\u003C/button\\u003E\\u000a{{/targets_more_than_1}}\\u000a\",\n            activity_item_follow: \"\\u003Cdiv class=\\\"stream-item-activity-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"activity-additional-info\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"activity-timestamp\\\"\\u003E\\u000a      \\u003Cspan class=\\\"_timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{full_timestamp}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-activity-line js-actionable-user stream-item-activity-line-me\\\"\\u003E\\u000a\\u000a    {{#sources_1}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} followed you\\u000a    {{/sources_1}}\\u000a    {{#sources_2}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} followed you\\u000a    {{/sources_2}}\\u000a    {{#sources_3}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} followed you\\u000a    {{/sources_3}}\\u000a    {{#sources_more}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others followed you\\u000a    {{/sources_more}}\\u000a\\u000a    \\u003Cb class=\\\"activity-type\\\"\\u003E\\u003Ci class=\\\"{{icon_class}}\\\"\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"activity-supplement {{#sources_2}}follow-exactly-two{{/sources_2}}{{#sources_3}}follow-more-than-two{{/sources_3}}{{#sources_more}}follow-more-than-two{{/sources_more}}\\\"\\u003E\\u000a  {{#sources_limited}}\\u000a    {{\\u003Euser_avatar_link_24}}\\u000a  {{/sources_limited}}\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_item_list_add: \"\\u003Cdiv class=\\\"stream-item-activity-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"activity-additional-info\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"activity-timestamp\\\"\\u003E\\u000a      \\u003Cspan class=\\\"_timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{short_timestamp}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-activity-line js-actionable-user stream-item-activity-line-me\\\"\\u003E\\u000a\\u000a    \\u000a\\u000a    {{#sources_1}}\\u000a      {{#target_objects_1}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} added you to list {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}\\u000a        \\u000a      {{/target_objects_1}}\\u000a      {{#target_objects_2}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}}\\u000a        \\u000a      {{/target_objects_2}}\\u000a      {{#target_objects_3}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}, {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}} and {{#target_object_2}}{{\\u003Elist_link}}{{/target_object_2}}\\u000a        \\u000a      {{/target_objects_3}}\\u000a      {{#target_objects_more}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and \\u003Cspan class='count-wrap'\\u003E{{target_objects_count_less_1}} others.\\u003C/span\\u003E\\u000a        \\u000a      {{/target_objects_more}}\\u000a    {{/sources_1}}\\u000a    {{#sources_2}}\\u000a      {{#target_objects_1}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} added you to list {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}\\u000a        \\u000a      {{/target_objects_1}}\\u000a      {{#target_objects_2}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}}\\u000a        \\u000a      {{/target_objects_2}}\\u000a      {{#target_objects_3}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}, {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}} and {{#target_object_2}}{{\\u003Elist_link}}{{/target_object_2}}\\u000a        \\u000a      {{/target_objects_3}}\\u000a      {{#target_objects_more}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and \\u003Cspan class='count-wrap'\\u003E{{target_objects_count_less_1}} others.\\u003C/span\\u003E\\u000a        \\u000a      {{/target_objects_more}}\\u000a    {{/sources_2}}\\u000a    {{#sources_3}}\\u000a      {{#target_objects_1}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} added you to list {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}\\u000a        \\u000a      {{/target_objects_1}}\\u000a      {{#target_objects_2}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}}\\u000a        \\u000a      {{/target_objects_2}}\\u000a      {{#target_objects_3}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}, {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}} and {{#target_object_2}}{{\\u003Elist_link}}{{/target_object_2}}\\u000a        \\u000a      {{/target_objects_3}}\\u000a      {{#target_objects_more}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and \\u003Cspan class='count-wrap'\\u003E{{target_objects_count_less_1}} others.\\u003C/span\\u003E\\u000a        \\u000a      {{/target_objects_more}}\\u000a    {{/sources_3}}\\u000a    {{#sources_more}}\\u000a      {{#target_objects_1}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}} others\\u003C/span\\u003E added you to list {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}\\u000a        \\u000a      {{/target_objects_1}}\\u000a      {{#target_objects_2}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}} others\\u003C/span\\u003E added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}}\\u000a        \\u000a      {{/target_objects_2}}\\u000a      {{#target_objects_3}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}} others\\u003C/span\\u003E added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}}, {{#target_object_1}}{{\\u003Elist_link}}{{/target_object_1}} and {{#target_object_2}}{{\\u003Elist_link}}{{/target_object_2}}\\u000a        \\u000a      {{/target_objects_3}}\\u000a      {{#target_objects_more}}\\u000a        \\u000a          {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}} others\\u003C/span\\u003E added you to lists {{#target_object_0}}{{\\u003Elist_link}}{{/target_object_0}} and \\u003Cspan class='count-wrap'\\u003E{{target_objects_count_less_1}} others.\\u003C/span\\u003E\\u000a        \\u000a      {{/target_objects_more}}\\u000a    {{/sources_more}}\\u000a\\u000a    \\u003Cb class=\\\"activity-type\\\"\\u003E\\u003Ci class=\\\"{{icon_class}}\\\"\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_item_mention: \"{{#target_object_0}}\\u000a  {{\\u003Estream_tweet}}\\u000a{{/target_object_0}}\\u000a\",\n            activity_item_reply: \"{{#target_0}}\\u000a  {{\\u003Estream_tweet}}\\u000a{{/target_0}}\",\n            activity_item_retweet: \"\\u003Cdiv class=\\\"stream-item-activity-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"activity-additional-info\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"activity-timestamp\\\"\\u003E\\u000a      \\u003Cspan class=\\\"_timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{full_timestamp}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-activity-line js-actionable-user stream-item-activity-line-me\\\"\\u003E\\u000a\\u000a    {{#sources_1}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} retweeted you\\u000a    {{/sources_1}}\\u000a    {{#sources_2}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} retweeted you\\u000a    {{/sources_2}}\\u000a    {{#sources_3}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}}, {{#source_1}}{{\\u003Eactivity_user_link}}{{/source_1}} and {{#source_2}}{{\\u003Eactivity_user_link}}{{/source_2}} retweeted you\\u000a    {{/sources_3}}\\u000a    {{#sources_more}}\\u000a      {{#source_0}}{{\\u003Eactivity_user_link}}{{/source_0}} and \\u003Cspan class='count-wrap'\\u003E{{sources_count_less_1}}\\u003C/span\\u003E others retweeted you\\u000a    {{/sources_more}}\\u000a\\u000a    \\u003Cb class=\\\"activity-type\\\"\\u003E\\u003Ci class=\\\"{{icon_class}}\\\"\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"activity-truncated-tweet\\\"\\u003E\\u000a  {{#target_0}}\\u000a    {{\\u003Elatest_tweet}}\\u000a  {{/target_0}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"activity-supplement{{#targets_more_than_1}} has-hidden-supplements{{/targets_more_than_1}}\\\"\\u003E\\u000a  {{#sources_limited}}\\u000a    {{#targets_1}}\\u000a      {{\\u003Euser_avatar_link_24}}\\u000a    {{/targets_1}}\\u000a    {{#targets_more_than_1}}\\u000a      {{#target_1_to_limit}}\\u000a        {{\\u003Elatest_tweet}}\\u000a      {{/target_1_to_limit}}\\u000a    {{/targets_more_than_1}}\\u000a  {{/sources_limited}}\\u000a\\u003C/div\\u003E\\u000a{{#targets_more_than_1}}\\u000a  \\u003Cbutton type=\\\"button\\\" class=\\\"btn-link view-all-supplements show\\\"\\u003E\\u000a    \\u003Cspan class=\\\"show-text\\\"\\u003E\\u000a      \\u000a        {{#targets_less_1_one}}1 other retweet{{/targets_less_1_one}}\\u000a        {{#targets_less_1_other}}{{targets_less_1}} other retweets{{/targets_less_1_other}}\\u000a      \\u000a    \\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"hide-text\\\"\\u003EHide other retweets\\u003C/span\\u003E\\u000a  \\u003C/button\\u003E\\u000a{{/targets_more_than_1}}\\u000a\",\n            activity_item_truncated_tweet: \"\\u003Cdiv class=\\\"sub-stream-item {{#hidden}}sub-stream-item-hidden{{/hidden}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-content tweet js-actionable-tweet truncated-tweet activity-item-tweet {{css_classes}}\\\" data-tweet-id=\\\"{{id}}\\\" {{{tweet_impression_id}}} {{#current_user_retweet}}data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}} data-item-id=\\\"{{id}}\\\" {{#was_retweeted}}{{#retweeting_status}}data-retweet-id=\\\"{{id}}\\\"{{/retweeting_status}}{{/was_retweeted}} {{#user}}data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"{{/user}} {{#protected}}data-protected=\\\"true\\\"{{/protected}} {{#is_sponsored}}data-promoted=\\\"true\\\"{{/is_sponsored}}\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a        {{\\u003Elatest_tweet_timestamp}}:\\u000a        {{#was_retweeted}}\\u000a          \\u003Cspan class=\\\"retweet-icon\\\"\\u003E\\u003C/span\\u003E\\u000a        {{{retweet_source_screen_name_link}}}\\u000a        {{/was_retweeted}}\\u000a        &#32;{{\\u003Etweet_text}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            activity_item_tweet: \"\\u000a  \\u003Cdiv class=\\\"in-reply-to js-tweet-ancestors\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"tweet js-stream-tweet js-hover js-actionable-tweet js-original-tweet {{#is_sponsored}} promoted-tweet{{/is_sponsored}}{{#is_my_tweet}} my-tweet{{/is_my_tweet}}{{#favorited}} favorited{{/favorited}}{{#current_user_retweet}} retweeted{{/current_user_retweet}} {{#hidden}}sub-stream-item-hidden{{/hidden}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a  \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      {{\\u003Etweet_user_block}}\\u000a      {{\\u003Etweet_timestamp}}\\u000a      {{\\u003Etweet_actions}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a      {{\\u003Etweet_context}}\\u000a      \\u003Ca class=\\\"details with-icn js-details\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Cspan class=\\\"js-icon-container\\\"{{#place_name}} data-placename=\\\"{{place_name}}\\\"{{/place_name}}\\u003E\\u000a          {{#is_reply}}\\u000a            \\u003Ci class=\\\"sm-convo\\\"\\u003E\\u003C/i\\u003E\\u000a          {{/is_reply}}\\u000a        \\u003C/span\\u003E\\u000a        \\u003Cb\\u003E\\u000a          \\u003Cspan class=\\\"view-expanded js-view-details\\\"\\u003E\\u000a            {{#is_reply}}in reply to @{{in_reply_to_screen_name}}{{/is_reply}}\\u000a          \\u003C/span\\u003E\\u000a          \\u003Cspan class=\\\"hide-expanded js-hide-details\\\"\\u003E\\u000a            {{#is_reply}}in reply to @{{in_reply_to_screen_name}}{{/is_reply}}\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Estream_tweet_expansion}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"replies js-other-components\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\",\n            activity_item_user: \"\\u003Cdiv class=\\\"sub-stream-item {{#hidden}}sub-stream-item-hidden{{/hidden}}\\\"\\u003E\\u000a  \\u003Cdiv data-user-id='{{id}}' class='stream-item-content js-actionable-user user-content-medium clearfix {{#promoted_content}}promoted-account{{/promoted_content}}' data-screen-name=\\\"{{screen_name}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a    {{#is_your_activity}}\\u000a      \\u003Cimg src='{{mini_profile_image_url}}' alt='{{name}}' class='user-content-image user-profile-link' data-user-id='{{id}}' title=\\\"{{name}}\\\"/\\u003E\\u000a    {{/is_your_activity}}\\u000a    {{^is_your_activity}}\\u000a      \\u003Cimg src='{{bigger_profile_image_url}}' alt='{{name}}' class='user-content-image user-profile-link' data-user-id='{{id}}' title=\\\"{{name}}\\\"/\\u003E\\u000a    {{/is_your_activity}}\\u000a\\u000a    \\u003Cdiv class=\\\"user-content-rest\\\"\\u003E\\u000a      \\u003Cspan class='user-name'\\u003E\\u000a        \\u003Ca class='user-profile-link' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E\\u003Cstrong\\u003E{{screen_name}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a        \\u003Cspan class='full-name'\\u003E{{name}}\\u003C/span\\u003E\\u000a        {{#verified}}\\u000a          \\u003Cspan class=\\\"verified-icon-small\\\" title=\\\"Verified Account\\\"\\u003E\\u003C/span\\u003E\\u000a        {{/verified}}\\u000a        {{#protected}}\\u000a          \\u003Cspan class=\\\"protected-icon\\\"\\u003E\\u003C/span\\u003E\\u000a        {{/protected}}\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a      {{\\u003Estream_user_buttons}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            activity_of_me_stream_title: \"\\u003Cspan\\u003E\\u000a  @mentions and more\\u000a\\u003C/span\\u003E\\u000a\\u003Cspan class='activity-filters'\\u003E\\u000a  \\u003Clabel for='show_mentions_only' class='show-mentions-only-label'\\u003E\\u000a    \\u003Cinput type=\\\"checkbox\\\" name=\\\"show_mentions_only\\\" id=\\\"show_mentions_only\\\" value=\\\"1\\\" /\\u003E\\u000a    \\u003Cspan class='filter-text'\\u003EShow mentions only\\u003C/span\\u003E\\u000a  \\u003C/label\\u003E\\u000a\\u003C/span\\u003E\",\n            activity_user_link: \"\\u003Ca class=\\\"pretty-link js-user-profile-link js-action-profile-name\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u003C/a\\u003E\",\n            add_people: \"\\u003Cdiv class=\\\"stream-placeholder\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EFind people to add to your list\\u003C/h2\\u003E\\u000a    \\u003Cform class=\\\"inline-form js-search-for-list-people\\\" action=\\\"{{who_to_follow_search_form_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a      \\u003Cinput type=\\\"text\\\" name=\\\"q\\\" placeholder=\\\"find users by name\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"btn js-submit\\\"\\u003ESearch\\u003C/button\\u003E\\u000a    \\u003C/form\\u003E\\u000a    \\u003Cp\\u003ESearch for a username, first or last name, business or brand. You can also add people from your \\u003Ca href=\\\"{{following_path}}\\\"\\u003EFollowing\\u003C/a\\u003E page or anyone's profile page.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            add_to_list_dialog: \"\\u003Cdiv class=\\\"add-to-list-prompt\\\"\\u003E\\u000a  \\u003Cp\\u003EInclude \\u003Cspan class=\\\"pretty-link\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E in:\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cul class=\\\"list-membership-container\\\"\\u003E\\u003C/ul\\u003E\",\n            admin_banner: \"\\u003Cdiv class=\\\"profile-user-only-admin-accessible\\\"\\u003E{{#suspended}}This account is suspended and is only accessible to admin users.{{/suspended}}{{^suspended}}This account is only accessible to admin users.{{/suspended}}\\u003C/div\\u003E\\u000a\",\n            ancestors: \"\\u003Cdiv class=\\\"in-reply-to js-tweet-ancestors\\\"\\u003E\\u000a  \\u003Cdiv\\u003E\\u000a    {{#rendering_on_server}}\\u000a      {{{ancestors_html}}}\\u000a    {{/rendering_on_server}}\\u000a    {{^rendering_on_server}}\\u000a      {{#ancestors}}\\u000a        {{\\u003Esimple_tweet}}\\u000a      {{/ancestors}}\\u000a      {{#protected_ancestor}}\\u000a        {{\\u003Eprotected_ancestor_tweet}}\\u000a      {{/protected_ancestor}}\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            avatar_row: \"\\u003Cdiv class=\\\"avatar-row\\\"\\u003E\\u000a  {{#items}}\\u000a    {{#image_is_placeholder}}\\u000a      \\u003Cdiv class=\\\"avatar avatar-placeholder size32\\\" alt=\\\"{{name}}\\\" original-title=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003C/div\\u003E\\u000a    {{/image_is_placeholder}}\\u000a    {{^image_is_placeholder}}\\u000a      \\u003Cspan class=\\\"js-user-profile-link user-thumb\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a        \\u003Cimg class=\\\"avatar size32 js-bubble-event js-user-tipsy js-tooltip\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" original-title=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a      \\u003C/span\\u003E\\u000a    {{/image_is_placeholder}}\\u000a  {{/items}}\\u000a\\u003C/div\\u003E\\u000a\",\n            back_link: \"\\u003Cspan\\u003E&middot; \\u003Ca href=\\\"{{route}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/span\\u003E\",\n            back_to_top: \"\\u003Cp\\u003E\\u003Cbutton type='button' class='btn-link back-to-top {{#swift}}hidden{{/swift}}'\\u003EBack to top &uarr;\\u003C/button\\u003E\\u003C/p\\u003E\",\n            banned_passwords: \"\\u000a\\u003Cscript type=\\\"text/javascript\\\" id=\\\"banned_passwords\\\"\\u003E\\u000a  twttr.BANNED_PASSWORDS = [];\\u000a  (function() {\\u000a    var r = {{{banned_pwds_rot13_json}}};\\u000a    for (var i = r.length - 1; i \\u003E= 0; i--){\\u000a      twttr.BANNED_PASSWORDS.push(r[i].replace(/[a-z]/gi, function(l){\\u000a          var c = l.charCodeAt(0), n = c + 13;\\u000a          if((c\\u003C=90 && n\\u003E90) || (n\\u003E122)) { n -= 26; }\\u000a          return String.fromCharCode(n);\\u000a      }));\\u000a    };\\u000a  })();\\u000a\\u003C/script\\u003E\",\n            became_user_banner: \"\\u003Cdiv class=\\\"became-user-banner-outer banner-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"became-user-banner-inside banner-inside\\\"\\u003E\\u000a      \\u003Cspan\\u003E\\u000a        You are accessing a user's account for support purposes. Please ensure you log out.\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            big_avatar_list_item: \"\\u000a\\u003Cli class=\\\"list-item js-list-item js-actionable-user\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  {{#dismissable}}\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a  {{/dismissable}}\\u000a\\u000a  \\u000a  \\u003Ca class=\\\"account-group js-account-group\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    {{\\u003Euser_image_128}}\\u000a    \\u003Cspan class=\\\"account-group-inner js-action-profile-name\\\"\\u003E\\u000a      \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E{{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a      \\u003Csmall class=\\\"username\\\" data-user-id='{{id}}'\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/small\\u003E\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a  {{^swift}}\\u000a    {{\\u003Ecombo_follow_button}}\\u000a  {{/swift}}\\u000a  {{#swift}}\\u000a    {{\\u003Euser_actions}}\\u000a  {{/swift}}\\u000a\\u003C/li\\u003E\",\n            blocked_from_following_error_message: \"Sorry, you can't follow this user (because they're blocking you).\\u000a\\u003Ca href=\\\"{{blocked_from_following_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            bouncing_email_banner: \"\\u003Cdiv class=\\\"module module-banner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    {{#stacked}}\\u000a      \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EWhoops, we're having problems sending you email!\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EWe've tried sending emails to \\u003Cstrong\\u003E{{current_email}}\\u003C/strong\\u003E but they are not getting delivered. You will not receive important account emails unless you update your email address.\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/stacked}}\\u000a    {{^stacked}}\\u000a      \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EIs your email address active?\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EWe've tried to send emails to \\u003Cstrong\\u003E{{current_email}}\\u003C/strong\\u003E but they are not getting delivered.\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"second-banner-row\\\"\\u003E\\u000a        \\u003Cp\\u003EPlease \\u003Ca id=\\\"bounce_settings_link\\\" href=\\\"{{change_email_path}}\\\"\\u003Eupdate your email settings\\u003C/a\\u003E or \\u003Ca href=\\\"#\\\" class='reset-bounce-link'\\u003Etry sending a message again\\u003C/a\\u003E to your current address.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/stacked}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            card_accounts_onebox: \"\\u003Cdiv class=\\\"user card\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"card-body\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"onebox-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ETop people\\u003C/h3\\u003E\\u000a      \\u003Csmall class=\\\"view-all\\\"\\u003E &middot; \\u003Ca class=\\\"js-onebox-view-all\\\" href=\\\"{{view_all_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"account-summary-grid\\\"\\u003E\\u000a      \\u000a      {{#items}}\\u000a        {{\\u003Ecard_accounts_onebox_item}}\\u000a      {{/items}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            card_accounts_onebox_item: \"\\u000a\\u003Cdiv class=\\\"account-summary js-onebox-user-item js-actionable-user\\\" data-user-id=\\\"{{id_str}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  {{^is_current_user}}\\u000a    {{\\u003Ecombo_follow_button}}\\u000a  {{/is_current_user}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id_str}}\\\"\\u003E\\u000a      \\u003Cimg class=\\\"avatar size48 js-action-profile-avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{screen_name}}\\\"\\u003E\\u000a      \\u003Cb class=\\\"fullname js-action-profile-name\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a      \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u000a      {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a      \\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Csmall class=\\\"bio js-onebox-ellipsis\\\"\\u003E{{{description}}}\\u003C/small\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            card_event_onebox: \"\\u003Cdiv class=\\\"news card js-onebox-event-item\\\"\\u003E\\u000a  \\u003Ca class=\\\"card-body\\\" href=\\\"{{url}}\\\"\\u003E\\u000a    {{#media}}\\u000a      {{#thumbnail}}\\u000a        \\u003Cdiv class=\\\"image-wrapper\\\"\\u003E\\u000a          \\u003Cimg class=\\\"resize-to-fit\\\" src=\\\"{{url}}\\\" alt=\\\"\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/thumbnail}}\\u000a    {{/media}}\\u000a    \\u003Ch2 class=\\\"js-news-headline\\\"\\u003E{{title}}\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"js-news-snippet\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a    \\u003Cspan class=\\\"attribution url\\\"\\u003E\\u000a      {{display_url}}\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            card_news: \"\\u003Cdiv class=\\\"story article js-story-item {{#is_hashtag}}is-hashtag{{/is_hashtag}}\\\" data-query=\\\"{{query}}\\\" data-story-type=\\\"news\\\" data-item-key=\\\"{{story_key}}\\\"\\u003E\\u000a  \\u003Cspan class=\\\"story-header\\\"\\u003E\\u000a    \\u000a    \\u003Ca class=\\\"view-tweets js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u000a      \\u003Csmall class=\\\"view-more-tweets\\\"\\u003EView Tweets about this &rarr;\\u003C/small\\u003E\\u000a      \\u003Csmall class=\\\"view-hashtag\\\"\\u003E\\u003Ci class=\\\"sm-search\\\"\\u003E\\u003C/i\\u003E\\u003Cb class=\\\"search-text\\\"\\u003ESearch this #hashtag\\u003C/b\\u003E\\u003C/small\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ch3 class=\\\"story-title js-story-title js-news-headline\\\"\\u003E\\u003Ca class=\\\"js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E{{story_name}}\\u003C/a\\u003E\\u003C/h3\\u003E\\u000a  \\u003C/span\\u003E\\u000a  \\u003Cdiv class=\\\"story-body\\\"\\u003E\\u000a    \\u003Ca class=\\\"story-article js-action-card-news\\\" href=\\\"{{article_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a      {{#article_image}}\\u000a        \\u003Cdiv class=\\\"image-wrapper\\\"\\u003E\\u000a          \\u003Cimg class=\\\"article-image\\\" src=\\\"{{article_image}}\\\" alt=\\\"{{title}}\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/article_image}}\\u000a      \\u003Ch4 class=\\\"story-title\\\"\\u003E{{title}}\\u003C/h4\\u003E\\u000a      \\u003Cp class=\\\"story-summary js-news-snippet\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a      \\u003Cp class=\\\"metadata js-metadata\\\"\\u003E{{article_display_url}}\\u003C/p\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            card_news_onebox: \"\\u003Cdiv class=\\\"news card js-onebox-news-item\\\"\\u003E\\u000a  \\u003Ca class=\\\"card-body\\\" href=\\\"{{article_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"onebox-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ETop news\\u003C/h3\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#article_image}}\\u000a      \\u003Cdiv class=\\\"image-wrapper\\\"\\u003E\\u000a        \\u003Cimg src=\\\"{{article_image}}\\\" alt=\\\"\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/article_image}}\\u000a    \\u003Ch2 class=\\\"js-news-headline\\\"\\u003E{{title}}\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"js-news-snippet\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a    \\u003Cspan class=\\\"attribution url\\\"\\u003E\\u000a      {{article_display_url}}\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            card_soccer_onebox: \"\\u000a\\u003Cdiv class=\\\"card card-soccer js-onebox-soccer-item\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"matched-event\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            card_topic: \"\\u000a\\u000a\\u000a\\u003Cdiv class=\\\"story {{media_type}} js-story-item js-loading loading {{^has_media}}js-nomedia nomedia{{/has_media}} {{#is_hashtag}}is-hashtag{{/is_hashtag}}\\\" data-query=\\\"{{escaped_query}}\\\" data-story-type=\\\"topic\\\" data-card-media-type=\\\"{{media_type}}\\\" data-item-key=\\\"{{story_key}}\\\"\\u003E\\u000a  \\u003Cspan class=\\\"story-header\\\"\\u003E\\u000a    \\u003Ca class=\\\"view-tweets js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u000a      \\u003Cspan class=\\\"view-more-tweets\\\"\\u003EView Tweets about this &rarr;\\u003C/span\\u003E\\u000a      \\u003Cspan class=\\\"view-hashtag\\\"\\u003E\\u003Ci class=\\\"sm-search\\\"\\u003E\\u003C/i\\u003E\\u003Cb class=\\\"search-text\\\"\\u003ESearch this #hashtag\\u003C/b\\u003E\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ch3 class=\\\"story-title js-news-headline\\\"\\u003E\\u003Ca class=\\\"js-action-card-search\\\" href=\\\"{{search_path}}\\\"  data-query-source=\\\"{{search_query_source}}\\\"\\u003E{{story_name}}\\u003C/a\\u003E\\u003C/h3\\u003E\\u000a  \\u003C/span\\u003E\\u000a  {{#has_media}}\\u000a  \\u003Cdiv class=\\\"story-body\\\"\\u003E\\u000a    \\u003Ca class=\\\"media-card js-action-card-media\\\" href=\\\"{{card_url}}\\\" \\u003E\\u000a      \\u003Cdiv class=\\\"story-load-status\\\"\\u003E\\u000a        \\u003Cp\\u003ELoading...\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cimg class=\\\"story-{{media_type}} js-story-media\\\" data-item-id=\\\"{{escaped_query}}\\\" alt=\\\"{{escaped_query}}\\\" data-img-src=\\\"{{data_image_url}}\\\"\\u003E\\u000a      {{#has_video}}\\u000a        \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a      {{/has_video}}\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"story-tweet js-action-card-media\\\" href=\\\"{{card_url}}\\\"\\u003E\\u000a    {{#tweet}}\\u000a      \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a        \\u003Cspan class=\\\"details\\\"\\u003E\\u000a          \\u003Ci class=\\\"disco-media-type\\\"\\u003E\\u003C/i\\u003EView details\\u000a        \\u003C/span\\u003E\\u000a        {{#user}}\\u000a          \\u003Cimg class=\\\"avatar size20\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a          \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a          \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/span\\u003E\\u000a        {{/user}}\\u000a        \\u003Cp class=\\\"tweet-text\\\"\\u003E{{tweet_text}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/tweet}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cspan class=\\\"media-headline\\\"\\u003E\\u000a    \\u003Ch3 class=\\\"story-title js-news-headline\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u000a        \\u003Cspan class=\\\"story-title-text\\\"\\u003E{{story_name}}\\u003C/span\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/h3\\u003E\\u000a  \\u003C/span\\u003E\\u000a  {{#has_attribution}}\\u000a  \\u003Ca class=\\\"attribution js-story-attribution\\\" href=\\\"{{attribution_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a    \\u003Cimg class=\\\"favicon\\\" src=\\\"{{attribution_img}}\\\" alt=\\\"{{attribution_name}}\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a  {{/has_attribution}}\\u000a  {{/has_media}}\\u000a\\u003C/div\\u003E\\u000a\",\n            card_tweet: \"\\u000a\\u000a\\u000a{{#has_media}}\\u000a  {{#has_image}}\\u000a    {{\\u003Ecard_tweet_image}}\\u000a  {{/has_image}}\\u000a  {{#has_video}}\\u000a    {{\\u003Ecard_tweet_video}}\\u000a  {{/has_video}}\\u000a{{/has_media}}\\u000a\\u000a\\u000a{{^has_media}}\\u000a  \\u003Cdiv class=\\\"card js-card-item\\\" data-tweet-id=\\\"{{id}}\\\" data-card-type=\\\"tweet\\\"\\u003E\\u000a    \\u000a    \\u003Cdiv class=\\\"stream-item\\\"\\u003E{{\\u003Estream_tweet}}\\u003C/div\\u003E\\u000a    \\u000a    \\u003Ca class=\\\"card-footer js-action-card-permalink\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a      \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003Cp class=\\\"context\\\"\\u003E{{social_proof}}\\u003C/p\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/has_media}}\\u000a\",\n            card_tweet_image: \"  \\u000a\\u000a\\u003Cdiv class=\\\"card image js-card-item\\\" data-tweet-id=\\\"{{id}}\\\" data-card-type=\\\"tweet\\\"\\u003E\\u000a  \\u000a  \\u003Ca class=\\\"card-footer-overlay js-action-card-permalink\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a    \\u003Ci class=\\\"chev-light-right\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cdiv class=\\\"headline\\\"\\u003E\\u000a      {{#user}}\\u000a        \\u003Cimg class=\\\"attribution-icon\\\" src=\\\"{{profile_image_url}}\\\"\\u003E\\u000a        \\u003Ch3\\u003E{{name}}:\\u003C/h3\\u003E\\u000a      {{/user}}\\u000a      \\u003Cspan class=\\\"content-preview\\\"\\u003E{{text}}\\u003C/span\\u003E\\u000a      \\u003Cp class=\\\"context\\\"\\u003E{{social_proof}}\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u000a  \\u003Ca class=\\\"card-background js-action-card-permalink\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a    \\u003Cimg class=\\\"card-background-image\\\" data-item-id=\\\"{{id}}\\\" src=\\\"{{card_background_image}}\\\" alt=\\\"\\\" /\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Ca href=\\\"#\\\"\\u003E\\u000a    \\u003Cimg class=\\\"media attribution-icon\\\" src=\\\"http://yfrog.com/favicon.ico\\\" alt=\\\"\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            card_tweet_video: \"\\u000a\\u000a\\u003Cdiv class=\\\"card full-bleed video js-card-item\\\" data-tweet-id=\\\"{{id}}\\\" data-card-type=\\\"tweet\\\"\\u003E\\u000a  \\u000a  \\u003Ca class=\\\"card-footer-overlay js-action-card-permalink\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a    \\u003Ci class=\\\"chev-light-right\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cdiv class=\\\"headline\\\"\\u003E\\u000a      {{#user}}\\u000a        \\u003Cimg class=\\\"attribution-icon\\\" src=\\\"{{profile_image_url}}\\\"\\u003E\\u000a        \\u003Ch3\\u003E{{name}}:\\u003C/h3\\u003E\\u000a      {{/user}}\\u000a      \\u003Cspan class=\\\"content-preview\\\"\\u003E{{text}}\\u003C/span\\u003E\\u000a      \\u003Cp class=\\\"context\\\"\\u003E{{social_proof}}\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u000a  \\u003Ca class=\\\"card-background js-action-card-permalink\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a    \\u003Cimg class=\\\"card-background-image\\\" data-item-id=\\\"{{id}}\\\" src=\\\"{{card_background_image}}\\\"alt=\\\"\\\" /\\u003E\\u000a    \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Ca href=\\\"#\\\"\\u003E\\u000a    \\u003Cimg class=\\\"media attribution-icon\\\" src=\\\"http://yfrog.com/favicon.ico\\\" alt=\\\"\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            cards_base: \"{{#photos}}{{\\u003Ecards_media}}{{/photos}}\\u000a{{#players}}{{\\u003Ecards_media}}{{/players}}\\u000a{{#summaries}}{{\\u003Ecards_summary}}{{/summaries}}\\u000a\",\n            cards_flag_media: \"\\u003Cspan class=\\\"flag-container flag-cards\\\"\\u003E\\u000a  \\u003Cbutton type=\\\"button\\\" class=\\\"flaggable btn-link\\\"\\u003E\\u000a    Flag media\\u000a  \\u003C/button\\u003E\\u000a  \\u003Cspan class=\\\"flagged hidden\\\"\\u003E\\u000a    Flagged\\u000a    \\u003Cspan\\u003E\\u000a      \\u003Ca target=\\\"_blank\\\" href=\\\"//support.twitter.com/articles/20069937\\\"\\u003E\\u000a        (learn more)\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/span\\u003E\",\n            cards_layout: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml\\u003E\\u000a  \\u003Chead\\u003E\\u000a    \\u003Cmeta charset=\\\"utf-8\\\"\\u003E\\u000a    \\u003Cbase href=\\\"https://twitter.com\\\" target=\\\"_top\\\"\\u003E\\u000a    \\u003Ctitle\\u003ETwitter Card Preview\\u003C/title\\u003E\\u000a    \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{core_css_bundle}}\\\"\\u003E\\u000a    \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{more_css_bundle}}\\\"\\u003E\\u000a  \\u003C/head\\u003E\\u000a  \\u003Cbody\\u003E\\u000a    {{{content_for_layout}}}\\u000a  \\u003C/body\\u003E\\u000a\\u003C/html\\u003E\",\n            cards_media: \"\\u003Cdiv data-card-url=\\\"{{url}}\\\" data-card-type=\\\"{{#players}}player{{/players}}{{^players}}photo{{/players}}\\\" class=\\\"cards-base cards-multimedia\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media\\\"\\u003E\\u000a    {{! Since players and photos are identical in terms of metadata, just show\\u000a        one or other here, and share the metadata component }}\\u000a    {{#players}}\\u000a    \\u003Ciframe src=\\\"{{source_url}}\\\" width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"\\u003E\\u003C/iframe\\u003E\\u000a    {{/players}}\\u000a    {{^players}}{{#images}}{{#web}}\\u000a    \\u003Ca {{^permalink_continuity}}target=\\\"_blank\\\" {{/permalink_continuity}}class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E\\u000a      \\u003Cimg src=\\\"{{image_url}}\\\" alt=\\\"Embedded image permalink\\\" {{#width}}{{#height}}width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"{{/height}}{{/width}} {{#title}}title=\\\"{{title}}\\\"{{/title}}\\u003E\\u000a    \\u003C/a\\u003E\\u000a    {{/web}}{{/images}}{{/players}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"cards-content\\\"\\u003E\\u000a    {{#title}}\\u003Ch3\\u003E\\u000a      \\u003Ca {{^permalink_continuity}}target=\\\"_blank\\\" {{/permalink_continuity}}class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E{{title}}\\u003C/a\\u003E\\u000a    \\u003C/h3\\u003E{{/title}}\\u000a    \\u003Cdiv class=\\\"byline\\\"\\u003E\\u000a      {{#author_user}}By {{\\u003Ecards_user_byline}}{{/author_user}}\\u000a      {{#twimg_attribution}}\\u000a        {{#author_user}}&middot; {{/author_user}}\\u000a        \\u003Cspan class=\\\"pb-attribution\\\"\\u003E\\u000a          Powered by \\u003Ca target=\\\"_blank\\\" class=\\\"with-icn\\\" href=\\\"http://photobucket.com/twitter\\\"\\u003E\\u003Ci class=\\\"service-sm-native-photobucket\\\"\\u003E\\u003C/i\\u003EPhotobucket\\u003C/a\\u003E\\u000a        \\u003C/span\\u003E\\u000a      {{/twimg_attribution}}\\u000a    \\u003C/div\\u003E\\u000a    {{#description}}\\u003Cp\\u003E\\u003Ca {{^permalink_continuity}}target=\\\"_blank\\\" {{/permalink_continuity}}class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E{{description}}\\u003C/a\\u003E\\u003C/p\\u003E{{/description}}\\u000a  \\u003C/div\\u003E\\u000a  {{#site_user}}{{\\u003Ecards_user_source}}{{/site_user}}\\u000a\\u003C/div\\u003E\",\n            cards_summary: \"\\u003Cdiv data-card-url=\\\"{{url}}\\\" data-card-type=\\\"summary\\\" class=\\\"cards-base cards-summary {{#images}}{{#web}}with-image{{/web}}{{/images}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"cards-content clearfix\\\"\\u003E\\u000a    {{#images}}{{#web}}\\u000a    \\u003Ca target=\\\"_blank\\\" class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E\\u000a      \\u003Cimg class=\\\"summary-thumbnail\\\" src=\\\"{{image_url}}\\\" alt=\\\"\\\" {{#width}}{{#height}}height=\\\"{{height}}\\\" width=\\\"{{width}}\\\"{{/height}}{{/width}}\\u003E\\u000a    \\u003C/a\\u003E\\u000a    {{/web}}{{/images}}\\u000a    \\u003Ch3\\u003E\\u000a      \\u003Ca {{^permalink_continuity}}target=\\\"_blank\\\" {{/permalink_continuity}}class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E{{title}}\\u003C/a\\u003E\\u000a    \\u003C/h3\\u003E\\u000a    {{#author_user}}\\u000a    \\u003Cdiv class=\\\"byline\\\"\\u003EBy {{\\u003Ecards_user_byline}}\\u003C/div\\u003E\\u000a    {{/author_user}}\\u000a    {{#description}}\\u000a    \\u003Cp class=\\\"article\\\"\\u003E\\u000a      \\u003Ca {{^permalink_continuity}}target=\\\"_blank\\\" {{/permalink_continuity}}class=\\\"twitter-timeline-link\\\" href=\\\"{{url}}\\\"\\u003E{{description}}\\u003C/a\\u003E\\u000a    \\u003C/p\\u003E\\u000a    {{/description}}\\u000a    {{#site_user}}{{\\u003Ecards_user_source}}{{/site_user}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            cards_user_byline: \"\\u003Ca class=\\\"account-group js-account-group js-action-profile js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cstrong class=\\\"fullname js-action-profile-name\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a  \\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a\\u003C/a\\u003E\",\n            cards_user_source: \"\\u003Cdiv class=\\\"source\\\"\\u003E\\u003Ca class=\\\"account-group js-action-profile js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cimg class=\\\"avatar js-action-profile-avatar\\\" src=\\\"{{profile_image_url_https}}\\\" alt=\\\"\\\"\\u003E\\u000a  \\u003Cstrong class=\\\"fullname js-action-profile-name\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a  \\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a\\u003C/a\\u003E\\u000a &middot; {{\\u003Euser_item_action}}\\u000a\\u003C/div\\u003E\\u000a\",\n            checkbox_list_item: \"\\u003Cli class=\\\"{{className}}\\\" data-list-id=\\\"{{id}}\\\"\\u003E\\u000a  {{#icon}}\\u000a    \\u003Cspan class=\\\"{{icon}}\\\"\\u003E\\u003C/span\\u003E\\u000a    {{{label}}}\\u000a  {{/icon}}\\u000a  {{^icon}}\\u000a    \\u003Cimg class=\\\"loading-spinner\\\" src=\\\"/images/spinner.gif\\\" alt=\\\"waiting\\\"\\u003E\\u000a    \\u003Cinput class=\\\"membership-checkbox\\\" id=\\\"list_{{id}}\\\" type=\\\"checkbox\\\" {{#user_is_member}}data-is-checked=\\\"true\\\" checked=\\\"checked\\\"{{/user_is_member}}\\u003E\\u000a    {{{label}}}\\u000a    {{#is_private}}\\u000a      \\u003Ci title=\\\"Private List\\\" class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a    {{/is_private}}\\u000a  {{/icon}}\\u000a\\u003C/li\\u003E\",\n            combo_follow_button: \"{{%TRANSLATION-HINT mode=actions}}\\u000a\\u003Cdiv class=\\\"js-follow-combo follow-combo btn-group js-actionable-user {{#blocking}}blocked{{/blocking}}{{^blocking}}{{^following}}not-following{{/following}}{{#following}}following{{/following}}{{#follow_request_sent}} follow-request-sent{{/follow_request_sent}}{{#protected}} protected{{/protected}}{{#following}}{{#want_retweets}} including{{/want_retweets}}{{#notifications}} notifying{{/notifications}}{{/following}}{{#can_dm}} can-dm{{/can_dm}}{{/blocking}}{{#dismissable}} dismissable{{/dismissable}}\\\"\\u000a    data-user-id=\\\"{{id}}\\\" data-screen-name=\\\"{{screen_name}}\\\" data-device-notification=\\\"{{device_notification}}\\\" {{{source_impression_id}}} {{{account_impression_id}}} {{{feedback_token}}}\\u003E\\u000a  \\u003Ca class=\\\"follow-btn btn js-combo-btn js-recommended-item\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-follow follow-text action-text\\\" data-user-id=\\\"{{id}}\\\" data-device-notification=\\\"{{device_notification}}\\\"\\u003E\\u000a      \\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003E\\u000a      Follow\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow following-text action-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Following\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow unfollow-text action-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Unfollow\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"block-text action-text\\\"\\u003E\\u000a      Blocked\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unblock unblock-text action-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Unblock\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow pending-text action-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Pending\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow cancel-req-text action-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Cancel\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  {{#logged_in}}\\u000a    \\u003Cspan href=\\\"#\\\" class=\\\"btn btn-user-actions js-action-profilemenu\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Ci class=\\\"account-arrow\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003C/span\\u003E\\u000a  {{/logged_in}}\\u000a\\u003C/div\\u003E\\u000a\",\n            combo_follow_button_dropdown: \"\\u003Cul class=\\\"js-combo-btn-dropdown-options dropdown-menu btn-group-dropdown\\\"\\u003E\\u000a  \\u003Cli class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-mention is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Tweet to \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-direct-message-action can-send-dm\\\" href=\\\"#\\\"\\u003E\\u000a      Send a Direct Message\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-add-to-list is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Add or remove from lists...\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u000a  \\u003Cli class=\\\"is-not-blocked dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-block is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Block \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-unblock is-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Unblock \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-spam is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Report \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}} for spam\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-action-dismiss is-dismissable\\\" href=\\\"#\\\"\\u003E\\u000a      Hide this suggestion\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u000a  \\u003Cli class=\\\"is-following dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-retweet-setting is-not-including\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Turn on Retweets\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-retweet-setting is-including\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u000a      Turn off Retweets\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-device-notifications is-not-notifying\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Turn on mobile notifications\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-device-notifications is-notifying\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u000a      Turn off mobile notifications\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            connect_dashboard: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"module\\\"\\u003E\\u000a    \\u003Cul class=\\\"js-nav-links\\\"\\u003E\\u000a      \\u003Cli class=\\\"{{#on_interactions}}active{{/on_interactions}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{interactions_path}}\\\" data-nav=\\\"connect\\\"\\u003EInteractions \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_mentions}}active{{/on_mentions}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{mentions_path}}\\\" data-nav=\\\"mentions\\\"\\u003EMentions \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{\\u003Ejapanese_ad_iframe}}\\u000a\\u000a  {{#who_to_follow}}\\u000a    {{\\u003Edashboard_user_recommendations}}\\u000a  {{/who_to_follow}}\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\",\n            interactions: \"{{\\u003Econnect/connect_dashboard}}\\u000a\\u003Cdiv class=\\\"content-main\\\" id=\\\"timeline\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2 class=\\\"js-timeline-title\\\"\\u003EInteractions\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Etimeline}}\\u000a\\u003C/div\\u003E\\u000a\",\n            mentions: \"{{\\u003Econnect/connect_dashboard}}\\u000a\\u003Cdiv class=\\\"content-main\\\" id=\\\"timeline\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2 class=\\\"js-timeline-title\\\"\\u003EMentions\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Etimeline}}\\u000a\\u003C/div\\u003E\\u000a{{\\u003Edialogs/sensitive_flag_confirmation}}\\u000a\",\n            contact_import_loading: \"\\u003Cdiv class=\\\"stream-loading\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Cspan class=\\\"spinner\\\" title=\\\"Loading...\\\"\\u003E\\u003C/span\\u003E\\u000a\\u000a    \\u003Cp\\u003E\\u000a      \\u003Cstrong\\u003EWe're loading your contacts.\\u003C/strong\\u003E\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cp\\u003E\\u000a      (This can take a while if you've got a large address book.)\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            contact_import_matches: \"\\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-items find-friends-results clearfix rm-streamitem-clearfix\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            contact_import_matches_header: \"{{\\u003Estream_header}}\\u000a\\u003Cdiv class=\\\"js-contact-import-header-placeholder\\\"\\u003E\\u003C/div\\u003E\",\n            contact_import_matches_stats: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    Your {{service_name}} contacts\\u000a    \\u003Csmall class=\\\"view-toggler\\\"\\u003E&middot; \\u003Ca href=\\\"{{retry_service_path}}\\\"\\u003ETry another service\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003Ca class=\\\"js-action-follow-all follow-btn btn small\\\"\\u003E\\u000a      \\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003E{{follow_all_text}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  \\u003Csmall class=\\\"view-toggler\\\"\\u003E\\u000a    {{#following_count}}\\u000a      \\u003Ca class=\\\"js-toggle-following\\\" href=\\\"#\\\"\\u003EShow \\u003Cspan\\u003E{{following_count}}\\u003C/span\\u003E following\\u003C/a\\u003E\\u000a      {{#others_count}}\\u000a       /\\u000a      {{/others_count}}\\u000a    {{/following_count}}\\u000a    {{#others_count}}\\u000a      \\u003Ca class=\\\"invite-contacts\\\" href=\\\"#\\\"\\u003EInvite {{others_count}} to join Twitter\\u003C/a\\u003E\\u000a    {{/others_count}}\\u000a  \\u003C/small\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            contact_import_service_icon: \"\\u003Cstrong class=\\\"service-name service-{{id}}\\\" data-service-id=\\\"{{id}}\\\"\\u003E\\u000a  {{#html_name}}\\u003Cstrong class='service hotmail'\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/strong\\u003E &nbsp;&nbsp; \\u003Cstrong class='service msn-messenger'\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/strong\\u003E{{/html_name}}\\u000a  {{^html_name}}\\u003Cspan\\u003E\\u003C/span\\u003E{{/html_name}}\\u000a\\u003C/strong\\u003E\",\n            contact_import_service_msn: \"\\u000a\\u003Ci class=\\\"service-hotmail\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003EHotmail\\u003C/b\\u003E\",\n            contact_import_service_name: \"\\u003Cdiv class=\\\"js-service-name source\\\" data-service-id=\\\"{{id}}\\\"\\u003E\\u000a  {{#html_name}}{{{html_name}}}{{/html_name}}\\u000a  {{^html_name}}\\u003Ci class=\\\"service-{{id}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E{{/html_name}}\\u000a\\u003C/div\\u003E\\u000a\",\n            contact_import_services_icon_list: \"\\u003Cdiv class=\\\"service-links\\\"\\u003E\\u000a  {{#services}}\\u000a    \\u003Ca class=\\\"service-button service-link {{#matched}}selected{{/matched}}\\\" href=\\\"#\\\"\\u000a        data-url=\\\"{{url}}\\\" data-popup=\\\"{{popup}}\\\" data-width=\\\"{{width}}\\\" data-height=\\\"{{height}}\\\" data-name=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a      {{\\u003Econtact_import_service_icon}}\\u000a    \\u003C/a\\u003E\\u000a  {{/services}}\\u000a\\u003C/div\\u003E\\u000a\",\n            contact_import_services_list: \"\\u003Cdiv class=\\\"service-links\\\"\\u003E\\u000a  {{#services}}\\u000a    \\u003Ca class=\\\"service-button service-link {{#matched}}selected{{/matched}}\\\" href=\\\"#\\\"\\u000a        data-url=\\\"{{url}}\\\" data-popup=\\\"{{popup}}\\\" data-width=\\\"{{width}}\\\" data-height=\\\"{{height}}\\\" data-name=\\\"{{name}}\\\"\\u003E\\u000a      {{\\u003Econtact_import_service_name}}\\u000a    \\u003C/a\\u003E\\u000a  {{/services}}\\u000a\\u003C/div\\u003E\\u000a\",\n            contact_import_services_vertical: \"\\u003Cdiv class=\\\"find-friends-sources stream-item\\\"\\u003E\\u000a  \\u003Cul class=\\\"find-friends-list\\\"\\u003E\\u000a    {{#services}}\\u000a      \\u003Cli class=\\\"js-service-row {{#matched_email}}service-row-matched{{/matched_email}}\\\" data-url=\\\"{{url}}\\\" data-popup=\\\"{{popup}}\\\" data-width=\\\"{{width}}\\\" data-height=\\\"{{height}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn {{#matched_email}} primary-btn {{/matched_email}}\\\"\\u003E\\u000a          Search contacts\\u000a        \\u003C/a\\u003E\\u000a        {{\\u003Econtact_import_service_name}}\\u000a        {{#matched_email}}\\u000a          \\u003Cdiv class=\\\"metadata matched-email\\\"\\u003E{{matched_email}}\\u003C/div\\u003E\\u000a        {{/matched_email}}\\u000a      \\u003C/li\\u003E\\u000a    {{/services}}\\u000a  \\u003C/ul\\u003E\\u000a  \\u003Cp class=\\\"fine-print\\\"\\u003E\\u000a  {{\\u003Eimport_disclaimer}}\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            content_home: \"\\u003Cdiv class=\\\"content-main js-content-main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            conversation: \"\\u003Cdiv class=\\\"conversation\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"related-tweets\\\" {{\\u003Erelated_tweets_data_attributes}}\\u003E\\u000a    {{#all_but_last_ancestor_tweet_views}}\\u000a      {{\\u003Esimple_tweet}}\\u000a    {{/all_but_last_ancestor_tweet_views}}\\u000a    {{#last_ancestor_tweet_view}}\\u000a      {{\\u003Econversation_last_ancestor_tweet}}\\u000a    {{/last_ancestor_tweet_view}}\\u000a    {{#has_earlier}}\\u000a      {{\\u003Econversation_earlier}}\\u000a    {{/has_earlier}}\\u000a  \\u003C/div\\u003E\\u000a  {{#tweet_view}}\\u000a    {{\\u003Edetails_pane_tweet}}\\u000a  {{/tweet_view}}\\u000a\\u003C/div\\u003E\",\n            conversation_earlier: \"\\u003Cfieldset class=\\\"in-reply-to-border conversation-earlier-border\\\"\\u003E\\u000a  \\u003Clegend class=\\\"in-reply-to-text\\\"\\u003E\\u000a    in reply to&nbsp;&uarr;\\u003C/a\\u003E\\u000a  \\u003C/legend\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\",\n            conversation_last_ancestor_tweet: \"\\u003Cdiv class=\\\"conversation-last-ancestor-tweet\\\"\\u003E\\u000a  {{\\u003Esimple_tweet}}\\u000a\\u003C/div\\u003E\",\n            conversation_thread: \"\\u003Cdiv class=\\\"messages-pane\\\" data-thread-id=\\\"{{screen_name}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"messages-pane-header\\\"\\u003E\\u000a    \\u003Ch2\\u003EYou and {{screen_name}}\\u003C/h2\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{#items}}\\u000a    {{#delimiter_text}}\\u000a    \\u003Cdiv class='message-divider'\\u003E\\u000a      \\u003Cspan\\u003E{{delimiter_text}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/delimiter_text}}\\u000a    {{\\u003Emessage}}\\u000a  {{/items}}\\u000a\\u003C/div\\u003E\",\n            conversation_thread_preview: \"\\u003Cdiv class='message-thread-preview stream-item-content' data-screen-name=\\\"{{#other_person}}{{screen_name}}{{/other_person}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"more\\\"\\u003E\\u00bb\\u003C/div\\u003E\\u000a  \\u003Cdiv class='message-inner'\\u003E\\u000a    {{#other_person}}\\u000a    \\u003Cimg src='{{profile_image_url}}' alt='{{name}}' class='thumb' data-user-id='{{id}}'/\\u003E\\u000a    \\u003Cspan class='user-name'\\u003E\\u003Cstrong\\u003E{{screen_name}}\\u003C/strong\\u003E \\u003Cb class='full-name'\\u003E{{name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a    {{/other_person}}\\u000a    \\u003Cdiv class='message-content'\\u003E\\u000a      \\u003Cspan class='created-at'\\u003E\\u003Cspan class=\\\"_timestamp\\\" data-time=\\\"{{last_message_date}}\\\" data-long-form=\\\"true\\\" data-include-sec=\\\"true\\\"\\u003E{{timestamp}}\\u003C/span\\u003E\\u003C/span\\u003E\\u000a      \\u003Cdiv class=\\\"message-count\\\"\\u003E{{message_count}}\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            copied_twimg: \"\\u003Cdiv class=\\\"copied-twimg\\\"\\u003E\\u000a  \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a    \\u003Cimg src=\\\"{{media_url}}\\\"/\\u003E\\u000a    {{\\u003Ecopied_twimg_attribution}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            copied_twimg_attribution: \"\\u003Cspan class=\\\"attribution-wrapper\\\"\\u003E\\u000a  \\u003Cspan class=\\\"attribution\\\"\\u003Eimage by @\\u003Cem class=\\\"profile-path user-profile-link\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E{{screen_name}}\\u003C/em\\u003E, \\u003Cspan class=\\\"unit\\\"\\u003E{{time_ago}}\\u003C/span\\u003E\\u003C/span\\u003E\\u000a\\u003C/span\\u003E\",\n            country_select: \"\\u000a{{#do_not_render_pctd_logged_out}}\\u000a\\u003Cdiv class=\\\"country-select-outer\\\"\\u003E\\u000a  \\u003Cstrong class=\\\"country-select-label\\\"\\u003ECountry:\\u003C/strong\\u003E\\u000a  \\u003Cspan class=\\\"country-select-inner\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\" /\\u003E\\u003Cspan class=\\\"country-select-mask\\\" /\\u003E\\u000a    \\u003Cselect class=\\\"country-select\\\"\\u003E\\u000a      {{#countries}}\\u000a        \\u003Coption value=\\\"{{code}}\\\"{{#selected}} selected=\\\"selected\\\"{{/selected}}\\u003E{{name}}\\u003C/option\\u003E\\u000a      {{/countries}}\\u000a    \\u003C/select\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/do_not_render_pctd_logged_out}}\\u000a\",\n            create_list_button: \"\\u003Ca class=\\\"{{^link_only}}btn {{/link_only}}js-create-list-button\\\" href=\\\"#\\\" data-modal=\\\"list-new\\\" data-element-term=\\\"create_list_button\\\"\\u003ECreate list\\u003C/a\\u003E\",\n            current_text_user_autocomplete_item: \"\\u003Cli class='selectable' data-user-screenname='{{screenname}}'\\u003E\\u000a  Go to @\\u003Cstrong\\u003E{{screenname}}\\u003C/strong\\u003E\\u000a\\u003C/li\\u003E\",\n            daily_limit_error_message: \"{{#is_dm}}\\u000a  You are over the daily limit for sending messages.\\u000a{{/is_dm}}\\u000a{{^is_dm}}\\u000a  {{#is_tweet}}\\u000a    You are over the daily limit for sending Tweets.\\u000a  {{/is_tweet}}\\u000a  {{^is_tweet}}\\u000a    You are over the daily limit for this action.\\u000a  {{/is_tweet}}\\u000a{{/is_dm}}\\u000aPlease wait a few hours and try again.\\u000a\\u003Ca href=\\\"{{daily_limit_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            dashboard_activity_item: \"\\u003Cdiv data-activity-type='{{event}}'\\u000a     data-activity-min-position='{{min_position}}'\\u000a     data-activity-max-position='{{max_position}}'\\u000a     class='clearfix dashboard-activity-item dashboard-item-{{event}}'\\u003E\\u000a\\u000a\\u000a  \\u003Cdiv class=\\\"dashboard-item-activity-line\\\"\\u003E\\u000a    \\u003Ca href='/#!/activity?item={{min_position}}' class='dashboard-activity-item-link' data-item-id='{{min_position}}'\\u003E\\u000a      {{#should_show_first_actor}}\\u000a        {{#first_actor}}\\u000a          {{\\u003Euser_image_24}}\\u000a        {{/first_actor}}\\u000a      {{/should_show_first_actor}}\\u000a\\u000a      \\u003Cspan class='dashboard-activity-item-sentence'\\u003E{{{activity_line}}}\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dashboard_activity_teaser: \"\\u003Cdiv class=\\\"dashboard-activity-teaser-inner\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Cspan class='dashboard-component-title'\\u003EActivity\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"dashboard-component-subtitle\\\"\\u003E\\u000a      \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a      \\u003Ca href=\\\"{{activity_path}}\\\"\\u003Eview all\\u003C/a\\u003E\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  \\u003Cdiv class=\\\"activity-items\\\"\\u003E\\u000a    {{#items}}\\u000a      {{\\u003Edashboard_activity_item}}\\u000a    {{/items}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dashboard_contact_import: \"\\u003Cdiv class=\\\"contact-import-inner\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"contact-import-component\\\"\\u003EFind Friends\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003EUse the services below to find people you know on Twitter\\u003C/p\\u003E\\u000a  \\u003Cdiv class=\\\"contact-import-services {{#compact}}compact{{/compact}} promptbird-action-bar\\\"\\u003E\\u000a    {{#compact}}\\u000a      {{\\u003Econtact_import_services_icon_list}}\\u000a    {{/compact}}\\u000a    {{^compact}}\\u000a      {{\\u003Econtact_import_services_list}}\\u000a    {{/compact}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dashboard_contact_import_matches_stats: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  \\u003Ca class=\\\"follow-btn btn small js not-following\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-follow-all follow-text\\\"\\u003E\\u000a      \\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003E{{follow_all_text}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cdiv\\u003E\\u000a    \\u003Cspan class=\\\"dashboard-import-header\\\"\\u003E{{service_name}}\\u003C/span\\u003E contacts\\u000a  \\u003C/div\\u003E\\u000a  \\u003Csmall class=\\\"view-toggler\\\"\\u003E\\u000a    {{#others_count}}\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"invite-contacts\\\"\\u003EInvite {{others_count}} to join Twitter\\u003C/a\\u003E\\u000a    {{/others_count}}\\u000a  \\u003C/small\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_discover: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"module discover-nav\\\"\\u003E\\u000a    \\u003Cul class=\\\"js-nav-links\\\"\\u003E\\u000a      \\u003Cli class=\\\"{{#on_discover}}active{{/on_discover}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{discover_path}}\\\" data-nav=\\\"discover\\\"\\u003E{{#single_expanded_tweets}}Tweets{{/single_expanded_tweets}}{{^single_expanded_tweets}}Stories{{/single_expanded_tweets}} \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_activity}}active{{/on_activity}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{activity_tab_path}}\\\" data-nav=\\\"network_activity\\\"\\u003EActivity\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{#show_lifeline}}\\u000a        \\u003Cli class=\\\"{{#on_lifeline}}active{{/on_lifeline}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{who_to_follow_lifeline_path}}\\\" data-nav=\\\"lifeline\\\"\\u003ELifeline\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{/show_lifeline}}\\u000a      \\u003Cli class=\\\"{{#on_wtf}}active{{/on_wtf}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{who_to_follow_suggestions_path}}\\\" data-nav=\\\"suggestions\\\"\\u003E\\u000a          Who to follow\\u000a          \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a          {{#avatar_row}}{{\\u003Eavatar_row}}{{/avatar_row}}\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_find_friends}}active{{/on_find_friends}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{who_to_follow_import_path}}\\\" data-nav=\\\"find_friends\\\"\\u003EFind friends \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_profile}}active{{/on_profile}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{who_to_follow_interests_path}}\\\" data-nav=\\\"interests\\\"\\u003EBrowse categories \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Edashboard_trends}}\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_follower_request_link: \"\\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn follower-request-link\\\" href=\\\"{{follower_requests_path}}\\\"\\u003E\\u000a    {{button_label}}\\u000a    {{^button_label}}\\u000a      \\u000a        {{#follower_request_count_one}}1 new follower request{{/follower_request_count_one}}\\u000a        {{#follower_request_count_other}}{{follower_request_count}} new follower requests{{/follower_request_count_other}}\\u000a      \\u000a    {{/button_label}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            dashboard_getting_started: \"\\u003Cdiv class=\\\"getting-started\\\"\\u003E\\u000a\\u000a  \\u003Ch2\\u003E\\u000a    {{title}}\\u000a    {{#is_noob_level_5_6_7}}\\u000a        \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E \\u003Ca href=\\\"#\\\" class=\\\"hidenextsteps\\\"\\u003Ehide next steps\\u003C/a\\u003E\\u000a    {{/is_noob_level_5_6_7}}\\u000a  \\u003C/h2\\u003E\\u000a\\u000a  \\u003Col\\u003E\\u000a\\u000a    {{#is_noob_level_0}}\\u000a      {{\\u003Egetting_started_follow}}\\u000a      {{\\u003Egetting_started_mobile}}\\u000a      {{\\u003Egetting_started_profile}}\\u000a      {{\\u003Egetting_started_tweet}}\\u000a    {{/is_noob_level_0}}\\u000a\\u000a    {{#is_noob_level_1_2_3}}\\u000a      {{\\u003Egetting_started_tweet}}\\u000a      {{\\u003Egetting_started_profile}}\\u000a      {{\\u003Egetting_started_mobile}}\\u000a    {{/is_noob_level_1_2_3}}\\u000a\\u000a    {{#is_noob_level_4}}\\u000a      {{\\u003Egetting_started_follow}}\\u000a      {{\\u003Egetting_started_mobile}}\\u000a      {{\\u003Egetting_started_profile}}\\u000a    {{/is_noob_level_4}}\\u000a\\u000a    {{#is_noob_level_5_6_7}}\\u000a      {{\\u003Egetting_started_mobile}}\\u000a      {{\\u003Egetting_started_profile}}\\u000a    {{/is_noob_level_5_6_7}}\\u000a\\u000a  \\u003C/ol\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\\u000a\",\n            dashboard_mini_profile: \"\\u003Cdiv class='profile-pane' {{{source_impression_id}}}\\u003E\\u000a  \\u003Cdiv class=\\\"profile-basics clearfix\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"profile-text\\\"\\u003E\\u000a      \\u003Ca href=\\\"{{profile_path}}\\\"\\u003E\\u000a        \\u003Cimg src='{{right_image_size}}' alt='{{name}}' width='128' class='thumb' data-user-id='{{id}}'/\\u003E\\u000a      \\u003C/a\\u003E\\u000a      {{\\u003Efull_name}}\\u000a      \\u003Cdiv class=\\\"screen-name-and-location\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"screen-name screen-name-{{screen_name}} pill\\\"\\u003E\\u003Cstrong\\u003E@{{screen_name}}\\u003C/strong\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"location\\\"\\u003E{{#location}}{{location}}{{/location}}\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"user-info\\\"\\u003E\\u000a      \\u003Cspan class=\\\"bio\\\"\\u003E{{{linkified_description}}}\\u003C/span\\u003E {{#url}}\\u003Ca rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\" target=\\\"_blank\\\"\\u003E{{{display_url_or_url}}}\\u003C/a\\u003E{{/url}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{\\u003Euser_stats}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_profile_stats: \"\\u003Cdiv class='dashboard-profile-annotations clearfix'\\u003E\\u000a  \\u003Ch2 class=\\\"dashboard-profile-title\\\"\\u003E\\u003Cimg src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" width=\\\"24\\\" class=\\\"profile-dashboard\\\"/\\u003E{{profile_stats_title}}\\u003C/h2\\u003E\\u000a  {{#is_translator}}\\u000a    \\u003Ca class='dashboard-profile-translator' href='{{translator_profile_path}}'\\u003E\\u000a      \\u003Cem\\u003ETranslator\\u003C/em\\u003E\\u000a    \\u003C/a\\u003E\\u000a  {{/is_translator}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Euser_stats}}\\u000a\",\n            dashboard_promo: \"\\u003Cdiv class='definition'\\u003E\\u000a  {{#promo}}\\u000a    \\u003Cp class=\\\"promo\\\"\\u003E{{{promo_contents}}}\\u003C/p\\u003E\\u000a  {{/promo}}\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_related_services: \"\\u003Cdiv class=\\\"related-services\\\"\\u003E\\u000a  \\u003Ch2\\u003ERelated Services\\u003C/h2\\u003E\\u000a  \\u003Cul\\u003E\\u000a    {{#promos}}\\u000a      \\u003Cli\\u003E{{{promo_contents}}}\\u003C/li\\u003E\\u000a    {{/promos}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_settings: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{\\u003Emini_home_profile}}\\u000a\\u000a  {{#current_user}}\\u000a  \\u003Cdiv class=\\\"module\\\"\\u003E\\u000a    \\u003Cul class=\\\"js-nav-links\\\"\\u003E\\u000a      \\u003Cli class=\\\"{{#on_account}}active{{/on_account}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{settings_path}}\\\" data-nav=\\\"account\\\"\\u003EAccount \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_password}}active{{/on_password}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{password_path}}\\\" data-nav=\\\"password\\\"\\u003EPassword\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{#device_available}}\\u000a        \\u003Cli class=\\\"{{#on_devices_main}}active{{/on_devices_main}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{devices_settings_path}}\\\" data-nav=\\\"devices\\\"\\u003EMobile \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{/device_available}}\\u000a      \\u003Cli class=\\\"{{#on_notifications}}active{{/on_notifications}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{notifications_path}}\\\" data-nav=\\\"notifications\\\"\\u003EEmail notifications \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_profile}}active{{/on_profile}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{settings_profile_path}}\\\" data-nav=\\\"profile\\\"\\u003EProfile \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u000a      {{#enhanced_profile_available}}\\u000a      \\u003Cli class=\\\"{{#on_enhanced_profile}}active{{/on_enhanced_profile}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{enhanced_profile_settings_path}}\\\" data-nav=\\\"enhanced_profile\\\"\\u003EEnhanced profile \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{/enhanced_profile_available}}\\u000a\\u000a      \\u003Cli class=\\\"{{#on_design}}active{{/on_design}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{design_path}}\\\" data-nav=\\\"design\\\"\\u003EDesign \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_applications}}active{{/on_applications}}\\\"\\u003E\\u003Ca class=\\\"list-link js-nav\\\" href=\\\"{{connections_path}}\\\" data-nav=\\\"connections\\\"\\u003EApps\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u000a      {{#contributors_available}}\\u000a        \\u003Cli\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{contributor_permissions_path}}\\\" data-nav=\\\"contributors\\\"\\u003EContributors \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{/contributors_available}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{/current_user}}\\u000a\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_social_context: \"{{%TRANSLATION-HINT mode=social_context}}\\u000a\\u003Cdiv class=\\\"social-context\\\"\\u003E\\u000a  \\u003Ch2\\u003EYou and @{{screen_name}}\\u003C/h2\\u003E\\u000a  {{#accounts_in_common}}\\u000a    \\u003Cdiv class=\\\"you-both-follow clearfix\\\"\\u003E\\u000a      {{\\u003Edashboard_social_context_subcomponent}}\\u000a    \\u003C/div\\u003E\\u000a  {{/accounts_in_common}}\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_social_context_subcomponent: \"\\u003Cp\\u003E{{{caption}}}\\u003C/p\\u003E\\u000a{{{avatar_list}}}\\u000a\",\n            dashboard_stream_user: \"\\u003Cdiv class=\\\"account-summary {{#promoted_content}}promoted-account {{/promoted_content}} dashboard-account-summary js-actionable-user\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  {{\\u003Ecombo_follow_button}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-account-group js-recommend-link user-thumb\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u000a      \\u003Cimg src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size48 js-action-profile-avatar\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"account-group-inner\\\"\\u003E\\u000a        \\u003Cb class=\\\"fullname js-action-profile-name\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a        \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        \\u003Cdiv class=\\\"screenname js-action-profile-name\\\"\\u003E\\u000a          \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/a\\u003E\\u000a    {{#is_sponsored}}\\u000a      \\u003Cspan class=\\\"metadata with-icn\\\"\\u003E\\u000a        \\u003Ca class=\\\"js-promoted-badge js-user-profile-link js-account-group\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003EPromoted\\u003C/a\\u003E\\u000a      \\u003C/span\\u003E\\u000a    {{/is_sponsored}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_timeline: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#mini_home_profile}}\\u000a    {{\\u003Emini_home_profile}}\\u000a  {{/mini_home_profile}}\\u000a\\u000a  {{#home_nav_top}}\\u000a    {{\\u003Enav}}\\u000a  {{/home_nav_top}}\\u000a\\u000a  {{#wtf}}\\u000a    {{\\u003Edashboard_user_recommendations}}\\u000a  {{/wtf}}\\u000a\\u000a  {{\\u003Emodule_trends}}\\u000a\\u000a  {{\\u003Emodule_footer}}\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_trends: \"\\u003Cdiv class=\\\"module trends {{hide_trends_class}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module trends-inner\\\"\\u003E\\u000a    {{\\u003Etrends_inner}}\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_user_recommendations: \"\\u003Cdiv class=\\\"module wtf-module js-wtf-module {{#recommended_followers}}has-content{{/recommended_followers}}\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch3\\u003EWho to follow\\u003C/h3\\u003E\\u000a      \\u003Csmall\\u003E&middot; \\u003Ca class=\\\"js-refresh-suggestions\\\" href=\\\"#\\\"\\u003ERefresh\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      \\u003Csmall class=\\\"view-all\\\"\\u003E&middot; \\u003Ca href=\\\"{{who_to_follow_suggestions_path}}\\\" data-element-term=\\\"view_all_link\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"js-recommended-followers dashboard-user-recommendations flex-module-inner{{#rendering_on_server}}{{^swift}}pre-rendered-stub{{/swift}}{{/rendering_on_server}}\\\" data-section-id=\\\"wtf\\\"\\u003E\\u000a      {{#recommended_followers}}\\u000a        {{\\u003Euser_small_list}}\\u000a      {{/recommended_followers}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#show_links}}\\u000a      \\u003Cdiv class=\\\"flex-module-footer\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{who_to_follow_interests_path}}\\\" data-element-term=\\\"interests_link\\\"\\u003EBrowse categories\\u003C/a\\u003E &middot; \\u003Ca href=\\\"{{who_to_follow_import_path}}\\\" data-element-term=\\\"import_link\\\"\\u003EFind friends\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/show_links}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_user_similarities: \"\\u003Cdiv class=\\\"module profile-nav wtf-module js-similar-to-module {{#recommended_followers}}has-content{{/recommended_followers}}\\\"\\u003E\\u000a\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli class=\\\"js-sidenav-link {{#on_similar_to}}active{{/on_similar_to}}\\\" data-name=\\\"similarTo\\\"\\u003E\\u000a      \\u003Ca class=\\\"list-link\\\" href=\\\"{{similar_to_path}}\\\"\\u003E\\u000a        {{#self_sims}}\\u000a          Similar to you\\u000a        {{/self_sims}}\\u000a        {{^self_sims}}\\u000a          Similar to {{profile_name}}\\u000a        {{/self_sims}}\\u000a        \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-recommended-followers dashboard-user-recommendations flex-module-inner{{#rendering_on_server}}{{^swift}} pre-rendered-stub{{/swift}}{{/rendering_on_server}}\\\" data-section-id=\\\"wtf\\\"\\u003E\\u000a      {{#recommended_followers}}\\u000a        {{\\u003Euser_small_list}}\\u000a      {{/recommended_followers}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard_your_profile: \"\\u003Cdiv class=\\\"tweet-activity\\\"\\u003E\\u000a\\u003Ch2\\u003E\\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"title-link\\\"\\u003E\\u003Cspan class='dashboard-component-title'\\u003EYour Tweets\\u003C/span\\u003E\\u003Cspan class=\\\"tweet-count user-stat-link\\\"\\u003E{{statuses_count_commaized}}\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/h2\\u003E\\u000a{{#status}}\\u000a  {{\\u003Elatest_tweet}}\\u000a{{/status}}\\u000a\\u003C/div\\u003E\",\n            default_dropdown_divider: \"\\u003Chr class=\\\"dropdown-divider\\\"/\\u003E\\u000a\",\n            default_dropdown_item: \"\\u003Cli class=\\\"{{class}}\\\" {{data}}\\u003E\\u003Cspan class=\\\"{{icon}}\\\"\\u003E\\u003C/span\\u003E\\u003Cb class=\\\"item-name\\\"\\u003E{{{label}}}\\u003C/b\\u003E\\u003C/li\\u003E\\u000a\",\n            default_error_message: \"Sorry! We did something wrong.\\u000a{{#is_tweet}}\\u000a  Try sending your Tweet again in a minute.\\u000a{{/is_tweet}}\\u000a{{#is_dm}}\\u000a  Try sending your message again in a minute.\\u000a{{/is_dm}}\\u000a{{#is_follow}}\\u000a  Try following that user again in a minute.\\u000a{{/is_follow}}\\u000a{{#is_unfollow}}\\u000a  Try unfollowing that user again in a minute.\\u000a{{/is_unfollow}}\\u000a{{#is_block}}\\u000a  Try blocking that user again in a minute.\\u000a{{/is_block}}\\u000a{{#is_unblock}}\\u000a  Try unblocking that user again in a minute.\\u000a{{/is_unblock}}\\u000a{{#is_report}}\\u000a  Try reporting that user again in a minute.\\u000a{{/is_report}}\\u000a{{#is_retweet}}\\u000a  Try Retweet again in a minute.\\u000a{{/is_retweet}}\\u000a{{#is_delete}}\\u000a  Try deleting your Tweet again in a minute.\\u000a{{/is_delete}}\\u000a{{#is_favorite}}\\u000a  Try favoriting your Tweet again in a minute.\\u000a{{/is_favorite}}\\u000a{{#is_unfavorite}}\\u000a  Try unfavoriting your Tweet again in a minute.\\u000a{{/is_unfavorite}}\\u000a{{#is_add_list_member}}\\u000a  Try adding a list member again in a minute.\\u000a{{/is_add_list_member}}\\u000a{{#is_remove_list_member}}\\u000a  Try removing a list member again in a minute.\\u000a{{/is_remove_list_member}}\\u000a{{#is_generic}}\\u000a  Please \\u003Ca class=\\\"js-reload\\\" href=\\\"#\\\"\\u003Erefresh the page\\u003C/a\\u003E and try again.\\u000a{{/is_generic}}\\u000a\",\n            delete_list_button: \"\\u003Cdiv class=\\\"button delete-list-button js-delete-list-action\\\" title=\\\"Delete\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\"\\u003E\\u003Cspan class=\\\"trashcan\\\"\\u003E\\u003C/span\\u003E\\u003Cb class=\\\"label\\\"\\u003EDelete\\u003C/b\\u003E\\u003C/div\\u003E\\u000a\",\n            detached_email_banner: \"\\u003Cdiv class=\\\"module module-banner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a      \\u003Cspan class=\\\"title\\\"\\u003ENew email address required.\\u003C/span\\u003E\\u000a      \\u003Cspan\\u003ETwitter has removed the email address from your account, by request of the email owner.\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"second-banner-row\\\"\\u003E\\u000a      \\u003Cp\\u003EPlease \\u003Ca href=\\\"{{change_email_path}}\\\"\\u003Eenter a new email address\\u003C/a\\u003E where you can be reached.&nbsp;\\u003Ca href=\\\"{{email_help_path}}\\\"\\u003ELearn more&nbsp; &rsaquo;\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            details_pane_tweet: \"\\u003Cdiv class=\\\"tweet js-actionable-tweet details-pane-tweet {{css_classes}}\\\" data-tweet-id=\\\"{{id}}\\\" {{{tweet_impression_id}}} {{#current_user_retweet}}data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}}  data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\"  {{#protected}}data-protected=\\\"true\\\"{{/protected}} {{#is_sponsored}}data-promoted=\\\"true\\\"{{/is_sponsored}}\\u003E\\u000a  {{\\u003Etweet_dogear}}\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{#user}}\\u000a      {{\\u003Etweet_user_block}}\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{\\u003Etweet_text_large}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"js-tweet-media-container tweet-media-container\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{\\u003Etweet_timestamp}}\\u000a    {{\\u003Etweet_contributor}}\\u000a    {{\\u003Etweet_source}}\\u000a    {{\\u003Etweet_actions}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{\\u003Etweet_geo_text}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            scribe_console: \"\\u000a\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"en\\\"\\u003E\\u000a  \\u003Chead\\u003E\\u000a    \\u003Cmeta http-equiv=\\\"X-UA-Compatible\\\" content=\\\"IE=edge,chrome=1\\\"\\u003E\\u000a    \\u003Cmeta charset=\\\"utf-8\\\"\\u003E\\u000a\\u000a    \\u000a    \\u003Cscript\\u003Edocument.domain='twitter.com'\\u003C/script\\u003E\\u000a    \\u003Clink rel=\\\"stylesheet\\\" href=\\\"/sc/scribe_console.css\\\" type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E\\u000a\\u000a    \\u003Ctitle\\u003EScribe Console\\u003C/title\\u003E\\u000a\\u000a    {{\\u003Eframe_busting}}\\u000a\\u000a  \\u003C/head\\u003E\\u000a  \\u003Cbody\\u003E\\u000a    \\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"welcome\\\"\\u003E\\u000a\\u003Cpre\\u003EWelcome to the Scribe Console!\\u000a\\u000aFrom here you can view all the scribe events triggered by the Twitter web\\u000aclient and filter events by category. As you interact with the web client,\\u000ascribe events will be displayed in this window.\\u000a\\u000aPLEASE NOTE: Not all scribes are logged from the webclient, some are scribed\\u000afrom the server-side code or from daemons. The data displayed in this\\u000aconsole does not represent all the data that will be included in the scribe\\u000alogs. Some additional data will be added on the server and may not appear\\u000ain this console. For more information, please visit \\u003Ca href=\\\"http://go/scribe\\\" target=\\\"_blank\\\"\\u003Ego/scribe\\u003C/a\\u003E.\\u003C/pre\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"toolbar\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"clear\\\"\\u003EClear\\u003C/a\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"toggle-warnings active\\\"\\u003EWarnings\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/sc/jquery.js\\\"\\u003E\\u003C/script\\u003E\\u000a    \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/sc/mustache.js\\\"\\u003E\\u003C/script\\u003E\\u000a    \\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a      // client_event validation constants\\u000a      var CLIENT_EVENT_FIELDS = {{{client_event_fields}}};\\u000a      var CLIENT_EVENT_PAGES = {{{client_event_pages}}};\\u000a      var CLIENT_EVENT_ACTIONS = {{{client_event_actions}}};\\u000a      var CLIENT_EVENT_ITEM_TYPES = {{{client_event_item_types}}};\\u000a      var CLIENT_EVENT_ASSOCIATION_TYPES = {{{client_event_association_types}}};\\u000a      var CLIENT_EVENT_EVENT_INITIATOR = {{{client_event_event_initiator}}};\\u000a    \\u003C/script\\u003E\\u000a    \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/sc/scribe_console.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003C/body\\u003E\\u000a\\u003C/html\\u003E\",\n            device_setup_dialog: \"\\u003Cdiv class='twttr-dialog-device-setup'\\u003E\\u000a  \\u003Cdiv class='loading'\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            device_setup_dialog_create: \"\\u003Cdiv\\u003E \\u000a  \\u003Cform class='dialog-form'\\u003E\\u000a    \\u003Cp\\u003ETwitter does not charge for this service. Standard message and data rates may apply.\\u003C/p\\u003E\\u000a\\u000a    \\u003Cfieldset class='common-form'\\u003E\\u000a      \\u003Cdiv class='field'\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class='label numbered'\\u003ESelect your country/region\\u003C/span\\u003E\\u000a          \\u003Cspan class='input-wrapper'\\u003E\\u000a            \\u003Cselect class='country-or-region'\\u003E\\u003C/select\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class='field' style=\\\"display: none;\\\"\\u003E\\u000a        \\u003Cspan class='label'\\u003E\\u003C/span\\u003E\\u000a        \\u003Cspan class='input-wrapper'\\u003E\\u000a          \\u003Cselect class='country-in-region'\\u003E\\u003C/select\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Clabel class='field'\\u003E\\u000a        \\u003Cspan class='label numbered'\\u003EEnter your mobile phone number\\u003C/span\\u003E\\u000a        \\u003Cspan class='input-wrapper phone-wrapper'\\u003E\\u000a          \\u003Cspan class='country-code'\\u003E\\u003C/span\\u003E\\u003Cinput class='phone' name='device[address]' type='tel' size='15' /\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/label\\u003E\\u000a\\u000a      \\u003Clabel class='field' style='display: none;'\\u003E\\u000a        \\u003Cspan class='label numbered'\\u003EChoose your carrier\\u003C/span\\u003E\\u000a        \\u003Cspan class='input-wrapper'\\u003E\\u000a          \\u003Cselect class='carrier' name='device[carrier]'\\u003E\\u003C/select\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/label\\u003E\\u000a\\u000a      \\u003Cdiv class='field'\\u003E\\u000a        \\u003Cspan class='label numbered'\\u003EVerify your phone\\u003C/span\\u003E\\u000a        \\u003Cdiv class='input-wrapper'\\u003E\\u000a          \\u003Cdiv class='button btn submit'\\u003EStart\\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u003Cinput name='device_type' type='hidden' value='phone' /\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            device_setup_dialog_duplicate: \"\\u003Cdiv class='twttr-dialog-device-setup-duplicate'\\u003E\\u000a  \\u003Cdiv class=\\\"error\\\"\\u003E\\u000a    \\u003Cp\\u003E\\u000a      The phone number you gave us is currently used by another Twitter account. Only one account can be used with a mobile phone at a time.\\u000a    \\u003C/p\\u003E\\u000a\\u000a    {{\\u003Edevice_setup_dialog_source_address}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cp\\u003E\\u000a    \\u003Cstrong\\u003ETo fix this, you need to reset your phone's link to Twitter\\u003C/strong\\u003E\\u003Cbr /\\u003E\\u000a    Send this message to Twitter:\\u000a  \\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"phone-instructions\\\"\\u003E\\u000a    Text '{{stop_command}}' to {{address_for_sms}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cp\\u003E\\u000a    Once you've sent the message, try to verify your phone again.\\u000a  \\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"submit button retry\\\"\\u003ERetry verification\\u003C/div\\u003E\\u000a\\u000a  \\u003Cp class=\\\"cancel-instructions\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\"\\u003ECancel verification\\u003C/a\\u003E and start over.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            device_setup_dialog_source_address: \"\\u003Cdiv class=\\\"phone-instructions\\\"\\u003E\\u000a  +{{country_code}} {{address_without_country_code}}\\u000a  ({{country_name}}{{#carrier_name}} &ndash; {{carrier_name}}{{/carrier_name}})\\u000a\\u003C/div\\u003E\\u000a\",\n            device_setup_dialog_verified: \"\\u000a\\u003Ch2\\u003ESuccessful device verification for +{{country_code}} {{address_without_country_code}}!\\u003C/h2\\u003E\\u000a\\u000a\\u003Cp\\u003E\\u000a  \\u003Cstrong\\u003EYou can now text message your Tweets to {{address_for_sms}}.\\u003C/strong\\u003E\\u000a  See the complete list of \\u003Ca href=\\\"{{sms_help_path}}\\\" target=\\\"_blank\\\"\\u003ETwitter mobile commands\\u003C/a\\u003E.\\u000a\\u003C/p\\u003E\\u000a\\u000a\\u003Cp\\u003E\\u000a  Set your mobile privacy controls and notification preferences on \\u003Ca href=\\\"{{devices_path}}\\\"\\u003Eyour Mobile settings page\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a\\u003C/p\\u003E\\u000a\\u000a\\u003Cp\\u003ETwitter does not charge for this service. Standard message and data rates may apply.\\u003C/p\\u003E\\u000a\",\n            device_setup_dialog_waiting: \"\\u003Cdiv class='twttr-dialog-device-setup-waiting'\\u003E\\u000a  \\u003Cp\\u003E\\u000a    Using the mobile phone you gave us:\\u000a  \\u003C/p\\u003E\\u000a\\u000a  {{\\u003Edevice_setup_dialog_source_address}}\\u000a\\u000a  \\u003Cp\\u003E\\u000a    Send a text message to Twitter:\\u000a  \\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"phone-instructions\\\"\\u003E\\u000a    Text '{{go_command}}' to {{address_for_sms}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cp\\u003E\\u000a    Twitter does not charge for this service. Standard message and data rates may apply.\\u000a  \\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"waiting-instructions\\\"\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u003Cstrong\\u003ETwitter is waiting for you to send your verification code...\\u003C/strong\\u003E\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cp\\u003E\\u000a      Already sent the verification code?  Wait a minute or two for Twitter to receive the message from your mobile carrier.\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cp class=\\\"refresh\\\"\\u003E\\u000a      Still nothing? \\u003Ca href=\\\"#\\\"\\u003ECheck again\\u003C/a\\u003E.\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cp class=\\\"cancel-instructions\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\"\\u003ECancel verification\\u003C/a\\u003E and start over.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            dialog: \"\\u003Cdiv {{#container_id}}id=\\\"{{container_id}}\\\" {{/container_id}}class=\\\"twttr-dialog-container\\\" style=\\\"visibility: hidden;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog\\\"\\u003E\\u000a    {{#title}}\\u000a      \\u003Cdiv class=\\\"twttr-dialog-header js-twttr-dialog-draggable\\\"\\u003E\\u000a        \\u003Ch3\\u003E{{{title}}}\\u003C/h3\\u003E {{#closable}}\\u003Cdiv class=\\\"twttr-dialog-close\\\"\\u003E\\u003Cb\\u003E&times;\\u003C/b\\u003E\\u003C/div\\u003E{{/closable}}\\u000a      \\u003C/div\\u003E\\u000a    {{/title}}\\u000a    \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-error clearfix\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"twttr-dialog-content\\\"\\u003E\\u000a          {{{content}}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-footer clearfix\\\"\\u003E\\u000a        {{{footer}}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_popup_container: \"\\u003Cdiv id=\\\"activity-popup-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content clearfix\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003E\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"activity-tweet clearfix\\\"\\u003E\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"loading\\\"\\u003E\\u000a          \\u003Cimg src=\\\"{{bigger_spinner_path}}\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"activity-content clearfix\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_popup_users: \"\\u003Cdiv class=\\\"activity-popup-users\\\"\\u003E\\u000a  {{{rendered_users}}}\\u000a\\u003C/div\\u003E\",\n            captcha_dialog: \"\\u003Cdiv id=\\\"captcha_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EProve you are human\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      {{\\u003Eshared/captcha}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn\\\" id=\\\"cancel_captcha_button\\\"\\u003ECancel\\u003C/button\\u003E\\u000a        \\u003Cbutton id=\\\"submit_captcha\\\" class=\\\"btn primary-btn modal-submit\\\"\\u003ESubmit\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            confirm_dialog: \"\\u003Cdiv id=\\\"confirm_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003E\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp class=\\\"modal-body-text\\\"\\u003E\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn\\\" id=\\\"confirm_dialog_cancel_button\\\"\\u003E\\u003C/button\\u003E\\u000a        \\u003Cbutton id=\\\"confirm_dialog_submit_button\\\" class=\\\"btn primary-btn modal-submit\\\"\\u003E\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            deactivation_password_dialog: \"\\u003Cdiv id=\\\"deactivation_password_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EDeactivate account\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp\\u003ERe-enter your Twitter password to deactivate @{{screen_name}}.\\u003C/p\\u003E\\u000a        \\u003Clabel for=\\\"auth_password\\\"\\u003EPassword\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"input-wrapper password-wrapper\\\"\\u003E\\u000a          \\u003Cinput id=\\\"auth_password\\\" name=\\\"auth_password\\\" type=\\\"password\\\"\\u003E\\u000a          \\u003Cdiv\\u003E\\u000a            \\u003Ca href=\\\"{{resend_password_link}}\\\" id=\\\"forgot_password\\\"\\u003EForgot your password?\\u003C/a\\u003E\\u000a            \\u003Cspan id=\\\"reminder_sent\\\" style=\\\"visibility: hidden\\\"\\u003EReminder sent!\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn\\\" id=\\\"cancel_password_button\\\"\\u003ECancel\\u003C/button\\u003E\\u000a        \\u003Cbutton id=\\\"save_password\\\" class=\\\"btn primary-btn modal-submit\\\"\\u003EDeactivate account\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u000a\",\n            delete_tweet_dialog: \"\\u003Cdiv id=\\\"delete-tweet-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EAre you sure you want to delete this Tweet?\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body modal-tweet\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn cancel-action\\\"\\u003ECancel\\u003C/button\\u003E\\u000a        \\u003Cbutton class=\\\"btn primary-btn delete-action\\\"\\u003EDelete\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dm_conversation: \"\\u003Cdiv id=\\\"dm_dialog_conversation\\\" class=\\\"modal-content\\\"\\u003E\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-header modal-header\\\"\\u003E\\u000a    \\u003Ch3\\u003E\\u003Ca class=\\\"js-dm-header-title\\\" href=\\\"#\\\"\\u003EDirect messages\\u003C/a\\u003E \\u203a with \\u003Cspan class=\\\"dm_dialog_real_name\\\"\\u003E\\u003C/span\\u003E\\u003C/h3\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-close\\\"\\u003E\\u003Cb\\u003E&times;\\u003C/b\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        {{\\u003Edirect_message_dialog_error}}\\u000a      \\u003Cdiv class=\\\"twttr-dialog-content\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{\\u003Eswift_dm_box}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{\\u003Edm_footer}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dm_conversation_list: \"\\u003Cdiv id=\\\"dm_dialog_conversation_list\\\" class=\\\"modal-content\\\"\\u003E\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-header modal-header\\\"\\u003E\\u000a    \\u003Ch3\\u003EDirect messages\\u003C/h3\\u003E\\u000a    \\u003Ca class=\\\"btn dm-new-button dm-header-new\\\" href=\\\"#\\\"\\u003ENew message\\u003C/a\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-close\\\"\\u003E\\u003Cb\\u003E&times;\\u003C/b\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a      {{\\u003Edirect_message_dialog_error}}\\u000a      \\u003Cdiv class=\\\"twttr-dialog-content\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dm-threads js-dm-threads js-modal-scrollable js-twttr-dialog-not-draggable\\\"\\u003E\\u000a          \\u003Cul class=\\\"dm-thread-list js-dm-thread-list\\\"\\u003E\\u000a            {{\\u003Edirect_message_dialog_empty}}\\u000a          \\u003C/ul\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      {{\\u003Edm_footer}}\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dm_new_conversation: \"\\u003Cdiv id=\\\"dm_dialog_new\\\" class=\\\"modal-content\\\"\\u003E\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-header modal-header\\\"\\u003E\\u000a    \\u003Ch3\\u003E\\u003Ca href=\\\"#\\\"\\u003EDirect messages\\u003C/a\\u003E \\u203a New\\u003C/h3\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-close\\\"\\u003E\\u003Cb\\u003E&rsaquo;\\u003C/b\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u000a  \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"dm-dialog-content\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dm-to\\\"\\u003E\\u000a          \\u003Cinput class=\\\"dm-to-input twttr-directmessage-input\\\" type=\\\"text\\\"\\u003E\\u003C/input\\u003E\\u000a          \\u003Cimg class=\\\"avatar size24 selected-profile\\\" src=\\\"{{default_profile_url}}\\\" data-default-img=\\\"{{default_profile_url}}\\\"\\u003E\\u000a          {{\\u003Eswift_autocomplete_dropdown}}\\u000a        \\u003C/div\\u003E\\u000a\\u000a        \\u003Cdiv class=\\\"dm-convo-placeholder\\\"\\u003E\\u000a          {{\\u003Edirect_message_dialog_error}}\\u000a        \\u003C/div\\u003E\\u000a\\u000a      \\u003C/div\\u003E\\u000a\\u000a      {{\\u003Eswift_dm_box}}\\u000a\\u000a      {{\\u003Edm_footer}}\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dm_shell: \"\\u003Cdiv id=\\\"dm_dialog\\\" class=\\\"modal-container dm-conversation-list\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable twttr-dialog dm-dialog\\\"\\u003E\\u000a    {{\\u003Edialogs/dm_conversation_list}}\\u000a    {{\\u003Edialogs/dm_conversation}}\\u000a    {{\\u003Edialogs/dm_new_conversation}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            embed: \"\\u003Cdiv id=\\\"embed-tweet-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-medium draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EEmbed this Tweet\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        {{\\u003Eembed_dialog}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            favorited_popup_title: \"{{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a  \\u000a    {{#favoriters_length_one}}Favorited {{favorites_count}} time{{/favoriters_length_one}}\\u000a    {{#favoriters_length_other}}Favorited {{favorites_count}} times{{/favoriters_length_other}}\\u000a  \\u000a{{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a{{#australian_fav_to_like}}\\u000a  \\u000a    {{#favoriters_length_one}}Liked {{favorites_count}} time{{/favoriters_length_one}}\\u000a    {{#favoriters_length_other}}Liked {{favorites_count}} times{{/favoriters_length_other}}\\u000a  \\u000a{{/australian_fav_to_like}}\\u000a{{#australian_fav_to_star}}\\u000a  \\u000a    {{#favoriters_length_one}}Starred {{favorites_count}} time{{/favoriters_length_one}}\\u000a    {{#favoriters_length_other}}Starred {{favorites_count}} times{{/favoriters_length_other}}\\u000a  \\u000a{{/australian_fav_to_star}}\\u000a\",\n            goto_user_dialog: \"\\u003Cdiv id=\\\"goto-user-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EGo to a person's profile\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a          \\u003Cform class=\\\"goto-user-form\\\"\\u003E\\u000a            \\u003Cinput class=\\\"username-input\\\" type=\\\"text\\\" placeholder=\\\"Start typing a name to jump to a profile\\\"\\u003E\\u000a            {{\\u003Eswift_autocomplete_dropdown}}\\u000a          \\u003C/form\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            in_product_help_dialog: \"\\u003Cdiv id=\\\"in_product_help_dialog\\\" class=\\\"modal-container modal-profile-image-help\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EUpload a profile image\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp\\u003EHow to upload or change your profile picture:\\u003C/p\\u003E\\u000a        \\u003Col\\u003E\\u000a          \\u003Cli\\u003EClick the \\u003Cstrong\\u003EChoose file\\u003C/strong\\u003E button.\\u003C/li\\u003E\\u000a          \\u003Cli\\u003E\\u003Cstrong\\u003ESelect a file\\u003C/strong\\u003E to upload as your picture. It must be smaller than 700k and in JPG, GIF, or PNG format (no animated GIFs).\\u003C/li\\u003E\\u000a          \\u003Cli\\u003EClick \\u003Cstrong\\u003ESave changes\\u003C/strong\\u003E at the bottom of the page to see a thumbnail.\\u003C/li\\u003E\\u000a        \\u003C/ol\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cspan class=\\\"satisfaction-prompt\\\"\\u003E\\u000a          \\u003Cspan id=\\\"satisfaction_question\\\"\\u003EWas this helpful?\\u003C/span\\u003E\\u000a          \\u003Cspan id=\\\"satisfaction_feedback\\\"\\u003EThanks for the feedback!\\u003C/span\\u003E\\u000a        \\u003C/span\\u003E\\u000a        \\u003Cdiv id=\\\"satisfaction_buttons\\\"\\u003E\\u000a          \\u003Cbutton id=\\\"helpful_button\\\" class=\\\"btn\\\"\\u003EYes\\u003C/button\\u003E\\u000a          \\u003Cbutton id=\\\"not_helpful_button\\\" class=\\\"btn\\\"\\u003ENo\\u003C/button\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            keyboard_shortcuts_dialog: \"\\u000a\\u003Cdiv id=\\\"keyboard-shortcut-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-large draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"modal-btn modal-close js-dimiss\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EKeyboard shortcuts\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a\\u000a        \\u003Cdiv class=\\\"keyboard-shortcuts clearfix\\\" id=\\\"keyboard-shortcut-menu\\\"\\u003E\\u000a\\u000a          {{#logged_in}}\\u000a          \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a            \\u003Cthead\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Cth colspan=\\\"2\\\"\\u003EActions\\u003C/th\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/thead\\u003E\\u000a            \\u003Ctbody\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EFavorite\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EReply\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003ET\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ERetweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EM\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EDirect message\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EN\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENew Tweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EEnter\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EOpen Tweet details\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EL\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EClose all open Tweets\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/tbody\\u003E\\u000a          \\u003C/table\\u003E\\u000a          \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a            \\u003Cthead\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Cth colspan=\\\"2\\\"\\u003ENavigation\\u003C/th\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/thead\\u003E\\u000a            \\u003Ctbody\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E?\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EThis menu\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EJ\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENext Tweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EK\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPrevious Tweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003ESpace\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPage down\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E/\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESearch\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E.\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELoad new Tweets\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/tbody\\u003E\\u000a          \\u003C/table\\u003E\\u000a          \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a            \\u003Cthead\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Cth colspan=\\\"2\\\"\\u003ETimelines\\u003C/th\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/thead\\u003E\\u000a            \\u003Ctbody\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EH\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EHome\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a\\u000a              {{#decider_activity_read}}\\u000a                \\u003Ctr\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                    \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EC\\u003C/b\\u003E\\u000a                  \\u003C/td\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut-label\\\"\\u003EConnect\\u003C/td\\u003E\\u000a                \\u003C/tr\\u003E\\u000a                \\u003Ctr\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                    \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EA\\u003C/b\\u003E\\u000a                  \\u003C/td\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut-label\\\"\\u003EActivity\\u003C/td\\u003E\\u000a                \\u003C/tr\\u003E\\u000a                \\u003Ctr\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                    \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a                  \\u003C/td\\u003E\\u000a                  \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMentions\\u003C/td\\u003E\\u000a                \\u003C/tr\\u003E\\u000a              {{/decider_activity_read}}\\u000a              {{^decider_activity_read}}\\u000a                  \\u003Ctr\\u003E\\u000a                    \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                      \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a                    \\u003C/td\\u003E\\u000a                    \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMentions\\u003C/td\\u003E\\u000a                  \\u003C/tr\\u003E\\u000a              {{/decider_activity_read}}\\u000a\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ED\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EDiscover\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EP\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EProfile\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EFavorites\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EL\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELists\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EM\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMessages\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ES\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESettings\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EU\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EGo to user...\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/tbody\\u003E\\u000a          \\u003C/table\\u003E\\u000a          {{/logged_in}}\\u000a          {{^logged_in}}\\u000a          \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a            \\u003Ctbody\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EEnter\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EOpen Tweet details\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EGo to user...\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E?\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EThis menu\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EJ\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENext Tweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003EK\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPrevious Tweet\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003ESpace\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPage down\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E/\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESearch\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                  \\u003Cb class=\\\"sc-key\\\"\\u003E.\\u003C/b\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELoad new Tweets\\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/tbody\\u003E\\u000a          \\u003C/table\\u003E\\u000a          {{/logged_in}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u000a\",\n            list_create_dialog: \"\\u003Cdiv id=\\\"list-create-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-medium draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003ECreate a new list\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        {{\\u003Elist_dialog}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            list_membership_dialog: \"\\u003Cdiv id=\\\"list-membership-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EYour lists\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"list-membership-content\\\"\\u003E\\u003C/div\\u003E\\u000a        \\u003Cspan class=\\\"spinner lists-spinner\\\" title=\\\"Loading&hellip;\\\"\\u003E\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            mobile_gallery_download_dialog: \"\\u003Cdiv id=\\\"mobile_gallery_download_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EDownload a Twitter app for your phone\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp\\u003EGive us your email address and we'll send a link to download the Twitter app, or visit twitter.com/download on your mobile device.\\u003C/p\\u003E\\u000a        \\u003Cform class=\\\"dialog-form\\\"\\u003E\\u000a          \\u003Cfieldset class=\\\"common-form\\\"\\u003E\\u000a            \\u003Clabel class=\\\"field\\\"\\u003E\\u000a              \\u003Cspan class=\\\"label\\\"\\u003EEnter your email address:\\u003C/span\\u003E\\u000a              \\u003Cspan class=\\\"input-wrapper\\\"\\u003E\\u000a                \\u003Cinput type=\\\"email\\\" name=\\\"email\\\" required\\u003E\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cspan class=\\\"notification\\\"\\u003E\\u003C/span\\u003E\\u000a            \\u003C/label\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a          \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"dialog-prompt\\\"\\u003E\\u000a              \\u003Cinput type=\\\"submit\\\" class=\\\"btn primary-btn submit js-submit\\\" value=\\\"Send link\\\"\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            password_dialog: \"\\u003Cdiv id=\\\"password_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003ESave account changes\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp\\u003ERe-enter your Twitter password to save changes to your account.\\u003C/p\\u003E\\u000a        \\u003Cdiv class=\\\"input-wrapper password-wrapper\\\"\\u003E\\u000a          \\u003Cinput class=\\\"input-password-confirm\\\" id=\\\"auth_password\\\" name=\\\"auth_password\\\" type=\\\"password\\\" placeholder=\\\"Password\\\"\\u003E\\u000a          \\u003Csmall\\u003E\\u000a            \\u003Ca href=\\\"{{resend_password_path}}\\\" id=\\\"forgot_password\\\"\\u003EForgot your password?\\u003C/a\\u003E\\u000a            \\u003Cspan id=\\\"reminder_sent\\\" style=\\\"visibility: hidden\\\"\\u003EReminder sent!\\u003C/span\\u003E\\u000a          \\u003C/small\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn\\\" id=\\\"cancel_password_button\\\"\\u003ECancel\\u003C/button\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" id=\\\"save_password\\\" class=\\\"btn primary-btn modal-submit\\\"\\u003ESave changes\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_popup_container: \"\\u003Cdiv id=\\\"profile_popup\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content clearfix\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EProfile summary\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body profile-modal\\\"\\u003E\\u000a\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"loading\\\"\\u003E\\u000a        \\u003Cimg src=\\\"{{bigger_spinner_path}}\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            protected_verified_dialog: \"\\u003Cdiv id=\\\"protected_verified_dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\" type=\\\"button\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003EWarning!\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        \\u003Cp\\u003EWe're sorry, Twitter only verifies public accounts. If you protect your account, you will lose your verified badge.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton id=\\\"stay_verified_link\\\" class=\\\"btn\\\" type=\\\"button\\\"\\u003EStay verified\\u003C/button\\u003E\\u000a        \\u003Cbutton id=\\\"protect_my_tweets_link\\\" class=\\\"btn primary-btn\\\" type=\\\"button\\\"\\u003EProtect my Tweets\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u000a\",\n            retweet_dialog: \"\\u000a\\u000a\\u003Cdiv id=\\\"retweet-tweet-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u000a        {{^change_german_verbs}}\\u003Ch3 class=\\\"modal-title\\\"\\u003ERetweet this to your followers?\\u003C/h3\\u003E{{/change_german_verbs}}\\u000a        {{#change_german_verbs}}\\u003Ch3 class=\\\"modal-title\\\"\\u003EDiesen Tweet mit Deinen Followern teilen?\\u003C/h3\\u003E{{/change_german_verbs}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body modal-tweet\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"btn cancel-action\\\"\\u003ECancel\\u003C/button\\u003E\\u000a        \\u000a        {{^change_german_verbs}}\\u003Cbutton class=\\\"btn primary-btn retweet-action\\\"\\u003ERetweet\\u003C/button\\u003E{{/change_german_verbs}}\\u000a        {{#change_german_verbs}}\\u003Cbutton class=\\\"btn primary-btn retweet-action\\\"\\u003ETeilen\\u003C/button\\u003E{{/change_german_verbs}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            retweeted_popup_title: \"\\u000a  {{#retweeters_length_one}}Retweeted {{retweets_count}} time{{/retweeters_length_one}}\\u000a  {{#retweeters_length_other}}Retweeted {{retweets_count}} times{{/retweeters_length_other}}\\u000a\\u000a\",\n            search_operators_shell: \"\\u003Cdiv id=\\\"search-operators-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003ESearch Operators\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        {{\\u003Esearch_operators}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            sensitive_flag_confirmation: \"\\u003Cdiv class=\\\"sensitive-confirm-form\\\"\\u003E\\u000a  \\u003Cp class=\\\"sensitive-title\\\"\\u003EThis has already been marked as containing sensitive content.\\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"sensitive-field\\\"\\u003E\\u000a    \\u003Clabel for=\\\"sensitive-settings-checkbox\\\"\\u003E\\u000a      \\u003Cinput class=\\\"checkbox\\\" type=\\\"checkbox\\\" id=\\\"sensitive-settings-checkbox\\\" value=\\\"settings\\\"/\\u003E\\u000a      \\u003Cspan class=\\\"sensitive-label\\\"\\u003EChange my settings to warn me before displaying media that may contain sensitive content.\\u003C/span\\u003E\\u000a    \\u003C/label\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"sensitive-field\\\"\\u003E\\u000a    \\u003Clabel for=\\\"sensitive-illegal-checkbox\\\"\\u003E\\u000a      \\u003Cinput class=\\\"checkbox\\\" type=\\\"checkbox\\\" id=\\\"sensitive-illegal-checkbox\\\" value=\\\"illegal\\\"/\\u003E\\u000a      \\u003Cspan class=\\\"sensitive-label\\\"\\u003EFlag this as containing illegal content.\\u003C/span\\u003E\\u000a    \\u003C/label\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"sensitive-confirmation\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"sensitive-buttons\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"button submit-sensitive-form js-prompt-ok\\\" data-tweet-id=\\\"{{id}}\\\"\\u003ESubmit\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"button cancel-sensitive-form js-prompt-cancel\\\" data-tweet-id=\\\"{{id}}\\\"\\u003ECancel\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Ca class=\\\"sensitive-learn-more\\\" href=\\\"{{flag_turkey_support_path}}\\\"\\u003ELearn more about flagging media\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            signin_or_signup_dialog: \"{{!\\u000a  This dialog can be displayed in one of two styles:\\u000a\\u000a  1. Prompt user to sign up\\u000a  2. Prompt user to sign up or sign in\\u000a\\u000a  We use CSS classes to change what content we actually display. Elements with the class\\u000a  \\\"signup-only\\\" are only shown in the first case. Elements with the class\\u000a  \\\"not-signup-only\\\" are only shown in the second case.\\u000a}}\\u000a{{#content_view}}\\u000a  \\u003Cdiv id=\\\"signin-or-signup-dialog\\\"\\u003E\\u000a    \\u003Cdiv id=\\\"signin-or-signup\\\" class=\\\"modal-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"modal modal-medium draggable\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a          \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a          \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a            \\u003Ch3 class=\\\"modal-title modal-long-title signup-only\\\"\\u003ESign up for Twitter &amp; follow @{{screen_name}}\\u003C/h3\\u003E\\u000a            \\u003Ch3 class=\\\"modal-title not-signup-only\\\"\\u003ESign in to Twitter\\u003C/h3\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"modal-body signup-only\\\"\\u003E\\u000a            {{\\u003Epartial_signup_form}}\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"modal-body not-signup-only\\\"\\u003E\\u000a            {{\\u003Esignin_form}}\\u000a            \\u003Cdiv class=\\\"signup\\\"\\u003E\\u000a              \\u003Ch2\\u003ENot on Twitter? Sign up, tune into the things you care about, and get updates as they happen.\\u003C/h2\\u003E\\u000a              {{\\u003Esignup_button}}\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/content_view}}\\u000a\",\n            sms_codes: \"\\u000a\\u003Ctable id=\\\"sms_codes\\\" cellpadding=\\\"0\\\" cellspacing=\\\"0\\\"\\u003E\\u000a  \\u003Cthead\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Cth\\u003ECountry\\u003C/th\\u003E\\u000a      \\u003Cth\\u003ECode\\u003C/th\\u003E\\u000a      \\u003Cth\\u003EFor customers of\\u003C/th\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003C/thead\\u003E\\u000a  \\u003Ctbody\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EUnited States\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E40404\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E(any)\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003ECanada\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E21212\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E(any)\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EUnited Kingdom\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E86444\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EVodafone, Orange, 3, O2\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EBrazil\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E40404\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003ENextel, TIM\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EHaiti\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E40404\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EDigicel, Voila\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EIreland\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E51210\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EVodafone, O2\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EIndia\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E53000\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EBharti Airtel, Videocon, Reliance\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003EIndonesia\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E89887\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EAXIS, 3, Telkomsel, Indosat, XL Axiata\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd rowspan=\\\"2\\\"\\u003EItaly\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E4880804\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EWind\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003E3424486444\\u003C/td\\u003E\\u000a      \\u003Ctd\\u003EVodafone\\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003C/tbody\\u003E\\u000a  \\u003Ctfoot\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd colspan=\\\"3\\\"\\u003E\\u000a        &raquo; \\u003Ca target=\\\"_blank\\\" href=\\\"http://support.twitter.com/articles/14226-how-to-find-your-twitter-short-code-or-long-code\\\"\\u003ESee SMS short codes for other countries\\u003C/a\\u003E\\u000a      \\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003C/tfoot\\u003E\\u000a\\u003C/table\\u003E\",\n            trend_dialog_location_item: \"\\u003Cli\\u003E\\u000a  \\u003Ca href=\\\"#\\\" class=\\\"trends-location-item js-trend-link\\\" data-woeid=\\\"{{woeid}}\\\"\\u003E\\u000a    {{name}}\\u000a    \\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            trends_dialog_inner: \"\\u003Cdiv class=\\\"trends-by-location\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"trends-breadcrumb\\\"\\u003E\\u000a    {{\\u003Etrends_dialog_breadcrumbs}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"trends-locations clearfix\\\"\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations0}}\\u000a        {{\\u003Edialogs/trend_dialog_location_item}}\\u000a      {{/locations0}}\\u000a    \\u003C/ul\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations1}}\\u000a        {{\\u003Edialogs/trend_dialog_location_item}}\\u000a      {{/locations1}}\\u000a    \\u003C/ul\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations2}}\\u000a        {{\\u003Edialogs/trend_dialog_location_item}}\\u000a      {{/locations2}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            trends_dialog_shell: \"\\u003Cdiv id=\\\"trends_dialog\\\" class=\\\"trends-dialog modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a          \\u003Ch3 class=\\\"modal-title\\\"\\u003E\\u000a            {{#decider_personalized_trends}}Trends{{/decider_personalized_trends}}\\u000a            {{^decider_personalized_trends}}Choose a trend location{{/decider_personalized_trends}}\\u000a          \\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a\\u000a        {{#decider_personalized_trends}}\\u000a          {{\\u003Etrends_personalized_dialog}}\\u000a        {{/decider_personalized_trends}}\\u000a\\u000a        \\u003Cdiv class=\\\"trends-wrapper\\\" id=\\\"trends_dialog_content\\\"\\u003E\\u000a          \\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{#decider_personalized_trends}}\\u000a        \\u003Cdiv class=\\\"modal-footer trends-by-location\\\"\\u003E\\u000a          {{\\u003Etrends_dialog_footer}}\\u000a        \\u003C/div\\u003E\\u000a      {{/decider_personalized_trends}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            tweet_dialog: \"\\u003Cdiv id=\\\"global-tweet-dialog\\\" class=\\\"modal-container\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"close-modal-background-target\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"modal draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-content\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"modal-btn modal-close\\\"\\u003E\\u003Ci class=\\\"close-medium\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EClose\\u003C/span\\u003E\\u003C/i\\u003E\\u003C/button\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"modal-title\\\"\\u003E\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a        {{\\u003Eswift_tweet_box}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"modal-footer modal-tweet\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            direct_message_delete_confirm: \"\\u003Cp\\u003EAre you sure you want to delete this message?\\u003C/p\\u003E\\u000a\\u003Cbutton type=\\\"button\\\" class=\\\"btn caution-btn js-prompt-ok\\\" data-message-id=\\\"{{messageId}}\\\"\\u003EDelete message\\u003C/button\\u003E\\u000a\\u003Cbutton type=\\\"button\\\" class=\\\"btn js-prompt-cancel\\\"\\u003ECancel\\u003C/button\\u003E\\u000a\",\n            direct_message_dialog: \"\\u003Cdiv class=\\\"twttr-dialog-container\\\" style=\\\"visibility: hidden;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog dm-dialog\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-header\\\"\\u003E\\u000a      \\u003Ch3 class=\\\"js-dm-header\\\"\\u003E\\u003C/h3\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-close\\\"\\u003E\\u003Cb\\u003E&times;\\u003C/b\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-error clearfix\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"twttr-dialog-content js-dm-content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"dm-tweetbox js-dm-tweetbox\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dm-delete-confirm js-dm-delete-confirm\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-footer clearfix\\\"\\u003E\\u000a        Tip: you can send a message to anyone who follows you. \\u003Ca href=\\\"{{direct_message_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            direct_message_dialog_conversation: \"{{\\u003Edirect_message_dialog_error}}\\u000a\\u003Cdiv class=\\\"dm-convo js-dm-conversation js-modal-scrollable js-twttr-dialog-not-draggable\\\" data-thread-id=\\\"{{threadId}}\\\"\\u003E\\u000a  {{#items}}\\u000a    {{\\u003Edirect_message_dialog_conversation_item}}\\u000a  {{/items}}\\u000a  \\u000a  \\u003Cdiv class=\\\"dm-ie-fix\\\"\\u003E&nbsp;\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            direct_message_dialog_conversation_item: \"\\u003Cdiv class=\\\"dm {{sent_or_received}} js-dm-item\\\" data-message-id=\\\"{{id}}\\\"\\u003E\\u000a  {{#sender}}\\u000a    \\u003Cimg class=\\\"avatar\\\" src=\\\"{{#rendering_on_server}}{{profile_image_absolute_url}}{{/rendering_on_server}}{{^rendering_on_server}}{{profile_image_url}}{{/rendering_on_server}}\\\"\\u003E\\u000a  {{/sender}}\\u000a  \\u003Cdiv class=\\\"dm-content clearfix\\\"\\u003E\\u000a    \\u003Csmall class=\\\"time\\\"\\u003E\\u000a      \\u000a      \\u003Cspan class=\\\"_timestamp{{#is_relative_timestamp}} js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\" data-include-sec=\\\"true\\\"\\u003E\\u000a        {{#rendering_on_server}}{{short_timestamp}}{{/rendering_on_server}}\\u000a        {{^rendering_on_server}}{{timestamp}}{{/rendering_on_server}}\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/small\\u003E\\u000a    \\u003Cdiv class=\\\"dm-message\\\"\\u003E\\u000a      \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a      \\u003Cdiv class=\\\"dm-caret\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dm-caret-outer\\\"\\u003E\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"dm-caret-inner\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Ca class=\\\"dm-delete js-dm-delete\\\" href=\\\"#\\\" title=\\\"Delete this direct message\\\" data-message-id=\\\"{{id}}\\\"\\u003E\\u003Ci class=\\\"trash\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            direct_message_dialog_conversation_list: \"\\u003Cdiv class=\\\"dm-threads js-dm-threads js-modal-scrollable js-twttr-dialog-not-draggable\\\"\\u003E\\u000a  \\u003Cul class=\\\"dm-thread-list js-dm-thread-list\\\"\\u003E\\u000a    {{#items}}\\u000a      {{\\u003Edirect_message_dialog_conversation_list_item}}\\u000a    {{/items}}\\u000a    {{^items}}\\u000a      {{\\u003Edirect_message_dialog_empty}}\\u000a    {{/items}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            direct_message_dialog_conversation_list_item: \"\\u003Cli class=\\\"dm-thread js-dm-thread\\\" data-thread-id=\\\"{{threadId}}\\\" data-last-message-id=\\\"{{last_message_id}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"dm-thread-link js-dm-thread-link\\\" href=\\\"#\\\" data-thread-id=\\\"{{threadId}}\\\"\\u003E\\u000a    \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cdiv class=\\\"dm-thread-status js-thread-status\\\"\\u003E\\u000a      \\u003Ci class=\\\"{{#is_unread}}unread{{/is_unread}}\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"dm-thread-content\\\"\\u003E\\u000a      {{#other_person}}\\u000a        \\u003Cspan class=\\\"account-group\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size32\\\" src=\\\"{{#rendering_on_server}}{{profile_image_absolute_url}}{{/rendering_on_server}}{{^rendering_on_server}}{{profile_image_url}}{{/rendering_on_server}}\\\"\\u003E\\u000a          \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a          \\u003Csmall class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/small\\u003E\\u000a        \\u003C/span\\u003E\\u000a      {{/other_person}}\\u000a      \\u003Cp class=\\\"dm-thread-snippet js-tweet-text\\\"\\u003E\\u000a        {{#is_replied}}\\u003Ci class=\\\"replied\\\"\\u003E\\u003C/i\\u003E{{/is_replied}}\\u000a        {{last_message_text}}\\u000a      \\u003C/p\\u003E\\u000a      \\u000a      \\u003Csmall class=\\\"time\\\"\\u003E\\u000a        \\u000a        \\u003Cspan class=\\\"_timestamp{{#is_relative_timestamp}} js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{last_message_actual_timestamp}}\\\" data-long-form=\\\"true\\\" data-include-sec=\\\"true\\\"\\u003E{{last_message_timestamp}}\\u003C/span\\u003E\\u000a      \\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            direct_message_dialog_empty: \"\\u003Cdiv class=\\\"dm-placeholder-empty dm-no-messages\\\"\\u003E\\u000a  \\u003Cp\\u003E\\u003Cstrong\\u003EYou don't have any messages yet.\\u003C/strong\\u003E\\u003C/p\\u003E\\u000a  \\u003Cp\\u003EDirect messages are 140 characters, private, and can be sent to any user who follows you on Twitter.\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            direct_message_dialog_error: \"\\u003Cdiv class=\\\"dm-error js-dm-error\\\"\\u003E\\u000a  \\u003Ca href=\\\"#\\\" class=\\\"js-dismiss\\\"\\u003E\\u000a    \\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cspan class=\\\"dm-error-text\\\"\\u003E\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\",\n            direct_message_dialog_header: \"{{%TRANSLATION-HINT mode=dmmodal}}\\u000a{{#conversation_list}}\\u000a  \\u003Ca class=\\\"btn js-dismiss dm-header-new js-dm-header-new\\\" href=\\\"#\\\"\\u003ENew message\\u003C/a\\u003E\\u000a  \\u003Ch2\\u003EDirect messages\\u003C/h2\\u003E\\u000a{{/conversation_list}}\\u000a{{^conversation_list}}\\u000a  \\u003Ch2\\u003E\\u003Ca class=\\\"js-dm-header-title\\\" href=\\\"#\\\"\\u003EDirect messages\\u003C/a\\u003E \\u203a\\u000a    {{#new_dm}}\\u000a      New\\u000a    {{/new_dm}}\\u000a    {{#conversation}}\\u000a      with {{name}}\\u000a    {{/conversation}}\\u000a  \\u003C/h2\\u003E\\u000a{{/conversation_list}}\\u000a\",\n            direct_message_dialog_new: \"\\u003Cdiv class=\\\"dm-to js-dm-new\\\"\\u003E\\u000a  \\u000a  \\u003Cimg class=\\\"avatar size24 js-dm-avatar\\\" src=\\\"#\\\"\\u003E\\u000a\\u000a  \\u000a  \\u003Cinput class=\\\"dm-to-input twttr-directmessage-input js-dm-user-autocomplete\\\" type=\\\"text\\\"\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u000a\\u003Cdiv class=\\\"js-dm-user-check\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"dm-convo-placeholder\\\"\\u003E\\u000a  {{\\u003Edirect_message_dialog_error}}\\u000a\\u003C/div\\u003E\",\n            discover: \"{{\\u003Edashboard_discover}}\\u000a{{\\u003Edialogs/trends_dialog_shell}}\\u000a\\u000a\\u003Cdiv id=\\\"{{content_div_id}}\\\" class=\\\"content-main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header {{#single_expanded_story}}content-header-detached{{/single_expanded_story}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003E{{#single_expanded_story}}Tweets{{/single_expanded_story}}{{^single_expanded_story}}Stories{{/single_expanded_story}}\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"subheader\\\"\\u003E{{subtitle_text}}\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv id=\\\"discover_items\\\"\\u003E\\u000a    {{#timeline}}\\u000a      {{\\u003Etimeline}}\\u000a    {{/timeline}}\\u000a    {{^timeline}}\\u000a      {{#discover_items}}\\u000a        {{\\u003Ediscover/discover_items}}\\u000a      {{/discover_items}}\\u000a      {{#has_items}}\\u000a        {{\\u003Estream_end}}\\u000a      {{/has_items}}\\u000a      {{^has_items}}\\u000a        {{\\u003Ediscovery_stream_error}}\\u000a      {{/has_items}}\\u000a    {{/timeline}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            discover_items: \" {{^in_timeline}}\\u003Cdiv class=\\\"items\\\"\\u003E{{/in_timeline}}\\u000a  {{#items}}\\u000a    {{\\u003Ediscover/story}}\\u000a  {{/items}}\\u000a{{^in_timeline}}\\u003C/div\\u003E{{/in_timeline}}\",\n            news_story: \"{{#article_image}}\\u000a  \\u003Cdiv class=\\\"discover-item-image-wrapper\\\"\\u003E\\u000a    \\u003Ca class=\\\"js-action-card-news\\\" href=\\\"{{article_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a      \\u003Cimg class=\\\"discover-item-image\\\" src=\\\"{{article_image}}\\\" alt=\\\"{{title}}\\\"\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/article_image}}\\u000a\\u000a\\u003Ch3 class=\\\"discover-item-title js-story-title js-news-headline\\\"\\u003E\\u000a  \\u003Ca class=\\\"js-action-card-news\\\" href=\\\"{{article_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a    {{title}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/h3\\u003E\\u000a\\u000a\\u003Cp class=\\\"discover-item-summary js-news-snippet\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a\\u003Cp class=\\\"metadata discover-item-metadata js-metadata\\\"\\u003E\\u000a  \\u003Ca class=\\\"js-action-card-news\\\" href=\\\"{{article_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a    {{article_display_url}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/p\\u003E\\u000a\",\n            social_proof: \"\\u000a\\u003Cdiv class=\\\"expanded-content js-expando-content\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"expanded-tweets\\\"\\u003E\\u000a    {{#statuses}}\\u000a      \\u003Cdiv class=\\\"supplement hidden-supplement sub-stream-item-hidden\\\"\\u003E{{\\u003Esimple_tweet}}\\u003C/div\\u003E\\u000a    {{/statuses}}\\u000a    {{#is_trend}}\\u000a      \\u003Cdiv class=\\\"social-proof-tweet\\\"\\u003E\\u000a        \\u003Cspan class=\\\"metadata\\\"\\u003E\\u000a          \\u003Ca class=\\\"js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"trend_click\\\"\\u003E\\u000a            \\u003Ci class=\\\"sm-search\\\"\\u003E\\u003C/i\\u003ESearch this trend\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/is_trend}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            social_proof_summary: \"\\u003Cdiv class=\\\"social-context\\\"\\u003E\\u000a  \\u003Cspan class=\\\"summary-closed js-expando-control-unexpanded show\\\"\\u003E\\u000a    \\u000a    \\u003Cdiv class=\\\"social-context-avatars\\\"\\u003E\\u000a      {{#tweeted_users}}\\u000a        {{\\u003Euser_avatar_link_24}}\\u000a      {{/tweeted_users}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/span\\u003E \\u000a\\u000a  \\u003Cspan class=\\\"metadata\\\"\\u003E\\u000a    {{#is_trend}}\\u000a      \\u000a        {{#status_count_one}}Trending Tweet about{{/status_count_one}}{{#status_count_other}}Trending Tweets about{{/status_count_other}}\\u000a        \\u003Ca class=\\\"social-emphasis js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"trend_click\\\"\\u003E{{story_name}}\\u003C/a\\u003E\\u000a      \\u000a    {{/is_trend}}\\u000a    {{^is_trend}}\\u000a      {{#first_user}}\\u000a        {{^tweeted_by_count}}\\u000a           Tweeted by \\u003Ca class=\\\"social-emphasis show-popup-with-id\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a        {{/tweeted_by_count}}\\u000a\\u000a        {{#tweeted_by_count}}\\u000a          \\u000a            Tweeted by \\u003Ca class=\\\"social-emphasis show-popup-with-id\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a              {{#tweeted_by_count_one}}and {{tweeted_by_count}} other{{/tweeted_by_count_one}}\\u000a              {{#tweeted_by_count_other}}and {{tweeted_by_count}} others{{/tweeted_by_count_other}}\\u000a          \\u000a        {{/tweeted_by_count}}\\u000a      {{/first_user}}\\u000a    {{/is_trend}}\\u000a\\u000a    \\u000a    \\u003Cspan class=\\\"metadata discover-item-actions\\\"\\u003E\\u000a      \\u003Cspan class=\\\"separator\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a      \\u003Ca class=\\\"open-close-tweets-link summary-closed show\\\" href=\\\"#\\\"\\u003E{{#status_count_one}}View Tweet{{/status_count_one}}{{#status_count_other}}View Tweets{{/status_count_other}}\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"open-close-tweets-link summary-opened hide\\\" href=\\\"#\\\"\\u003E{{#status_count_one}}Hide Tweet{{/status_count_one}}{{#status_count_other}}Hide Tweets{{/status_count_other}}\\u003C/a\\u003E\\u000a      {{#is_news}}\\u000a        \\u003Cspan class=\\\"separator\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a        \\u003Ca class=\\\"story-social-new-tweet\\\" href=\\\"#\\\"\\u003ETweet this story\\u003C/a\\u003E\\u000a      {{/is_news}}\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            story: \"\\u003Cdiv class=\\\"{{story_class}} {{#single_expanded_story}}disco-item-expanded stream-item-expanded open{{/single_expanded_story}}\\\"\\u003E\\u000a  \\u003Cdiv {{\\u003Ediscover/story_data}}\\u003E\\u000a    \\u003Cdiv class=\\\"js-expand-trigger-area expand-trigger-area\\\"\\u003E\\u000a      {{#show_card_title}}\\u000a        \\u003Cdiv class=\\\"onebox-header\\\"\\u003E\\u000a          \\u003Ch3\\u003E{{card_title}}\\u003C/h3\\u003E\\u000a          {{#view_all_path}}\\u003Csmall class=\\\"view-all\\\"\\u003E &middot; \\u003Ca class=\\\"js-onebox-view-all\\\" href=\\\"{{view_all_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E{{/view_all_path}}\\u000a        \\u003C/div\\u003E\\u000a      {{/show_card_title}}\\u000a      \\u003Cdiv class=\\\"discover-item-content\\\"\\u003E\\u000a        {{#single_expanded_story}}\\u000a          {{#expanded_tweet}}\\u000a            \\u003Cdiv class=\\\"permalink\\\"\\u003E\\u000a              {{\\u003Esingle_tweet}}\\u000a            \\u003C/div\\u003E\\u000a          {{/expanded_tweet}}\\u000a        {{/single_expanded_story}}\\u000a        {{^single_expanded_story}}\\u000a          {{#is_news}}\\u000a            {{\\u003Ediscover/news_story}}\\u000a          {{/is_news}}\\u000a          {{#is_topic}}\\u000a            {{\\u003Ediscover/topic_story}}\\u000a          {{/is_topic}}\\u000a          {{#is_user}}\\u000a            {{\\u003Ediscover/user_story}}\\u000a          {{/is_user}}\\u000a        {{/single_expanded_story}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{#social_proof_summary_view}}\\u000a        {{\\u003Ediscover/social_proof_summary}}\\u000a      {{/social_proof_summary_view}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u000a    {{#social_proof_view}}\\u000a      {{\\u003Ediscover/social_proof}}\\u000a    {{/social_proof_view}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            story_data: \"\\u000aclass=\\\"discover-item js-hover js-story-item {{#is_hashtag}}is-hashtag{{/is_hashtag}} {{#is_news}}discover-news{{/is_news}} {{#is_topic}}discover-topic {{media_type}} js-loading loading {{^has_media}}js-nomedia nomedia{{/has_media}}{{/is_topic}}\\\"\\u000adata-query=\\\"{{escaped_query}}\\\"\\u000adata-story-type=\\\"{{type}}\\\"\\u000adata-card-media-type=\\\"{{#is_topic}}{{media_type}}{{/is_topic}}\\\"\\u000adata-url=\\\"{{#is_news}}{{article_expanded_url}}{{/is_news}}{{#is_topic}}{{query}}{{/is_topic}}\\\"\\u000adata-source=\\\"{{story_source}}\\\"\\u000adata-item-key=\\\"{{story_key}}\\\"\",\n            topic_story: \"\\u003Ch3 class=\\\"discover-item-title js-story-title js-news-headline\\\"\\u003E\\u000a  \\u003Ca class=\\\"js-action-card-search\\\" href=\\\"{{search_path}}\\\" data-query-source=\\\"trend_click\\\"\\u003E\\u000a    {{#has_image}}Photo of {{story_name}}{{/has_image}}{{#has_video}}Video of {{story_name}}{{/has_video}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/h3\\u003E\\u000a\\u000a{{#has_media}}\\u000a  \\u003Cdiv class=\\\"discover-item-media-wrapper\\\"\\u003E\\u000a     \\u003Cdiv class=\\\"discover-item-loading\\\"\\u003E\\u000a      \\u003Cp\\u003ELoading&hellip;\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Ca class=\\\"discover-item-media js-action-card-media\\\" href=\\\"{{card_url}}\\\"\\u003E\\u000a      \\u003Cimg class=\\\"story-{{media_type}} js-story-media\\\" data-item-id=\\\"{{escaped_query}}\\\" alt=\\\"{{escaped_query}}\\\" data-img-src=\\\"{{data_image_url}}\\\"\\u003E\\u000a      {{#has_video}}\\u000a        \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a      {{/has_video}}\\u000a    \\u003C/a\\u003E\\u000a    {{#has_attribution}}\\u000a      \\u003Ca class=\\\"discover-item-attribution js-story-attribution\\\" href=\\\"{{attribution_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a        \\u003Cimg class=\\\"favicon\\\" src=\\\"{{attribution_img}}\\\" alt=\\\"{{attribution_name}}\\\"\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/has_attribution}}\\u000a  \\u003C/div\\u003E\\u000a{{/has_media}}\\u000a\",\n            user_story: \"{{#items}}\\u000a  {{\\u003Estream_item}}\\u000a{{/items}}\",\n            discovery_dialog: \"\\u003Cdiv {{#container_id}}id=\\\"{{container_id}}\\\" {{/container_id}}class=\\\"twttr-dialog-container\\\" style=\\\"visibility: hidden;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog twttr-dialog-discovery\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"twttr-dialog-content\\\"\\u003E\\u000a          \\u003Cdiv\\u003E\\u000a            \\u003Ch2 class=\\\"discoverability-header\\\"\\u003EBe found on Twitter\\u003C/h2\\u003E\\u000a            \\u003Cp\\u003E\\u000a              We were hoping you could help us make it easier for people to discover their friends and colleagues on Twitter. Review your settings below to make sure the people you care about can easily find you.\\u000a            \\u003C/p\\u003E\\u000a            \\u003Cform action=\\\"#\\\" class=\\\"dialog-form\\\"\\u003E\\u000a              \\u003Cfieldset class=\\\"common-form\\\"\\u003E\\u000a                \\u003Cul\\u003E\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Clabel for=\\\"discoverable_name\\\"\\u003EName\\u003C/label\\u003E\\u000a                    \\u003Cinput type=\\\"text\\\" name=\\\"name\\\" id=\\\"discoverable_name\\\" maxlength=\\\"20\\\" value=\\\"{{name}}\\\"/\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Clabel for=\\\"discoverable_description\\\"\\u003EBio\\u003Cbr/\\u003E\\u000a                      \\u003Csmall\\u003Eoptional\\u003C/small\\u003E\\u000a                    \\u003C/label\\u003E\\u000a                    \\u003Ctextarea name=\\\"description\\\" class=\\\"discovery-description\\\" id=\\\"discoverable_description\\\"\\u003E{{description}}\\u003C/textarea\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Clabel for=\\\"discoverable_location\\\"\\u003ELocation\\u003Cbr/\\u003E\\u000a                      \\u003Csmall\\u003Eoptional\\u003C/small\\u003E\\u000a                    \\u003C/label\\u003E\\u000a                    \\u003Cinput type=\\\"text\\\" name=\\\"location\\\" id=\\\"discoverable_location\\\" maxlength=\\\"100\\\" value=\\\"{{location}}\\\"/\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                \\u003C/ul\\u003E\\u000a                \\u003Cul class=\\\"discoverability-settings\\\"\\u003E\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Clabel for=\\\"discoverable_by_email\\\"\\u003EEmail\\u003C/label\\u003E\\u000a                    \\u003Cspan class=\\\"input-wrapper\\\"\\u003E\\u000a                      \\u003Cstrong\\u003E{{email_address}}\\u003C/strong\\u003E\\u000a                      \\u003Cinput type=\\\"checkbox\\\" name=\\\"discoverable_by_email\\\" id=\\\"discoverable_by_email\\\" {{#email_checked}}checked=\\\"checked\\\"{{/email_checked}} value=\\\"1\\\" /\\u003E\\u000a                      \\u003Cspan class=\\\"discover-label\\\"\\u003ELet others find me by my email address\\u003C/span\\u003E\\u000a                      \\u003Ca href=\\\"{{help_url}}\\\" target=\\\"_blank\\\" class=\\\"help-discover\\\"\\u003E\\u003C/a\\u003E\\u000a                      \\u003Cinput type=\\\"hidden\\\" name=\\\"email_discoverability_set\\\" value=\\\"1\\\" /\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                  {{#device_setup}}\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Clabel for=\\\"discoverable_by_mobile_phone\\\"\\u003EPhone\\u003C/label\\u003E\\u000a                    \\u003Cspan class=\\\"input-wrapper\\\"\\u003E\\u000a                      \\u003Cstrong\\u003E{{device_address}}\\u003C/strong\\u003E\\u000a                      \\u003Cinput type=\\\"checkbox\\\" name=\\\"discoverable_by_mobile_phone\\\" id=\\\"discoverable_by_mobile_phone\\\" {{#phone_checked}}checked=\\\"checked\\\"{{/phone_checked}} value=\\\"1\\\" /\\u003E\\u000a                      \\u003Cspan class=\\\"discover-label\\\"\\u003ELet others find me by my phone number\\u003C/span\\u003E\\u000a                      \\u003Ca href=\\\"{{help_url}}\\\" target=\\\"_blank\\\" class=\\\"help-discover\\\"\\u003E\\u003C/a\\u003E\\u000a                      \\u003Cinput type=\\\"hidden\\\" name=\\\"mobile_phone_discoverability_set\\\" value=\\\"1\\\" /\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                  {{/device_setup}}\\u000a                  \\u003Cli\\u003E\\u000a                    \\u003Cspan class=\\\"input-wrapper privacy-statement\\\"\\u003E\\u000a                      {{#device_setup}}\\u000a                        Your email and phone \\u003Ca href=\\\"{{help_url}}\\\" target=\\\"_blank\\\"\\u003Ewill not be publicly displayed\\u003C/a\\u003E. You can change your settings anytime.\\u000a                      {{/device_setup}}\\u000a                      {{^device_setup}}\\u000a                        Your email \\u003Ca href=\\\"{{help_url}}\\\" target=\\\"_blank\\\"\\u003Ewill not be publicly displayed\\u003C/a\\u003E. You can change your settings anytime.\\u000a                      {{/device_setup}}\\u000a                    \\u003C/span\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                \\u003C/ul\\u003E\\u000a                \\u003Cdiv class=\\\"discover-buttons\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"button submit\\\"\\u003EGood to go!\\u003C/div\\u003E\\u000a                  \\u003Cdiv class=\\\"button cancel\\\"\\u003EAsk me later\\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/fieldset\\u003E\\u000a            \\u003C/form\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            discovery_stream_error: \"\\u003Cdiv class=\\\"stream-end stream-placeholder js-discovery-error\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EOops, something went wrong!\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003ESorry for the inconvenience. Please try refreshing the page in a moment.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dismiss_button: \"\\u003Ca class=\\\"dismiss js-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"dismiss-white\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a\",\n            dm_footer: \"\\u003Cdiv class=\\\"twttr-dialog-footer\\\"\\u003E\\u000a  Tip: you can send a message to anyone who follows you. \\u003Ca href=\\\"http://support.twitter.com/groups/31-twitter-basics/topics/109-tweets-messages/articles/14606-what-is-a-direct-message-dm\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            dropdown: \"\\u003Cul class=\\\"drop-down\\\" style=\\\"visibility: hidden\\\"\\u003E\\u000a  {{{items}}}\\u000a\\u003C/ul\\u003E\",\n            duplicate_tweet_error_message: \"{{#is_dm}}\\u000a  Whoops! You already said that...\\u000a{{/is_dm}}\\u000a{{^is_dm}}\\u000a  Whoops! You already tweeted that...\\u000a{{/is_dm}}\\u000a\",\n            edit_list_button: \"\\u003Cdiv class=\\\"button edit-list-button js-edit-list-action\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\" title=\\\"Edit\\\"\\u003E\\u003Cspan class=\\\"edit-list\\\"\\u003E\\u003C/span\\u003E\\u003Cb class=\\\"label\\\"\\u003EEdit\\u003C/b\\u003E\\u003C/div\\u003E\\u000a\",\n            edit_profile_button: \"\\u003Ca class=\\\"btn js-thats-you edit-profile-btn js-nav\\\" href=\\\"{{settings_profile_path}}\\\"\\u003EEdit your profile\\u003C/a\\u003E\",\n            email_already_verified_banner: \"\\u003Cdiv class=\\\"banner-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"banner-inside email-already-verified-banner\\\"\\u003E\\u000a      \\u003Ca class='pane-close' href='#'\\u003Eclose \\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a      \\u003Cspan class=\\\"warning\\\"\\u003E\\u003C/span\\u003E\\u000a      \\u003Ch5\\u003E{{already_verified_message}}\\u003C/h5\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            embed_dialog: \"\\u003Cdiv class=\\\"embed-code-container\\\"\\u003E\\u000a  \\u003Cp\\u003EAdd this Tweet to your website by copying the code below. \\u003Ca href=\\\"{{embed_documentation_path}}\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/p\\u003E\\u000a  \\u003Cform\\u003E\\u000a\\u000a    \\u003Cul class=\\\"embed-target tabs\\\"\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"btn active\\\" href=\\\"javascript:;\\\" data-target=\\\"HTML\\\"\\u003EHTML\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"btn\\\" href=\\\"javascript:;\\\" data-target=\\\"shortcode\\\"\\u003EShortcode\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"btn\\\" href=\\\"javascript:;\\\" data-target=\\\"link\\\"\\u003ELink\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a\\u000a    \\u003Ctextarea\\u003E\\u003C/textarea\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"clearfix embed-alignment\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"legend\\\"\\u003EAlignment\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"input\\\"\\u003E\\u000a        \\u003Clabel for=\\\"embed-alignment-none\\\" class=\\\"btn btn-first active\\\"\\u003E\\u003Ci class=\\\"embed-align-none\\\"\\u003E\\u003C/i\\u003ENone\\u003C/label\\u003E\\u000a        \\u003Cinput type=\\\"radio\\\" id=\\\"embed-alignment-none\\\" name=\\\"align\\\" value=\\\"none\\\" checked=\\\"checked\\\"\\u003E\\u000a        \\u003Clabel for=\\\"embed-alignment-left\\\" class=\\\"btn\\\"\\u003E\\u003Ci class=\\\"embed-align-left\\\"\\u003E\\u003C/i\\u003ELeft\\u003C/label\\u003E\\u000a        \\u003Cinput type=\\\"radio\\\" id=\\\"embed-alignment-left\\\" name=\\\"align\\\" value=\\\"left\\\"\\u003E\\u000a        \\u003Clabel for=\\\"embed-alignment-right\\\" class=\\\"btn\\\"\\u003E\\u003Ci class=\\\"embed-align-right\\\"\\u003E\\u003C/i\\u003ERight\\u003C/label\\u003E\\u000a        \\u003Cinput type=\\\"radio\\\" id=\\\"embed-alignment-right\\\" name=\\\"align\\\" value=\\\"right\\\"\\u003E\\u000a        \\u003Clabel for=\\\"embed-alignment-center\\\" class=\\\"btn btn-last\\\"\\u003E\\u003Ci class=\\\"embed-align-center\\\"\\u003E\\u003C/i\\u003ECenter\\u003C/label\\u003E\\u000a        \\u003Cinput type=\\\"radio\\\" id=\\\"embed-alignment-center\\\" name=\\\"align\\\" value=\\\"center\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cp class=\\\"help-block\\\"\\u003EControl position and text wrapping on the page.\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a  \\u003C/form\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"embed-preview\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            embedded_pic_twitter: \"\\u003Cdiv class=\\\"tweet-media\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media-instance-container\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twimg\\\"\\u003E\\u000a      \\u003Ca target=\\\"_blank\\\" href=\\\"{{expanded_url}}\\\"\\u003E\\u000a        \\u003Cimg src=\\\"{{media_url_https}}\\\"\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cspan class=\\\"flag-container\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"flaggable btn-link\\\"\\u003E\\u000a        Flag this media\\u000a      \\u003C/button\\u003E\\u000a      \\u003Cspan class=\\\"flagged hidden\\\"\\u003E\\u000a        Flagged\\u000a        \\u003Cspan\\u003E\\u000a          \\u003Ca target=\\\"_blank\\\" href=\\\"//support.twitter.com/articles/20069937\\\"\\u003E\\u000a            (learn more)\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/span\\u003E\\u000a    \\u003Cdiv class='media-attribution'\\u003E\\u000a      \\u003Cspan\\u003Epowered by\\u003C/span\\u003E \\u003Cimg src=\\\"/phoenix/img/turkey-icon.png\\\"/\\u003E \\u003Ca target='_blank' data-media-type='Twimg' class='media-attribution-link' href='http://photobucket.com/twitter'\\u003EPhotobucket\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            embedded_tweet: \"\\u003Cdiv class=\\\"tweet embedded-tweet\\\" data-tweet-id=\\\"{{id}}\\\" data-item-id=\\\"{{id}}\\\" data-screen-name='{{#user}}{{screen_name}}{{/user}}'\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{#user}}\\u000a      {{\\u003Etweet_user_block}}\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Elatest_tweet_timestamp}}:\\u000a      {{#was_retweeted}}\\u000a        \\u003Cspan class=\\\"retweet-icon\\\"\\u003E\\u003C/span\\u003E\\u000a      {{{retweet_source_screen_name_link}}}\\u000a      {{/was_retweeted}}\\u000a      &#32;{{\\u003Etweet_text}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            empty_home: \"\\u003Cdiv class=\\\"empty-home empty-stream\\\"\\u003E\\u000a\\u000a  \\u003Ch2\\u003EThis is your homepage @\\u003Cstrong\\u003E{{screen_name}}\\u003C/strong\\u003E\\u003C/h2\\u003E\\u000a\\u000a  \\u003Cp\\u003EIt's looking mighty bare right now. When you follow people their updates will appear here. So go \\u003Ca href=\\\"{{who_to_follow_interests_path}}\\\"\\u003Efind some interesting people\\u003C/a\\u003E to follow!\\u003C/p\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"tweeting\\\"\\u003E\\u000a    \\u003Cp\\u003E\\u000a      You can tell the world \\u003Cstrong\\u003Ewhat's happening\\u003C/strong\\u003E in the box above.\\u000a    \\u003C/p\\u003E\\u000a    \\u003Cp class=\\\"protection\\\"\\u003E\\u000a      {{#protected_account}}\\u000a        \\u003Cspan\\u003EYour Tweets are protected and only available to your followers.\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EYou can make your Tweets public on your  \\u003Ca href=\\\"{{settings_path}}\\\"\\u003Eaccount page\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a      {{/protected_account}}\\u000a      {{^protected_account}}\\u000a        \\u003Cspan\\u003ENote that your Tweets will be available publicly.\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EYou can make your Tweets private on your \\u003Ca href=\\\"{{settings_path}}\\\"\\u003Eaccount page\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a      {{/protected_account}}\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u000a\",\n            empty_timeline_message: \"{{^abtest_timeline_copy_317_any_bucket}}\\u000a  Your timeline is currently empty. Follow people and topics you find interesting to see their Tweets in your timeline.\\u000a{{/abtest_timeline_copy_317_any_bucket}}\\u000a{{#abtest_timeline_copy_317_stream}}\\u000a  Your stream is currently empty. Follow people and topics you find interesting to see their Tweets in your stream.\\u000a{{/abtest_timeline_copy_317_stream}}\\u000a\",\n            empty_timeline_recommendations_module_followers: \"\\u003Cul class=\\\"clearfix js-recommended-followers\\\"\\u003E\\u000a  {{#recommendations}}\\u000a    {{\\u003Ebig_avatar_list_item}}\\u000a  {{/recommendations}}\\u000a\\u003C/ul\\u003E\",\n            empty_timeline_recommendations_module_short: \"\\u003Cdiv class=\\\"module big-avatar-list empty-timeline js-empty-timeline\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"empty-timeline-header\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-done disabled\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    \\u003Ch2\\u003E{{\\u003Eempty_timeline_title}}\\u003C/h2\\u003E\\u000a    \\u003Csmall\\u003E\\u003Ca href=\\\"#\\\" class=\\\"js-refresh-suggestions\\\"\\u003ERefresh\\u003C/a\\u003E \\u00b7 \\u003Ca href=\\\"{{who_to_follow_suggestions_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv data-section-id=\\\"wtf\\\" class=\\\"empty-timeline-footer\\\"\\u003E\\u000a    {{\\u003Eempty_timeline_recommendations_module_followers}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            empty_timeline_subtitle: \"{{#following}}\\u000a  \\u000a  {{#follow_event}}\\u000a    {{#one}}Follow more people to make Twitter even better.{{/one}}\\u000a    {{#two}}You\\u2019re on your way to a great home timeline.{{/two}}\\u000a    {{#several}}See what\\u2019s happening in the world, as it happens.{{/several}}\\u000a    {{#almost}}Watch life unfold in real time.{{/almost}}\\u000a    {{#done}}Keep following people everywhere on Twitter.{{/done}}\\u000a  {{/follow_event}}\\u000a{{/following}}\\u000a{{^following}}\\u000a  {{^abtest_timeline_copy_317_any_bucket}}\\u000a    Your timeline is currently empty. Follow people and topics you find interesting to see their Tweets in your timeline.\\u000a  {{/abtest_timeline_copy_317_any_bucket}}\\u000a  {{#abtest_timeline_copy_317_stream}}\\u000a    Your stream is currently empty. Follow people and topics you find interesting to see their Tweets in your stream.\\u000a  {{/abtest_timeline_copy_317_stream}}\\u000a{{/following}}\",\n            empty_timeline_title: \"{{#following}}\\u000a  \\u000a  {{^follow_event}}Follow more people to make Twitter even better.{{/follow_event}}\\u000a  \\u000a  {{#follow_event}}\\u000a    {{#one}}Victory! That\\u2019s 1.{{/one}}\\u000a    {{#two}}Congratulations! That\\u2019s 2.{{/two}}\\u000a    {{#several}}Excellent! You\\u2019re making progress.{{/several}}\\u000a    {{#almost}}Good work! You\\u2019ve almost reached {{goal}}.{{/almost}}\\u000a    {{#done}}Yee-haw! That\\u2019s {{count}} follows. Now you\\u2019re on a roll.{{/done}}\\u000a  {{/follow_event}}\\u000a{{/following}}\\u000a{{^following}}\\u000a  Here are some people you might enjoy following.\\u000a{{/following}}\\u000a\",\n            hashtag: \"{{\\u003Eevents/hashtag_header}}\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#logged_in}}\\u000a    {{^new_user}}\\u000a      {{\\u003Eevents/hashtag_tweetbox}}\\u000a    {{/new_user}}\\u000a    {{#new_user}}\\u000a      {{\\u003Eevents/hashtag_new_user}}\\u000a    {{/new_user}}\\u000a  {{/logged_in}}\\u000a  {{\\u003Eevents/top_people}}\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-main\\\" id=\\\"timeline\\\" data-pixel-tracking-id=\\\"{{pixel_tracking_id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      {{#autoplay_timeline}}\\u000a        \\u003Cdiv class=\\\"autoplay-control\\\"\\u003E\\u000a          \\u003Ci class=\\\"play-pause autoplay-play js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Stream Tweets as they arrive\\\"\\u003E\\u003C/i\\u003E\\u000a          \\u003Ci class=\\\"play-pause autoplay-pause js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Pause streaming of Tweets\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/autoplay_timeline}}\\u000a      \\u003Csmall class=\\\"view-original-search\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{view_search_url}}\\\"\\u003EView all Tweets\\u003C/a\\u003E\\u000a      \\u003C/small\\u003E\\u000a      \\u003Ch2 class=\\\"js-timeline-title\\\"\\u003ETweets\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Etimeline}}\\u000a\\u003C/div\\u003E\",\n            hashtag_header: \"{{#user_view}}\\u000a\\u003Cdiv\\u003E\\u000a  \\u003Cdiv class=\\\"module header-module hashtag-landing-header minified\\\" data-component-term=\\\"search_header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"flex-module-inner\\\"\\u003E\\u000a        \\u003Ch1 class=\\\"hashtag-landing-title\\\"\\u003E{{name}}\\u003C/h1\\u003E\\u000a        \\u003Cp class=\\\"hashtag-landing-subline\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a        {{^logged_in}}\\u000a          \\u003Ca href=\\\"/signup?event={{key}}\\\" class=\\\"btn signup-btn\\\"\\u003ESign up to get closer to {{name}}\\u003C/a\\u003E\\u000a        {{/logged_in}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#url}}\\u000a    \\u003Cimg class=\\\"hero-graphic secondary\\\" src=\\\"{{url}}\\\" alt=\\\"\\\"\\u003E\\u000a    {{/url}}\\u000a\\u000a    \\u003Cimg class=\\\"hero-graphic\\\" src=\\\"{{#user_view}}{{raw_profile_image_url}}{{/user_view}}\\\" alt=\\\"\\\"\\u003E\\u000a\\u000a    {{#photo_strip}}\\u000a      {{\\u003Emedia/events_media_thumbnails}}\\u000a    {{/photo_strip}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/user_view}}\",\n            hashtag_new_user: \"\\u003Cdiv class=\\\"module component promptbird finish-signup-prompt\\\" data-component-term=\\\"find_people\\\"\\u003E\\u000a  \\u003Ch2\\u003EGet started on Twitter\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003EFind people to follow to keep up to date with the things you care about.\\u003C/p\\u003E\\u000a  \\u003Ca href=\\\"{{welcome_path}}\\\" class=\\\"btn primary-btn\\\"\\u003EFind people to follow\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            hashtag_tweetbox: \"{{#user_view}}\\u000a\\u003Cdiv class=\\\"module component\\\" data-component-term=\\\"profile_tweetbox\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"profile-tweet-box flex-module\\\" data-hashtag=\\\"{{name}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      \\u003Ch2\\u003ETweet about {{name}}\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Eswift_tweet_box}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/user_view}}\",\n            top_people: \"\\u003Cdiv class=\\\"module component\\\" id=\\\"top-people\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ETop people\\u003C/h3\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-inner\\\"\\u003E\\u000a\\u000a      {{#top_three_people}}\\u000a        {{\\u003Eevents/top_people_item}}\\u000a      {{/top_three_people}}\\u000a\\u000a      \\u003Cul class=\\\"avatar-cluster\\\"\\u003E\\u000a        {{#top_people}}\\u000a          \\u003Cli\\u003E\\u000a            \\u003Ca href=\\\"/#!/{{screen_name}}\\\" title=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\" class=\\\"js-user-tipsy show-popup-with-id\\\"\\u003E\\u000a              \\u003Cimg class=\\\"avatar size48 js-tooltip\\\" src=\\\"{{profile_image_url_https}}\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/top_people}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            top_people_item: \"\\u003Cdiv class=\\\"js-account-summary account-summary js-actionable-user\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-recommend-link js-user-profile-link user-thumb\\\" href=\\\"/{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u000a      \\u003Cimg class=\\\"avatar js-action-profile-avatar\\\" src=\\\"{{profile_image_url_https}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a      \\u003Cspan class=\\\"account-group-inner js-action-profile-name\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a        \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a        \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cspan class=\\\"js-username\\\"\\u003E{{screen_name}}\\u003C/span\\u003E\\u003C/span\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Csmall class=\\\"metadata social-context\\\"\\u003E{{description}}\\u003C/small\\u003E\\u000a    {{\\u003Euser_item_action}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            geo_with_map: \"{{#show_map}}\\u000a  \\u003Cdiv class=\\\"geo-embedded-map\\\"\\u003E\\u000a    {{#js_map}}\\u000a      \\u003Cdiv style=\\\"width:{{map_width}}px; height:{{map_height}}px;\\\" data-map=\\\"{{js_map_data}}\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/js_map}}\\u000a    {{^js_map}}\\u000a      \\u003Ca href=\\\"{{{full_page_map_url}}}\\\" target=\\\"_blank\\\"\\u003E\\u000a        \\u003Cimg width=\\\"{{map_width}}\\\" height=\\\"{{map_height}}\\\" src=\\\"{{{static_map_url}}}\\\"\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/js_map}}\\u000a  \\u003C/div\\u003E\\u000a  {{#has_place}}\\u000a    \\u003Cdiv class=\\\"geo-place-name\\\"\\u003E\\u000a      {{\\u003Eexpanded/link_to_map}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{street_address}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{container}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{phone}}\\u003C/div\\u003E\\u000a  {{/has_place}}\\u000a  {{^has_place}}\\u000a    {{\\u003Eexpanded/link_to_map}}\\u000a  {{/has_place}}\\u000a{{/show_map}}\\u000a{{^show_map}}\\u000a  {{\\u003Eexpanded/link_to_map}}\\u000a{{/show_map}}\\u000a\",\n            link_to_map: \"{{#has_place}}\\u000a  {{#full_page_map_url}}\\u003Ca href=\\\"{{{full_page_map_url}}}\\\" target=\\\"_blank\\\"\\u003E{{/full_page_map_url}}\\u000a     from {{name}}\\u000a  {{#full_page_map_url}}\\u003C/a\\u003E{{/full_page_map_url}}\\u000a{{/has_place}}\\u000a{{^has_place}}\\u000a  {{#full_page_map_url}}\\u000a    \\u003Ca href=\\\"{{{full_page_map_url}}}\\\" target=\\\"_blank\\\"\\u003E\\u000a      View larger map  &rarr;\\u000a    \\u003C/a\\u003E\\u000a  {{/full_page_map_url}}\\u000a{{/has_place}}\\u000a\",\n            face_pile: \"{{#users}}\\u000a  {{\\u003Euser_avatar_link_24}}\\u000a{{/users}}\\u000a\",\n            facebook_token_iframe: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"{{twitter_locale}}\\\" xmlns=\\\"http://www.w3.org/1999/html\\\"\\u003E\\u000a  \\u003Chead\\u003E\\u000a    \\u003Cmeta http-equiv=\\\"X-UA-Compatible\\\" content=\\\"IE=edge\\\" /\\u003E\\u000a    \\u003Cmeta charset=\\\"utf-8\\\"\\u003E\\u000a    \\u003Cscript src=\\\"//ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js\\\"\\u003E\\u003C/script\\u003E\\u000a    \\u003Cscript\\u003E\\u000a      window.facebookFrameConfig = {{{config}}};\\u000a      $.ajaxSetup(facebookFrameConfig.ajaxSetup);\\u000a    \\u003C/script\\u003E\\u000a    \\u000a    \\u003Cscript src=\\\"//connect.facebook.net/{{language_tag}}/all.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003C/head\\u003E\\u000a  \\u003Cbody\\u003E\\u000a    \\u000a    \\u003Cdiv id=\\\"fb-root\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u000a    \\u003Cscript\\u003E{{{facebook_token_js}}}\\u003C/script\\u003E\\u000a  \\u003C/body\\u003E\\u000a\\u003C/html\\u003E\",\n            facet_media: \"\\u003Cli class=\\\"list-link js-facets\\\"\\u003E\\u000a  \\u003Ca href=\\\"{{view_all_href}}\\\" class=\\\"list-action js-view-all\\\"\\u003E\\u000a    {{title}} {{#count}}\\u003Cspan class=\\\"count\\\"\\u003E{{count}}\\u003C/span\\u003E{{/count}} \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cdiv class=\\\"media-row media-videos js-media-images\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            facets_media_not_displayed: \"\\u003Cli class=\\\"facets-media-not-displayed list-link\\\"\\u003E\\u000a \\u003Cdiv\\u003E\\u000a   \\u003Ca class=\\\"header\\\"\\u003EPopular images &amp; videos\\u003C/a\\u003E\\u000a   \\u003Cp class=\\\"not-displayed-text metadata\\\"\\u003EThese results include media shared by people you don&#8217;t follow.\\u003C/p\\u003E\\u000a   \\u003Ca class=\\\"btn small display-this-media\\\"\\u003E\\u000a     Display media\\u000a   \\u003C/a\\u003E\\u000a   {{#logged_in}}\\u000a     &middot;\\u000a     \\u003Ca href=\\\"#\\\" class=\\\"always-display-media\\\"\\u003EAlways display media like this\\u003C/a\\u003E\\u000a   {{/logged_in}}\\u000a \\u003C/div\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            firefox_download: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a\\u003Cdiv class=\\\"firefox-header clearfix\\\"\\u003E\\u000a\\u000a  {{#firefox_download}}\\u000a    \\u003Cdiv class=\\\"firefox-intro\\\"\\u003E\\u000a      \\u003Ch1\\u003E\\u003Cstrong\\u003EFirefox\\u003C/strong\\u003E with Twitter\\u003C/h1\\u003E\\u000a      \\u003Ch2\\u003EMozilla Firefox with Twitter instantly connects you to what\\u2019s happening in the world. Search people and topics on Twitter using \\u003Cspan\\u003E@\\u003C/span\\u003E and \\u003Cspan\\u003E#\\u003C/span\\u003E from the address bar.\\u003C/h2\\u003E\\u000a      \\u003Cdiv class=\\\"firefox-download\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn signup-btn large\\\" href=\\\"{{{download_url}}}\\\" target=\\\"_blank\\\"\\u003E{{#product_addon}}Get Twitter Address Bar Search{{/product_addon}}{{#product_bundle}}Get Firefox with Twitter{{/product_bundle}}\\u003C/a\\u003E\\u000a        \\u003Cdiv class=\\\"firefox-actions\\\"\\u003E\\u000a          \\u003Ca href=\\\"{{tweet_button_url}}\\\" class=\\\"firefox-tweet-button\\\" \\u003E\\u003C/a\\u003E\\u000a          \\u003Ca href=\\\"{{twirefox_support_path}}\\\" target=\\\"_blank\\\"\\u003ELearn more &raquo;\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"firefox-brand\\\"\\u003E\\u003C/div\\u003E\\u000a  {{/firefox_download}}\\u000a\\u000a  {{#firefox_welcome}}\\u000a    \\u003Cdiv class=\\\"firefox-intro firefox-installed\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"firefox-brand\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Ch1\\u003ESearch Twitter with Firefox. Stay connected.\\u003C/h1\\u003E\\u000a      \\u003Ch2\\u003ESearch people and topics on Twitter using \\u003Cspan\\u003E@\\u003C/span\\u003E and \\u003Cspan\\u003E#\\u003C/span\\u003E from the address bar.\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/firefox_welcome}}\\u000a\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Ctable class=\\\"mobile-footer firefox-footer\\\" cellpadding=\\\"0\\\" cellspacing=\\\"0\\\"\\u003E\\u000a  \\u003Ctbody\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd\\u003E\\u000a        \\u003Cdiv class=\\\"screenshot\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"screenshot-a\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Ch4\\u003EInstantly connect\\u003C/h4\\u003E\\u000a          \\u003Cp\\u003ESearch people and topics on Twitter using @ and # from the address bar.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/td\\u003E\\u000a      \\u003Ctd\\u003E\\u000a        \\u003Cdiv class=\\\"screenshot\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"screenshot-b\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Ch4\\u003EStay informed and updated\\u003C/h4\\u003E\\u000a          \\u003Cp\\u003EThe pinned Twitter app tab lights up when new Tweets arrive.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/td\\u003E\\u000a      \\u003Ctd class=\\\"last\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"screenshot\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"screenshot-c\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Ch4\\u003ESearch Twitter\\u003C/h4\\u003E\\u000a          \\u003Cp\\u003ESwitch to Twitter Search by clicking the drop down arrow in the search box.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003Ctbody\\u003E\\u000a\\u003C/table\\u003E\\u000a\\u000a{{#firefox_welcome}}\\u000a  \\u003Cdiv class=\\\"firefox-footer\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"firefox-actions\\\"\\u003E\\u000a      \\u003Ca href=\\\"{{tweet_button_url}}\\\" class=\\\"firefox-tweet-button\\\"\\u003E\\u003C/a\\u003E\\u000a      \\u003Ca href=\\\"{{twirefox_support_path}}\\\" target=\\\"_blank\\\"\\u003ENeed help?\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/firefox_welcome}}\\u000a\\u000a\\u003C/div\\u003E\",\n            first_time_turkey: \"\\u003Cdiv {{#container_id}}id=\\\"{{container_id}}\\\" {{/container_id}}class=\\\"twttr-dialog-container\\\" style=\\\"visibility: hidden;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"twttr-dialog-content twttr-dialog-first-turkey\\\"\\u003E\\u000a          \\u003Cdiv\\u003E\\u000a            \\u003Ch2 class=\\\"first-time\\\"\\u003EShare an image on Twitter\\u003C/h2\\u003E\\u000a            \\u003Cp class=\\\"first-time-text\\\"\\u003E\\u000a              Now you can upload and share images, right from Twitter! Just click the camera icon to add an image to your Tweet.\\u000a            \\u003C/p\\u003E\\u000a            \\u003Cdiv class=\\\"turkey-container first-time\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"callout1\\\"\\u003E1. Click the camera icon to add\\u003C/div\\u003E\\u000a              \\u003Cdiv class=\\\"callout2\\\"\\u003E2. Preview before sharing\\u003C/div\\u003E\\u000a              \\u003Cdiv class=\\\"turkey\\\"\\u003E\\u003Cimg src=\\\"/phoenix/img/first_photo_promo.png\\\"/\\u003E\\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a            \\u003Cdiv class=\\\"first-turkey-actions\\\"\\u003E\\u000a              \\u003Cspan class=\\\"button ok-thanks\\\"\\u003E\\u003Cstrong\\u003EOK, thanks!\\u003C/strong\\u003E\\u003C/span\\u003E\\u000a              \\u003Ca class=\\\"learn-more\\\" target=\\\"_blank\\\" href=\\\"{{turkey_support_path}}\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            flex_module: \"\\u003Cdiv class=\\\"module {{class_name}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module js-items-container\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            flex_module_link: \"\\u003Ca href=\\\"{{route}}\\\"\\u003E{{title}}\\u003C/a\\u003E\",\n            flex_module_more_links: \"\\u003Cp class=\\\"more-links js-more-links\\\"\\u003E\\u000a  {{#links}}\\u000a    {{\\u003Eflex_module_link}} {{^is_last}} &middot; {{/is_last}}\\u000a  {{/links}}\\u000a\\u003C/p\\u003E\",\n            flex_module_title: \"\\u003Ch4 class=\\\"flex-module-title\\\"\\u003E{{title}} {{#view_all_route}}\\u003Csmall\\u003E&middot; \\u003Ca href=\\\"{{view_all_route}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E{{/view_all_route}}\\u003C/h4\\u003E\",\n            follow_link: \"\\u003Ca href=\\\"#\\\" class=\\\"user-follow-link js-action-follow js-link follow-action\\\" data-user-id=\\\"{{id}}\\\" {{#protected}}title=\\\"Send follow request\\\"{{/protected}}\\u003EFollow\\u003C/a\\u003E\",\n            follow_list: \"\\u003Ch3\\u003E{{header}}\\u003C/h3\\u003E\\u000a{{#follow_list}}\\u000a  {{{follow_list}}}\\u000a{{/follow_list}}\",\n            follow_request_sent_button: \"\\u003Cdiv class=\\\"pending-request js-action-unfollow js-button\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cspan\\u003Epending\\u003C/span\\u003E\\u000a  \\u003Ca class='follow-request-cancel-button' href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E(cancel)\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            follow_request_sent_link: \"\\u003Ca href='#' class=\\\"cancel-request-link js-action-unfollow js-link\\\" data-user-id=\\\"{{id}}\\\" title=\\\"Cancel follow request\\\"\\u003ECancel\\u003C/a\\u003E\",\n            followers_list_small: \"{{%TRANSLATION-HINT mode=user_stats}}\\u000a\\u000a\\u003Cdiv class=\\\"your-activity new-followers-activity\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Ca href=\\\"{{user_followers_path}}\\\" class=\\\"title-link\\\"\\u003E\\u003Cspan class='dashboard-component-title'\\u003EFollowers\\u003C/span\\u003E \\u003Cspan class='user-stat-link'\\u003E{{followers_count_commaized}}\\u003C/span\\u003E\\u003C/a\\u003E\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            followers_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#profile_user}}\\u000a    \\u003Cdiv class=\\\"profile-subpage-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"upper-nav\\\" \\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\"\\u003E&larr; @{{screen_name}}&rsquo;s profile\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"profile-subpage-title\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"profile-subpage-title-copy\\\"\\u003E\\u000a            \\u003Ch1\\u003E{{{followers_header_string}}}\\u003C/h1\\u003E\\u000a            \\u003Ch2\\u003EHere&rsquo;s more about them.\\u003C/h2\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-followers active\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_followers_path}}\\\"\\u003EPeople\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a   \\u003C/div\\u003E\\u000a\\u000a    {{/profile_user}}\\u000a    {{\\u003Estream_manager}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a{{\\u003Eprofile_subpage_dashboard}}\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            followers_stream_view_toggler: \"{{\\u003Estream_view_toggler}}\",\n            followers_subtabs: \"\\u003Cspan class=\\\"subtabs\\\"\\u003E\\u000a  \\u003Ca {{#active_subtab_all}} class='active'{{/active_subtab_all}} href='{{user_followers_path}}'\\u003EAll\\u003C/a\\u003E\\u000a    &middot;\\u000a  \\u003Ca {{#active_subtab_followers_you_follow}} class='active'{{/active_subtab_followers_you_follow}} href='{{followers_you_follow_path}}'\\u003EFollowers you follow\\u003C/a\\u003E\\u000a\\u003C/span\\u003E\\u000a\",\n            following_limit_reached_error_message: \"It looks like you've hit a following limit.\\u000a\\u003Ca href=\\\"{{follow_limit_reached_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            following_list_full: \"{{%TRANSLATION-HINT mode=user_stats}}\\u000a\\u000a\\u003Cdiv class=\\\"your-activity following-activity-full\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Cspan class='dashboard-component-title'\\u003EFollowing\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a    \\u003Ca href=\\\"{{user_following_path}}\\\" class=\\\"view-all\\\"\\u003Eview all\\u003C/a\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  {{#show_wtf_links}}\\u000a    {{#following_nobody}}\\u000a      {{\\u003Ewho_to_follow_links}}\\u000a    {{/following_nobody}}\\u000a  {{/show_wtf_links}}\\u000a\\u003C/div\\u003E\\u000a\",\n            following_list_small: \"{{%TRANSLATION-HINT mode=user_stats}}\\u000a\\u000a\\u003Cdiv class=\\\"your-activity following-activity\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Ca href=\\\"{{user_following_path}}\\\" class=\\\"title-link\\\"\\u003E\\u003Cspan class='dashboard-component-title'\\u003E\\u000a      Following\\u003C/span\\u003E \\u003Cspan class='user-stat-link'\\u003E{{friends_count_commaized}}\\u003C/span\\u003E\\u003C/a\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  {{#show_wtf_links}}\\u000a    {{#following_nobody}}\\u000a      {{\\u003Ewho_to_follow_links}}\\u000a    {{/following_nobody}}\\u000a  {{/show_wtf_links}}\\u000a\\u003C/div\\u003E\\u000a\",\n            following_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#profile_user}}\\u000a    \\u003Cdiv class=\\\"profile-subpage-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"upper-nav\\\" \\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\"\\u003E&larr; @{{screen_name}}&rsquo;s profile\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"profile-subpage-title\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"profile-subpage-title-copy\\\"\\u003E\\u000a            \\u003Ch1\\u003E{{{following_header_string}}}\\u003C/h1\\u003E\\u000a            \\u003Ch2 id=\\\"following-page-context\\\"\\u003E\\u003C/h2\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-users{{#active_tab_users}} active{{/active_tab_users}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_following_path}}\\\"\\u003EPeople: {{following_count_commaized}}\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-tweets{{#active_tab_tweets}} active{{/active_tab_tweets}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_following_tweets_path}}\\\"\\u003ETweets\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a   \\u003C/div\\u003E\\u000a\\u000a    {{/profile_user}}\\u000a    {{\\u003Estream_manager}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a{{\\u003Eprofile_subpage_dashboard}}\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            following_page_signup_call_out: \"\\u003Cdiv class=\\\"signup-call-out\\\"\\u003E\\u000a  \\u003Ch1\\u003E\\u000a    Ready to make Twitter your own?\\u000a  \\u003C/h1\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    Follow your interests to instantly connect to what&rsquo;s most meaningful to you.\\u000a  \\u003C/h2\\u003E\\u000a  {{\\u003Esignup_button}}\\u000a\\u003C/div\\u003E\\u000a\",\n            following_subtabs: \"\\u003Cspan class=\\\"subtabs\\\"\\u003E\\u000a  \\u003Ca {{#active_subtab_all}} class='active'{{/active_subtab_all}} href='{{user_following_path}}'\\u003EAll\\u003C/a\\u003E\\u000a    &middot;\\u000a  \\u003Ca {{#active_subtab_you_both_follow}} class='active'{{/active_subtab_you_both_follow}} href='{{you_both_follow_path}}'\\u003EYou both follow\\u003C/a\\u003E\\u000a\\u003C/span\\u003E\\u000a\",\n            following_tweet: \"{{\\u003Estream_tweet}}\",\n            footer: \"\\u003Cdiv class=\\\"module site-footer {{#is_slim}}slim-site-footer{{/is_slim}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-inner js-items-container\\\"\\u003E\\u000a      \\u003Cul class=\\\"clearfix\\\"\\u003E\\u000a        \\u003Cli class=\\\"copyright\\\"\\u003E&copy; {{year}} Twitter\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{about_path}}\\\"\\u003EAbout\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{support_path}}\\\"\\u003EHelp\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        {{^is_slim}}\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{tos_path}}\\\"\\u003ETerms\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{privacy_path}}\\\"\\u003EPrivacy\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{blog_path}}\\\"\\u003EBlog\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{status_path}}\\\"\\u003EStatus\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}\\\"\\u003EApps\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{resources_path}}\\\"\\u003EResources\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{jobs_path}}\\\"\\u003EJobs\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{advertisers_path}}\\\"\\u003EAdvertisers\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{businesses_path}}\\\"\\u003EBusinesses\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{partnerships_path}}\\\"\\u003EMedia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"{{developers_path}}\\\"\\u003EDevelopers\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        {{/is_slim}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            frame_busting: \"\\u003Cscript\\u003E\\u000afunction bust () {\\u000a  document.write = \\\"\\\";\\u000a  window.JSBNG__top.location = window.JSBNG__self.location;\\u000a  setTimeout(function() {\\u000a    document.body.innerHTML = '';\\u000a    }, 0);\\u000a  window.JSBNG__self.JSBNG__onload = function(evt) {\\u000a    document.body.innerHTML = '';\\u000a  };\\u000a}\\u000aif (window.top !== window.self) { // are you trying to put self in an iframe?\\u000a  try {\\u000a    if (window.JSBNG__top.JSBNG__location.host) { // this is illegal to access unless you share a non-spoofable document domain\\u000a      // fun times\\u000a    } else {\\u000a      bust(); // chrome executes this\\u000a    }\\u000a  } catch (ex) {\\u000a    bust(); // everyone executes this\\u000a  }\\u000a}\\u000a\\u003C/script\\u003E\\u000a\",\n            front_page: \"\\u003Cdiv class=\\\"leftside\\\"\\u003E\\u000a  \\u003Ch1\\u003ETwitter\\u003C/h1\\u003E\\u000a  \\u003Ch2\\u003EFollow your interests\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003EInstant updates from your friends, industry experts, favorite celebrities, and what&#8217;s happening around the world.\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{#render_page_content}}\\u000a  \\u003Cnoscript\\u003E\\u000a    \\u003Cdiv class=\\\"warning\\\"\\u003E\\u000a      \\u003Cstrong\\u003ETwitter.com makes heavy use of JavaScript.\\u003C/strong\\u003E\\u000a      \\u003Cem\\u003EIf you cannot enable it in your browser's preferences, you may have a better experience on our \\u003Ca href=\\\"http://m.twitter.com\\\"\\u003Emobile site\\u003C/a\\u003E.\\u003C/em\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/noscript\\u003E\\u000a{{/render_page_content}}\\u000a\\u000a\\u003Cdiv class=\\\"rightside\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"front-signin js-front-signin\\\"\\u003E\\u000a    \\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"signin\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"textbox\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"holding username\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"session[username_or_email]\\\" title=\\\"Username or email\\\" autocomplete=\\\"on\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"holder\\\"\\u003EUsername\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"holding password\\\"\\u003E\\u000a          \\u003Cinput type=\\\"password\\\" name=\\\"session[password]\\\" title=\\\"Password\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"holder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      {{\\u003Esignin_form_subchck}}\\u000a      \\u003Cp\\u003E\\u000a        \\u003Ca class=\\\"forgot\\\" href=\\\"{{resend_password_path}}\\\"\\u003EForgot it?\\u003C/a\\u003E\\u000a      \\u003C/p\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u000a  \\u003Cdiv class=\\\"front-signup js-front-signup\\\"\\u003E\\u000a    \\u003Ch3\\u003ENew to Twitter? \\u003Cem\\u003EJoin today!\\u003C/em\\u003E\\u003C/h3\\u003E\\u000a    {{\\u003Epartial_signup_form}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"bottompart\\\"\\u003E\\u000a  {{\\u003Egeneric_footer}}\\u000a\\u003C/div\\u003E\\u000a\",\n            full_name: \"\\u003Cdiv class=\\\"full-name\\\"\\u003E\\u000a  \\u003Ch1\\u003E{{name}}\\u003C/h1\\u003E\\u000a  {{#verified}}\\u000a    \\u003Cspan class=\\\"verified-icon\\\" title=\\\"Verified Account\\\"\\u003E\\u003C/span\\u003E\\u000a  {{/verified}}\\u000a  {{#protected}}\\u000a    \\u003Cspan class=\\\"protected-icon\\\"\\u003E\\u003C/span\\u003E\\u000a  {{/protected}}\\u000a\\u003C/div\\u003E\",\n            full_page_trends: \"\\u003Cdiv class=\\\"full-page-trends\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"trends-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"trends-header-gradient\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"trends-header-map\\\"\\u003E\\u000a        \\u003Ch2 class=\\\"trends-header-label\\\"\\u003E\\u000a          Trends:\\u000a          \\u003Cspan class=\\\"trends-inline-controls\\\"\\u003E\\u000a            \\u003Cspan class=\\\"trend-location js-trend-location\\\"\\u003E\\u000a              Worldwide\\u000a              \\u003C/span\\u003E\\u000a            \\u003Cspan class='trend-toggle js-trend-toggle'\\u003E\\u000a              \\u003Ca href='#' class=\\\"trend-toggle-link\\\"\\u003E\\u000a              Change location\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/span\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/h2\\u003E\\u000a        \\u003Cform action=\\\"{{signup_path}}\\\" class=\\\"signup signup-btn trends-description-container\\\" method=\\\"get\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"trends-description\\\"\\u003E\\u000a            Topics and #hashtags people are talking about now.\\u000a          \\u003C/div\\u003E\\u000a          {{^logged_in}}\\u000a            \\u003Cinput class=\\\"promotional\\\" type=\\\"submit\\\" value=\\\"Sign up &raquo;\\\" /\\u003E\\u000a          {{/logged_in}}\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cul class='trends js-trends'\\u003E\\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            card_image_onebox: \"\\u000a\\u000a\\u003Cdiv class=\\\"{{type}} card\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"card-body\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"onebox-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ETop images\\u003C/h3\\u003E\\u000a      \\u003Csmall class=\\\"view-all\\\"\\u003E &middot; \\u003Ca href=\\\"#\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Ca href=\\\"#\\\"\\u003E\\u003Cimg src=\\\"http://www.placehold.it/154x154\\\" alt=\\\"\\\"\\u003E\\u003C/a\\u003E\\u000a    \\u003Ca href=\\\"#\\\"\\u003E\\u003Cimg src=\\\"http://www.placehold.it/154x154\\\" alt=\\\"\\\"\\u003E\\u003C/a\\u003E\\u000a    \\u003Ca href=\\\"#\\\"\\u003E\\u003Cimg src=\\\"http://www.placehold.it/154x154\\\" alt=\\\"\\\"\\u003E\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            card_video_onebox: \"\\u000a\\u000a\\u003Cdiv class=\\\"{{type}} card\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"card-body\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"onebox-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ETop videos\\u003C/h3\\u003E\\u000a      \\u003Csmall class=\\\"view-all\\\"\\u003E &middot; \\u003Ca href=\\\"#\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Ca class=\\\"onebox-video\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Cimg src=\\\"http://www.placehold.it/154x115\\\" alt=\\\"\\\"\\u003E\\u000a        \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"onebox-video\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Cimg src=\\\"http://www.placehold.it/154x115\\\" alt=\\\"\\\"\\u003E\\u000a        \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"onebox-video\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Cimg src=\\\"http://www.placehold.it/154x115\\\" alt=\\\"\\\"\\u003E\\u000a        \\u003Ci class=\\\"play-large\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            follow_profile_card_large: \"\\u000a\\u000a \\u003Cdiv class=\\\"module follow-card\\\"\\u003E\\u000a  \\u003Cimg src=\\\"http://placehold.it/300x300\\\" class=\\\"size300\\\" /\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a   \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch1\\u003EFull Name\\u003C/h1\\u003E\\u000a      \\u003Ch2\\u003E@username\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"location\\\"\\u003ESan Francisco, CA\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"full-bio\\\"\\u003E\\u000a      \\u003Cp class=\\\"bio\\\"\\u003ENulla vitae elit libero, a pharetra augue. Maecenas faucibus mollis interdum. Cras justo odio, dapibus ac facilisis in, egestas eget quame faucibus mollis int.\\u003C/p\\u003E\\u000a      \\u003Cp class=\\\"bio2\\\"\\u003EFusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justos.\\u003C/p\\u003E\\u000a      \\u003Cul class=\\\"elsewhere\\\"\\u003E\\u000a        \\u003Cli class=\\\"flickr\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EFlickr\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"facebook\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EFacebook\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"formspring\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EFormspring\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"yelp\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EYelp\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"youtube\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EYoutube\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"nikeplus\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003ENike+\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"ebay\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EeBay\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a      \\u003Cp class=\\\"url\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003Esomething.site.com\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-box\\\"\\u003E\\u000a    \\u003Cinput type=\\\"text\\\" placeholder=\\\"Tweet to @username\\\" /\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"follow-bar\\\"\\u003E\\u000a    {{\\u003Ecombo_follow_button}}\\u000a    \\u003Cspan class=\\\"user-toggles\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"toggle-retweets active\\\"\\u003E\\u003Ci class=\\\"toggle-retweets\\\"\\u003E\\u003C/i\\u003E Toggle Retweets\\u003C/a\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"toggle-sms\\\"\\u003E\\u003Ci class=\\\"toggle-sms\\\"\\u003E\\u003C/i\\u003E Toggle SMS\\u003C/a\\u003E\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            modal_account_changes: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay account-changes\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003ESave account settings\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cform clas=\\\"form-horizontal\\\"\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"password\\\"\\u003EPassword\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Cinput class=\\\"input-medium\\\" type=\\\"password\\\" name=\\\"password\\\"\\u003E\\u000a              \\u003Cp class=\\\"help-block\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EForgot your password?\\u003C/a\\u003E\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ESave changes\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003ECancel\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_contact_import: \"\",\n            modal_dms: \"\\u000a\\u003Cstyle type=\\\"text/css\\\"\\u003E\\u000a  .modal-overlay.dms .modal-header .btn {\\u000a    float: right;\\u000a    margin: -5px -5px 0 0;\\u000a    font-weight: normal;\\u000a  }\\u000a\\u000a  .dm-thread-list {\\u000a\\u000a  }\\u000a  .dm-thread a {\\u000a    display: block;\\u000a    padding: 12px;\\u000a    border-top: 1px solid #eee;\\u000a  }\\u000a  .dm-thread:first-child a {\\u000a    border-top: 0;\\u000a  }\\u000a  .dm-thread:last-child a {\\u000a    -webkit-border-radius: 0 0 6px 6px;\\u000a       -moz-border-radius: 0 0 6px 6px;\\u000a            border-radius: 0 0 6px 6px;\\u000a  }\\u000a  .dm-thread a:hover {\\u000a    text-decoration: none;\\u000a    background-color: #f5f5f5; /* Old browsers */\\u000a    background-repeat: repeat-x; /* Repeat the gradient */\\u000a    background-image: -moz-linear-gradient(top, #f9f9f9 0%, #f5f5f5 100%); /* FF3.6+ */\\u000a    background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f9f9f9), color-stop(100%,#f5f5f5)); /* Chrome,Safari4+ */\\u000a    background-image: -webkit-linear-gradient(top, #f9f9f9 0%,#f5f5f5 100%); /* Chrome 10+,Safari 5.1+ */\\u000a    background-image: -ms-linear-gradient(top, #f9f9f9 0%,#f5f5f5 100%); /* IE10+ */\\u000a    background-image: -o-linear-gradient(top, #f9f9f9 0%,#f5f5f5 100%); /* Opera 11.10+ */\\u000a    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f9f9f9', endColorstr='#f5f5f5',GradientType=0 ); /* IE6-9 */\\u000a    background-image: linear-gradient(top, #f9f9f9 0%,#f5f5f5 100%); /* W3C */\\u000a  }\\u000a  .dm-thread .chev-right {\\u000a    float: right;\\u000a    margin-top: 9px;\\u000a  }\\u000a  /* TODO: fix this in the modals css because we have .modal .account-summary elsewhere and that sucks */\\u000a  .modal .dm-thread .account-summary {\\u000a    margin: 0;\\u000a    min-height: 32px;\\u000a    margin-left: 18px;\\u000a  }\\u000a\\u000a  .dm-thread-status {\\u000a    float: left;\\u000a    width: 13px;\\u000a    height: 32px;\\u000a  }\\u000a  .dm-thread-status .unread {\\u000a    margin-top: 9px;\\u000a  }\\u000a  .dm-thread-status .replied {\\u000a    margin-top: 10px;\\u000a  }\\u000a\\u000a  /* DMs\\u000a  -------------------------------------------------- */\\u000a\\u000a  /* The list of threads */\\u000a  .dm-threads .list-link {\\u000a    padding: 12px;\\u000a  }\\u000a  .dm-threads .list-link .chev-right {\\u000a    position: absolute;\\u000a    top: 50%;\\u000a    right: 12px;\\u000a    margin-top: -6px;\\u000a  }\\u000a\\u000a  /* Le DMs */\\u000a  .dms {\\u000a    padding-bottom: 12px;\\u000a    border-bottom: 1px solid #eee;\\u000a  }\\u000a  .dm-item .avatar {\\u000a    position: absolute;\\u000a    top: 12px;\\u000a    left: 12px;\\u000a  }\\u000a  .dm-item .content {\\u000a    margin-left: 58px;\\u000a  }\\u000a  /* Base styles for stream-item types */\\u000a  .dm-item {\\u000a    position: relative;\\u000a    min-height: 48px; /* Never shorter than avatar + padding */\\u000a    padding: 12px;\\u000a  }\\u000a  .dm-item {\\u000a    line-height: 16px;\\u000a  }\\u000a  /* reposition content and avatar to allow for message thread status (unread/replied) */\\u000a  .dm-item .content {\\u000a    margin-left: 58px;\\u000a  }\\u000a  /* unread indicator */\\u000a  .dm-item .unread {\\u000a    float: left;\\u000a    margin: 18px 0 0 -3px;\\u000a  }\\u000a  .dm-item .status {\\u000a    display: none;\\u000a  }\\u000a  .dm-item.new-messages .status {\\u000a    display: block;\\u000a  }\\u000a\\u000a  /* replied-to indicator */\\u000a  .dm-item .status .sm-reply {\\u000a    position: absolute;\\u000a    top: 30px;\\u000a    left: 8px;\\u000a  }\\u000a  /* latest message snippet */\\u000a  .dm-item p {\\u000a    padding: 9px;\\u000a    margin-bottom: 5px;\\u000a    font-size: 12px;\\u000a    color: #999;\\u000a    background-color: #f5f5f5;\\u000a    border: 1px solid #eee;\\u000a    -webkit-border-radius: 4px;\\u000a       -moz-border-radius: 4px;\\u000a            border-radius: 4px;\\u000a  }\\u000a  /* sender gets flipped */\\u000a  .dm-item.sent .avatar {\\u000a    right: 12px;\\u000a    left: auto;\\u000a  }\\u000a  .dm-item.sent .content {\\u000a    margin-left: 0;\\u000a    margin-right: 58px;\\u000a  }\\u000a  /* time stamp */\\u000a  .dm-item time {\\u000a    display: block;\\u000a    text-align: center;\\u000a    font-size: 12px;\\u000a    color: #999;\\u000a  }\\u000a\\u000a\\u000a  .dms .modal-scroll {\\u000a    width: 360px;\\u000a    overflow-x: hidden;\\u000a  }\\u000a  .dm-modal-wrapper {\\u000a    clear: both;\\u000a    width: 720px;\\u000a  }\\u000a  .dm-threads {\\u000a    float: left;\\u000a    width: 345px;\\u000a  }\\u000a  .dm-convos {\\u000a    float: left;\\u000a    width: 345px;\\u000a    display: none;\\u000a  }\\u000a\\u003C/style\\u003E\\u000a\\u000a\\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a  $(document).ready(function() {\\u000a\\u000a    $('.dm-thread a').click(function(e) {\\u000a      e.preventDefault();\\u000a      $('.dm-threads').hide();\\u000a      $('.dm-convos').show();\\u000a    });\\u000a\\u000a  });\\u000a\\u003C/script\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay dms\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn js-dismiss\\\" href=\\\"#\\\"\\u003EDone\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EDirect messages\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body modal-scroll\\\"\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"dm-modal-wrapper\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dm-threads\\\"\\u003E\\u000a          \\u003Cul class=\\\"dm-thread-list\\\"\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"unread\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"unread\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"unread\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"replied\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"replied\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"replied\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"dm-thread-status\\\"\\u003E\\u000a                  \\u003Ci class=\\\"replied\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a            \\u003Cli class=\\\"dm-thread\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\"\\u003E\\u000a                \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"account-group\\\" href=\\\"#\\\"\\u003E\\u000a                      \\u003Cimg src=\\\"http://placehold.it/32x32\\\" class=\\\"avatar size32\\\"\\u003E\\u000a                      \\u003Cb class=\\\"fullname\\\"\\u003EFull Name\\u003C/b\\u003E\\u000a                    \\u003C/span\\u003E\\u000a                    \\u003Csmall class=\\\"metadata\\\"\\u003E@screen_name\\u003C/small\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a          \\u003C/ul\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a        \\u003Cdiv class=\\\"dms dm-convos\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item received\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item sent\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item received\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item sent\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item received\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"dm-item sent\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size48\\\" src=\\\"http://placehold.it/48x48\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a              \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a      \\u003C/div\\u003E\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_go_to_user: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay go-to-user\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal modal-small\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EGo to a person's profile\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cform action=\\\"\\\" class=\\\"\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" placeholder=\\\"Start typing a name to jump to a profile\\\"\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_list_add_to: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay list-add-to\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EAdd [Full Name] to your lists\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body modal-scroll\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"membership\\\"\\u003E\\u000a        \\u003Clabel class=\\\"item checked\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" checked /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003EList name\\u003C/strong\\u003E\\u000a            \\u003Csmall\\u003EFusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus.\\u003C/small\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel class=\\\"item\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003EAnother list name\\u003C/strong\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel class=\\\"item\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003ELook, a list!\\u003C/strong\\u003E\\u000a            \\u003Csmall\\u003EFusce dapibus, tellus ac cursus commodo, tortor mauris condimentum.\\u003C/small\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel class=\\\"item checked\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" checked /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003EList name\\u003C/strong\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel class=\\\"item\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003EAnother list name\\u003C/strong\\u003E\\u000a            \\u003Csmall\\u003EFusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus.\\u003C/small\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel class=\\\"item\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" /\\u003E\\u000a          \\u003Cspan class=\\\"inner\\\"\\u003E\\u000a            \\u003Cstrong\\u003ELook, a list!\\u003C/strong\\u003E\\u000a            \\u003Csmall\\u003EFusce dapibus, tellus ac cursus commodo, tortor mauris condimentum.\\u003C/small\\u003E\\u000a          \\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ESave changes\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003ECancel\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_list_edit: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay list-edit\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003E\\u000a        Edit list\\u000a        \\u003Csmall class=\\\"view-toggler\\\"\\u003E\\u003Ca class=\\\"active\\\" href=\\\"#\\\"\\u003EList details\\u003C/a\\u003E / \\u003Ca href=\\\"#\\\"\\u003EMembers\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      \\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cform class=\\\"form-horizontal edit-list\\\"\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listName\\\"\\u003EName\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Cinput class=\\\"input-large\\\" id=\\\"listName\\\" type=\\\"text\\\" value=\\\"SF Food Cards\\\"\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listDescription\\\"\\u003EDescription\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Ctextarea class=\\\"input-large\\\" id=\\\"listDescription\\\"\\u003ESan Francisco food carts I love.\\u003C/textarea\\u003E\\u000a              \\u003Cp class=\\\"help-text\\\"\\u003EOptional. Maximum 100 characters.\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listPrivacy\\\"\\u003EPrivacy\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"control-list\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput name=\\\"listPrivacy\\\" id=\\\"listPublic\\\" type=\\\"checkbox\\\" checked\\u003E\\u000a                  Public \\u003Csmall\\u003Eanyone can follow this list\\u003C/small\\u003E\\u000a                \\u003C/label\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput name=\\\"listPrivacy\\\" id=\\\"listPrivate\\\" type=\\\"checkbox\\\"\\u003E\\u000a                  Private \\u003Csmall\\u003EOnly you can access this list\\u003C/small\\u003E\\u000a                \\u003C/label\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a        \\u003C/form\\u003E\\u000a     \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ESave changes\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003ECancel\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_list_edit_members: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay list-edit-members\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003E\\u000a        Edit members\\u000a        \\u003Csmall class=\\\"view-toggler\\\"\\u003E\\u003Ca href=\\\"#\\\"\\u003EList details\\u003C/a\\u003E / \\u003Ca class=\\\"active\\\" href=\\\"#\\\"\\u003EMembers\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Cform class=\\\"modal-search\\\"\\u003E\\u000a        \\u003C!-- NOTE: fallback to jquery for placeholder? --\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" class=\\\"search\\\" id=\\\"\\\" placeholder=\\\"Search for people to add to this list\\\" /\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body modal-scroll\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a           {{\\u003Estream_user}}\\u000a           {{\\u003Estream_user}}\\u000a           {{\\u003Estream_user}}\\u000a           {{\\u003Estream_user}}\\u000a           {{\\u003Estream_user}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ESave changes\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003ECancel\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_list_new: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay list-new\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003ECreate list\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cform class=\\\"form-horizontal edit-list\\\"\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listName\\\"\\u003EName\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Cinput class=\\\"input-large\\\" id=\\\"listName\\\" type=\\\"text\\\"\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listDescription\\\"\\u003EDescription\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Ctextarea class=\\\"input-large\\\" id=\\\"listDescription\\\"\\u003E\\u003C/textarea\\u003E\\u000a              \\u003Cp class=\\\"help-text\\\"\\u003EOptional. Maximum 100 characters.\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a          \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a            \\u003Clabel class=\\\"control-label\\\" for=\\\"listPrivacy\\\"\\u003EPrivacy\\u003C/label\\u003E\\u000a            \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"control-list\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput name=\\\"listPrivacy\\\" id=\\\"listPublic\\\" type=\\\"checkbox\\\"\\u003E\\u000a                  Public \\u003Csmall\\u003Eanyone can follow this list\\u003C/small\\u003E\\u000a                \\u003C/label\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput name=\\\"listPrivacy\\\" id=\\\"listPrivate\\\" type=\\\"checkbox\\\"\\u003E\\u000a                  Private \\u003Csmall\\u003EOnly you can access this list\\u003C/small\\u003E\\u000a                \\u003C/label\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\" data-modal=\\\"list-new-add-members\\\"\\u003ENext\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_list_new_add_members: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay list-new-add-members\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EAdd members to list\\u003C/h2\\u003E\\u000a      \\u003Cform class=\\\"modal-search\\\"\\u003E\\u000a        \\u003C!-- NOTE: fallback to jquery for placeholder? --\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" class=\\\"search\\\" id=\\\"\\\" placeholder=\\\"Search for people to add to this list\\\" /\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body modal-scroll\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"placeholder\\\"\\u003E\\u000a        \\u003Cp\\u003E\\u000a          \\u003Cstrong\\u003EYou don't have members in your list yet!\\u003C/strong\\u003E\\u003Cbr /\\u003E\\u000a          Search for a username, first or last name, business, or brand to add as members of this list.\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn js-action-dismiss\\\" href=\\\"#\\\"\\u003ECreate list\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003EBack\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_message_new: \"\\u003Cdiv class=\\\"modal-overlay message-new\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003ENew message\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cform class=\\\"tweet-form\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"message-to\\\"\\u003E\\u000a        \\u003Cimg src=\\\"http://placehold.it/24x24\\\" alt=\\\"\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" placeholder=\\\"Message anyone who follows you\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Ctextarea class=\\\"tweetbox\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003Cbutton class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ESend\\u003C/button\\u003E\\u000a      \\u003Cspan class=\\\"tweet-count\\\"\\u003E140\\u003C/span\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_message_thread: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay message-thread\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EMessage Full name \\u003Csmall\\u003E@username\\u003C/small\\u003E\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body modal-scroll\\\"\\u003E\\u000a\\u000a     \\u000a      \\u003Cdiv class=\\\"messages\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"message-item received\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"message-item sent\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"message-item received\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"message-item sent\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"message-item received\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis. Etiam porta sem malesuada magna mollis euismod. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"message-item sent\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size48\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a            \\u003Cp\\u003ESed posuere consectetur est at lobortis.\\u003C/p\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E8/1/11 9:00am\\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Cform class=\\\"tweet-form\\\"\\u003E\\u000a        \\u003Ctextarea class=\\\"tweetbox\\\"\\u003E\\u003C/textarea\\u003E\\u000a        \\u003Cbutton class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ESend message\\u003C/button\\u003E\\u000a        \\u003Cspan class=\\\"tweet-count\\\"\\u003E140\\u003C/span\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_profile_card: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay profile-modal\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    {{\\u003Eprofile_pane}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_reply: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay tweet-reply\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{\\u003Estream_tweet}}\\u000a\\u000a    \\u003Cdiv class=\\\"in-reply-to\\\"\\u003E\\u000a      \\u003Ch4\\u003EIn reply to\\u003C/h4\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cform class=\\\"tweet-form\\\"\\u003E\\u000a      \\u003Ctextarea class=\\\"tweetbox\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003Cdiv class=\\\"tweet-buttons\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-hash\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-at\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-camera\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-geo\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cbutton class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ETweet\\u003C/button\\u003E\\u000a      \\u003Cspan class=\\\"tweet-count\\\"\\u003E140\\u003C/span\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_retweet: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay tweet-retweet\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003ERetweet this to your followers?\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"modal-tweet-wrapper\\\"\\u003E\\u000a          Tweet here, please!\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"modal-inner-footer clearfix\\\"\\u003E\\u000a          \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ERetweet\\u003C/a\\u003E\\u000a          \\u003Cp class=\\\"learn-more\\\"\\u003E\\u003Ca class=\\\"muted\\\" href=\\\"#\\\"\\u003ELearn more about Retweets\\u003C/a\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"btn primary-btn\\\" href=\\\"#\\\"\\u003ERetweet\\u003C/a\\u003E\\u000a      \\u003Ca class=\\\"btn js-action-dismiss\\\" href=\\\"#\\\"\\u003ECancel\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_shortcuts: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay shortcuts\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EKeyboard shortcuts\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"keyboard-shortcuts clearfix\\\"\\u003E\\u000a        \\u003Cdl\\u003E\\u000a          \\u003Cdt\\u003EActions\\u003C/dt\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Ef\\u003C/strong\\u003E \\u003Cspan\\u003E: favorite\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Er\\u003C/strong\\u003E \\u003Cspan\\u003E: reply\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Et\\u003C/strong\\u003E \\u003Cspan\\u003E: retweet\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Em\\u003C/strong\\u003E \\u003Cspan\\u003E: direct message\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003En\\u003C/strong\\u003E \\u003Cspan\\u003E: new Tweet\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eenter\\u003C/strong\\u003E \\u003Cspan\\u003E: toggle details pane\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a        \\u003C/dl\\u003E\\u000a        \\u003Cdl\\u003E\\u000a          \\u003Cdt\\u003ENavigation\\u003C/dt\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003E?\\u003C/strong\\u003E \\u003Cspan\\u003E: this menu\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Ej\\u003C/strong\\u003E \\u003Cspan\\u003E: next Tweet\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Ek\\u003C/strong\\u003E \\u003Cspan\\u003E: previous Tweet\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Espace\\u003C/strong\\u003E \\u003Cspan\\u003E: page down\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003E/\\u003C/strong\\u003E \\u003Cspan\\u003E: search\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003E.\\u003C/strong\\u003E \\u003Cspan\\u003E: load new Tweets\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a        \\u003C/dl\\u003E\\u000a        \\u003Cdl\\u003E\\u000a          \\u003Cdt\\u003ETimelines\\u003C/dt\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg h\\u003C/strong\\u003E \\u003Cspan\\u003E: \\u003Cu\\u003Eh\\u003C/u\\u003Eome\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg r\\u003C/strong\\u003E \\u003Cspan\\u003E: @me\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg a\\u003C/strong\\u003E \\u003Cspan\\u003E: \\u003Cu\\u003Ea\\u003C/u\\u003Ectivity\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg p\\u003C/strong\\u003E \\u003Cspan\\u003E: \\u003Cu\\u003Ep\\u003C/u\\u003Erofile\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg f\\u003C/strong\\u003E \\u003Cspan\\u003E: \\u003Cu\\u003Ef\\u003C/u\\u003Eavorites\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg m\\u003C/strong\\u003E \\u003Cspan\\u003E: \\u003Cu\\u003Em\\u003C/u\\u003Eessages\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a          \\u003Cdd\\u003E\\u003Cstrong\\u003Eg u\\u003C/strong\\u003E \\u003Cspan\\u003E: go to \\u003Cu\\u003Eu\\u003C/u\\u003Eser\\u003C/span\\u003E\\u003C/dd\\u003E\\u000a        \\u003C/dl\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_switch_accounts: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay switch-accounts\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003ESwitch accounts\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"account-switcher clearfix\\\"\\u003E\\u000a          \\u003Ca class=\\\"active\\\" href=\\\"#\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size73\\\" src=\\\"http://placehold.it/73x73\\\" alt=\\\"\\\" /\\u003E\\u000a            \\u003Cstrong\\u003E@longusername\\u003C/strong\\u003E\\u000a          \\u003C/a\\u003E\\u000a          \\u003Ca href=\\\"#\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size73\\\" src=\\\"http://placehold.it/73x73\\\" alt=\\\"\\\" /\\u003E\\u000a            \\u003Cstrong\\u003E@user\\u003C/strong\\u003E\\u000a          \\u003C/a\\u003E\\u000a          \\u003Ca href=\\\"#\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size73\\\" src=\\\"http://placehold.it/73x73\\\" alt=\\\"\\\" /\\u003E\\u000a            \\u003Cstrong\\u003E@leUser\\u003C/strong\\u003E\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_trends_change: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay change-trends\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EChange trends location\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"modal-body\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"modal-inner\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"local-trends\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"local-trends-breadcrumb\\\"\\u003E\\u000a            \\u003Cul\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca class=\\\"trend-breadcrumb-location\\\" data-woeid=\\\"1\\\" href=\\\"#\\\"\\u003EWorldwide\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli class=\\\"divider\\\"\\u003E/\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca class=\\\"trend-breadcrumb-location selected\\\" data-woeid=\\\"23424977\\\" href=\\\"#\\\"\\u003EUnited States \\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a            \\u003C/ul\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u000a            \\u003Cul class=\\\"local-trends-list\\\"\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424747\\\" href=\\\"#\\\"\\u003EArgentina\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424748\\\" href=\\\"#\\\"\\u003EAustralia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424768\\\" href=\\\"#\\\"\\u003EBrazil\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424775\\\" href=\\\"#\\\"\\u003ECanada\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424782\\\" href=\\\"#\\\"\\u003EChile\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424787\\\" href=\\\"#\\\"\\u003EColombia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424800\\\" href=\\\"#\\\"\\u003EDominican Republic\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424801\\\" href=\\\"#\\\"\\u003EEcuador\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424819\\\" href=\\\"#\\\"\\u003EFrance\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424829\\\" href=\\\"#\\\"\\u003EGermany\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424848\\\" href=\\\"#\\\"\\u003EIndia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a            \\u003C/ul\\u003E\\u000a            \\u003Cul class=\\\"local-trends-list\\\"\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424846\\\" href=\\\"#\\\"\\u003EIndonesia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424803\\\" href=\\\"#\\\"\\u003EIreland\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424853\\\" href=\\\"#\\\"\\u003EItaly\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424856\\\" href=\\\"#\\\"\\u003EJapan\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424901\\\" href=\\\"#\\\"\\u003EMalaysia\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424900\\\" href=\\\"#\\\"\\u003EMexico\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424909\\\" href=\\\"#\\\"\\u003ENetherlands\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424916\\\" href=\\\"#\\\"\\u003ENew Zealand\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424908\\\" href=\\\"#\\\"\\u003ENigeria\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424919\\\" href=\\\"#\\\"\\u003EPeru\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424934\\\" href=\\\"#\\\"\\u003EPhilippines\\u003C/a\\u003E\\u003C/li\\u003E\\u000a            \\u003C/ul\\u003E\\u000a            \\u003Cul class=\\\"local-trends-list\\\"\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424948\\\" href=\\\"#\\\"\\u003ESingapore\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424942\\\" href=\\\"#\\\"\\u003ESouth Africa\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424950\\\" href=\\\"#\\\"\\u003ESpain\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424954\\\" href=\\\"#\\\"\\u003ESweden\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424969\\\" href=\\\"#\\\"\\u003ETurkey\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424738\\\" href=\\\"#\\\"\\u003EUnited Arab Emirates\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424975\\\" href=\\\"#\\\"\\u003EUnited Kingdom\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca class=\\\"selected\\\" data-woeid=\\\"23424977\\\" href=\\\"#\\\"\\u003EUnited States \\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u003Ca data-woeid=\\\"23424982\\\" href=\\\"#\\\"\\u003EVenezuela\\u003C/a\\u003E\\u003C/li\\u003E\\u000a            \\u003C/ul\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modal_tweet: \"\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay new-tweet\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"modal\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"modal-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close-large\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003Ch2\\u003EWhat's happening?\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cform class=\\\"tweet-form\\\"\\u003E\\u000a      \\u003Ctextarea class=\\\"tweetbox\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003Cdiv class=\\\"tweet-buttons\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-hash\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-at\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-camera\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-geo\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cbutton class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ETweet\\u003C/button\\u003E\\u000a      \\u003Cspan class=\\\"tweet-count\\\"\\u003E140\\u003C/span\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            modals: \"\\u000a\\u000a\\u000a{{\\u003Emodal_tweet}}\\u000a\\u000a\\u000a{{\\u003Emodal_reply}}\\u000a{{\\u003Emodal_retweet}}\\u000a\\u000a\\u000a{{\\u003Emodal_list_new}}\\u000a{{\\u003Emodal_list_new_add_members}}\\u000a{{\\u003Emodal_list_edit}}\\u000a{{\\u003Emodal_list_edit_members}}\\u000a{{\\u003Emodal_list_add_to}}\\u000a\\u000a\\u000a{{\\u003Emodal_trends_change}}\\u000a\\u000a\\u000a{{\\u003Emodal_switch_accounts}}\\u000a\\u000a\\u000a{{\\u003Emodal_shortcuts}}\\u000a\\u000a\\u000a{{\\u003Emodal_message_new}}\\u000a{{\\u003Emodal_message_thread}}\\u000a{{\\u003Emodal_dms}}\\u000a\\u000a\\u000a{{\\u003Emodal_profile_card}}\\u000a\\u000a\\u000a{{\\u003Emodal_go_to_user}}\\u000a\\u000a\\u000a{{\\u003Emodal_account_changes}}\",\n            gallery: \"{{\\u003Emobile_gallery_all}}\\u000a{{\\u003Edialogs/mobile_gallery_download_dialog}}\\u000a{{\\u003Efooter}}\",\n            generic_footer: \"\\u003Cdiv class=\\\"footer inline-list\\\"\\u003E\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{about_path}}\\\"\\u003EAbout\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{support_path}}\\\"\\u003EHelp\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{blog_path}}\\\"\\u003EBlog\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a{{^is_slim}}\\u000a    {{#decider_mobile_download_gallery}}\\u000a      \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}\\\"\\u003EMobile\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    {{/decider_mobile_download_gallery}}\\u000a{{/is_slim}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{status_path}}\\\"\\u003EStatus\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a{{#decider_trends_page}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{trends_path}}\\\"\\u003ETrends\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a{{/decider_trends_page}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{jobs_path}}\\\"\\u003EJobs\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{tos_path}}\\\"\\u003ETerms\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{privacy_path}}\\\"\\u003EPrivacy\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a{{^is_slim}}\\u000a    {{#logged_in}}\\u000a        \\u003Cli\\u003E\\u003Ca href=\\\"#\\\" id=\\\"keyboard-shortcut-trigger\\\"\\u003EShortcuts\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    {{/logged_in}}\\u000a{{/is_slim}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{advertisers_path}}\\\"\\u003EAdvertisers\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{businesses_path}}\\\"\\u003EBusinesses\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{partnerships_path}}\\\"\\u003EMedia\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{developers_path}}\\\"\\u003EDevelopers\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{resources_path}}\\\"\\u003EResources\\u003C/a\\u003E\\u003Cspan class=\\\"dot divider\\\"\\u003E &middot;\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Cspan class=\\\"copyright\\\"\\u003E&copy; {{year}} Twitter\\u003C/span\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a  {{#is_mobile}}\\u000a    \\u003Cp class=\\\"mobile-option\\\"\\u003E\\u000a      View Twitter in:&nbsp;Standard&nbsp;- \\u003Ca href=\\\"{{mobile_path}}\\\"\\u003EMobile\\u003C/a\\u003E\\u000a    \\u003C/p\\u003E\\u000a  {{/is_mobile}}\\u000a\\u003C/div\\u003E\\u000a\",\n            disabled_dropdown: \"\\u003Cul class=\\\"dropdown-menu\\\" tabindex=\\\"-1\\\"\\u003E\\u000a  \\u003Cli class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"geo-not-enabled-yet\\\"\\u003E\\u000a    \\u003Ch2\\u003EAdd a location to your Tweets\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      When you tweet with a location, Twitter stores that location.&#32;\\u000a      You can switch location on/off before each Tweet and always have the option to delete your location history.\\u000a      \\u003Ca href=\\\"http://support.twitter.com/forums/26810/entries/78525\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a    \\u003C/p\\u003E\\u000a    \\u003Cdiv\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"geo-turn-on btn primary-btn\\\"\\u003ETurn location on\\u003C/button\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"geo-not-now btn-link\\\"\\u003ENot now\\u003C/button\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            dropdown_places: \"{{#places}}\\u000a  \\u003Cli class=\\\"dropdown-link geo-place-result geo-focusable\\\" data-place-id=\\\"{{id}}\\\"\\u003E{{#is_first_place}}\\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E{{/is_first_place}}{{full_name}}\\u003C/li\\u003E\\u000a{{/places}}\\u000a\\u003Cli class=\\\"geo-place-result dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a\",\n            dropdown_search_results: \"{{#places}}\\u000a  \\u003Cli class=\\\"dropdown-link geo-search-result geo-focusable\\\" data-place-id=\\\"{{id}}\\\"\\u003E{{full_name}}\\u003C/li\\u003E\\u000a{{/places}}\\u000a{{^places}}\\u000a  \\u003Cli class=\\\"dropdown-link geo-search-result geo-no-search-results\\\"\\u003ENo search results\\u003C/li\\u003E\\u000a{{/places}}\\u000a\\u003Cli class=\\\"geo-search-result dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a\",\n            enabled_dropdown: \"\\u003Cul class=\\\"dropdown-menu\\\" tabindex=\\\"-1\\\"\\u003E\\u000a  \\u003Cli class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"geo-query-location\\\"\\u003E\\u000a    \\u003Cinput type=\\\"text\\\" autocomplete=\\\"off\\\" placeholder=\\\"Search for a neighborhood or city\\\"\\u003E\\u000a    \\u003Ci class=\\\"generic-search\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"geo-dropdown-status\\\"\\u003E\\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"dropdown-link geo-turn-off-item geo-focusable\\\"\\u003E\\u000a    \\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003ETurn off location\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            geo_picker: \"\\u003Cdiv class=\\\"geo-picker\\\"\\u003E\\u000a  \\u003Cbutton class=\\\"btn geo-picker-btn\\\" type=\\\"button\\\" tabindex=\\\"-1\\\"\\u003E\\u000a    \\u003Ci class=\\\"tweet-geo\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EAdd location\\u003C/span\\u003E\\u003C/i\\u003E \\u003Cspan class=\\\"caret\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/button\\u003E\\u000a  \\u003Cspan class=\\\"dropdown-container\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"geo-status\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"place_id\\\"\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            geo_control: \"\\u003Cspan class=\\\"geo-control\\\"\\u003E\\u000a  \\u003Ca href=\\\"#\\\" class=\\\"geo-location\\\"\\u003E\\u000a    \\u003Cspan class=\\\"geo-icon\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a    {{^suppress_geo_text}}\\u003Cspan class=\\\"geo-text\\\"\\u003E\\u003C/span\\u003E{{/suppress_geo_text}}\\u003Cspan class=\\\"geo-dropdown-icon\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/span\\u003E\",\n            geo_location_dropdown: \"\\u003Cdiv class=\\\"geo-location-dropdown\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"geo-location-dropdown-divot\\\"\\u003E&nbsp;\\u003C/div\\u003E\\u000a  \\u003Cul class=\\\"geo\\\"\\u003E\\u000a    \\u003Cli class=\\\"query-location\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"query-location-container\\\"\\u003E\\u000a        \\u003Cinput class=\\\"query-location-input\\\" type=\\\"text\\\" autocomplete=\\\"off\\\" /\\u003E\\u000a        \\u003Cspan class=\\\"glass\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a        \\u003Cspan class=\\\"help-text\\\"\\u003ESearch for a neighborhood or city\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"location-error\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/li\\u003E\\u000a    \\u003Cli class=\\\"geo-turn-off-item focusable\\\"\\u003E\\u003Ca class=\\\"geo\\\" href=\\\"#\\\"\\u003E\\u000a      \\u003Cspan class=\\\"geo-turn-off-icon\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a      Turn off location\\u000a    \\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            geo_location_dropdown_items: \"{{#places}}\\u000a  \\u003Cli class=\\\"override-location focusable{{#for_search_results}} location-search-result{{/for_search_results}}\\\"\\u003E\\u000a    \\u003Ca class=\\\"geo\\\" href=\\\"#\\\" data-place-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Cspan class=\\\"menu-item-icon\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a      {{full_name}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a{{/places}}\\u000a\",\n            geo_map_big: \"\\u003Cdiv class=\\\"tweet_geo_big\\\"\\u003E\\u000a{{#place}}\\u000a  \\u003Cdiv class=\\\"geo_map_place_details\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"geo_map_place_name\\\"\\u003E{{name}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{full_address}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{phone}}\\u003C/div\\u003E\\u000a    {{#place_path}}\\u000a    \\u003Cdiv\\u003E\\u000a      \\u003Ca class=\\\"geo_map_place_page_link\\\" href=\\\"{{place_path}}\\\"\\u003E\\u000a        View more about this place &rarr;\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/place_path}}\\u000a  \\u003C/div\\u003E\\u000a{{/place}}\\u000a{{^place}}\\u000a  {{#user}}\\u000a  \\u003Cdiv class=\\\"geo_map_place_details\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"geo_map_place_name\\\"\\u003E@{{screen_name}}'s Tweet location\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{/user}}\\u000a{{/place}}\\u000a{{#show_map}}\\u000a  \\u003Cdiv class=\\\"map_canvas\\\"\\u003E\\u003C/div\\u003E\\u000a{{/show_map}}\\u000a\\u003C/div\\u003E\\u000a\",\n            geo_map_small: \"\\u003Cdiv class=\\\"tweet_geo_small\\\"\\u003E\\u000a{{#place}}\\u000a  {{#show_map}}\\u000a    \\u003Cdiv class=\\\"map_canvas\\\"\\u000a         data-tweet-id=\\\"{{tweet_id}}\\\"\\u000a         data-place-id=\\\"{{id}}\\\"\\u000a         data-place-name=\\\"{{full_name}}\\\"\\u003E\\u003C/div\\u003E\\u000a  {{/show_map}}\\u000a  \\u003Cdiv class=\\\"geo_map_place_details\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{place_map_url}}\\\" target=\\\"_blank\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"geo_map_place_name\\\"\\u003E\\u000a      {{#is_from}}\\u000a        from {{name}}\\u000a      {{/is_from}}\\u000a      {{^is_from}}\\u000a        {{name}}\\u000a      {{/is_from}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Cdiv\\u003E{{address}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{container}}\\u003C/div\\u003E\\u000a    \\u003Cdiv\\u003E{{phone}}\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/place}}\\u000a{{^place}}\\u000a  {{#show_map}}\\u000a    \\u003Cdiv class=\\\"map_canvas\\\"\\u000a         data-tweet-id=\\\"{{tweet_id}}\\\"\\u003E\\u003C/div\\u003E\\u000a  {{/show_map}}\\u000a{{/place}}\\u000a\\u003C/div\\u003E\\u000a\",\n            geo_promo_dialog: \"\\u003Cdiv id=\\\"geo_promo_dialog_content\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tiny-map\\\"\\u003E&nbsp;\\u003C/div\\u003E\\u000a  \\u003Cdiv id=\\\"geo_dialog_descr\\\"\\u003E\\u000a    Ever had something you wanted to share (\\\"fireworks!\\\", \\\"party!\\\", \\\"ice cream truck!\\\", or \\\"quicksand...\\\") that would be better with a location?&#32;\\u000a    By turning on this feature, you can include location information like neighborhood, town, or exact point when you tweet.\\u003Cbr\\u003E\\u003Cbr\\u003E\\u000a    When you tweet with a location, Twitter stores that location.&#32;\\u000a    You can switch location on/off before each Tweet and always have the option to delete your location history.&#32;\\u000a    \\u003Ca id=\\\"geo_learn_more\\\" href=\\\"http://support.twitter.com/forums/26810/entries/78525\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv\\u003E\\u000a    \\u003Cbutton id=\\\"geo_turn_location_on\\\" class=\\\"btn btn-default\\\"\\u003ETurn location on\\u003C/button\\u003E\\u000a    \\u003Ca href=\\\"#\\\" id=\\\"geo_not_now\\\" class=\\\"geo_dialog_close\\\"\\u003ENot now\\u003C/a\\u003E\\u000a    \\u003Cspan class=\\\"geo-progress\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"geo-unable-to-turn-location-on\\\"\\u003E\\u000a    Unable to turn location on at this time. Please try again later.\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            getting_started_follow: \"\\u003Cli class=\\\"follow\\\"\\u003E\\u000a  \\u003Cspan\\u003EFollow your first 10 accounts\\u003C/span\\u003E\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{who_to_follow_interests_path}}\\\"\\u003EBrowse popular accounts by interest\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{who_to_follow_import_path}}\\\"\\u003ELook for your friends\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli class=\\\"search\\\"\\u003E\\u003Cform class=\\\"who-to-follow-search\\\" action=\\\"{{who_to_follow_search_form_path}}\\\" method=\\\"GET\\\"\\u003E\\u003Cinput type=\\\"text\\\" value=\\\"\\\" name=\\\"q\\\" placeholder=\\\"find users by name\\\" /\\u003E&nbsp;\\u003Cdiv class=\\\"submit button\\\"\\u003ESearch\\u003C/div\\u003E\\u003C/form\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/li\\u003E\",\n            getting_started_mobile: \"\\u003Cli class=\\\"mobile\\\"\\u003E\\u000a  \\u003Cspan\\u003EGet Twitter on your phone\\u003C/span\\u003E\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{devices_path}}\\\"\\u003ESet up mobile notifications\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{#decider_mobile_download_gallery}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}\\\"\\u003EDownload a Twitter application to your phone\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/decider_mobile_download_gallery}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            getting_started_profile: \"\\u003Cli class=\\\"profile\\\"\\u003E\\u000a  \\u003Cspan\\u003ESet up your profile\\u003C/span\\u003E\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{settings_profile_path}}\\\"\\u003EUpload a profile picture\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{settings_profile_path}}\\\"\\u003EWrite a short bio\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/li\\u003E\",\n            getting_started_tweet: \"\\u003Cli class=\\\"tweet\\\"\\u003E\\u000a  \\u003Cspan\\u003EWrite your first Tweet!\\u003C/span\\u003E\\u000a  \\u003Cul\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"#\\\" class=\\\"new-tweet\\\"\\u003ETell the world what's happening in 140 characters or less\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/li\\u003E\",\n            global_nav_saved_search: \"\\u003Cli\\u003E\\u003Ca href=\\\"{{saved_search_path}}\\\" data-search-query=\\\"{{query}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\",\n            government_account_search: \"\\u003Cdiv class=\\\"government-account-search-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003E\\u000a      \\u003Cspan class=\\\"js-stream-title\\\"\\u003E{{stream_title}}\\u003C/span\\u003E\\u000a\\u000a      \\u003Csmall class=\\\"view-toggler js-view-toggler\\\"\\u003E\\u003C/small\\u003E\\u000a    \\u003C/h2\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"government-account-search-inner\\\"\\u003E\\u000a    \\u003Ch3\\u003EFind your elected government representatives\\u003C/h3\\u003E\\u000a    \\u003Cform class=\\\"js-government-account-search\\\" action=\\\"#\\\"\\u003E\\u000a      \\u003Cinput type=\\\"text\\\" placeholder=\\\"Enter your zip code\\\" name=\\\"zip\\\" {{#zip_code}}value=\\\"{{zip_code}}\\\"{{/zip_code}}\\u003E\\u000a      \\u003Cinput type=\\\"submit\\\" class=\\\"btn js-zip-code-btn\\\" value=\\\"Search\\\"\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            guest_modal_signup: \"\\u000a\\u003Cdiv id=\\\"guest-modal-signup\\\"\\u003E\\u000a  \\u003Ch2\\u003EDon't miss any updates on what matters to you. Sign up today and follow these accounts:\\u003C/h2\\u003E\\u000a\\u000a  \\u003Cul class=\\\"users\\\"\\u003E\\u000a\\u0009{{#user_data_list}}\\u000a\\u0009\\u0009{{\\u003Euser_small_list_item}}\\u000a\\u0009{{/user_data_list}}\\u000a  \\u003C/ul\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"guest-modal-signup-box front-signup\\\"\\u003E\\u000a\\u0009  \\u003Ch3\\u003ENew to Twitter? \\u003Cem\\u003EJoin today!\\u003C/em\\u003E\\u003C/h3\\u003E\\u000a\\u0009  {{\\u003Epartial_signup_form}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            pip: \"{{#icon}}\\u000a  \\u003Cdiv class=\\\"js-pip stork-pip stork-pip-right\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stork-pulse\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Ci class=\\\"stork-icon {{icon}}\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/icon}}\\u000a\\u000a{{^icon}}\\u000a  \\u003Cdiv class=\\\"js-pip module stork stork-open\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"contrast-flex-module\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"contrast-module-header\\\"\\u003E\\u000a        {{#expand_photo}}\\u000a          {{#prompt}}\\u000a            There\\u2019s a photo in this Tweet. Check it out.\\u000a          {{/prompt}}\\u000a          {{#explain}}\\u000a            \\u003Cp\\u003EYou\\u2019ll also find music, videos, and replies inside Tweets, so keep expanding them.\\u003C/p\\u003E\\u000a          {{/explain}}\\u000a        {{/expand_photo}}\\u000a\\u000a        {{#expand_video}}\\u000a          {{#prompt}}\\u000a            There\\u2019s a video in this Tweet. Check it out.\\u000a          {{/prompt}}\\u000a          {{#explain}}\\u000a            You\\u2019ll also find photos, music, and replies inside Tweets, so keep expanding them.\\u000a          {{/explain}}\\u000a        {{/expand_video}}\\u000a\\u000a        {{#retweet_profile}}\\u000a          {{#explain}}\\u000a            \\u000a            \\u003Cp\\u003EA \\u003Cstrong\\u003Eretweet\\u003C/strong\\u003E is a Tweet that was shared by someone you\\u2019re following.\\u003C/p\\u003E \\u003Cp\\u003EThe author of that Tweet may be someone you don\\u2019t follow, so it\\u2019s a great way to check out somebody new.\\u003C/p\\u003E\\u000a          {{/explain}}\\u000a        {{/retweet_profile}}\\u000a\\u000a        {{#hashtag}}\\u000a          {{#explain}}\\u000a            \\u003Cp\\u003EThe # symbol makes this word a \\u003Cstrong\\u003Ehashtag\\u003C/strong\\u003E. People add hashtags to their Tweets to give them topics.\\u003C/p\\u003E \\u003Cp\\u003EClick on it to find other Tweets with the same hashtag.\\u003C/p\\u003E\\u000a          {{/explain}}\\u000a        {{/hashtag}}\\u000a\\u000a        {{#mention}}\\u000a          {{#explain}}\\u000a            \\u003Cp\\u003EThe @ symbol is used to \\u003Cstrong\\u003Emention\\u003C/strong\\u003E another person by username. Mentions call attention to someone and can start a conversation.\\u003C/p\\u003E \\u003Cp\\u003EClick on it to see that user\\u2019s profile.\\u003C/p\\u003E\\u000a          {{/explain}}\\u000a        {{/mention}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"pointer\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"contrast-module-footer\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/icon}}\",\n            JSBNG__home: \"{{\\u003Edialogs/search_operators_shell}}\\u000a\\u003Cdiv id=\\\"search-home\\\" class=\\\"main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"search basic-search\\\"\\u003E\\u000a    \\u003Ch1\\u003ESee what\\u2019s happening \\u003Cstrong\\u003Eright now\\u003C/strong\\u003E\\u003C/h1\\u003E\\u000a    \\u003Cform id=\\\"search-home-form\\\" action=\\\"{{form_search_results_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"input-wrapper\\\"\\u003E\\u000a        \\u003Cinput id=\\\"search-home-input\\\" class=\\\"search-input\\\" autocomplete=\\\"off\\\" spellcheck=\\\"false\\\" value=\\\"\\\" name=\\\"q\\\" type=\\\"text\\\" placeholder=\\\"\\\" /\\u003E\\u000a        {{#swift_typeahead}}\\u000a          {{\\u003Eswift_typeahead_dropdown}}\\u000a        {{/swift_typeahead}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"button btn primary-btn submit selected search-btn\\\"\\u003ESearch\\u003C/div\\u003E\\u000a      {{\\u003Esearch_help_operators}}\\u000a    \\u003C/form\\u003E\\u000a    {{\\u003Edashboard_trends}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"bottompart\\\"\\u003E\\u000a    {{\\u003Efooter}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            home_dashboard: \"{{^rendering_on_server}}\\u000a  \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a  {{\\u003Edashboard_your_profile}}\\u000a  \\u003Chr/\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a  {{\\u003Egeneric_footer}}\\u000a  \\u003C/div\\u003E\\u000a{{/rendering_on_server}}\",\n            follower_stat: \"\\u000a  {{#number_one}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Follower{{/number_one}}\\u000a  {{#number_other}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Followers{{/number_other}}\\u000a\",\n            following_stat: \"\\u000a  {{#number_one}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Following{{/number_one}}\\u000a  {{#number_other}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Following{{/number_other}}\\u000a\",\n            tweet_stat: \"\\u000a  {{#number_one}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Tweet{{/number_one}}\\u000a  {{#number_other}}\\u003Cstrong\\u003E{{localized_number}}\\u003C/strong\\u003E Tweets{{/number_other}}\\u000a\",\n            import_disclaimer: \"{{^in_welcome_flow}}\\u000aChoosing a service will open a window for you to log in securely and import your contacts to Twitter. You'll only find users who have allowed their accounts to be found by email address.  We won't email anyone without your consent, but we may use contact information to make Who To Follow suggestions.  You can \\u003Ca href=\\\"#\\\" class=\\\"js-wipe-addressbook\\\"\\u003Eremove\\u003C/a\\u003E your contacts from Twitter at any time.\\u000a{{/in_welcome_flow}}\\u000a{{#in_welcome_flow}}\\u000aChoosing a service will open a window for you to log in securely and import your contacts to Twitter. You'll only find users who have allowed their accounts to be found by email address.  We won't email anyone without your consent, but we may use contact information to make Who To Follow suggestions.  You can remove your contacts from Twitter at any time.\\u000a{{/in_welcome_flow}}\\u000a\",\n            in_reply_to: \"\\u003Cdiv class=\\\"permalink-inner in-reply-to\\\" data-replied-tweet-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweets-wrapper\\\"\\u003E\\u000a    {{#has_multiple_ancestors}}\\u000a      \\u003Cdiv class=\\\"ancestors-window-container\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"ancestors-window\\\"\\u003E\\u000a          {{#ancestors_without_in_reply_to}}\\u000a            {{\\u003Esimple_tweet}}\\u000a          {{/ancestors_without_in_reply_to}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/has_multiple_ancestors}}\\u000a    {{\\u003Esimple_tweet}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            inline_media_icon: \"\\u003Ci class=\\\"js-sm-icon {{#is_image}} sm-image{{/is_image}} {{#is_video}} sm-video{{/is_video}} {{#is_summary}} sm-summary{{/is_summary}} {{#is_audio}} sm-audio{{/is_audio}} {{#is_geo}} sm-geo{{/is_geo}} {{#is_convo}} sm-convo{{/is_convo}} {{#is_embed}} sm-embed{{/is_embed}}\\\"\\u000a{{#icon}} data-media-class=\\\"{{icon}}\\\"{{/icon}} {{#media_name}} data-media-type=\\\"{{media_name}}\\\"{{/media_name}}\\u003E\\u003C/i\\u003E\",\n            inline_reply_box: \"\\u003Cdiv class=\\\"inline-reply-tweetbox\\\"\\u003E\\u000a  \\u003Cimg class=\\\"inline-reply-user-image avatar size{{profile_image_size}}\\\" src=\\\"{{profile_image_url}}\\\"\\u003E\\u000a\\u003C/div\\u003E\",\n            invite_contacts: \"\\u003Cdiv class=\\\"invite-contacts-component\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"people-chooser-list\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"select-all-people\\\"\\u003E\\u000a      \\u003Clabel class=\\\"contacts-select-all\\\"\\u003E\\u000a        \\u003Cinput type=\\\"checkbox\\\" name=\\\"select_all\\\" id=\\\"select-all-contacts\\\"\\u003E\\u000a        {{select_all_text}}\\u000a      \\u003C/label\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"contacts\\\"\\u003E\\u000a      {{#contacts}}\\u000a        \\u003Clabel class=\\\"contact-item\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" name=\\\"emails[]\\\" value=\\\"{{email}}\\\"\\u000a            id=\\\"contact-box-{{index}}\\\"\\u003E\\u000a          \\u003Cspan class=\\\"contact-item-name\\\" title=\\\"{{name}}\\\"\\u003E{{truncated_name}}\\u003C/span\\u003E\\u000a          \\u003Cspan class=\\\"contact-item-email\\\" title=\\\"{{email}}\\\"\\u003E&lt;{{truncated_email}}&gt;\\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a      {{/contacts}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"list-editor\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"save\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"invite-preview-link\\\"\\u003E\\u003Ca href=\\\"{{preview_link_url}}\\\" class=\\\"js-popup\\\" name=\\\"invitation_email_preview\\\" data-popup=\\\"height=450,width=670\\\"\\u003ESee what you'll send them\\u003C/a\\u003E.\\u003C/div\\u003E\\u000a        \\u003Cbutton type=\\\"button\\\" class=\\\"btn invite-contacts-button disabled\\\"\\u003EInvite these friends\\u003C/button\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            invite_contacts_header: \"\\u003Cdiv class=\\\"contact-import-invite-header\\\"\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u003Cspan\\u003E{{count}} of your contacts aren\\u2019t on Twitter yet. We\\u2019ll invite the ones you select here.\\u003C/span\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            invite_friends: \"\\u003Cform class=\\\"invite-friends\\\"\\u003E\\u000a  \\u003Ctable class=\\\"flex-table\\\"\\u003E\\u000a    \\u003Ctbody\\u003E\\u000a      \\u003Ctr\\u003E\\u000a        \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"flex-table-form\\\"\\u003E\\u000a            \\u000a            \\u000a            \\u003Ctextarea class=\\\"flex-table-input\\\" name=\\\"addresses\\\" rows=\\\"1\\\" placeholder=\\\"Invite friends to Twitter via email\\\"\\u003E\\u003C/textarea\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/td\\u003E\\u000a        \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a          \\u003Cbutton class=\\\"btn flex-table-btn js-submit\\\" type=\\\"submit\\\"\\u003EInvite friends\\u003C/button\\u003E\\u000a        \\u003C/td\\u003E\\u000a      \\u003C/tr\\u003E\\u000a    \\u003C/tbody\\u003E\\u000a  \\u003C/table\\u003E\\u000a  \\u003Cp class=\\\"fine-print\\\"\\u003E\\u000a    Lots of people to invite? Separate multiple email addresses with commas.\\u003Cbr\\u003E\\u000a    \\u003Ca href=\\\"{{invitation_email_preview_path}}\\\" class=\\\"js-popup\\\" name=\\\"invitation_email_preview\\\" data-popup=\\\"height=550,width=750\\\"\\u003ESee what you'll send them.\\u003C/a\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/form\\u003E\",\n            japanese_ad: \"\\u003Cdiv id=\\\"custom_49\\\" class=\\\"eTologyToken\\\"\\u003E\\u003C/div\\u003E\",\n            japanese_ad_iframe: \"{{#show_japanese_ad}}\\u000a  \\u003Ciframe id=\\\"j_ad\\\" src=\\\"//web-jp.ad-v.jp/adam/detect?tag=htm&cat=twitter.all&format=side_banner\\\" width=\\\"300\\\" height=\\\"185\\\" frameborder=\\\"no\\\" border=\\\"0\\\" marginwidth=\\\"0\\\" marginheight=\\\"0\\\" scrolling=\\\"no\\\"\\u003E\\u003C/iframe\\u003E\\u000a{{/show_japanese_ad}}\",\n            javascript_includes: \"\\u000a{{!\\u000a\\u000a  IMPORTANT:\\u000a  Do not add JavaScript code directly to this file. If you need to add new code, load it with Loadrunner\\u000a  or inline it using inline_script.\\u000a\\u000a}}\\u000a\\u000a\\u003Cscript type=\\\"text/javascript\\\"\\u003EWATCH('loadrunner', function() {\\u000a    {{{loadrunner_script}}}\\u000a    {{{loadrunner_plugin_json}}}\\u000a    {{{loadrunner_plugin_css}}}\\u000a    {{{loadrunner_plugin_signal}}}\\u000a});\\u003C/script\\u003E\\u003Cscript\\u003EWATCH.end('loadrunner');\\u003C/script\\u003E\\u000a\\u000a{{^logged_in}}\\u000a  {{#home_page}}\\u000a    \\u003Cscript type=\\\"text/javascript\\\"\\u003EWATCH('javascript_logged_out', function() {\\u000a      {{\\u003Emini_scribe}}\\u000a      {{{cookie_disabler_selenium}}}\\u000a      {{{logged_out_js}}}\\u000a    });\\u003C/script\\u003E\\u000a    \\u003Cscript type=\\\"text/javascript\\\"\\u003EWATCH.end('javascript_logged_out');\\u003C/script\\u003E\\u000a  {{/home_page}}\\u000a{{/logged_in}}\\u000a\\u000a{{#logged_in}}\\u000a  {{#render_page_content}}\\u000a  \\u003Cscript\\u003EWATCH('actionQueue', function() {\\u000a    {{{action_queue_js}}}\\u000a  });\\u003C/script\\u003E\\u003Cscript\\u003EWATCH.end('actionQueue');\\u003C/script\\u003E\\u000a  {{/render_page_content}}\\u000a{{/logged_in}}\\u000a\\u000a\\u003Cscript\\u003EWATCH('boot', function() {\\u000a  using.cssPath = '{{{loadrunner_csspath}}}';\\u000a  using.path = '{{{loadrunner_modpath}}}';\\u000a  using.autoLoad = {{{loadrunner_autoload}}};\\u000a\\u000a  {{#inline_bootstrap_data}}\\u000a    provide('boot/bootstrap_data', function(exports) {\\u000a      exports({{{bootstrap_data_json}}});\\u000a    });\\u000a  {{/inline_bootstrap_data}}\\u000a\\u000a  {{{boot_js}}}\\u000a  {{{inline_request_log_selenium}}}\\u000a  using('boot/init', function(boot) {\\u000a    var data = {{{boot_data_json}}};\\u000a    boot.init(data);\\u000a  });\\u000a\\u000a  {{^logged_in}}\\u000a    {{#home_page}}\\u000a      {{^front_page_full_signup_256_old_signup_form}}\\u000a        using('bundle/signup').load();\\u000a      {{/front_page_full_signup_256_old_signup_form}}\\u000a    {{/home_page}}\\u000a  {{/logged_in}}\\u000a\\u000a});\\u003C/script\\u003E\\u003Cscript\\u003EWATCH.end('boot');\\u003C/script\\u003E\\u000a\\u000a{{^logged_in}}\\u000a  {{#home_page}}\\u000a    {{^front_page_full_signup_256_old_signup_form}}\\u000a      {{\\u003Ebanned_passwords}}\\u000a    {{/front_page_full_signup_256_old_signup_form}}\\u000a  {{/home_page}}\\u000a{{/logged_in}}\\u000a\\u000a\\u000a{{{admin_js}}}\\u000a\\u000a\\u003C!--[if lte IE 6]\\u003E\\u000a  \\u003Cscript\\u003Eusing('bundle/ie6').load();\\u003C/script\\u003E\\u000a\\u003C![endif]--\\u003E\\u000a\",\n            keyboard_shortcuts: \"\\u000a\\u003Cdiv class=\\\"keyboard-shortcuts\\\" id=\\\"keyboard-shortcut-menu\\\"\\u003E\\u000a  {{#logged_in}}\\u000a    \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a      \\u003Cthead\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Cth colspan=\\\"2\\\"\\u003EActions\\u003C/th\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/thead\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EFavorite\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EReply\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003ET\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ERetweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EM\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EDirect message\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EN\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENew Tweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EEnter\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EOpen Tweet details\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EL\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EClose all open Tweets\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a    \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a      \\u003Cthead\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Cth colspan=\\\"2\\\"\\u003ENavigation\\u003C/th\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/thead\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E?\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EThis menu\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EJ\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENext Tweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EK\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPrevious Tweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003ESpace\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPage down\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E/\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESearch\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E.\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELoad new Tweets\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a    \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a      \\u003Cthead\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Cth colspan=\\\"2\\\"\\u003ETimelines\\u003C/th\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/thead\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EH\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EHome\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a\\u000a        {{#decider_activity_read}}\\u000a            \\u003Ctr\\u003E\\u000a              \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EC\\u003C/b\\u003E\\u000a              \\u003C/td\\u003E\\u000a              \\u003Ctd class=\\\"shortcut-label\\\"\\u003EConnect\\u003C/td\\u003E\\u000a            \\u003C/tr\\u003E\\u000a            \\u003Ctr\\u003E\\u000a              \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EA\\u003C/b\\u003E\\u000a              \\u003C/td\\u003E\\u000a              \\u003Ctd class=\\\"shortcut-label\\\"\\u003EActivity\\u003C/td\\u003E\\u000a            \\u003C/tr\\u003E\\u000a            \\u003Ctr\\u003E\\u000a              \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a              \\u003C/td\\u003E\\u000a              \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMentions\\u003C/td\\u003E\\u000a            \\u003C/tr\\u003E\\u000a        {{/decider_activity_read}}\\u000a        {{^decider_activity_read}}\\u000a            \\u003Ctr\\u003E\\u000a              \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a                \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ER\\u003C/b\\u003E\\u000a              \\u003C/td\\u003E\\u000a              \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMentions\\u003C/td\\u003E\\u000a            \\u003C/tr\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ED\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EDiscover\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EP\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EProfile\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EFavorites\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EL\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELists\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EM\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EMessages\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003ES\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESettings\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EU\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EGo to user...\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a  {{/logged_in}}\\u000a  {{^logged_in}}\\u000a    \\u003Ctable class=\\\"modal-table\\\"\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EEnter\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EOpen Tweet details\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EG\\u003C/b\\u003E \\u003Cb class=\\\"sc-key\\\"\\u003EF\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EGo to user...\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E?\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EThis menu\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EJ\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ENext Tweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003EK\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPrevious Tweet\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003ESpace\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003EPage down\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E/\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ESearch\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd class=\\\"shortcut\\\"\\u003E\\u000a            \\u003Cb class=\\\"sc-key\\\"\\u003E.\\u003C/b\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd class=\\\"shortcut-label\\\"\\u003ELoad new Tweets\\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a  {{/logged_in}}\\u000a\\u003C/div\\u003E\\u000a\",\n            language_links: \"\\u003Cdiv class=\\\"module language-list\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-inner js-items-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"language inline-list\\\"\\u003E\\u000a        \\u003Cform action=\\\"{{change_locale_path}}\\\" method=\\\"POST\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"lang\\\" value=\\\"\\\"\\u003E\\u000a          {{#redirect}}\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect\\\" value=\\\"{{redirect}}\\\"\\u003E\\u000a          {{/redirect}}\\u000a          \\u003Cstrong\\u003ELanguages\\u003C/strong\\u003E\\u000a          {{#languages_by_own}}\\u000a          \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a          {{#current}}\\u000a          \\u003Cem class=\\\"current\\\"\\u003E{{localized_name}}\\u003C/em\\u003E\\u000a          {{/current}}\\u000a          {{^current}}\\u000a          \\u003Ca href=\\\"?lang={{code}}\\\" hreflang=\\\"{{code}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a          {{/current}}\\u000a          {{/languages_by_own}}\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            latest_tweet: \"\\u003Cdiv class=\\\"tweet latest-tweet js-actionable-tweet{{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}\\\" data-tweet-id=\\\"{{id}}\\\" data-item-id=\\\"{{id}}\\\" data-screen-name='{{#user}}{{screen_name}}{{/user}}'\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Elatest_tweet_timestamp}}:\\u000a      {{#was_retweeted}}\\u000a        \\u003Cspan class=\\\"retweet-icon\\\"\\u003E\\u003C/span\\u003E\\u000a      {{{retweet_source_screen_name_link}}}\\u000a      {{/was_retweeted}}\\u000a      &#32;{{\\u003Etweet_text}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            latest_tweet_timestamp: \"\\u003Ca href=\\\"{{permalink_path}}\\\" class=\\\"latest-tweet-timestamp js-permalink\\\" title=\\\"{{explicit_timestamp}}\\\"\\u003E\\u003Cspan class=\\\"_timestamp\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{full_timestamp}}\\u003C/span\\u003E\\u003C/a\\u003E\",\n            boot: \"{{#content_view}}\\u000a  {{#javascript_module}}\\u000a    {{{prerequisites}}}\\u000a    \\u003Cscript\\u003E\\u000a      using.path = '{{javascript_module_path}}';\\u000a\\u000a      {{{loadrunner_aliases}}}\\u000a      {{{setup_debug}}}\\u000a\\u000a      using(\\u000a        '{{javascript_module}}',\\u000a        'core/jquery',\\u000a        {{#selenium}}'app/utils/request_logger',{{/selenium}}\\u000a      function(page, ${{#selenium}}, requestLogger{{/selenium}}) {\\u000a        var initData = {{{javascript_init_data}}};\\u000a        {{#selenium}}\\u000a          window.requestLogger = requestLogger;\\u000a          requestLogger.initialize();\\u000a          window.pageInitialOptions = initData;\\u000a        {{/selenium}}\\u000a        page(initData);\\u000a        window.__swift_loaded = true;\\u000a        window.swiftActionQueue && window.swiftActionQueue.flush($);\\u000a        $(document).trigger('uiSwiftLoaded');\\u000a        {{#track_ttft}}\\u000a          window.ttft && window.ttft.recordMilestone('aq_empty_time',new Date().getTime());\\u000a          using('app/utils/ttft',function(ttft){ttft.startAjaxTracking()});\\u000a        {{/track_ttft}}\\u000a      });\\u000a    \\u003C/script\\u003E\\u000a  {{/javascript_module}}\\u000a{{/content_view}}\\u000a\",\n            browser: \"\\u003Cmeta http-equiv=\\\"X-UA-Compatible\\\" content=\\\"IE=edge,chrome=1\\\"\\u003E\\u000a\\u000a{{^current_user}}\\u000a  \\u003Cmeta name=\\\"description\\\" content=\\\"Instantly connect to what's most important to you. Follow your friends, experts, favorite celebrities, and breaking news.\\\"\\u003E\\u000a{{/current_user}}\\u000a\\u000a{{#dns_prefetch}}\\u000a  \\u003Clink rel=\\\"dns-prefetch\\\" href=\\\"{{.}}\\\"\\u003E\\u000a{{/dns_prefetch}}\\u000a\\u000a{{#include_ie9_meta}}\\u000a  \\u003Clink href=\\\"/favicons/favicon32x32.ico\\\" rel=\\\"shortcut icon\\\" type=\\\"image/x-icon\\\"\\u003E\\u000a{{/include_ie9_meta}}\\u000a{{^include_ie9_meta}}\\u000a  \\u003Clink href=\\\"/favicons/favicon.ico\\\" rel=\\\"shortcut icon\\\" type=\\\"image/x-icon\\\"\\u003E\\u000a{{/include_ie9_meta}}\\u000a\\u000a{{#content_view}}\\u000a  {{#provide_mobile_viewport}}\\u000a    \\u003Cmeta name=\\\"viewport\\\" id=\\\"viewport\\\" content=\\\"width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0\\\"\\u003E\\u000a  {{/provide_mobile_viewport}}\\u000a{{/content_view}}\\u000a\\u000a{{#content_view}}\\u000a  {{#canonical_url}}\\u000a    \\u003Clink rel=\\\"canonical\\\" href=\\\"{{canonical_url}}\\\"\\u003E\\u000a  {{/canonical_url}}\\u000a{{/content_view}}\",\n            css: \"{{#current_user}}\\u000a  \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{core_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E\\u000a{{/current_user}}\\u000a{{^current_user}}\\u000a  \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{core_logged_out_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E\\u000a{{/current_user}}\\u000a\\u000a{{#content_view}}\\u000a  {{#include_more_css_early}}\\u000a    \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{more_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E\\u000a  {{/include_more_css_early}}\\u000a\\u000a  {{#theme_user}}\\u000a    {{\\u003Euser_css_t1}}\\u000a    {{\\u003Ebg_img_css}}\\u000a  {{/theme_user}}\\u000a{{/content_view}}\\u000a\",\n            dialogs: \"{{#include_gallery}}\\u000a  {{\\u003Egallery/gallery}}\\u000a{{/include_gallery}}\\u000a\\u000a\\u003Cdiv class=\\\"modal-overlay\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"hidden-elements\\\"\\u003E\\u000a  \\u003Cdiv id=\\\"flash-preload\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Ciframe class=\\\"tweet-post-iframe\\\" name=\\\"tweet-post-iframe\\\"\\u003E\\u003C/iframe\\u003E\\u000a\\u000a  {{#include_tweet_dialog}}\\u000a  \\u000a  \\u003Cdiv id=\\\"inline-reply-tweetbox\\\"\\u003E\\u000a    {{\\u003Eswift_tweet_box}}\\u000a  \\u003C/div\\u003E\\u000a  {{/include_tweet_dialog}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{#include_direct_message_dialog}}\\u000a  {{\\u003Edialogs/dm_shell}}\\u000a{{/include_direct_message_dialog}}\\u000a\\u000a{{#include_tweet_dialog}}\\u000a  {{\\u003Edialogs/tweet_dialog}}\\u000a\\u000a{{/include_tweet_dialog}}\\u000a\\u000a{{\\u003Edialogs/goto_user_dialog}}\\u000a\\u000a{{#include_tweet_action_dialogs}}\\u000a  {{\\u003Edialogs/retweet_dialog}}\\u000a  {{\\u003Edialogs/delete_tweet_dialog}}\\u000a{{/include_tweet_action_dialogs}}\\u000a\\u000a{{\\u003Edialogs/keyboard_shortcuts_dialog}}\\u000a\\u000a{{#include_geo_picker}}\\u000a\\u000a  \\u000a  \\u000a\\u000a  {{^geo_enabled}} \\u000a    \\u003Cdiv id=\\\"geo-disabled-dropdown\\\"\\u003E\\u000a      {{\\u003Egeo/disabled_dropdown}}\\u000a    \\u003C/div\\u003E\\u000a  {{/geo_enabled}}\\u000a\\u000a  \\u003Cdiv id=\\\"geo-enabled-dropdown\\\"\\u003E\\u000a    {{\\u003Egeo/enabled_dropdown}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a{{/include_geo_picker}}\\u000a\\u000a{{#include_profile_popup}}\\u000a  {{\\u003Edialogs/profile_popup_container}}\\u000a  {{\\u003Edialogs/list_membership_dialog}}\\u000a  {{\\u003Edialogs/list_create_dialog}}\\u000a{{/include_profile_popup}}\\u000a\\u000a{{#include_activity_popup}}\\u000a  {{\\u003Edialogs/activity_popup_container}}\\u000a{{/include_activity_popup}}\\u000a\\u000a{{\\u003Edialogs/confirm_dialog}}\\u000a\\u000a{{^logged_in}}\\u000a  {{\\u003Edialogs/signin_or_signup_dialog}}\\u000a  {{\\u003Edialogs/sms_codes}}\\u000a{{/logged_in}}\",\n            head_scripts: \"{{#content_view}}\\u000a  {{#resolve_inline_redirects}}\\u000a  \\u003Cscript\\u003E\\u000a  (function() {\\u000a    var events = {{{active_events}}};\\u000a    {{{resolve_inline_redirects}}}\\u000a  }());\\u000a  \\u003C/script\\u003E\\u000a  {{/resolve_inline_redirects}}\\u000a{{/content_view}}\\u000a\\u000a\\u003Cscript\\u003E\\u000a  {{{watch_errors_source}}}\\u000a  {{{ttft_boot_data}}}\\u000a  {{{frame_busting_source}}}\\u000a\\u003C/script\\u003E\\u000a\\u000a{{#swift_action_queue}}\\u003Cscript\\u003E{{{swift_action_queue}}}\\u003C/script\\u003E{{/swift_action_queue}}\",\n            link_list: \"\\u003Cul\\u003E\\u000a  {{#links}}\\u000a    \\u003Cli\\u003E\\u000a      {{#href}}\\u003Ca href=\\\"{{href}}\\\"\\u003E{{text}}\\u003C/a\\u003E{{/href}}\\u000a      {{^href}}\\u003Cspan\\u003E{{text}}\\u003C/span\\u003E{{/href}}\\u000a    \\u003C/li\\u003E\\u000a    {{#separator}}\\u000a    \\u003Cli class=\\\"link-separator\\\"\\u003E{{{separator}}}\\u003C/li\\u003E\\u000a    {{/separator}}\\u000a  {{/links}}\\u000a\\u003C/ul\\u003E\",\n            link_simple_list: \"{{%IMPLICIT-ITERATOR iterator=link}}\\u000a\\u003Cul class=\\\"thumbs\\\"\\u003E\\u000a  {{#links}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{link}}\\\" target=\\\"_blank\\\"\\u003E{{link}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  {{/links}}\\u000a\\u003C/ul\\u003E\",\n            list_actions: \"\\u003Cdiv class=\\\"list-actions js-list-actions list-actions-{{id}}\\\"\\u003E\\u000a  {{#is_own_list}}\\u000a    \\u003Cdiv class=\\\"buttons\\\"\\u003E\\u000a      {{\\u003Eedit_list_button}}\\u000a      {{\\u003Edelete_list_button}}\\u000a    \\u003C/div\\u003E\\u000a  {{/is_own_list}}\\u000a  {{^is_own_list}}\\u000a    \\u003Cdiv class=\\\"follow-state\\\"\\u003E\\u000a      {{#following}}\\u000a        \\u003Cspan class=\\\"you-follow\\\"\\u003EFollowing \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u003C/span\\u003E\\u000a        \\u003Ca href='#' class=\\\"unfollow-list-link js-unfollow-list-action\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\"\\u003EUnfollow\\u003C/a\\u003E\\u000a      {{/following}}\\u000a      {{^following}}\\u000a        \\u003Cdiv class=\\\"button follow-list-button js-follow-list-action\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\"\\u003E\\u000a          \\u003Cspan class=\\\"plus\\\"\\u003E\\u003C/span\\u003E \\u003Cstrong\\u003EFollow this list\\u003C/strong\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/following}}\\u000a    \\u003C/div\\u003E\\u000a  {{/is_own_list}}\\u000a\\u003C/div\\u003E\",\n            list_dialog: \"{{%TRANSLATION-HINT mode=lists}}\\u000a\\u003Cdiv class=\\\"list-editor\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"field\\\"\\u003E\\u000a    \\u003Clabel for=\\\"list-name\\\"\\u003EList name\\u003C/label\\u003E\\u000a    \\u003Cinput type=\\\"text\\\" class=\\\"text\\\" name=\\\"name\\\" value=\\\"{{name}}\\\" /\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"field\\\" style=\\\"display:none\\\"\\u003E\\u000a    \\u003Clabel for=\\\"list-link\\\"\\u003EList link\\u003C/label\\u003E\\u000a    \\u003Cspan\\u003E{{full_name}}\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Chr/\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"field\\\"\\u003E\\u000a    \\u003Clabel for=\\\"description\\\"\\u003EDescription\\u003C/label\\u003E\\u000a    \\u003Ctextarea name=\\\"description\\\"\\u003E{{description}}\\u003C/textarea\\u003E\\u000a    \\u003Cspan class=\\\"help-text\\\"\\u003EUnder 100 characters, optional\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Chr/\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"field\\\"\\u003E\\u000a    \\u003Clabel for=\\\"mode\\\"\\u003EPrivacy\\u003C/label\\u003E\\u000a    \\u003Cdiv class=\\\"options\\\"\\u003E\\u000a      \\u003Clabel for=\\\"list-public-radio\\\"\\u003E\\u000a        \\u003Cinput class=\\\"radio\\\" type=\\\"radio\\\" name=\\\"mode\\\" id=\\\"list-public-radio\\\" value=\\\"public\\\" {{#swift}}checked=\\\"checked\\\"{{/swift}} {{^swift}}{{#is_public}}checked=\\\"checked\\\"{{/is_public}}{{/swift}} /\\u003E\\u000a        \\u003Cb\\u003EPublic\\u003C/b\\u003E &middot; Anyone can follow this list\\u000a      \\u003C/label\\u003E\\u000a      \\u003Clabel for=\\\"list-private-radio\\\"\\u003E\\u000a        \\u003Cinput class=\\\"radio\\\" type=\\\"radio\\\" name=\\\"mode\\\" id=\\\"list-private-radio\\\" value=\\\"private\\\" {{^swift}}{{^is_public}}checked=\\\"checked\\\"{{/is_public}}{{/swift}} /\\u003E\\u000a        \\u003Cb\\u003EPrivate\\u003C/b\\u003E &middot; Only you can access this list\\u000a      \\u003C/label\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Chr/\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"list-editor-save\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"button btn btn-primary update-list-button\\\" data-list-id=\\\"{{id}}\\\"\\u003ESave list\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\",\n            list_follow_actions: \"{{#is_own_list}}\\u000a  \\u003Ca class=\\\"btn js-edit-list-action\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\" title=\\\"Edit\\\"\\u003E\\u000a    Edit\\u000a  \\u003C/a\\u003E\\u000a\\u000a  \\u003Ca class=\\\"btn js-delete-list-action\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\" title=\\\"Delete\\\"\\u003E\\u000a    Delete\\u000a  \\u003C/a\\u003E\\u000a{{/is_own_list}}\\u000a\\u000a{{^is_own_list}}\\u000a  \\u003Ca class=\\\"btn subscribe-btn {{^following}}not-{{/following}}subscribed {{^following}}js-follow-list-action{{/following}} {{#following}}js-unfollow-list-action{{/following}}\\\" data-screen-name=\\\"{{#user}}{{screen_name}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"subscribe-text\\\"\\u003E\\u000a      \\u003Ci class=\\\"subscribe-text\\\"\\u003E\\u003C/i\\u003E\\u000a      Subscribe\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"remove-text\\\"\\u003E\\u000a      Unsubscribe from list\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a{{/is_own_list}}\",\n            list_follow_card: \"\\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a    \\u003Ch1 class=\\\"js-list-name\\\"\\u003E{{name}}\\u003C/h1\\u003E\\u000a    \\u003Cp class=\\\"metadata\\\"\\u003E\\u000a    {{#is_public}}\\u000a      A public list by\\u000a    {{/is_public}}\\u000a    {{^is_public}}\\u000a      A private list by\\u000a    {{/is_public}}\\u000a    {{#user}}\\u003Ca href=\\\"{{profile_path}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003Ca class=\\\"list-author\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u003Cimg class=\\\"avatar size32 \\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u003C/a\\u003E\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module-inner description\\\"\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Elist_follow_card_stats}}\\u000a\\u000a{{#logged_in}}\\u000a  \\u003Cdiv class=\\\"follow-card-footer\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"follow-bar js-list-actions\\\"\\u003E\\u000a      {{\\u003Elist_follow_actions}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/logged_in}}\\u000a\",\n            list_follow_card_stats: \"\\u003Cul class=\\\"stats\\\"\\u003E\\u000a  \\u003Cli\\u003E\\u003Ca href=\\\"{{list_members_path}}\\\"\\u003E\\u003Cstrong\\u003E{{member_count}}\\u003C/strong\\u003E Members\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003Cli\\u003E\\u003Ca href=\\\"{{list_subscribers_path}}\\\"\\u003E\\u003Cstrong\\u003E{{subscriber_count}}\\u003C/strong\\u003E Subscribers\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            list_header: \"\\u003Cdiv class=\\\"list-info\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"full-name\\\"\\u003E{{name}}\\u003C/h2\\u003E\\u000a  \\u003Cp class=\\\"description\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a  \\u003Chr/\\u003E\\u000a  \\u003Cdiv class=\\\"things-below-the-hr\\\"\\u003E\\u000a    \\u003Cdiv class='list-creator clearfix'\\u003E\\u000a      {{#user}}\\u000a        \\u003Cimg id='profile-picture' src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"/\\u003E\\u000a      {{/user}}\\u000a      \\u003Cp\\u003E\\u000a        {{#is_public}}\\u000a          A \\u003Cstrong\\u003Epublic\\u003C/strong\\u003E list\\u000a        {{/is_public}}\\u000a        {{^is_public}}\\u000a          A \\u003Cstrong\\u003Eprivate\\u003C/strong\\u003E list\\u000a        {{/is_public}}\\u000a        \\u003Cbr /\\u003E\\u000a        {{#user}}\\u000a          \\u003Cspan\\u003ECurated by \\u003Ca href=\\\"{{profile_path}}\\\"\\u003E{{name}}\\u003C/span\\u003E\\u003C/a\\u003E\\u000a        {{/user}}\\u000a      \\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#logged_in}}\\u000a      \\u003Cdiv class=\\\"list-actions-component\\\"\\u003E\\u000a        {{\\u003Elist_actions}}\\u000a      \\u003C/div\\u003E\\u000a    {{/logged_in}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003C!-- todo: put the list actions here with display:none rather than appending them in js ( twttr.components.pages.List.renderListInfo() ) --\\u003E\",\n            list_link: \"\\u003Cspan class=\\\"list\\\"\\u003E\\u003Ca class=\\\"pretty-link twitter-timeline-link list-link\\\" data-list-id=\\\"{{id}}\\\" href=\\\"{{user_list_path}}\\\" title=\\\"{{full_name}}\\\"\\u000a  \\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{full_name_sans_at}}\\u003C/b\\u003E\\u003C/a\\u003E\\u003C/span\\u003E\",\n            list_membership_content: \"\\u003Cdiv class=\\\"add-to-list-prompt {{#has_lists}}has-lists{{/has_lists}}\\\"\\u003E\\u000a  \\u003Cp\\u003EInclude \\u003Cspan class=\\\"pretty-link\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{#user}}{{screen_name}}{{/user}}\\u003C/b\\u003E\\u003C/span\\u003E in:\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cul class=\\\"list-membership-container\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\"\\u003E\\u000a  {{#items}}\\u000a    {{\\u003Echeckbox_list_item}}\\u000a  {{/items}}\\u000a  \\u003Cli class=\\\"btn create-a-list\\\"\\u003ECreate a list\\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            list_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{{noscript}}}\\u000a    {{#list}}\\u000a      \\u003Cdiv class=\\\"list-header user-sidebar-color\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"js-list-header-container\\\"\\u003E\\u000a          {{\\u003Elist_header}}\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a          {{\\u003Elist_stream_tabs}}\\u000a        \\u003C/ul\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{\\u003Estream_manager}}\\u000a    {{/list}}\\u000a  {{{end_noscript}}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u003C/div\\u003E\\u000a{{\\u003Edetails_pane_container}}\",\n            list_stream_tabs: \"\\u003Cli class=\\\"stream-tab stream-tab-tweets {{#active_tab_tweets}}active{{/active_tab_tweets}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_list_path}}\\\"\\u003ETweets\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\\u003Cli class=\\\"stream-tab stream-tab-members {{#active_tab_members}}active{{/active_tab_members}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"tab-text\\\" href=\\\"{{list_members_path}}\\\"\\u003EFollowing: \\u003Cstrong\\u003E{{member_count}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\\u003Cli class=\\\"stream-tab stream-tab-followers {{#active_tab_followers}}active{{/active_tab_followers}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"tab-text\\\" href=\\\"{{list_subscribers_path}}\\\"\\u003EFollowers: \\u003Cstrong\\u003E{{subscriber_count}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            list_stream_title: \"\\u003Cspan\\u003E\\u000a  {{full_name}}\\u000a\\u003C/span\\u003E\\u000a{{#showTitleLink}}\\u000a  \\u003Ca class='go-to-list-page' href='{{user_list_path}}'\\u003E\\u000a    View list page &rarr;\\u000a  \\u003C/a\\u003E\\u000a{{/showTitleLink}}\",\n            lists_stream_view_toggler: \"{{\\u003Estream_view_toggler}}\",\n            local_trend_location: \"\\u003Cdd\\u003E\\u003Ca href='#' data-woeid=\\\"{{woeid}}\\\"\\u003E{{name}}\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/dd\\u003E\",\n            local_trend_location_new: \"\\u003Cli\\u003E\\u000a  \\u003Ca href=\\\"#\\\" class=\\\"trends-location-item js-trend-link\\\" data-woeid=\\\"{{woeid}}\\\"\\u003E\\u000a    {{name}}\\u000a    \\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            local_trends: \"\\u003Cdl class=\\\"local-trends-list\\\"\\u003E\\u000a  \\u003Cdt\\u003ECountries\\u003C/dt\\u003E\\u000a  {{#country_locations}}\\u000a    {{\\u003Elocal_trend_location}}\\u000a  {{/country_locations}}\\u000a\\u003C/dl\\u003E\\u000a\\u003Cdl class=\\\"local-trends-list\\\"\\u003E\\u000a  \\u003Cdt\\u003ECities\\u003C/dt\\u003E\\u000a  {{#city_locations}}\\u000a    {{\\u003Elocal_trend_location}}\\u000a  {{/city_locations}}\\u000a\\u003C/dl\\u003E\\u000a\",\n            local_trends_new: \"{{#show_personalized}}\\u000a  {{\\u003Etrends_personalized_dialog}}\\u000a{{/show_personalized}}\\u000a{{^show_personalized}}\\u000a  \\u003Cdiv class=\\\"trends-breadcrumb\\\"\\u003E\\u000a    {{\\u003Etrends_dialog_breadcrumbs}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"trends-locations clearfix\\\"\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations0}}\\u000a        {{\\u003Elocal_trend_location_new}}\\u000a      {{/locations0}}\\u000a    \\u003C/ul\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations1}}\\u000a        {{\\u003Elocal_trend_location_new}}\\u000a      {{/locations1}}\\u000a    \\u003C/ul\\u003E\\u000a    \\u003Cul class=\\\"trends-locations-list\\\"\\u003E\\u000a      {{#locations2}}\\u000a        {{\\u003Elocal_trend_location_new}}\\u000a      {{/locations2}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/show_personalized}}\",\n            login_page: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"signin-wrapper\\\" data-login-message=\\\"{{show_must_login_message}}\\\"\\u003E\\u000a    \\u003Ch1\\u003ESign in to Twitter\\u003C/h1\\u003E\\u000a    \\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"clearfix signin js-signin\\\" method=\\\"post\\\"\\u003E\\u000a      {{\\u003Esignin_form_textbox}}\\u000a      \\u003Cdiv class=\\\"captcha js-captcha\\\"\\u003E\\u000a        {{#should_render_captcha}}\\u000a          {{\\u003Eshared/captcha}}\\u000a        {{/should_render_captcha}}\\u000a      \\u003C/div\\u003E\\u000a      {{\\u003Esignin_form_subchck}}\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"clearfix mobile has-sms\\\"\\u003E\\u000a    \\u003Cp class=\\\"mobile-helper\\\"\\u003E\\u000a      Already using Twitter via text message?\\u000a      \\u003Ca href=\\\"{{mobile_complete_path}}\\\"\\u003EActivate your account&#32;&raquo;\\u003C/a\\u003E\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            logout_page: \"\\u003Cdiv class=\\\"page-canvas signout-page\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"signout-wrapper\\\"\\u003E\\u000a    \\u003Cform action=\\\"{{logout_action_path}}\\\" class=\\\"signout\\\" method=\\\"post\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a      \\u003Ch1\\u003E\\u003Cstrong\\u003ESign out\\u003C/strong\\u003E of Twitter?\\u003C/h1\\u003E\\u000a      \\u003Cdiv class=\\\"buttons-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"buttons\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"btn cancel\\\"\\u003ECancel\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"btn primary-btn js-submit\\\"\\u003ESign out\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"aside\\\"\\u003E\\u000a        \\u003Cp\\u003E\\u000a          You can always sign back in at any time.\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            machine_translated_tweet: \"\\u003Cdiv class=\\\"machine-translated-tweet js-machine-translated-tweet\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"machine-translated-text\\\"\\u003E{{{translated_text}}}\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"machine-translated-meta\\\"\\u003E{{{attribution}}}\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            malware_error_message: \"{{#is_dm}}\\u000a  Oops! A URL in your message appears to link to a page that has spammy or unsafe content.\\u000a{{/is_dm}}\\u000a{{^is_dm}}\\u000a  Oops! A URL in your Tweet appears to link to a page that has spammy or unsafe content.\\u000a{{/is_dm}}\\u000a\\u003Ca href=\\\"{{malware_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            matched_contact_user: \"\\u003Cdiv class=\\\"stream-item-content find-friends-result js-actionable-user\\\" data-user-id=\\\"{{id}}\\\" data-screen-name=\\\"{{screen_name}}\\\" {{{feedback_token}}}\\u003E\\u000a  \\u003Ca class=\\\"account-group js-account-group\\\" data-user-id=\\\"{{id}}\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u000a    \\u003Cimg class=\\\"avatar size128\\\" src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a    \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a    \\u003Csmall class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a      {{#verified}}\\u000a        \\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E\\u000a      {{/verified}}\\u000a      {{#protected}}\\u000a        \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a      {{/protected}}\\u000a    \\u003C/small\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u000a  \\u003Cspan class=\\\"small-follow-all-wrapper\\\"\\u003E\\u000a    {{\\u003Ecombo_follow_button}}\\u000a  \\u003C/span\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            events_media_photo: \"\\u003Ca href=\\\"{{url}}\\\" target=\\\"_blank\\\" data-status-id=\\\"{{status_id}}\\\" data-href=\\\"{{url}}\\\" data-url=\\\"{{media_url}}\\\" {{#resolved_url}}data-resolved-url-medium=\\\"{{resolved_url}}\\\"{{/resolved_url}}  {{#resolved_url_large}}data-resolved-url-large=\\\"{{resolved_url_large}}\\\"{{/resolved_url_large}} class=\\\"media-thumbnail\\\"\\u003E\\u003C/a\\u003E\",\n            events_media_thumbnails: \"\\u003Cdiv class=\\\"photo-strip\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"inner-shadow\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cul class=\\\"photo-list\\\"\\u003E\\u000a    {{#items}}\\u000a      {{\\u003Emedia/events_media_photo}}\\u000a    {{/items}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            grid_layout_media_thumbnails: \"\\u003Cdiv class=\\\"module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    &nbsp;\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            media_photo: \"\\u003Cspan data-href=\\\"{{url}}\\\" data-url=\\\"{{media_url}}\\\" {{#resolved_url}}data-resolved-url-small=\\\"{{resolved_url}}\\\"{{/resolved_url}} class=\\\"media-thumbnail\\\" data-type=\\\"photo\\\"\\u003E\\u003C/span\\u003E\\u000a\",\n            media_thumbnails: \"\\u003Cli class=\\\"media-thumbnails {{#class_name}}{{class_name}}{{/class_name}} {{#is_video}}media-videos{{/is_video}}\\\"\\u003E\\u000a  {{\\u003Emedia/media_thumbnails_inner}}\\u000a\\u003C/li\\u003E\",\n            media_thumbnails_inner: \"\\u003Ca href=\\\"{{view_all_path}}\\\" class=\\\"list-link\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media-header\\\"\\u003E\\u000a    {{title}}\\u000a    \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"media-row\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"media-row-content\\\"\\u003E\\u000a      {{#items}}\\u000a        {{#is_video}}\\u000a          {{\\u003Emedia/media_video}}\\u000a        {{/is_video}}\\u000a        {{^is_video}}\\u000a          {{\\u003Emedia/media_photo}}\\u000a        {{/is_video}}\\u000a      {{/items}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/a\\u003E\",\n            media_video: \"\\u003Cspan data-href=\\\"{{url}}\\\" data-url=\\\"{{media_url}}\\\" {{#resolved_url}}data-resolved-url=\\\"{{resolved_url}}\\\"{{/resolved_url}} class=\\\"media-thumbnail video\\\" data-type=\\\"video\\\"\\u003E\\u000a  \\u003Ci class=\\\"play\\\"\\u003E\\u003C/i\\u003E\\u000a\\u003C/span\\u003E\",\n            media_attribution: \"\\u003Cdiv class='media-attribution'\\u003E\\u000a  \\u003Cimg src='{{icon_url}}'/\\u003E\\u000a  \\u003Ca target='_blank' data-media-type='{{media_type}}' class='media-attribution-link' href='{{url}}'\\u003E\\u000a    {{title}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            media_gallery_controls: \"\\u003Cdiv class=\\\"media-gallery-controls\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media-gallery-back-nav\\\"\\u003E&larr; \\u003Cspan\\u003E{{back_text}}\\u003C/span\\u003E\\u003C/div\\u003E\\u000a{{#is_search}}\\u000a  \\u003Cdiv class=\\\"media-gallery-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"media-gallery-bird\\\"\\u003E\\u003C/span\\u003E\\u000a    {{#mode_photos}}\\u000a      \\u003Cspan\\u003ETop images for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\\u003C/span\\u003E\\u000a    {{/mode_photos}}\\u000a    {{#mode_videos}}\\u000a      \\u003Cspan\\u003ETop videos for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\\u003C/span\\u003E\\u000a    {{/mode_videos}}\\u000a    \\u003Cdiv class=\\\"media-gallery-loading\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/is_search}}\\u000a{{#is_usermedia}}\\u000a  \\u003Cdiv class=\\\"media-gallery-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"media-gallery-bird\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan\\u003ERecent images by \\u003Ca class=\\\"controls-profile-link\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u003Cem class=\\\"at\\\"\\u003E@\\u003C/em\\u003E{{screen_name}}\\u003C/a\\u003E\\u003C/span\\u003E\\u000a    \\u003Cdiv class=\\\"media-gallery-loading\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/is_usermedia}}\\u000a\\u000a  {{^disable_grid}}\\u000a  \\u003Cdiv class=\\\"media-gallery-buttons {{#disable_thumbs}}no-thumbs{{/disable_thumbs}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"toggle-set\\\"\\u003E\\u000a      \\u003Cdiv title=\\\"View detail\\\" class=\\\"toggle-button detailview {{#is_detail_view}}selected{{/is_detail_view}}\\\"\\u003E\\u000a        \\u003Cspan\\u003E\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"divider\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv title=\\\"View all\\\" class=\\\"toggle-button gridview {{#is_grid_view}}selected{{/is_grid_view}}\\\"\\u003E\\u000a        \\u003Cspan\\u003E\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{/disable_grid}}\\u000a\\u003C/div\\u003E\\u000a\",\n            media_gallery_no_results: \"\\u003Cdiv class=\\\"media-gallery-no-results\\\"\\u003E\\u000a  {{#is_search}}\\u000a    {{#mode_photos}}\\u000a      Sorry, there are no top images for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E.\\u000a    {{/mode_photos}}\\u000a    {{#mode_videos}}\\u000a      Sorry, there are no top videos for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E.\\u000a    {{/mode_videos}}\\u000a  {{/is_search}}\\u000a  {{#is_usermedia}}\\u000a    Sorry, there are no recent images for \\u003Cem\\u003E@\\u003C/em\\u003E{{screen_name}}.\\u000a  {{/is_usermedia}}\\u000a\\u003C/div\\u003E\\u000a\",\n            media_gallery_page: \"\\u003Cdiv class='media-gallery-overlay'\\u003E\\u000a  \\u003Cdiv class='media-gallery-content'\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            media_not_displayed: \"{{^rendering_on_server}}\\u000a\\u003Cdiv class='media-not-displayed'\\u003E\\u000a  \\u003Ch2\\u003EWe can't show you everything!\\u003C/h2\\u003E\\u000a\\u000a  {{#logged_in}}\\u000a    {{#possibly_sensitive}}\\u000a      \\u003Cp\\u003EYour \\u003Ca href=\\\"{{settings_path}}\\\" target=\\\"_blank\\\"\\u003Emedia display settings\\u003C/a\\u003E are set up to hide photos and videos that might contain sensitive content.\\u003C/p\\u003E\\u000a    {{/possibly_sensitive}}\\u000a    {{^possibly_sensitive}}\\u000a      {{#not_following}}\\u000a        \\u003Cp\\u003EYour \\u003Ca href=\\\"{{settings_path}}\\\" target=\\\"_blank\\\"\\u003Emedia display settings\\u003C/a\\u003E are set up to hide photos and videos from people you don't follow.\\u003C/p\\u003E\\u000a      {{/not_following}}\\u000a    {{/possibly_sensitive}}\\u000a    \\u003Cp\\u003ELucky for you, that's easy to \\u003Ca href=\\\"{{settings_path}}\\\" target=\\\"_blank\\\"\\u003Echange\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a  {{/logged_in}}\\u000a\\u000a  {{^logged_in}}\\u000a    {{#possibly_sensitive}}\\u000a      \\u003Cp\\u003EWe automatically hide photos and videos that might contain sensitive content.\\u003C/p\\u003E\\u000a    {{/possibly_sensitive}}\\u000a   \\u003Cp\\u003ESign in to apply your media display settings. Don't have an account? \\u003Ca href=\\\"{{signup_path}}\\\" target=\\\"_blank\\\"\\u003ESign up!\\u003C/a\\u003E\\u003C/p\\u003E\\u000a  {{/logged_in}}\\u000a\\u000a  \\u003Cdiv class=\\\"btn button display-this-media\\\"\\u003E\\u000a    Display this\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{#logged_in}}\\u000a    &middot;\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"always-display-media\\\"\\u003EAlways display media like this.\\u003C/a\\u003E\\u000a  {{/logged_in}}\\u000a\\u003C/div\\u003E\\u000a{{/rendering_on_server}}\\u000a{{#rendering_on_server}}\\u000a\\u003Cdiv class=\\\"media-not-displayed\\\"\\u003E\\u000a  \\u003Ch2\\u003EWe can't show you everything!\\u003C/h2\\u003E\\u000a\\u000a  {{#logged_in}}\\u000a    \\u003Cp\\u003EYour \\u003Ca href=\\\"{{settings_path}}\\\" target=\\\"_blank\\\"\\u003Emedia display settings\\u003C/a\\u003E are set up to hide photos and videos that might contain sensitive content.\\u003C/p\\u003E\\u000a    \\u003Cp\\u003ELucky for you, that's easy to \\u003Ca href=\\\"{{settings_path}}\\\" target=\\\"_blank\\\"\\u003Echange\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a  {{/logged_in}}\\u000a\\u000a  {{^logged_in}}\\u000a    \\u003Cp\\u003EWe automatically hide photos and videos that might contain sensitive content.\\u003C/p\\u003E\\u000a    \\u003Cp\\u003ESign in to apply your media display settings. Don't have an account? \\u003Ca href=\\\"/signup\\\" target=\\\"_blank\\\"\\u003ESign up!\\u003C/a\\u003E\\u003C/p\\u003E\\u000a  {{/logged_in}}\\u000a\\u000a  \\u003Cbutton type=\\\"button\\\" class=\\\"btn display-this-media\\\"\\u003E\\u000a    Display this\\u000a  \\u003C/button\\u003E\\u000a\\u000a  {{#logged_in}}\\u000a    &middot;\\u000a    \\u003Cbutton type=\\\"button\\\" class=\\\"btn-link always-display-media\\\"\\u003EAlways display media like this.\\u003C/button\\u003E\\u000a  {{/logged_in}}\\u000a\\u003C/div\\u003E\\u000a{{/rendering_on_server}}\",\n            media_slideshow: \"\\u003Cdiv class=\\\"media-slideshow-wrapper\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media-slideshow-thumbnails\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"media-slideshow-content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"media-slideshow-pictures\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"media-slideshow-picture\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"media-slideshow-media-container\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"media-control-button prev\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"media-control-button-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"media-control-button next\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"media-control-button-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"media-slideshow-tweet\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            media_slideshow_not_found: \"\\u003Cdiv class=\\\"media-slideshow-not-found\\\"\\u003E\\u000a  Sorry, we couldn't find that!\\u000a\\u003C/div\\u003E\\u000a\",\n            media_type_container: \"\\u003Cdiv class=\\\"media-instance-container {{media_type_class}}-container\\\" data-url-id=\\\"{{url}}\\\" data-media-type=\\\"{{media_type}}\\\"\\u003E\\u003C/div\\u003E\",\n            mentioned_in_tweet: \"\\u003Cdiv class=\\\"mentioned-in-tweet\\\"\\u003E\\u000a  \\u003Ch3\\u003EMentioned in this Tweet\\u003C/h3\\u003E\\u000a  \\u003Cul class=\\\"clearfix\\\"\\u003E\\u000a  {{#mentioned_users}}\\u000a    {{\\u003Euser_detailed_list}}\\u000a  {{/mentioned_users}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mentions_stream_view_toggler: \"{{\\u003Estream_view_toggler}}\",\n            message: \"\\u003Cdiv class=\\\"js-message message-item message-temp\\\" data-message-id=\\\"{{id}}\\\" data-thread-id=\\\"{{thread_id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"message-inner\\\"\\u003E\\u000a    {{#sender}}\\u000a    \\u003Cimg src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"thumb user-profile-link\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Cspan class=\\\"user-name\\\"\\u003E\\u000a      {{\\u003Emessage_user_name}}\\u000a    \\u003C/span\\u003E\\u000a    {{/sender}}\\u000a    \\u003Cdiv class=\\\"message-content\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"linked-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"message-footer\\\"\\u003E\\u000a        \\u003Cspan class=\\\"created-at\\\"\\u003E\\u003Cspan class=\\\"_timestamp\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\" data-include-sec=\\\"true\\\"\\u003E{{timestamp}}\\u003C/span\\u003E\\u003C/span\\u003E\\u000a        \\u003Ca class=\\\"js-delete-message delete-action\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"icon delete-icon\\\"\\u003E\\u003C/span\\u003E \\u003Cb\\u003EDelete\\u003C/b\\u003E\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            message_drawer_outer: \"\\u003Cdiv class=\\\"alert-messages {{#content_view}}{{#hide_message_drawer}}hidden{{/hide_message_drawer}}{{/content_view}}\\\" id=\\\"message-drawer\\\"\\u003E\\u000a  {{#content_view}}\\u000a    {{\\u003Emessage_drawer}}\\u000a  {{/content_view}}\\u000a\\u003C/div\\u003E\\u000a\",\n            message_thread: \"\\u003Cdiv class=\\\"messages-pane js-modal-scrollable js-twttr-dialog-not-draggable\\\" data-thread-id=\\\"{{thread_id}}\\\"\\u003E\\u000a  {{#items}}\\u000a    {{\\u003Emessage}}\\u000a  {{/items}}\\u000a\\u003C/div\\u003E\\u000a\",\n            message_thread_preview: \"\\u003Cdiv class=\\\"js-message message-item message-temp {{#has_new_message}} new-messages{{/has_new_message}}\\\" data-modal=\\\"message-thread\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"status\\\"\\u003E\\u000a    \\u003Ci class=\\\"unread private\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Csmall class=\\\"time\\\"\\u003E\\u000a        {{#last_message}}\\u003Ca href=\\\"#\\\"\\u003E{{timestamp}}\\u003C/a\\u003E{{/last_message}}\\u000a      \\u003C/small\\u003E\\u000a      \\u003Cdiv\\u003E\\u000a        {{#other_person}}\\u000a          \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"/\\u003E\\u000a          \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a          \\u003Cspan class=\\\"username\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E\\u000a        {{/other_person}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"js-last-message-text\\\"\\u003E{{#last_message}}{{text}}{{/last_message}}\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            message_user_name: \"\\u003Cspan class=\\\"user-profile-name\\\" title='{{name}}'\\u003E{{screen_name}}\\u003C/span\\u003E\\u000a\",\n            messages_page: \"\\u003Cdiv class=\\\"main-content messages-main-content\\\"\\u003E\\u000a  {{{noscript}}}\\u000a    \\u003Cdiv class=\\\"messages-header header\\\"\\u003E\\u000a      \\u003Ch1\\u003EMessages\\u003C/h1\\u003E\\u003Cdiv class=\\\"new-message-button js-new-message-button button\\\"\\u003ENew Message\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Estream_manager}}\\u000a  {{{end_noscript}}}\\u000a\\u003C/div\\u003E\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            mini_current_user: \"\\u000a\\u003Ca href=\\\"\\u000a  {{#site_header_with_profile_tab}}{{profile_info_path}}{{/site_header_with_profile_tab}}\\u000a  {{^site_header_with_profile_tab}}{{profile_path}}{{/site_header_with_profile_tab}}\\\"\\u000a   class=\\\"account-summary account-summary-small\\\"\\u000a   data-nav=\\\"{{#site_header_with_profile_tab}}edit_profile{{/site_header_with_profile_tab}}{{^site_header_with_profile_tab}}profile{{/site_header_with_profile_tab}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"account-group js-mini-current-user\\\" data-user-id=\\\"{{id}}\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E\\u000a      \\u003Cimg class=\\\"avatar size32\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a      \\u003Csmall class=\\\"metadata\\\"\\u003E\\u000a          {{#site_header_with_profile_tab}}Edit profile{{/site_header_with_profile_tab}}\\u000a          {{^site_header_with_profile_tab}}View my profile page{{/site_header_with_profile_tab}}\\u000a      \\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/a\\u003E\",\n            mini_home_profile: \"\\u003Cdiv class=\\\"module mini-profile\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"flex-module profile-summary js-profile-summary\\\"\\u003E\\u000a    {{#user}}\\u000a      {{\\u003Emini_current_user}}\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{^short_profile}}\\u000a    \\u003Cdiv class=\\\"js-mini-profile-stats-container\\\"\\u003E\\u000a      {{#rendering_on_server}}\\u000a        {{#stats}}\\u000a          {{\\u003Emini_profile_stats}}\\u000a        {{/stats}}\\u000a      {{/rendering_on_server}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#swift}}\\u000a      \\u003Cdiv class=\\\"home-tweet-box tweet-box component tweet-user\\\"\\u003E\\u000a        {{\\u003Eswift_tweet_box}}\\u000a      \\u003C/div\\u003E\\u000a    {{/swift}}\\u000a    {{^swift}}\\u000a      {{#rendering_on_server}}\\u000a        \\u003Cdiv class=\\\"component tweet-user tweetbox-placeholder\\\"\\u003E\\u003C/div\\u003E\\u000a      {{/rendering_on_server}}\\u000a    {{/swift}}\\u000a  {{/short_profile}}\\u000a\\u003C/div\\u003E\\u000a\",\n            mini_profile_stats: \"{{#swift}}\\u000a  \\u003Cul class=\\\"stats js-mini-profile-stats\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{profile_path}}\\\" data-element-term=\\\"tweet_stats\\\" data-nav='profile'\\u003E{{{tweet_stat}}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{following_path}}\\\" data-element-term=\\\"following_stats\\\" data-nav='following'\\u003E{{{following_stat}}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{followers_path}}\\\" data-element-term=\\\"follower_stats\\\" data-nav='followers'\\u003E{{{follower_stat}}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a{{/swift}}\\u000a{{^swift}}\\u000a  \\u003Cul class=\\\"stats js-mini-profile-stats\\\"\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{profile_path}}\\\" data-element-term=\\\"tweet_stats\\\" data-nav='profile'\\u003E\\u000a      \\u000a        {{#statuses_count_one}}\\u003Cstrong\\u003E{{statuses_count_commaized}}\\u003C/strong\\u003E Tweet{{/statuses_count_one}}\\u000a        {{#statuses_count_other}}\\u003Cstrong\\u003E{{statuses_count_commaized}}\\u003C/strong\\u003E Tweets{{/statuses_count_other}}\\u000a      \\u000a    \\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{#is_current_user}}{{following_path}}{{/is_current_user}}{{^is_current_user}}{{user_following_path}}{{/is_current_user}}\\\" data-element-term=\\\"following_stats\\\" data-nav='following'\\u003E\\u003Cstrong\\u003E{{friends_count_commaized}}\\u003C/strong\\u003E Following\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{#is_current_user}}{{followers_path}}{{/is_current_user}}{{^is_current_user}}{{user_followers_path}}{{/is_current_user}}\\\" data-element-term=\\\"follower_stats\\\" data-nav='followers'\\u003E\\u003Cstrong\\u003E{{followers_count_commaized}}\\u003C/strong\\u003E Followers\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a{{/swift}}\",\n            mini_profile_user: \"\\u003Cdiv class=\\\"account-summary\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-account-group js-bubble-event\\\" href=\\\"{{profile_path}}\\\" data-element-term=\\\"view_profile_link\\\"\\u003E\\u000a      \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a    \\u003C/a\\u003E\\u000a    {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a    \\u003Csmall class=\\\"metadata\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-screen-name\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a      {{^is_current_user}}\\u000a        \\u003Cspan class=\\\"js-follows-you maybe-follows-you\\\"\\u003Efollows you\\u003C/span\\u003E\\u000a      {{/is_current_user}}\\u000a      {{#protected}}\\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/protected}}\\u000a    \\u003C/small\\u003E\\u000a    {{^rendering_on_server}}{{#location}}\\u003Csmall class=\\\"location js-profile-location\\\"\\u003E{{location}}\\u003C/small\\u003E{{/location}}{{/rendering_on_server}}\\u000a    \\u003Csmall\\u003E\\u003Ca class=\\\"view-profile js-mini-profile-user\\\" href=\\\"{{profile_path}}\\\" data-element-term=\\\"view_profile_link\\\"\\u003E\\u000a      {{#is_current_user}}\\u000a        View your profile page\\u000a      {{/is_current_user}}\\u000a      {{^is_current_user}}\\u000a        View @{{screen_name}}'s profile page\\u000a      {{/is_current_user}}\\u000a    \\u003C/a\\u003E\\u003C/small\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mini_scribe: \"\\u000afunction miniScribe(eName,more,cat){\\u000avar log=[],cat=cat||'client_event',more=more||{};more.event_name=eName;for(var k in more){log.push('\\\"'+k+'\\\":\\\"'+more[k]+'\\\"');};\\u000a(new Image()).src='{{scribe_path}}?category='+encodeURIComponent(cat)+'&log='+encodeURIComponent('{'+log.join(',')+'}')+'&ts='+(+new Date);\\u000a}\",\n            mini_social_proof: \"\\u003Cp class=\\\"social-proof\\\"\\u003E\\u000a  {{#mini_social_proof_context}}\\u000a    {{#shared_count_1}}\\u000a      Followed by {{#follower_0}}{{\\u003Emini_social_proof_link}}{{/follower_0}}.\\u000a    {{/shared_count_1}}\\u000a    {{#shared_count_2}}\\u000a      Followed by {{#follower_0}}{{\\u003Emini_social_proof_link}}{{/follower_0}} and\\u000a      {{#follower_1}}{{\\u003Emini_social_proof_link}}{{/follower_1}}.\\u000a    {{/shared_count_2}}\\u000a    {{#shared_count_3}}\\u000a      Followed by {{#follower_0}}{{\\u003Emini_social_proof_link}}{{/follower_0}},\\u000a      {{#follower_1}}{{\\u003Emini_social_proof_link}}{{/follower_1}} and\\u000a      {{#follower_2}}{{\\u003Emini_social_proof_link}}{{/follower_2}}.\\u000a    {{/shared_count_3}}\\u000a    {{#shared_count_4}}\\u000a      Followed by {{#follower_0}}{{\\u003Emini_social_proof_link}}{{/follower_0}},\\u000a      {{#follower_1}}{{\\u003Emini_social_proof_link}}{{/follower_1}},\\u000a      {{#follower_2}}{{\\u003Emini_social_proof_link}}{{/follower_2}} and\\u000a      {{#follower_3}}{{\\u003Emini_social_proof_link}}{{/follower_3}}.\\u000a    {{/shared_count_4}}\\u000a    {{#shared_count_more}}\\u000a      Followed by {{#follower_0}}{{\\u003Emini_social_proof_link}}{{/follower_0}},\\u000a      {{#follower_1}}{{\\u003Emini_social_proof_link}}{{/follower_1}},\\u000a      {{#follower_2}}{{\\u003Emini_social_proof_link}}{{/follower_2}} and\\u000a      \\u003Ca href=\\\"{{followers_you_follow_url}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003E{{remaining_follower_count}} others\\u003C/b\\u003E\\u003C/a\\u003E.\\u000a    {{/shared_count_more}}\\u000a  {{/mini_social_proof_context}}\\u000a\\u003C/p\\u003E\\u000a\",\n            mini_social_proof_link: \"\\u003Ca href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\" class=\\\"show-popup-with-id\\\"\\u003E{{name}}\\u003C/a\\u003E\",\n            apps: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"gallery-link\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{mobile_gallery_path}}{{lang_param}}\\\"\\u003E&larr; Back to Mobile\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"mobile-gallery-app mobile-gallery-{{app_id}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"mobile-gallery-app-wrapper\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"app-header\\\"\\u003E\\u000a        \\u003Ch2\\u003E{{app_short_name}}\\u003C/h2\\u003E\\u000a        \\u003Cp class=\\\"compatibility\\\"\\u003E{{compatibility}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"actions actions-single yes-script {{^no_camera}} qr-code-actions {{/no_camera}}\\\"\\u003E\\u000a{{#app_link}}\\u000a        \\u003Cdiv class=\\\"app-link\\\"\\u003E\\u000a          \\u003Cp\\u003EURL:\\u003C/p\\u003E\\u000a          \\u003Ca href=\\\"{{app_link}}\\\" class=\\\"js-app-link\\\"\\u003E{{app_link}}\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a{{/app_link}}\\u000a{{^no_download}}\\u000a        \\u003Cdiv class=\\\"app-download\\\"\\u003E\\u000a          \\u003Ca class=\\\"btn signup-btn promotional\\\" href=\\\"{{url}}\\\" target=\\\"_blank\\\"\\u003EDownload now\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cform class=\\\"app-download-form dialog-form\\\" method=\\\"post\\\" action=\\\"send_link\\\"\\u003E\\u000a          \\u003Cp\\u003EOr email a link to your {{device_noun}} to download: {{download_notice}}\\u003C/p\\u003E\\u000a          \\u003Cfieldset\\u003E\\u000a            \\u003Cdiv class=\\\"field\\\"\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" name=\\\"appId\\\" value=\\\"{{app_id}}\\\"\\u003E\\u000a              \\u003Cinput type=\\\"email\\\" autocomplete=\\\"off\\\" class=\\\"email\\\" name=\\\"email\\\" placeholder=\\\"Email address\\\"\\u003E\\u000a              \\u003Cinput type='submit' class=\\\"btn primary-btn submit js-submit\\\" value=\\\"Send link\\\"\\u003E\\u000a\\u0009          \\u003Cspan class=\\\"notification\\\"\\u003E\\u003C/span\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a        \\u003C/form\\u003E\\u000a{{/no_download}}\\u000a{{#qr_code_url}}\\u000a        \\u003Cdiv class=\\\"qr-code\\\"\\u003E\\u000a          \\u003Cp\\u003EQR Code:\\u003C/p\\u003E\\u000a          \\u003Cimg width=\\\"{{qr_code_width}}\\\" height=\\\"{{qr_code_height}}\\\" src=\\\"{{qr_code_url}}\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a{{/qr_code_url}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"mobile-download clearfix\\\"\\u003E\\u000a\\u000a    \\u003Ctable class=\\\"mobile-footer mobile-footer-app\\\" cellpadding=\\\"0\\\"\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EWhat\\u2019s happening?\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Discover what\\u2019s happening right now, anywhere in the world, with the official {{app_long_name}} app.\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EWhat matters to you\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Search, Top Tweets, trending topics, and maps show what\\u2019s happening everywhere and nearby.\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003ECommunicate easily\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              {{^no_video}}\\u000a              Tweet, send messages, share photos, videos, and links with your friends and the world.\\u000a              {{/no_video}}\\u000a              {{#no_video}}\\u000a              Tweet, send messages, share photos and links with your friends and the world.\\u000a              {{/no_video}}\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EIt\\u2019s free!\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Don't have an account? Just sign up from the app! Questions? See \\u003Ca href=\\\"{{support_url}}\\\"\\u003ETwitter Support: {{app_long_name}}\\u003C/a\\u003E\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Efooter}}\",\n            firefox: \"{{\\u003Efirefox_download}}\\u000a{{\\u003Efooter}}\",\n            mobile_gallery_all: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a\\u000a  \\u003Ch1\\u003E{{^logged_out_justnow}}Take Twitter with you. Get the app.{{/logged_out_justnow}}{{#logged_out_justnow}}\\u003Cb\\u003EYou\\u2019ve signed out of Twitter.\\u003C/b\\u003E Now go mobile.{{/logged_out_justnow}}\\u003C/h1\\u003E\\u000a\\u000a  \\u003Cul class=\\\"gallery\\\"\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/iphone{{lang_param}}\\\" class=\\\"mobile-app iphone\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EiPhone\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/android{{lang_param}}\\\" class=\\\"mobile-app android\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EAndroid\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/ipad{{lang_param}}\\\" class=\\\"mobile-app ipad\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EiPad\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a{{#lang_ja}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/iappli{{lang_param}}\\\" class=\\\"mobile-app iappli\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EiAppli\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/twtrjp{{lang_param}}\\\" class=\\\"mobile-app twtrjp\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EKeitai\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a{{/lang_ja}}\\u000a{{^lang_ja}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/blackberry{{lang_param}}\\\" class=\\\"mobile-app blackberry\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EBlackBerry\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a{{/lang_ja}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/wp7{{lang_param}}\\\" class=\\\"mobile-app wp7\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003EWindows Phone 7\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{mobile_gallery_path}}/nokias40{{lang_param}}\\\" class=\\\"mobile-app nokias40\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cbr\\u003E\\u003Cspan\\u003ENokia s40\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"mobile-download clearfix\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"actions yes-script\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"download-info\\\"\\u003E\\u000a        \\u003Ca class=\\\"promotional download-now btn signup-btn\\\"\\u003EDownload now\\u003C/a\\u003E\\u000a        \\u003Ca class=\\\"btn primary-btn activate-sms has-sms\\\" href=\\\"{{devices_settings_path}}\\\"\\u003EUse via text message\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Ctable class=\\\"mobile-footer mobile-footer-home\\\" cellpadding=\\\"0\\\"\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Cp\\u003EHave your device with you?\\u003Cbr\\u003E\\u003Ca href=\\\"http://m.twitter.com\\\"\\u003EVisit m.twitter.com on your device &raquo;\\u003C/a\\u003E\\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Cp\\u003EQuestions about using Twitter mobile?\\u003Cbr\\u003E\\u003Ca href=\\\"{{mobile_help_path}}\\\"\\u003EVisit our Mobile Help Center &raquo;\\u003C/a\\u003E\\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            {{#logged_out_totally}}\\u000a            \\u003Cp\\u003EAlready using Twitter via text message?\\u003Cbr\\u003E\\u003Ca href=\\\"{{mobile_complete_path}}\\\"\\u003EComplete signup &raquo;\\u003C/a\\u003E\\u003C/p\\u003E\\u000a            {{/logged_out_totally}}\\u000a            {{^logged_out_totally}}\\u000a            \\u003Cp\\u003EPrivacy controls &amp; notification settings?\\u003Cbr\\u003E\\u003Ca href=\\\"{{devices_path}}\\\"\\u003EVisit our Mobile Settings page &raquo;\\u003C/a\\u003E\\u003C/p\\u003E\\u000a            {{/logged_out_totally}}\\u000a          \\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mobile_gallery_app: \"\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"gallery-link\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{mobile_gallery_path}}\\\"\\u003E&larr; Back to Mobile\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"mobile-gallery-app mobile-gallery-{{app_id}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"mobile-gallery-app-wrapper\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"app-header\\\"\\u003E\\u000a        \\u003Ch2\\u003E{{app_short_name}}\\u003C/h2\\u003E\\u000a        \\u003Cp class=\\\"compatibility\\\"\\u003E{{compatibility}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"actions actions-single yes-script {{^no_camera}} qr-code-actions {{/no_camera}}\\\"\\u003E\\u000a{{#app_link}}\\u000a        \\u003Cdiv class=\\\"app-link\\\"\\u003E\\u000a          \\u003Cp\\u003EURL:\\u003C/p\\u003E\\u000a          \\u003Ca href=\\\"{{app_link}}\\\" class=\\\"js-app-link\\\"\\u003E{{app_link}}\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a{{/app_link}}\\u000a{{^no_download}}\\u000a        \\u003Cdiv class=\\\"app-download\\\"\\u003E\\u000a          \\u003Ca class=\\\"btn signup-btn promotional\\\" href=\\\"{{url}}\\\" target=\\\"_blank\\\"\\u003EDownload now\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cform class=\\\"app-download-form dialog-form\\\"\\u003E\\u000a          \\u003Cp\\u003EOr email a link to your {{device_noun}} to download: {{download_notice}}\\u003C/p\\u003E\\u000a          \\u003Cfieldset\\u003E\\u000a            \\u003Cdiv class=\\\"field\\\"\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" name=\\\"appId\\\" value=\\\"{{app_id}}\\\" /\\u003E\\u000a              \\u003Cinput type=\\\"email\\\" autocomplete=\\\"off\\\" class=\\\"email\\\" name=\\\"email\\\" placeholder=\\\"Email address\\\"\\u003E\\u003Cdiv class=\\\"btn submit js-submit\\\"\\u003ESend link\\u003C/div\\u003E\\u000a              \\u000a              \\u003Cdiv class='label'\\u003E\\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/fieldset\\u003E\\u000a        \\u003C/form\\u003E\\u000a{{/no_download}}\\u000a{{#qr_code_url}}\\u000a        \\u003Cdiv class=\\\"qr-code\\\"\\u003E\\u000a          \\u003Cp\\u003EQR Code:\\u003C/p\\u003E\\u000a          \\u003Cimg width=\\\"{{qr_code_width}}\\\" height=\\\"{{qr_code_height}}\\\" src=\\\"{{qr_code_url}}\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a{{/qr_code_url}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"mobile-download clearfix\\\"\\u003E\\u000a\\u000a    \\u003Ctable class=\\\"mobile-footer mobile-footer-app\\\" cellpadding=\\\"0\\\"\\u003E\\u000a      \\u003Ctbody\\u003E\\u000a        \\u003Ctr\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EWhat\\u2019s happening?\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Discover what\\u2019s happening right now, anywhere in the world, with the official {{app_long_name}} app.\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EWhat matters to you\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Search, Top Tweets, trending topics, and maps show what\\u2019s happening everywhere and nearby.\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003ECommunicate easily\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              {{^no_video}}\\u000a              Tweet, send messages, share photos, videos, and links with your friends and the world.\\u000a              {{/no_video}}\\u000a              {{#no_video}}\\u000a              Tweet, send messages, share photos and links with your friends and the world.\\u000a              {{/no_video}}\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a          \\u003Ctd\\u003E\\u000a            \\u003Ch4\\u003EIt\\u2019s free!\\u003C/h4\\u003E\\u000a            \\u003Cp\\u003E\\u000a              Don't have an account? Just sign up from the app! Questions? See \\u003Ca href=\\\"{{support_url}}\\\"\\u003ETwitter Support: {{app_long_name}}\\u003C/a\\u003E\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/td\\u003E\\u000a        \\u003C/tr\\u003E\\u000a      \\u003C/tbody\\u003E\\u000a    \\u003C/table\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mobile_gallery_logged_out_header: \"\\u003Cdiv id=\\\"mobile-gallery-logged-out-header\\\"\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            mobile_gallery_page: \"{{#render_page_content}}\\u000a  {{^firefox}}\\u000a    {{#app_id}}\\u000a      {{\\u003Emobile_gallery_app}}\\u000a    {{/app_id}}\\u000a    {{^app_id}}\\u000a      {{\\u003Emobile_gallery_all}}\\u000a    {{/app_id}}\\u000a  {{/firefox}}\\u000a  {{#firefox}}\\u000a    {{\\u003Efirefox_download}}\\u000a  {{/firefox}}\\u000a\\u000a  \\u003Cdiv class=\\\"logged-out\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"bottompart\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/render_page_content}}\\u000a\",\n            \"module\": \"\\u003Cdiv class=\\\"module {{class_name}}\\\"\\u003E\\u003C/div\\u003E\",\n            module_section: \"\\u003C{{tag}} data-section-id=\\\"{{id}}\\\"\\u003E\\u003C/{{tag}}\\u003E\",\n            more_css: \"{{#is_t1}}\\u000a  \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{t1_more_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a{{/is_t1}}\\u000a{{^is_t1}}\\u000a  \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{phoenix_more_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a{{/is_t1}}\",\n            more_lists: \"\\u003Cdiv class=\\\"module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    {{#user}}\\u000a      \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a        \\u003Ch3\\u003EMore lists by \\u003Ca href=\\\"{{profile_path}}\\\"\\u003E@{{screen_name}}\\u003C/a\\u003E\\u003C/h3\\u003E\\u000a        \\u003Csmall class=\\\"view-all\\\"\\u003E&middot; \\u003Ca href=\\\"{{user_lists_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/user}}\\u000a    {{#lists}}\\u000a      \\u003Cdiv class=\\\"flex-module-inner\\\"\\u003E\\u000a        \\u003Cul class=\\\"list-of-lists\\\"\\u003E\\u000a          {{#items}}\\u000a            \\u003Cli\\u003E\\u003Ca href=\\\"{{user_list_path}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a          {{/items}}\\u000a        \\u003C/ul\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/lists}}\\u000a    {{#show_new_list_link}}\\u000a      {{\\u003Ecreate_list_button}}\\u000a    {{/show_new_list_link}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            must_follow_first_error_message: \"{{#dm_recipient}}\\u000a  You must follow @{{dm_recipient}} before sending a message to them.\\u000a{{/dm_recipient}}\\u000a{{^dm_recipient}}\\u000a  You must follow this user first before sending a message to them.\\u000a{{/dm_recipient}}\\u000a\\u000a\\u003Ca href=\\\"{{dms_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            mute_users: \"\\u003Cdiv class=\\\"muted-users\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"input-autocomplete\\\"\\u003E\\u000a    \\u003Cinput type=\\\"text\\\" size=\\\"20\\\" class=\\\"mute-input\\\"/\\u003E \\u003Ca href=\\\"#\\\" class=\\\"button\\\"\\u003EAdd\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cul class=\\\"muted-user-list\\\"\\u003E\\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            nav: \"\\u003Cdiv class=\\\"module {{name}}\\\"\\u003E\\u000a  \\u003Cul class=\\\"js-items-container\\\"\\u003E\\u000a    {{#items}}\\u000a      {{#visible}}\\u000a        {{\\u003Enav_item}}\\u000a      {{/visible}}\\u000a    {{/items}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            nav_item: \"\\u003Cli class=\\\"js-sidenav-link{{#active}} active{{/active}}\\\" data-name=\\\"{{name}}\\\" data-element-term=\\\"{{element_term}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"list-link\\\" href=\\\"{{route}}\\\"\\u003E\\u000a    {{title}}\\u000a    {{#count}}\\u003Csmall\\u003E{{count_commaized}}\\u003C/small\\u003E{{/count}}\\u000a    \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a    {{#show_metadata_container}}\\u003Cspan class=\\\"js-metadata metadata\\\"\\u003E{{{metadata}}}\\u003C/span\\u003E{{/show_metadata_container}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            new_message_button: \"\\u003Ca class=\\\"btn js-new-message-button\\\" href=\\\"#\\\" data-modal=\\\"dm-new\\\"\\u003ENew message\\u003C/a\\u003E\",\n            new_signup_call_out: \"\\u003Cdiv class=\\\"module signup-call-out search-signup-call-out\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-header profile-signup\\\"\\u003E\\u000a      \\u003Ch2\\u003E{{#query}}Get instant updates on {{query}}{{/query}}{{^query}}New to Twitter?{{/query}} \\u003Csmall\\u003EJoin Twitter today\\u003C/small\\u003E\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Epartial_signup_form}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            newest_list_members: \"\\u003Cdiv class=\\\"module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a  {{#list}}\\u000a    \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch3\\u003ERecently added members\\u003C/h3\\u003E\\u000a      \\u003Csmall class=\\\"view-all\\\"\\u003E&middot; \\u003Ca href=\\\"{{list_members_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/list}}\\u000a    \\u003Cdiv class=\\\"flex-module-inner js-recent-members\\\"\\u003E\\u000a    {{#members}}\\u000a      {{\\u003Euser_small_list}}\\u000a    {{/members}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            no_letter_start_list_name_error_message: \"Oops! List names can't start with a number.\\u000a\\u003Ca href=\\\"{{list_name_error_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\",\n            no_list_members: \"\\u003Cdiv class=\\\"stream-placeholder centered-placeholder\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Cp\\u003EThis list doesn\\u2019t follow any users yet. It probably will soon, though.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            no_lists: \"\\u003Cdiv class=\\\"empty-drop-down\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"no-lists title\\\"\\u003EYou don't have any lists yet.\\u003C/div\\u003E\\u000a  \\u003Cp class=\\\"no-lists info\\\"\\u003E\\u000a    {{^abtest_timeline_copy_317_any_bucket}}\\u000a      Create a custom timeline of Tweets by adding users to a list (\\u003Ca href=\\\"{{lists_help_path}}\\\" target=\\\"_blank\\\"\\u003Esee how\\u003C/a\\u003E). You can also follow lists curated by others.\\u000a    {{/abtest_timeline_copy_317_any_bucket}}\\u000a    {{#abtest_timeline_copy_317_stream}}\\u000a      Create a custom stream of Tweets by adding users to a list (\\u003Ca href=\\\"{{lists_help_path}}\\\" target=\\\"_blank\\\"\\u003Esee how\\u003C/a\\u003E). You can also follow lists curated by others.\\u000a    {{/abtest_timeline_copy_317_stream}}\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            no_saved_searches: \"\\u003Cdiv class=\\\"empty-drop-down\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"no-saved-searches title\\\"\\u003EYou haven't saved any searches yet.\\u003C/div\\u003E\\u000a  \\u003Cp class=\\\"no-saved-searches info\\\"\\u003E\\u000a    Click on \\\"Save this search\\\" from the results page to quickly access the latest Tweets about a topic or query, right from here. \\u003Ca href=\\\"{{saved_searches_help_path}}\\\" target=\\\"_blank\\\"\\u003ELearn More\\u003C/a\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            noscript_banner: \"\\u003Cdiv class=\\\"banner-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"banner-inside noscript-warning\\\"\\u003E\\u000a      \\u003Ch5\\u003ETwitter.com makes heavy use of JavaScript.\\u003C/h5\\u003E\\u000a      \\u003Cspan class=\\\"warning\\\"\\u003EIf you cannot enable it in your browser's preferences, you may have a better experience on our \\u003Ca href=\\\"http://m.twitter.com\\\"\\u003Emobile site\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            not_following_error_message: \"{{#dm_recipient}}\\u000a  Your message could not be sent to @{{dm_recipient}} because they do not follow you.\\u000a{{/dm_recipient}}\\u000a{{^dm_recipient}}\\u000a  You cannot send messages to users who are not following you.\\u000a{{/dm_recipient}}\\u000a\\u000a\\u003Ca href=\\\"{{dms_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            not_found_error_message: \"{{#is_user_not_found}}\\u000a  Sorry, we couldn't find that user.\\u000a{{/is_user_not_found}}\\u000a{{#is_generic}}\\u000a  Sorry, something went wrong.\\u000a{{/is_generic}}\\u000a\",\n            nothing: \"\\u003C!-- nothing! --\\u003E\",\n            JSBNG__onebox: \"\\u003Cdiv class=\\\"onebox {{#is_new_search_header_available}}ddg-192-new-header{{/is_new_search_header_available}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"js-onebox-container onebox-inner {{#is_new_search_header_available}}ddg-192-new-header{{/is_new_search_header_available}}\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            other_user_suspended_error_message: \"{{#is_follow}}\\u000a  Sorry, the user you tried to follow is suspended.\\u000a{{/is_follow}}\\u000a{{^is_follow}}\\u000a  Sorry, that user is suspended.\\u000a{{/is_follow}}\",\n            page_profile: \"{{^render_withheld}}\\u000a{{\\u003Etop_content}}\\u000a{{\\u003Edashboard}}\\u000a{{\\u003Econtent}}\\u000a{{/render_withheld}}\\u000a{{#render_withheld}}\\u000a\\u003Cdiv class=\\\"permalink-header\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"permalink\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"components-above\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"components-middle\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet js-actionable-tweet permalink-tweet permalink-tweet-withheld\\\"\\u003E\\u000a      {{#profile_user}}\\u000a      \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"tweet-user-withheld\\\"\\u003E\\u000a          @{{screen_name}} withheld\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a        {{description}} \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/profile_user}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"components-below\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"permalink-footer\\\"\\u003E\\u003C/div\\u003E\\u000a{{/render_withheld}}\\u000a\",\n            partial: \"t1 partial\\u000a\",\n            partial_signup_form: \"\\u003Cform action=\\\"{{signup_path}}\\\" class=\\\"clearfix signup\\\" method=\\\"post\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"holding name\\\"\\u003E\\u000a    \\u003Cinput type=\\\"text\\\" autocomplete=\\\"off\\\" name=\\\"user[name]\\\" maxlength=\\\"20\\\"\\u003E\\u000a    \\u003Cspan class=\\\"holder\\\"\\u003EFull name\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"holding email\\\"\\u003E\\u000a    \\u003Cinput class=\\\"email-input\\\" type=\\\"text\\\" autocomplete=\\\"off\\\" name=\\\"user[email]\\\"\\u003E\\u000a    \\u003Cspan class=\\\"holder\\\"\\u003EEmail\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"holding password\\\"\\u003E\\u000a    \\u003Cinput type=\\\"password\\\" name=\\\"user[user_password]\\\"\\u003E\\u000a    \\u003Cspan class=\\\"holder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{#screen_name}}\\u000a    \\u003Cinput name=\\\"follow\\\" type=\\\"hidden\\\" value=\\\"{{screen_name}}\\\"\\u003E\\u000a  {{/screen_name}}\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{signup_source}}\\\" name=\\\"context\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a  \\u003Cinput name=\\\"follows\\\" type=\\\"hidden\\\" value=\\\"{{screen_names}}\\\"\\u003E\\u000a  \\u003Cinput type=\\\"submit\\\" class=\\\"btn signup-btn js-submit js-signup-btn\\\" value=\\\"{{#in_ja_profile_page}}Registration is free{{/in_ja_profile_page}}{{^in_ja_profile_page}}Sign up{{/in_ja_profile_page}}\\\"\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            people_results: \"\\u003Ch2\\u003EPeople results for&nbsp;\\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E &middot;\\u000a\\u0009\\u003Ca class=\\\"view-all\\\" href=\\\"{{#logged_in}}{{who_to_follow_search_path}}{{/logged_in}}{{^logged_in}}{{user_search_path}}{{/logged_in}}\\\"\\u003Eview all\\u003C/a\\u003E\\u000a\\u003C/h2\\u003E\\u000a\\u003Cul class='people-results clearfix'\\u003E\\u000a  {{#found_people}}\\u000a    {{\\u003Euser_small_list}}\\u000a  {{/found_people}}\\u000a\\u003C/ul\\u003E\\u000a\",\n            people_search: \"\\u003Cform class=\\\"js-search-form content-searchbar\\\"\\u003E\\u000a  \\u003Ctable class=\\\"flex-table\\\"\\u003E\\u000a    \\u003Ctbody\\u003E\\u000a      \\u003Ctr\\u003E\\u000a        \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"flex-table-form\\\"\\u003E\\u000a            \\u003Cinput class=\\\"flex-table-input search-query\\\" type=\\\"text\\\" name=\\\"q\\\" {{#query}}value=\\\"{{query}}\\\"{{/query}} placeholder=\\\"{{placeholder}}\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/td\\u003E\\u000a        \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a          \\u003Cbutton class=\\\"btn flex-table-btn js-submit\\\" type=\\\"submit\\\"\\u003E{{button_text}}\\u003C/button\\u003E\\u000a        \\u003C/td\\u003E\\u000a      \\u003C/tr\\u003E\\u000a    \\u003C/tbody\\u003E\\u000a  \\u003C/table\\u003E\\u000a\\u003C/form\\u003E\",\n            permalink_page: \"\\u003Cdiv class=\\\"permalink\\\"\\u003E\\u000a\\u000a  {{#rendering_on_server}}\\u000a    {{#include_embed_link}}\\u000a      {{\\u003Edialogs/embed}}\\u000a    {{/include_embed_link}}\\u000a  {{/rendering_on_server}}\\u000a\\u000a\\u000a  \\u000a  {{^rendering_on_server}}\\u000a  \\u003Cdiv class=\\\"components-above\\\"\\u003E\\u000a  {{/rendering_on_server}}\\u000a\\u000a    {{#rendering_on_server}}\\u000a      {{#in_reply_to}}\\u000a        \\u003Cdiv class=\\\"permalink-in-reply-tos\\\" data-component-term=\\\"in_reply_to\\\"\\u003E\\u000a          {{\\u003Ein_reply_to}}\\u000a        \\u003C/div\\u003E\\u000a      {{/in_reply_to}}\\u000a    {{/rendering_on_server}}\\u000a\\u000a  \\u000a  {{^rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"components-middle\\\"\\u003E\\u000a  {{/rendering_on_server}}\\u000a\\u000a    {{#render_page_content}}\\u000a      {{#tweet}}\\u000a        {{\\u003Esingle_tweet}}\\u000a      {{/tweet}}\\u000a    {{/render_page_content}}\\u000a\\u000a  \\u000a  {{^rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"components-below\\\"\\u003E\\u000a  {{/rendering_on_server}}\\u000a\\u000a    {{#rendering_on_server}}\\u000a      {{^render_withheld}}\\u000a        {{\\u003Ereplies}}\\u000a      {{/render_withheld}}\\u000a    {{/rendering_on_server}}\\u000a\\u000a  \\u000a  {{^rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a  {{/rendering_on_server}}\\u000a\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"permalink-footer\\\"\\u003E\\u000a  {{#rendering_on_server}}\\u000a    {{^logged_in}}\\u000a      {{#status}}\\u000a        {{#user}}\\u000a          {{\\u003Epermalink_signup_call_out}}\\u000a        {{/user}}\\u000a      {{/status}}\\u000a    {{/logged_in}}\\u000a    {{\\u003Efooter}}\\u000a  {{/rendering_on_server}}\\u000a\\u003C/div\\u003E\\u000a\",\n            permalink_photo_page: \"\\u003Cdiv class=\\\"media-gallery-overlay swift\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"media-gallery-content big-photo-permalink media-slideshow-tweet\\\"\\u003E\\u000a    {{#tweet}}\\u000a      {{\\u003Eslideshow_tweet}}\\u000a    {{/tweet}}\\u000a    {{#photo}}\\u000a      {{#large}}\\u000a        \\u003Cdiv class=\\\"media-gallery-image-wrapper\\\"\\u003E\\u000a          \\u003Cimg class=\\\"large media-slideshow-image\\\" alt=\\\"\\\" src=\\\"{{url}}\\\" height=\\\"{{h}}\\\" width=\\\"{{w}}\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/large}}\\u000a    {{/photo}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            permalink_signup_call_out: \"\\u003Cdiv class=\\\"module signup-call-out\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch2\\u003EDon\\u2019t miss any updates from {{name}} \\u003Csmall\\u003EJoin Twitter today and follow what interests you!\\u003C/small\\u003E\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Epartial_signup_form}}\\u000a    {{#rendering_on_server}}\\u000a      {{\\u003Esms_follow_prompt}}\\u000a    {{/rendering_on_server}}\\u000a    {{^rendering_on_server}}\\u000a      {{\\u003Esms_follow}}\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            permission_error_message: \"Your account may not be allowed to perform this action. Please \\u003Ca class=\\\"js-reload\\\" href=\\\"#\\\"\\u003Erefresh the page\\u003C/a\\u003E and try again.\",\n            phoenix: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml{{#nav_highlight_class_name}} data-nav-highlight-class-name=\\\"{{nav_highlight_class_name}}\\\"{{/nav_highlight_class_name}}\\u003E\\u000a  \\u003Chead\\u003E\\u000a    \\u000a    {{\\u003Ephoenix_head}}\\u000a\\u000a    {{#is_t1}}\\u000a      {{#escaped_js_redirect_path}}\\u000a      \\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a        \\u000a          window.JSBNG__location.replace('{{escaped_js_redirect_path}}');\\u000a      \\u003C/script\\u003E\\u000a      {{/escaped_js_redirect_path}}\\u000a\\u000a      {{#logged_in}}\\u000a        \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{t1_core_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a      {{/logged_in}}\\u000a      {{^logged_in}}\\u000a        \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{t1_core_logged_out_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a      {{/logged_in}}\\u000a\\u000a    {{/is_t1}}\\u000a    {{^is_t1}}\\u000a      {{#logged_in}}\\u000a        {{#inline_core_css}}\\u000a          \\u003Cstyle type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E{{{phoenix_core_css_content}}}\\u003C/style\\u003E\\u000a        {{/inline_core_css}}\\u000a        {{^inline_core_css}}\\u000a          \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{phoenix_core_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a        {{/inline_core_css}}\\u000a      {{/logged_in}}\\u000a      {{^logged_in}}\\u000a        \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{phoenix_core_logged_out_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a      {{/logged_in}}\\u000a\\u000a      {{#render_page_content}}\\u000a        {{#no_script}}\\u000a          \\u003Clink rel=\\\"stylesheet\\\" href=\\\"/phoenix/css/noscript.css\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a        {{/no_script}}\\u000a      {{/render_page_content}}\\u000a    {{/is_t1}}\\u000a\\u000a    {{#render_page_content}}\\u000a      \\u003Clink rel=\\\"canonical\\\" href=\\\"{{canonical_url}}\\\" /\\u003E\\u000a    {{/render_page_content}}\\u000a\\u000a    {{#noscript_detection}}\\u000a      \\u003Cnoscript\\u003E\\u000a        {{#noscript_url}}\\u000a          \\u003Cmeta http-equiv=refresh content=\\\"0; URL={{noscript_url}}\\\" /\\u003E\\u000a        {{/noscript_url}}\\u000a      \\u003C/noscript\\u003E\\u000a    {{/noscript_detection}}\\u000a\\u000a    {{#theme_user}}\\u000a      {{#is_t1}}\\u000a        {{\\u003Euser_css_t1}}\\u000a      {{/is_t1}}\\u000a      {{^is_t1}}\\u000a        {{\\u003Euser_css_p1}}\\u000a      {{/is_t1}}\\u000a      {{\\u003Ebg_img_css}}\\u000a    {{/theme_user}}\\u000a\\u000a    {{#render_page_content}}\\u000a      \\u003Cscript\\u003E{{{swift_preboot_js}}}\\u003C/script\\u003E\\u000a    {{/render_page_content}}\\u000a\\u000a\\u000a    {{#include_more_css_early}}{{\\u003Emore_css}}{{/include_more_css_early}}\\u000a\\u000a\\u000a    \\u003Cscript\\u003E{{{google_analytics_js}}}\\u003C/script\\u003E\\u000a\\u000a  \\u003C/head\\u003E\\u000a{{#is_t1}}\\u000a  {{\\u003Et1_body}}\\u000a{{/is_t1}}\\u000a{{^is_t1}}\\u000a  \\u003Cbody class=\\\"{{^theme}}user-style-twttr{{/theme}} {{theme}} {{locale_css}} {{^render_page_content}}loading-body{{/render_page_content}} {{#logged_in}} logged-in {{/logged_in}} {{^logged_in}} logged-out {{/logged_in}}\\\"\\u003E\\u000a    \\u003Cdiv id=\\\"doc\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"top-stuff\\\" class=\\\"js-topbar\\\"\\u003E\\u000a        \\u003Cdiv id=\\\"banners\\\" class=\\\"js-banners\\\" style=\\\"clear:both;\\\"\\u003E\\u000a          {{#became_user}}{{\\u003Ebecame_user_banner}}{{/became_user}}\\u000a          {{#noscript_banner}}\\u003Cnoscript\\u003E{{\\u003Enoscript_banner}}\\u003C/noscript\\u003E{{/noscript_banner}}\\u000a          {{#logged_in}}{{\\u003Eslow_load_banner}}{{/logged_in}}\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv id=\\\"top-bar-outer\\\"\\u003E\\u000a          \\u003Cdiv id=\\\"top-bar-bg\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Cdiv id=\\\"top-bar\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"top-bar-inside\\\"\\u003E\\u000a              {{\\u003Ephoenix_top_bar}}\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv id=\\\"message-drawer\\\"\\u003E\\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv id=\\\"page-outer\\\" {{#expando}}class=\\\"flush-to-top\\\"{{/expando}}\\u003E\\u000a        {{^logged_in}}\\u000a          {{#home_page}}\\u000a            \\u003Cdiv id=\\\"front-container\\\" class=\\\"js-front-container\\\"\\u003E\\u000a              {{\\u003Efront_page}}\\u000a            \\u003C/div\\u003E\\u000a          {{/home_page}}\\u000a        {{/logged_in}}\\u000a\\u000a        \\u003Cdiv id=\\\"page-container\\\" class=\\\"page-container {{#container_class}}{{container_class}}{{/container_class}}\\\"\\u003E\\u000a          \\u003Cdiv{{#page_node_id}} id=\\\"{{page_node_id}}\\\"{{/page_node_id}}\\u003E\\u000a            {{#home_page}}\\u000a              {{#current_user}}\\u000a                {{\\u003Ehome_page}}\\u000a              {{/current_user}}\\u000a            {{/home_page}}\\u000a\\u000a            {{#four_oh_four_page}}\\u000a              {{\\u003E404_page}}\\u000a            {{/four_oh_four_page}}\\u000a\\u000a            {{#profile_page}}\\u000a              {{\\u003Eprofile_page}}\\u000a            {{/profile_page}}\\u000a\\u000a            {{#mobile_gallery_page}}\\u000a              {{\\u003Emobile_gallery_page}}\\u000a            {{/mobile_gallery_page}}\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{^logged_in}}\\u000a        {{#home_page}}\\u000a          \\u003Cdiv class=\\\"homepage-gradient\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"homepage-gold-bar\\\"\\u003E\\u003C/div\\u003E\\u000a        {{/home_page}}\\u000a      {{/logged_in}}\\u000a\\u000a      \\u003Cdiv id=\\\"message-notifications\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv id=\\\"flash-message-storage\\\" style=\\\"display:none\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv id=\\\"flash-object-container\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv id=\\\"off-screen-preload\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"content-fe-sprites\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#escaped_js_redirect_path}}\\u000a    \\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a      \\u000a        window.JSBNG__location.replace('{{escaped_js_redirect_path}}');\\u000a    \\u003C/script\\u003E\\u000a    {{/escaped_js_redirect_path}}\\u000a\\u000a    {{\\u003Ejavascript_includes}}\\u000a\\u000a    {{#include_more_css}}\\u000a      {{^include_more_css_early}}{{\\u003Emore_css}}{{/include_more_css_early}}\\u000a    {{/include_more_css}}\\u000a  \\u003C/body\\u003E\\u000a{{/is_t1}}\\u000a\\u000a\\u003C/html\\u003E\\u000a\",\n            phoenix_head: \"\\u003Ctitle\\u003E{{page_title}}\\u003C/title\\u003E\\u000a\\u003Cmeta http-equiv=\\\"X-UA-Compatible\\\" content=\\\"IE=edge\\\"\\u003E\\u000a\\u003Cmeta charset=\\\"utf-8\\\" /\\u003E\\u000a\\u000a{{^logged_in}}\\u000a  {{#meta_description}}\\u000a    \\u003Cmeta name=\\\"description\\\" content=\\\"{{meta_description}}\\\" /\\u003E\\u000a  {{/meta_description}}\\u000a{{/logged_in}}\\u000a\\u000a{{#dns_prefetch}}\\u000a  \\u003Clink rel=\\\"dns-prefetch\\\" href=\\\"{{.}}\\\"\\u003E\\u000a{{/dns_prefetch}}\\u000a\\u000a\\u003Cscript type=\\\"text/javascript\\\" charset=\\\"utf-8\\\"\\u003E\\u000a  \\u000a  \\u000a  document.domain = 'twitter.com';\\u000a\\u000a  // this will be copied to twttr.appStartTime once our JS has started up\\u000a  document.startTime = new Date().getTime();\\u000a  var twttr = {};\\u000a  twttr.versionName = 'phoenix';\\u000a  {{#is_t1}}twttr.isT1 = true;{{/is_t1}}\\u000a  twttr.didPingKeynote = false;\\u000a  twttr.keynoteTTFTPing = function() {\\u000a    if (!twttr.didPingKeynote && window.JSBNG__location.href.indexOf('keynoteTest') \\u003E 0) {\\u000a      var image = document.createElement('img');\\u000a      image.src = '/images/keynote.gif';\\u000a      twttr.didPingKeynote = true;\\u000a    }\\u000a  }\\u000a\\u000a  {{{fake_console_js}}}\\u000a\\u000a  {{#include_events_reroute}}\\u000a    twttr.griffin = {\\u000a      current: {{{active_events}}}\\u000a    };\\u000a\\u000a    {{#euro2012_search_terms}}\\u000a      twttr.griffin.euroTerms = {{{euro2012_search_terms}};\\u000a    {{/euro2012_search_terms}}\\u000a\\u000a    \\u000a    {{{swift_reroute}}}\\u000a  {{/include_events_reroute}}\\u000a\\u000a\\u003C/script\\u003E\\u000a\\u000a{{#ttft_data}}\\u000a\\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000awindow.ttftData={{{ttft_data}}};{{{ttft_js}}}\\u000a\\u003C/script\\u003E\\u000a{{/ttft_data}}\\u000a\\u000a\\u003Cscript type=\\\"text/javascript\\\"\\u003E{{{watch_script}}}\\u003C/script\\u003E\\u000a\\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a  {{#js_watch_enabled}}\\u000a    WATCH.activate();\\u000a    WATCH.natives();\\u000a  {{/js_watch_enabled}}\\u000a\\u003C/script\\u003E\\u000a\\u000a\\u000a{{^is_admin}}\\u000a  {{\\u003Eframe_busting}}\\u000a{{/is_admin}}\\u000a\\u000a{{#include_ie9_meta}}\\u000a  \\u003Clink href=\\\"/favicons/favicon32x32.ico\\\" rel=\\\"shortcut icon\\\" type=\\\"image/x-icon\\\"\\u003E\\u000a{{/include_ie9_meta}}\\u000a{{^include_ie9_meta}}\\u000a  \\u003Clink href=\\\"/favicons/favicon.ico\\\" rel=\\\"shortcut icon\\\" type=\\\"image/x-icon\\\"\\u003E\\u000a{{/include_ie9_meta}}\\u000a\\u000a{{#base_url}}\\u003Cbase href=\\\"{{base_url}}\\\" /\\u003E{{/base_url}}\\u000a\",\n            phoenix_signup: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"{{locale}}\\\"\\u003E\\u000a  \\u003Chead\\u003E\\u000a    {{\\u003Ephoenix_head}}\\u000a\\u000a    \\u003Cscript\\u003E\\u000a      twttr.versionName = \\\"phoenix-signup\\\";\\u000a      {{^abtest_recaptcha_in_your_language_154_not_translated}}\\u000a        twttr.pageLocale = \\\"{{locale}}\\\";\\u000a      {{/abtest_recaptcha_in_your_language_154_not_translated}}\\u000a      {{#is_selenium}}\\u000a      // loadrunner target that we know exists\\u000a      twttr.recaptchaUrlForTest = 'constants';\\u000a      {{/is_selenium}}\\u000a    \\u003C/script\\u003E\\u000a\\u000a    {{^assets_from_cdn}}\\u000a      {{#is_t1}}\\u000a        \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{signup_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a      {{/is_t1}}\\u000a      {{^is_t1}}\\u000a        {{#css_files}}\\u000a          \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{file_name}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a        {{/css_files}}\\u000a      {{/is_t1}}\\u000a    {{/assets_from_cdn}}\\u000a\\u000a    {{#assets_from_cdn}}\\u000a      \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{signup_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a    {{/assets_from_cdn}}\\u000a\\u000a    \\u003Cscript\\u003E{{{google_analytics_js}}}\\u003C/script\\u003E\\u000a  \\u003C/head\\u003E\\u000a  {{\\u003Et1_signup}}\\u000a\\u003C/html\\u003E\\u000a\",\n            phoenix_top_bar: \"\\u003Cdiv class=\\\"static-links\\\"\\u003E\\u000a  \\u003Cdiv id=\\\"logo\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{index_path}}\\\"\\u003ETwitter\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cform id=\\\"search-form\\\" class=\\\"js-search-form\\\" action=\\\"{{search_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a    \\u003Cspan class=\\\"glass js-search-action\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u000a    \\u003Cinput value=\\\"\\\" placeholder=\\\"Search\\\" name=\\\"q\\\" id=\\\"search-query\\\" type=\\\"text\\\" /\\u003E\\u000a  \\u003C/form\\u003E\\u000a  \\u003Cdiv id=\\\"global-nav\\\"\\u003E\\u000a    \\u003Cul id=\\\"global-actions\\\"\\u003E\\u000a      {{#current_user}}\\u000a        \\u003Cli id=\\\"global-nav-home\\\" data-global-action=\\\"home\\\"\\u003E\\u003Ca href=\\\"{{index_path}}\\\"\\u003EHome\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli id=\\\"global-nav-profile\\\" data-global-action=\\\"profile\\\"\\u003E\\u003Ca href=\\\"{{profile_path}}\\\"\\u003EProfile\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli id=\\\"global-nav-messages\\\" data-global-action=\\\"messages\\\"\\u003E\\u003Ca href=\\\"{{messages_path}}\\\"\\u003EMessages\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli id=\\\"global-nav-who_to_follow\\\" data-global-action=\\\"who_to_follow\\\"\\u003E\\u003Ca href=\\\"{{who_to_follow_path}}\\\"\\u003EWho To Follow\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      {{/current_user}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv id=\\\"sections\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"active-links\\\"\\u003E\\u000a  {{#current_user}}\\u000a    \\u003Ca id=\\\"new-tweet\\\" class=\\\"js-global-new-tweet\\\" title=\\\"New Tweet\\\"\\u003E\\u000a      \\u003Cspan\\u003ENew Tweet\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u003Cspan class=\\\"vr\\\"\\u003E\\u000a    \\u003C/span\\u003E\\u003Cspan id=\\\"session\\\" class=\\\"loggedin js-session\\\"\\u003E\\u000a      \\u003Ca class=\\\"profile-links\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Cimg src=\\\"{{profile_image_url}}\\\" /\\u003E\\u000a      \\u003C/a\\u003E\\u000a      \\u003Cspan id=\\\"screen-name\\\"\\u003E\\u000a        {{screen_name_from_server}}\\u000a      \\u003C/span\\u003E&nbsp;\\u003Cspan id=\\\"screen-name-dropdown\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a      \\u003Cdiv class=\\\"dropdown\\\"\\u003E\\u000a        {{\\u003Euser_dropdown}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/span\\u003E\\u000a  {{/current_user}}\\u000a  {{^current_user}}\\u000a    \\u003Cdiv id=\\\"session\\\" class=\\\"js-session\\\"\\u003E\\u000a      \\u003Ca id=\\\"signin-link\\\" href=\\\"{{login_path}}\\\"\\u003E\\u000a        \\u003Cem\\u003EHave an account?\\u003C/em\\u003E\\u000a        \\u003Cstrong\\u003ESign in\\u003C/strong\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u000a      \\u003C/a\\u003E\\u000a      \\u003Ca id=\\\"signup-link\\\" href=\\\"{{signup_path}}?context=login\\\"\\u003E\\u000a        \\u003Cem\\u003ENew to Twitter?\\u003C/em\\u003E\\u000a        \\u003Cstrong\\u003EJoin Today&#32;&raquo;\\u003C/strong\\u003E\\u000a      \\u003C/a\\u003E\\u000a      \\u003Cdiv id=\\\"signin-dropdown\\\" class=\\\"dropdown dark\\\"\\u003E\\u000a        {{\\u003Esignin_form}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/current_user}}\\u000a\\u003C/div\\u003E\\u000a\",\n            phone_setup_prompt: \"\\u003Cdiv\\u003EBefore you can receive mobile notifications for @{{screen_name}}'s Tweets, you need to set up your phone.\\u003Cdiv\\u003E\\u000a{{\\u003Eprompt}}\\u000a\",\n            phone_tweets_off_prompt: \"\\u003Cdiv\\u003EBefore you can receive mobile notifications for @{{screen_name}}'s Tweets, you need to enable the Tweet notification setting.\\u003Cdiv\\u003E\\u000a{{\\u003Eprompt}}\\u000a\",\n            photo_control: \"\\u003Cdiv class=\\\"turkey-control\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"turkey-add-action\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"turkey\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"swf\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cform method=\\\"post\\\" action=\\\"{{api_url}}/1/statuses/update_with_media.iframe\\\" enctype=\\\"multipart/form-data\\\" class=\\\"turkey-selected-files\\\" target=\\\"{{tweet_box_id}}\\\"\\u003E\\u003C/form\\u003E\\u000a  \\u003Ciframe class=\\\"turkey-post-target\\\" name=\\\"{{tweet_box_id}}\\\"\\u003E\\u003C/iframe\\u003E\\u000a\\u003C/div\\u003E\",\n            photo_timeout_error_message: \"Tweeting a photo timed out. Try sending your Tweet again in a minute.\",\n            photobucket_attribution: \"\\u003Cdiv class='media-attribution'\\u003E\\u000a  \\u003Cspan\\u003Epowered by\\u003C/span\\u003E \\u003Cimg src=\\\"/phoenix/img/turkey-icon.png\\\"/\\u003E \\u003Ca target='_blank' data-media-type='{{media_type}}' class='media-attribution-link' href='http://photobucket.com/twitter'\\u003EPhotobucket\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            place_mention_button: \"\\u003Ca href=\\\"#\\\" class=\\\"button geo-insert-place-button\\\"\\u000a  title=\\\"Mention a place in your Tweet\\\"\\u003E\\u000a  \\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u003Cspan class=\\\"geo-separator\\\"\\u003E&nbsp;\\u003C/span\\u003E\\u000a\\u003Cspan class=\\\"geo-status\\\"\\u003E{{{status_html}}}\\u003C/span\\u003E\",\n            place_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{{noscript}}}\\u000a    \\u003Cdiv class=\\\"search-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"back-to-home\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{index_path}}\\\"\\u003E&larr; Back to Home\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"geo-place-page-title\\\"\\u003E\\u000a      \\u003Ch2\\u003E\\u000a      \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Cdiv class=\\\"geo-place-page-details\\\"\\u003E\\u000a        {{#full_address}}\\u000a          {{full_address}}\\u003Cspan class=\\\"geo_map_link_separator\\\"\\u003E|\\u003C/span\\u003E\\u000a        {{/full_address}}\\u000a        {{#map_link}}\\u000a          \\u003Ca target=\\\"_blank\\\" href=\\\"{{map_link}}\\\"\\u003Efull map\\u003C/a\\u003E\\u000a        {{/map_link}}\\u000a        \\u003Cdiv\\u003E{{phone}}\\u003C/div\\u003E\\u000a        {{#location_service_down}}\\u000a        Location service is temporarily unavailable\\u000a        {{/location_service_down}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#show_map}}\\u000a    \\u003Cdiv class=\\\"geo-place-page-map-container\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"geo_place_page_map_canvas\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/show_map}}\\u000a    \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-tweets {{#active_tab_tweets}}active{{/active_tab_tweets}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{place_path}}\\\"\\u003EAll Tweets\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-links {{#active_tab_links}}active{{/active_tab_links}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{place_links_path}}\\\"\\u003ETweets with links\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a    {{\\u003Estream_manager}}\\u000a  {{{end_noscript}}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"geo-map-place-bubble\\\"\\u003E\\u000a  \\u003Cspan/\\u003E\\u000a  \\u003Cdiv class=\\\"round\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"geo-place-title\\\" /\\u003E\\u000a    \\u003Cdiv class=\\\"geo-place-details\\\" /\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard place-dashboard\\\"\\u003E\\u003C/div\\u003E\\u000a{{\\u003Edetails_pane_container}}\",\n            place_page_links_title: \"{{#poi}}\\u000a  Twitter / Tweets with links at {{{placeName}}}\\u000a{{/poi}}\\u000a{{^poi}}\\u000a  Twitter / Tweets with links in {{{placeName}}}\\u000a{{/poi}}\",\n            place_page_tweets_title: \"Twitter / Tweets about {{{placeName}}}\\u000a\",\n            place_page_users_following_title: \"Twitter / Recent people you are following who mentioned {{{placeName}}}\\u000a\",\n            place_page_users_title: \"Twitter / Recent people for {{{placeName}}}\\u000a\",\n            place_people: \"\\u003Ch2 class=\\\"place-component\\\"\\u003E\\u000a  Recent people\\u000a  \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a  \\u003Ca class=\\\"view-all\\\" href=\\\"{{place_users_path}}\\\"\\u003Eview all\\u003C/a\\u003E\\u000a\\u003C/h2\\u003E\\u000a{{#user_thumbs}}\\u000a  {{\\u003Euser_thumb_list}}\\u000a{{/user_thumbs}}\\u000a\\u003Cdiv style=\\\"clear:both;\\\"\\u003E\\u003C/div\\u003E\",\n            place_tweets: \"\\u003Cdiv class=\\\"related-tweets\\\"\\u003E\\u000a  \\u003Ch3\\u003ETweets about {{place_name}}\\u003C/h3\\u003E\\u000a  {{#tweets}}\\u000a    {{\\u003Esimple_tweet}}\\u000a  {{/tweets}}\\u000a  {{#place_path}}\\u000a  \\u003Ca class=\\\"place-tweets-footer-link more-link\\\" href=\\\"{{place_path}}\\\"\\u003E\\u000a    View all Tweets about this place &rarr;\\u000a  {{/place_path}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            place_users_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{{noscript}}}\\u000a    \\u003Cdiv class=\\\"search-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"back-to-home\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{place_path}}\\\"\\u003E&larr; Back to {{name}}\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"geo-place-page-title\\\"\\u003E\\u000a      \\u003Ch2\\u003E\\u000a      Recent people for \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Cdiv class=\\\"geo-place-page-details\\\"\\u003E\\u000a        {{#location_service_down}}\\u000a          Location service is temporarily unavailable\\u000a        {{/location_service_down}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-all {{#active_tab_all}}active{{/active_tab_all}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{place_users_path}}\\\"\\u003EAll\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-following {{#active_tab_following}}active{{/active_tab_following}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{place_users_following_path}}\\\"\\u003EFollowing\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a    {{\\u003Estream_manager}}\\u000a  {{{end_noscript}}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard place-dashboard\\\"\\u003E\\u003C/div\\u003E\\u000a{{\\u003Edetails_pane_container}}\",\n            profile_actions: \"{{#rendering_on_server}}\\u000a  \\u000a  {{^is_current_user}}\\u000a    {{#no_follow_bar}}\\u000a       {{\\u003Euser_actions}}\\u000a    {{/no_follow_bar}}\\u000a    {{^no_follow_bar}}\\u000a      \\u000a      \\u003Cdiv class=\\\"follow-bar\\\"\\u003E\\u000a        {{\\u003Euser_actions}}\\u000a      \\u003C/div\\u003E\\u000a    {{/no_follow_bar}}\\u000a  {{/is_current_user}}\\u000a  {{#is_current_user}}\\u000a    {{\\u003Eedit_profile_button}}\\u000a  {{/is_current_user}}\\u000a{{/rendering_on_server}}\\u000a\\u000a{{^rendering_on_server}}\\u000a  \\u000a  {{^is_current_user}}\\u000a    {{\\u003Ecombo_follow_button}}\\u000a  {{/is_current_user}}\\u000a  {{#is_current_user}}\\u000a    {{\\u003Eedit_profile_button}}\\u000a  {{/is_current_user}}\\u000a{{/rendering_on_server}}\\u000a\",\n            profile_banner: \"\\u003Cdiv class=\\\"profile-banner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner-shadow\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cimg src=\\\"{{banner_url}}\\\"\\u003E\\u000a\\u003C/div\\u003E\",\n            profile_dashboard: \"\\u003Cdiv class=\\\"dashboard profile-dashboard\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#rendering_on_server}}\\u000a      {{#profile_user}}\\u000a      \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a        {{\\u003Edashboard_profile_stats}}\\u000a        \\u003Chr/\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a        {{\\u003Egeneric_footer}}\\u000a      \\u003C/div\\u003E\\u000a      {{/profile_user}}\\u000a    {{/rendering_on_server}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_follow_card: \"\\u003Cdiv class=\\\"flex-module clearfix {{#is_current_user_withheld}}withheld-user{{/is_current_user_withheld}}\\\"\\u003E\\u000a  {{#is_current_user_withheld}}\\u000a    \\u003Cdiv class=\\\"withheld-message\\\"\\u003E{{description}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/div\\u003E\\u000a  {{/is_current_user_withheld}}\\u000a\\u000a  \\u003Ca href=\\\"{{raw_profile_image_url}}\\\" class=\\\"profile-picture\\\" target=\\\"_blank\\\"\\u003E\\u000a    \\u003Cimg src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size128\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cdiv class=\\\"profile-card-inner js-actionable-user\\\" data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Ch1 class=\\\"fullname\\\"\\u003E\\u000a      {{name}}\\u000a      {{#verified}}\\u003Ci class=\\\"verified-large\\\" title=\\\"Verified profile\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a      {{#is_translator}}\\u000a        \\u003Ca class=\\\"translator-badge\\\" href=\\\"{{translator_profile_path}}\\\"\\u003E\\u000a          \\u003Ci class=\\\"translator-large\\\" title=\\\"Translator\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/a\\u003E\\u000a      {{/is_translator}}\\u000a    \\u003C/h1\\u003E\\u000a    \\u003Ch2 class=\\\"username\\\"\\u003E\\u000a      \\u003Cspan class=\\\"js-username\\\"\\u003E\\u003C/span\\u003E\\u000a      {{#protected}}\\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/protected}}\\u000a    \\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}\\u003C/p\\u003E\\u000a    \\u003Cp class=\\\"location-and-url\\\"\\u003E\\u000a      \\u003Cspan class=\\\"location\\\"\\u003E\\u000a        {{location}}\\u000a      \\u003C/span\\u003E\\u000a      {{#location}}\\u000a        {{#display_url_or_url}}\\u000a          \\u003Cspan class=\\\"divider\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a        {{/display_url_or_url}}\\u000a      {{/location}}\\u000a      \\u003Cspan class=\\\"url\\\"\\u003E\\u000a        \\u003Ca target=\\\"_blank\\\" rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\"\\u003E\\u000a          {{{display_url_or_url}}}\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/p\\u003E\\u000a    {{#is_only_admin_accessible}}\\u000a      {{\\u003Eadmin_banner}}\\u000a    {{/is_only_admin_accessible}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"profile-card-actions js-profile-card-actions\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"follow-btn-container\\\"\\u003E\\u000a      {{\\u003Eprofile_actions}}\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Emini_profile_stats}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_header: \"{{%TRANSLATION-HINT mode=profile_tabs}}\\u000a\\u000a\\u003Cdiv class=\\\"profile-header\\\" {{#user_data}}data-user=\\\"{{user_data}}\\\"{{/user_data}} data-screen-name=\\\"{{screen_name}}\\\"\\u003E\\u000a  {{#is_only_admin_accessible}}\\u000a    {{\\u003Eadmin_banner}}\\u000a  {{/is_only_admin_accessible}}\\u000a  \\u003Cdiv class=\\\"profile-info clearfix\\\"\\u003E\\u000a\\u000a    {{#is_withheld}}\\u000a      \\u003Cdiv class=\\\"withheld-message\\\"\\u003E{{description}} \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/div\\u003E\\u000a    {{/is_withheld}}\\u000a\\u000a    \\u003Cdiv class=\\\"profile-image-container\\\"\\u003E\\u000a      \\u003Ca href=\\\"{{raw_profile_image_url}}\\\" class='profile-picture' target=\\\"_blank\\\"\\u003E\\u003Cimg src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\" /\\u003E\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"profile-details\\\"\\u003E\\u000a      {{\\u003Efull_name}}\\u000a      \\u003Cdiv class=\\\"screen-name-and-location\\\"\\u003E\\u003Cspan class=\\\"screen-name screen-name-{{screen_name}} pill\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E {{location}}\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"bio\\\"\\u003E{{{linkified_description}}}\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"url\\\"\\u003E\\u003Ca target=\\\"_blank\\\" rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\"\\u003E{{{display_url_or_url}}}\\u003C/a\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"profile-actions-container {{#should_show_tweet_box}}preceeding-profile-tweet-box{{/should_show_tweet_box}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    {{#rendering_on_server}}\\u000a      \\u003Cdiv class=\\\"component profile-actions-component\\\"\\u003E\\u000a        {{\\u003Eprofile_actions}}\\u000a      \\u003C/div\\u003E\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a  {{#rendering_on_server}}\\u000a    {{#should_show_tweet_box}}\\u000a    \\u003Cdiv class=\\\"profile-actions profile-tweet-box profile-tweet-box-placeholder\\\"\\u003E\\u003C/div\\u003E\\u000a    {{/should_show_tweet_box}}\\u000a  {{/rendering_on_server}}\\u000a\\u000a    \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-tweets {{#active_tab_tweets}}active{{/active_tab_tweets}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{profile_path}}\\\"\\u003ETweets\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{#can_view}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-favorites {{#active_tab_favorites}}active{{/active_tab_favorites}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_favorites_path}}\\\"\\u003EFavorites\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a      {{/can_view}}\\u000a      {{#social_context}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-following dropdown-link {{#active_tab_following}}active{{/active_tab_following}}\\\"\\u003E\\u000a          \\u003Cp class=\\\"tab-text\\\"\\u003EFollowing\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/p\\u003E\\u000a        \\u003C/li\\u003E\\u000a      {{/social_context}}\\u000a      {{^social_context}}\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-following {{#active_tab_following}}active{{/active_tab_following}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_following_path}}\\\"\\u003EFollowing\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{/social_context}}\\u000a      {{#social_context}}\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-followers dropdown-link {{#active_tab_followers}}active{{/active_tab_followers}}\\\"\\u003E\\u000a        \\u003Cp class=\\\"tab-text\\\"\\u003EFollowers\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/p\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{/social_context}}\\u000a      {{^social_context}}\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-followers {{#active_tab_followers}}active{{/active_tab_followers}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"tab-text\\\" href=\\\"{{user_followers_path}}\\\"\\u003EFollowers\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{/social_context}}\\u000a      {{#has_pending_requests}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-pending {{#active_tab_pending}}active{{/active_tab_pending}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text pending-follow\\\" title='Follower requests' href=\\\"{{follower_requests_path}}\\\"\\u003ERequests\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a      {{/has_pending_requests}}\\u000a      \\u003Cli class=\\\"stream-tab stream-tab-lists dropdown-link {{#active_tab_lists}}active{{/active_tab_lists}}\\\"\\u003E\\u000a        \\u003Cp class=\\\"tab-text\\\"\\u003ELists\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/p\\u003E\\u000a      \\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_lists_stream_view_toggler: \"{{\\u003Estream_view_toggler}}\",\n            profile_page: \"{{^render_withheld}}\\u000a  \\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a    {{#render_page_content}}\\u000a      {{#profile_user}}\\u000a        {{\\u003Eprofile_header}}\\u000a      {{/profile_user}}\\u000a      {{\\u003Estream_manager}}\\u000a      {{#rendering_on_server}}\\u003Cscript\\u003Eif (window.ttft) window.ttft.serverRendered('profile');\\u003C/script\\u003E{{/rendering_on_server}}\\u000a    {{/render_page_content}}\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Eprofile_dashboard}}\\u000a  {{\\u003Edetails_pane_container}}\\u000a{{/render_withheld}}\\u000a{{#render_withheld}}\\u000a  {{\\u003Eprofile_page_withheld}}\\u000a{{/render_withheld}}\\u000a\",\n            profile_page_withheld: \"\\u003Cdiv class=\\\"withheld-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a  \\u003Cdiv class=\\\"withheld-user\\\"\\u003E\\u000a    {{#profile_user}}\\u000a      \\u003Ch2\\u003E@{{screen_name}}\\u003C/h2\\u003E\\u000a      \\u003Cp\\u003E{{description}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    {{/profile_user}}\\u000a  \\u003C/div\\u003E\\u000a  {{/render_page_content}}\\u000a  \\u003Cdiv class=\\\"profile-actions-container\\\"/\\u003E\\u000a\\u003C/div\\u003E\",\n            profile_pane: \"\\u003Cdiv class=\\\"profile-modal\\\" {{{source_impression_id}}} {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"profile-modal-header js-twttr-dialog-draggable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-close\\\"/\\u003E\\u000a    \\u003Ca class=\\\"account-group js-account-group js-bubble-event\\\" href=\\\"{{profile_path}}\\\" data-element-term=\\\"view_profile_link\\\" {{#impression_cookie}}data-send-impression-cookie=\\\"true\\\"{{/impression_cookie}}\\u003E\\u000a      \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Cdiv class=\\\"profile-modal-header-inner\\\"\\u003E\\u000a      \\u003Ch2 class=\\\"fullname\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\" {{#impression_cookie}}data-send-impression-cookie=\\\"true\\\"{{/impression_cookie}}\\u003E{{name}}\\u003C/a\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        {{#is_translator}}\\u000a          \\u003Ca class=\\\"translator-badge\\\" href=\\\"{{translator_profile_path}}\\\"\\u003E\\u000a            \\u003Ci class=\\\"translator\\\" title=\\\"Translator\\\"\\u003E\\u003C/i\\u003E\\u000a          \\u003C/a\\u003E\\u000a        {{/is_translator}}\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Ch3 class=\\\"username\\\"\\u003E\\u000a        \\u003Ca class=\\\"pretty-link js-screen-name\\\" href=\\\"{{profile_path}}\\\" {{#impression_cookie}}data-send-impression-cookie=\\\"true\\\"{{/impression_cookie}}\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a        {{^is_current_user}}\\u000a          \\u003Cspan class=\\\"follow-status js-follows-you\\\"\\u003Efollows you\\u003C/span\\u003E\\u000a        {{/is_current_user}}\\u000a        {{#protected}}\\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/protected}}\\u000a      \\u003C/h3\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"profile-modal-extended\\\"\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}\\u003C/p\\u003E\\u000a    \\u003Cp class=\\\"location-and-url\\\"\\u003E\\u000a      \\u003Cspan class=\\\"location\\\"\\u003E\\u000a        {{location}}\\u000a      \\u003C/span\\u003E\\u000a      {{#location}}\\u000a        {{#display_url_or_url}}\\u000a          \\u003Cspan class=\\\"divider\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a        {{/display_url_or_url}}\\u000a      {{/location}}\\u000a      \\u003Cspan class=\\\"url\\\"\\u003E\\u000a        \\u003Ca target=\\\"_blank\\\" rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\"\\u003E\\u000a          {{{display_url_or_url}}}\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/p\\u003E\\u000a    \\u003Cp class=\\\"social-proof js-mini-social-proof-container\\\"\\u003E\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{\\u003Emini_profile_stats}}\\u000a\\u000a  \\u003Cdiv class=\\\"mini-profile-footer {{#protected}}protected-mini-profile-footer{{/protected}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"follow-bar\\\"\\u003E\\u000a      \\u003Csmall\\u003E\\u003Ca class=\\\"view-profile js-mini-profile-user\\\" href=\\\"{{profile_path}}\\\" {{#impression_cookie}}data-send-impression-cookie=\\\"true\\\"{{/impression_cookie}}\\u003EGo to full profile &rarr;\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      {{\\u003Eprofile_actions}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_popup: \"{{#user_view}}\\u000a    \\u003Cdiv class=\\\"profile-modal-header\\\"  data-user-id=\\\"{{id}}\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E\\u000a      \\u003Ca class=\\\"account-group\\\" href=\\\"{{profile_path}}\\\" data-send-impression-cookie=\\\"true\\\"\\u003E\\u000a        \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a      \\u003C/a\\u003E\\u000a      \\u003Cdiv class=\\\"profile-modal-header-inner\\\"\\u003E\\u000a        \\u003Ch2 class=\\\"fullname\\\"\\u003E\\u000a          \\u003Ca href=\\\"{{profile_path}}\\\" data-send-impression-cookie=\\\"true\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a          {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a          {{#is_translator}}\\u000a            \\u003Ca class=\\\"translator-badge\\\" href=\\\"{{translator_profile_path}}\\\"\\u003E\\u000a              \\u003Ci class=\\\"translator\\\" title=\\\"Translator\\\"\\u003E\\u003C/i\\u003E\\u000a            \\u003C/a\\u003E\\u000a          {{/is_translator}}\\u000a        \\u003C/h2\\u003E\\u000a        \\u003Ch3 class=\\\"username\\\"\\u003E\\u000a          \\u003Ca class=\\\"pretty-link\\\" href=\\\"{{profile_path}}\\\" data-send-impression-cookie=\\\"true\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a          {{^is_current_user}}\\u000a            {{#follows_you}}\\u000a              \\u003Cspan class=\\\"follow-status\\\"\\u003Efollows you\\u003C/span\\u003E\\u000a            {{/follows_you}}\\u000a          {{/is_current_user}}\\u000a          {{#protected}}\\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/protected}}\\u000a        \\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"profile-modal-extended\\\"\\u003E\\u000a      \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}\\u003C/p\\u003E\\u000a      \\u003Cp class=\\\"location-and-url\\\"\\u003E\\u000a        \\u003Cspan class=\\\"location\\\"\\u003E\\u000a          {{location}}\\u000a        \\u003C/span\\u003E\\u000a        {{#location}}\\u000a          {{#url}}\\u000a            \\u003Cspan class=\\\"divider\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a          {{/url}}\\u000a        {{/location}}\\u000a        \\u003Cspan class=\\\"url\\\"\\u003E\\u000a          \\u003Ca target=\\\"_blank\\\" rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\"\\u003E\\u000a            {{url}}\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/p\\u003E\\u000a      {{^is_current_user}}\\u000a        {{\\u003Emini_social_proof}}\\u000a      {{/is_current_user}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#page_links}}\\u000a      {{\\u003Emini_profile_stats}}\\u000a    {{/page_links}}\\u000a\\u000a    \\u003Cdiv class=\\\"mini-profile-footer {{#protected}}profile-popup-rounded-bottom{{/protected}}{{^last_three_tweets}}profile-popup-rounded-bottom{{/last_three_tweets}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"follow-bar\\\"\\u003E\\u000a        \\u003Csmall\\u003E\\u003Ca class=\\\"view-profile\\\" href=\\\"{{profile_path}}\\\" data-send-impression-cookie=\\\"true\\\"\\u003EGo to full profile &rarr;\\u003C/a\\u003E\\u003C/small\\u003E\\u000a        {{#is_current_user}}\\u000a          \\u003Ca class=\\\"btn edit-profile-btn js-nav\\\" href=\\\"{{settings_profile_path}}\\\"\\u003EEdit your profile\\u003C/a\\u003E\\u000a        {{/is_current_user}}\\u000a        {{^is_current_user}}\\u000a          {{\\u003Euser_actions}}\\u000a        {{/is_current_user}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#can_view_tweets}}\\u000a    \\u003Cdiv class=\\\"recent-tweets clearfix\\\"\\u003E\\u000a      {{{last_three_tweets}}}\\u000a    \\u003C/div\\u003E\\u000a    {{/can_view_tweets}}\\u000a{{/user_view}}\\u000a\",\n            profile_signup_call_out: \"\\u003Cdiv class=\\\"module signup-call-out profile-signup-call-out\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a      \\u003Ch2\\u003EFollow {{name}}\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Epartial_signup_form}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_similar_to_header: \"\\u003Cdiv class=\\\"profile-similar-to-header clearfix\\\"\\u003E\\u000a  \\u003Ca class=\\\"profile-back-link\\\" href=\\\"{{profile_path}}\\\"\\u003E&larr;&nbsp;Back to&nbsp;@{{screen_name}}\\u003C/a\\u003E\\u000a  \\u003Cdiv class=\\\"profile-similar-to-image-container component\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"user-profile-link user-thumb\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" /\\u003E\\u003C/a\\u003E\\u000a    \\u003Ch2 \\u003ESimilar to @{{screen_name}}\\u003C/h2\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_subpage_dashboard: \"\\u003Ca id=\\\"user-shuffle\\\" title=\\\"{{#logged_in}}Jump to someone you follow{{/logged_in}}{{^logged_in}}Jump to a featured account{{/logged_in}}\\\" /\\u003E\\u000a\\u003Cdiv class=\\\"dashboard profile-subpage-dashboard\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#rendering_on_server}}\\u000a      {{#profile_user}}\\u000a      \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a        {{\\u003Egeneric_footer}}\\u000a      \\u003C/div\\u003E\\u000a      {{/profile_user}}\\u000a    {{/rendering_on_server}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\",\n            profile_tweet_to_button: \"\\u003Ca class=\\\"js-tweet-btn module btn tweet-btn large-tweet-btn\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"tweet-new\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"tweet-to-text\\\"\\u003ETweet to {{name}}\\u003C/span\\u003E\\u003C/a\\u003E\",\n            profile_tweetbox: \"\\u003Ch3\\u003ETweet to {{name}}\\u003C/h3\\u003E\",\n            swift_profile_dashboard: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#profile_banner_available}}\\u000a    {{\\u003Eprofiles/swift_profile_nav}}\\u000a  {{/profile_banner_available}}\\u000a\\u000a  {{#logged_in}}\\u000a    {{^is_current_user}}\\u000a      {{\\u003Eprofiles/swift_profile_tweet_to}}\\u000a    {{/is_current_user}}\\u000a  {{/logged_in}}\\u000a  {{^logged_in}}\\u000a    {{\\u003Eprofile_signup_call_out}}\\u000a  {{/logged_in}}\\u000a\\u000a  {{^profile_banner_available}}\\u000a    {{\\u003Eprofiles/swift_profile_nav}}\\u000a  {{/profile_banner_available}}\\u000a\\u000a  {{#profile_banner_available}}\\u000a    {{\\u003Emedia/grid_layout_media_thumbnails}}\\u000a  {{/profile_banner_available}}\\u000a\\u000a  {{\\u003Ejapanese_ad_iframe}}\\u000a\\u000a  {{#logged_in}}\\u000a    {{#similar_to}}\\u000a      \\u003Cdiv class=\\\"component\\\" data-component-term=\\\"similar_user_recommendations\\\"\\u003E\\u000a        {{\\u003Edashboard_user_similarities}}\\u000a      \\u003C/div\\u003E\\u000a    {{/similar_to}}\\u000a  {{/logged_in}}\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_profile_enhanced_nav: \"\\u003Cul class=\\\"timelines-navigation\\\"\\u003E\\u000a  \\u003Cli class=\\\"profile-nav-btn {{#on_tweets}}active{{/on_tweets}}\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{tweets_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Tweets\\\" original-title=\\\"Tweets\\\" data-original-title=\\\"Tweets\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-tweets\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"profile-nav-btn {{#on_following}}active{{/on_following}}\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{following_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"People\\\" original-title=\\\"People\\\" data-original-title=\\\"People\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-people\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"profile-nav-btn {{#on_lists}}active{{/on_lists}}\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{lists_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Lists\\\" original-title=\\\"Lists\\\" data-original-title=\\\"Lists\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-lists\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"profile-nav-btn {{#on_favorites}}active{{/on_favorites}}\\\"\\u003E\\u000a\\u000a    {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a      \\u003Ca href=\\\"{{favorites_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Favorites\\\" original-title=\\\"Favorites\\\" data-original-title=\\\"Favorites\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-favorites\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a    {{#australian_fav_to_like}}\\u000a      \\u003Ca href=\\\"{{favorites_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Likes\\\" original-title=\\\"Likes\\\" data-original-title=\\\"Likes\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-favorites\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    {{/australian_fav_to_like}}\\u000a    {{#australian_fav_to_star}}\\u000a      \\u003Ca href=\\\"{{favorites_path}}\\\" class=\\\"profile-nav-link js-tooltip\\\" data-placement=\\\"bottom\\\" title=\\\"Stars\\\" original-title=\\\"Stars\\\" data-original-title=\\\"Stars\\\"\\u003E\\u003Ci class=\\\"profile-nav-icon icon-nav-favorites\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    {{/australian_fav_to_star}}\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            swift_profile_header: \"\\u003Cdiv class=\\\"module profile-card component{{#profile_banner_available}} profile-header{{/profile_banner_available}}\\\" data-component-term=\\\"profile_follow_card\\\" {{#user_view}}{{#impression_id}}data-impression-id=\\\"{{impression_id}}\\\"{{/impression_id}}{{/user_view}}\\u003E\\u000a  \\u003Cdiv class=\\\"profile-header-inner flex-module clearfix {{#is_current_user_withheld}}withheld-user{{/is_current_user_withheld}}\\\"\\u003E\\u000a\\u000a    {{#is_current_user_withheld}}\\u000a      \\u003Cdiv class=\\\"withheld-message\\\"\\u003E{{description}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/div\\u003E\\u000a    {{/is_current_user_withheld}}\\u000a\\u000a    {{#should_show_add_photo_image}}\\u000a    \\u003Ca href=\\\"{{settings_profile_path}}\\\" class=\\\"profile-picture\\\" target=\\\"_blank\\\"\\u003E\\u000a      {{^profile_banner_available}}\\u000a        \\u003Cimg src=\\\"{{default_profile_add_photo}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size128\\\"\\u003E\\u000a      {{/profile_banner_available}}\\u000a      {{#profile_banner_available}}\\u000a        \\u003Cimg src=\\\"{{default_profile_add_photo}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size73\\\"\\u003E\\u000a      {{/profile_banner_available}}\\u000a    \\u003C/a\\u003E\\u000a    {{/should_show_add_photo_image}}\\u000a    {{^should_show_add_photo_image}}\\u000a    \\u003Ca href=\\\"{{raw_profile_image_url}}\\\" class=\\\"profile-picture\\\" target=\\\"_blank\\\"\\u003E\\u000a      {{^profile_banner_available}}\\u000a        \\u003Cimg src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size128\\\"\\u003E\\u000a      {{/profile_banner_available}}\\u000a      {{#profile_banner_available}}\\u000a        \\u003Cimg src=\\\"{{bigger_profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size73\\\"\\u003E\\u000a      {{/profile_banner_available}}\\u000a    \\u003C/a\\u003E\\u000a    {{/should_show_add_photo_image}}\\u000a\\u000a    \\u003Cdiv class=\\\"profile-card-inner\\\" data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Ch1 class=\\\"fullname\\\"\\u003E\\u000a        {{name}}\\u000a        {{#verified}}\\u003Ci class=\\\"verified-large\\\" title=\\\"Verified profile\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        {{#is_translator}}\\u000a          \\u003Ca class=\\\"translator-badge\\\" href=\\\"{{translator_profile_path}}\\\"\\u003E\\u000a            \\u003Ci class=\\\"translator-large\\\" title=\\\"Translator\\\"\\u003E\\u003C/i\\u003E\\u000a          \\u003C/a\\u003E\\u000a        {{/is_translator}}\\u000a      \\u003C/h1\\u003E\\u000a      \\u003Ch2 class=\\\"username\\\"\\u003E\\u000a        \\u003Cspan class=\\\"screen-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/span\\u003E\\u000a        {{^is_current_user}}\\u000a          {{#follows_you}}\\u000a            \\u003Cspan class=\\\"follow-status\\\"\\u003Efollows you\\u003C/span\\u003E\\u000a          {{/follows_you}}\\u000a        {{/is_current_user}}\\u000a        {{#protected}}\\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/protected}}\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}\\u003C/p\\u003E\\u000a      \\u003Cp class=\\\"location-and-url\\\"\\u003E\\u000a        \\u003Cspan class=\\\"location\\\"\\u003E\\u000a          {{location}}\\u000a        \\u003C/span\\u003E\\u000a        {{#location}}\\u000a          {{#url}}\\u000a            \\u003Cspan class=\\\"divider\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a          {{/url}}\\u000a        {{/location}}\\u000a        \\u003Cspan class=\\\"url\\\"\\u003E\\u000a          \\u003Ca target=\\\"_blank\\\" rel=\\\"me nofollow\\\" href=\\\"{{url}}\\\"\\u003E\\u000a            {{url}}\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/p\\u003E\\u000a      {{#is_only_admin_accessible}}\\u000a        {{\\u003Eadmin_banner}}\\u000a      {{/is_only_admin_accessible}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{^profile_banner_available}}\\u000a      \\u003Cdiv class=\\\"profile-card-actions\\\"\\u003E\\u000a        {{#is_current_user}}\\u000a          \\u003Ca class=\\\"btn edit-profile-btn js-nav\\\" href=\\\"{{settings_profile_path}}\\\"\\u003EEdit your profile\\u003C/a\\u003E\\u000a        {{/is_current_user}}\\u000a        {{^is_current_user}}\\u000a          {{\\u003Euser_actions}}\\u000a        {{/is_current_user}}\\u000a\\u000a        {{#page_links}}\\u000a          {{\\u003Emini_profile_stats}}\\u000a        {{/page_links}}\\u000a      \\u003C/div\\u003E\\u000a    {{/profile_banner_available}}\\u000a  \\u003C/div\\u003E\\u000a  {{^profile_banner_available}}\\u000a    {{#banner_url}}\\u000a      {{\\u003Eprofile_banner}}\\u000a    {{/banner_url}}\\u000a  {{/profile_banner_available}}\\u000a  {{#profile_banner_available}}\\u000a    \\u003Cdiv class=\\\"flex-module profile-banner-footer clearfix\\\"\\u003E\\u000a      {{#page_links}}\\u000a        {{\\u003Emini_profile_stats}}\\u000a      {{/page_links}}\\u000a\\u000a      {{#is_current_user}}\\u000a        \\u003Cbutton class=\\\"btn dm-button\\\" type=\\\"button\\\"\\u003E\\u003C/button\\u003E\\u000a      {{/is_current_user}}\\u000a      {{^is_current_user}}\\u000a        {{\\u003Euser_actions}}\\u000a      {{/is_current_user}}\\u000a    \\u003C/div\\u003E\\u000a  {{/profile_banner_available}}\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_profile_nav: \"\\u003Cdiv class=\\\"component\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"module profile-nav\\\"\\u003E\\u000a    {{#page_links}}\\u000a    \\u003Cul class=\\\"js-nav-links\\\"\\u003E\\u000a      \\u003Cli class=\\\"{{#on_tweets}}active{{/on_tweets}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{tweets_path}}\\\" data-nav=\\\"profile\\\"\\u003ETweets\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_following}}active{{/on_following}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{following_path}}\\\" data-nav=\\\"following\\\"\\u003EFollowing\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_followers}}active{{/on_followers}}{{#on_followers_you_follow}}active{{/on_followers_you_follow}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{followers_path}}\\\" data-nav=\\\"followers\\\"\\u003EFollowers\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"{{#on_favorites}}active{{/on_favorites}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{favorites_path}}\\\" data-nav=\\\"favorites\\\"\\u003E\\u000a          {{^australian_fav_to_like}}{{^australian_fav_to_star}}Favorites{{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a          {{#australian_fav_to_like}}Likes{{/australian_fav_to_like}}\\u000a          {{#australian_fav_to_star}}Stars{{/australian_fav_to_star}}\\u000a        \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{#show_requests_link}}\\u000a        \\u003Cli class=\\\"{{#on_follower_requests}}active{{/on_follower_requests}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"list-link\\\" href=\\\"{{follower_requests_path}}\\\" data-nav=\\\"follower_requests\\\"\\u003ERequests\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a\\u000a        \\u003C/li\\u003E\\u000a      {{/show_requests_link}}\\u000a      \\u003Cli class=\\\"{{#on_lists}}active{{/on_lists}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{lists_path}}\\\" data-nav=\\\"all_lists\\\"\\u003ELists\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{^profile_banner_available}}\\u000a        {{#photo_thumbnails}}\\u000a          {{\\u003Emedia/media_thumbnails}}\\u000a        {{/photo_thumbnails}}\\u000a      {{/profile_banner_available}}\\u000a    \\u003C/ul\\u003E\\u000a    {{/page_links}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_profile_page: \"{{#user_view}}\\u000a  {{#profile_banner_available}}\\u000a    {{\\u003Eprofiles/swift_profile_dashboard}}\\u000a    {{\\u003Eprofiles/swift_profile_header}}\\u000a  {{/profile_banner_available}}\\u000a  {{^profile_banner_available}}\\u000a    {{\\u003Eprofiles/swift_profile_header}}\\u000a    {{\\u003Eprofiles/swift_profile_dashboard}}\\u000a  {{/profile_banner_available}}\\u000a\\u000a  {{\\u003Eprofiles/swift_profile_suggested_users_shell}}\\u000a  {{\\u003Eprofiles/swift_profile_timeline}}\\u000a{{/user_view}}\\u000a\",\n            swift_profile_suggested_users_shell: \"\\u003Cdiv class=\\\"component\\\" id=\\\"suggested-users\\\"\\u003E\\u003C/div\\u003E\\u000a\",\n            swift_profile_timeline: \"\\u003Cdiv class=\\\"content-main\\\" id=\\\"timeline\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      {{#enhanced_navigation}}\\u000a        {{\\u003Eprofiles/swift_profile_enhanced_nav}}\\u000a      {{/enhanced_navigation}}\\u000a      {{#show_new_list_link}}\\u000a        \\u003Cspan class=\\\"content-header-buttons js-header-button-container\\\"\\u003E\\u000a          {{\\u003Ecreate_list_button}}\\u000a        \\u003C/span\\u003E\\u000a      {{/show_new_list_link}}\\u000a      \\u003Ch2 class=\\\"js-timeline-title\\\"\\u003E{{timeline_title}}\\u000a        {{#toggle}}\\u000a          \\u003Csmall class=\\\"view-toggler\\\"\\u003E{{\\u003Estream_view_toggler}}\\u003C/small\\u003E\\u000a        {{/toggle}}\\u000a      \\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{#can_view_tweets}}\\u000a    {{\\u003Etimeline}}\\u000a  {{/can_view_tweets}}\\u000a  {{^can_view_tweets}}\\u000a    {{\\u003Eprotected_user}}\\u000a  {{/can_view_tweets}}\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_profile_tweet_to: \"\\u003Cdiv class=\\\"module component\\\" data-component-term=\\\"profile_tweetbox\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"profile-tweet-box flex-module\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      \\u003Ch2\\u003ETweet to {{name}}\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Eswift_tweet_box}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            promoted_icon: \"{{#promoted_content}}\\u003Ci class=\\\"badge-tweet badge-tweet-{{disclosure_type}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003EPromoted\\u003C/b\\u003E{{/promoted_content}}\",\n            JSBNG__prompt: \"\\u003Cdiv class=\\\"twttr-prompt\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"btn js-prompt-ok\\\"\\u003E{{ok}}\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"btn js-prompt-cancel\\\"\\u003E{{cancel}}\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            prompt_facebook: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"facebook\\\"\\u003E\\u000a  \\u003Ch2\\u003ESend tweets to Facebook\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003EShare your tweets with your friends on Facebook.\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"{{settings_profile_path}}#fb-button\\\"\\u003ETry it out\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            prompt_facebook_de: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt facebook-de\\\"\\u003E\\u000a  \\u003Ch2\\u003ESende Tweets zu Facebook\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003ETeile Deine Tweets mit Deinen Freunden auf Facebook.\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action js-nav\\\" href=\\\"{{settings_profile_path}}#fb-button\\\"\\u003EProbiere es aus\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_import: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt import\\\"\\u003E\\u000a  \\u003Ch2\\u003EFind your friends on Twitter\\u003C/h2\\u003E\\u000a  \\u003Cp class=\\\"wide\\\"\\u003EImport your contacts from \\u003Cstrong\\u003E{{email}}\\u003C/strong\\u003E or\\u003C/p\\u003E\\u000a  \\u003Cp class=\\\"narrow\\\"\\u003EImport your contacts from \\u003Cstrong\\u003E{{email}}\\u003C/strong\\u003E\\u003C/p\\u003E\\u000a  \\u003Cp class=\\\"narrow\\\"\\u003ESelect another service:\\u003C/p\\u003E\\u000a  \\u003Ca class=\\\"services call-to-action\\\" href=\\\"{{who_to_follow_import_path}}\\\"\\u003E\\u000a    \\u003Cspan class=\\\"gmail\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"yahoo\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"msn\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"aol\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"linkedin\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca href=\\\"{{who_to_follow_import_path}}\\\" class=\\\"btn call-to-action\\\"\\u003EFind friends\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_import_inline: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt import import-inline\\\"\\u003E\\u000a{{\\u003Edashboard_contact_import}}\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_invite: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt invite\\\"\\u003E\\u000a  \\u003Ch2\\u003EInvite friends via email\\u003C/h2\\u003E\\u000a  \\u003Cp class=\\\"fine-print\\\"\\u003ELots of people to invite? Separate multiple email addresses with commas.\\u003C/p\\u003E\\u000a  \\u003Cp class=\\\"fine-print\\\"\\u003E\\u000a    \\u003Ca href=\\\"/invitations/email_preview\\\" class=\\\"js-popup\\\" name=\\\"invitation_email_preview\\\" data-popup=\\\"height=450,width=670\\\"\\u003ESee what you'll send them.\\u003C/a\\u003E\\u000a  \\u003C/p\\u003E\\u000a  \\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u003Cform\\u003E\\u000a      \\u003Ctable class=\\\"flex-table\\\"\\u003E\\u000a        \\u003Ctbody\\u003E\\u000a          \\u003Ctr\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"flex-table-form\\\"\\u003E\\u000a                \\u003Ctextarea class=\\\"flex-table-input\\\" name=\\\"addresses\\\" placeholder=\\\"Your friend's email address\\\"\\u003E\\u003C/textarea\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/td\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a              \\u003Cbutton class=\\\"btn flex-table-btn js-submit call-to-action\\\" type=\\\"submit\\\" tabindex=\\\"0\\\"\\u003ESend\\u003C/button\\u003E\\u000a            \\u003C/td\\u003E\\u000a          \\u003C/tr\\u003E\\u000a        \\u003C/tbody\\u003E\\u000a      \\u003C/table\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language: \"{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"language\\\" data-language=\\\"{{lang_code}}\\\"{{dir}}\\u003E\\u000a  \\u000a  \\u003Ch2\\u003E{{speak_text}}\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    {{available_text}}\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"{{dir}}\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E{{button_text}}\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\",\n            prompt_language_de: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"de\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003ESprichst du deutsch?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter ist auf deutsch verf\\u00fcgbar. Klicke, um deine Spracheinstellung zu \\u00e4ndern.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EVerwende Twitter auf deutsch\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_es: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"es\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003E\\u00bfHablas espa\\u00f1ol?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter esta disponible en espa\\u00f1ol. Haz clic para cambiar tu configuraci\\u00f3n de idioma.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EUsa Twitter en espa\\u00f1ol\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_fil: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"fil\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003ENagsasalita ka ba ng Filipino?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Ang Twitter ay magagamit na sa Filipino. I-click upang baguhin ang iyong mga setting ng wika.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EGamitin ang Twitter sa Filipino.\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_fr: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"fr\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003EParlez-vous fran\\u00e7ais?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter est disponible en fran\\u00e7ais. Cliquez pour changer de langue.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EUtiliser Twitter en fran\\u00e7ais\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_hi: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"hi\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003E\\u0915\\u094d\\u092f\\u093e \\u0906\\u092a \\u0939\\u093f\\u0902\\u0926\\u0940 \\u092c\\u094b\\u0932\\u0924\\u0947 \\u0939\\u0948\\u0902?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    \\u091f\\u094d\\u0935\\u093f\\u091f\\u094d\\u091f\\u0930 \\u0939\\u093f\\u0928\\u094d\\u0926\\u0940 \\u092e\\u0947\\u0902 \\u0909\\u092a\\u0932\\u092c\\u094d\\u0927 \\u0939\\u0948. \\u0905\\u092a\\u0928\\u0940 \\u092d\\u093e\\u0937\\u093e \\u0938\\u0947\\u091f\\u093f\\u0902\\u0917 \\u092c\\u0926\\u0932\\u0928\\u0947 \\u0915\\u0947 \\u0932\\u093f\\u090f \\u0915\\u094d\\u0932\\u093f\\u0915 \\u0915\\u0930\\u0947\\u0902.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\u0939\\u093f\\u0902\\u0926\\u0940 \\u092e\\u0947\\u0902 \\u091f\\u094d\\u0935\\u093f\\u091f\\u094d\\u091f\\u0930 \\u0915\\u093e \\u092a\\u094d\\u0930\\u092f\\u094b\\u0917 \\u0915\\u0930\\u0947\\u0902\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_id: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"id\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003EBisa berbahasa Indonesia?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter tersedia dalam Bahasa Indonesia. Klik untuk mengubah bahasa.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EPakai Twitter dalam Bahasa Indonesia\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_it: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"it\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003EParli italiano?\\u003C/h2\\u003E\\u000a    \\u000a    \\u003Cp\\u003ETwitter \\u00e8 disponibile in italiano. Clicca per modificare le impostazioni sulla lingua\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EUsa Twitter in italiano\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_ja: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"ja\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003E\\u65e5\\u672c\\u8a9e\\u3092\\u4f7f\\u3044\\u307e\\u3059\\u304b\\uff1f\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u000a      \\u65e5\\u672c\\u8a9e\\u3067 Twitter \\u3092\\u5229\\u7528\\u3067\\u304d\\u307e\\u3059\\u3002\\u8a00\\u8a9e\\u8a2d\\u5b9a\\u3092\\u5909\\u66f4\\u3059\\u308b\\u306b\\u306f\\u30af\\u30ea\\u30c3\\u30af\\u3057\\u3066\\u304f\\u3060\\u3055\\u3044\\u3002\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u000a  \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\u65e5\\u672c\\u8a9e\\u3067 Twitter \\u3092\\u5229\\u7528\\u3059\\u308b \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_ko: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"ko\\\"\\u003E\\u000a      \\u000a      \\u003Ch2\\u003E\\ud55c\\uad6d\\uc5b4\\ub97c \\uc0ac\\uc6a9\\ud558\\uc138\\uc694?\\u003C/h2\\u003E\\u000a      \\u000a      \\u003Cp\\u003E\\u000a        \\ud2b8\\uc704\\ud130\\ub97c \\ud55c\\uad6d\\uc5b4\\ub85c \\uc990\\uae30\\uc2e4 \\uc218 \\uc788\\uc2b5\\ub2c8\\ub2e4. \\ud074\\ub9ad\\ud558\\uba74 \\uc5b8\\uc5b4\\uc124\\uc815\\uc73c\\ub85c \\uc774\\ub3d9\\ud569\\ub2c8\\ub2e4.\\u000a      \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a      \\u000a      \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\ud55c\\uad6d\\uc5b4\\ub85c \\ud2b8\\uc704\\ud130 \\uc774\\uc6a9\\ud558\\uae30\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_msa: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"msa\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003EAnda cakap Malaysia?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter tersedia dalam Bahasa Malaysia. Klik untuk mengubah tetapan bahasa anda.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003EPakai Twitter dalam Bahasa Malaysia.\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_nl: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"nl\\\"\\u003E\\u000a  \\u000a  \\u003Ch2\\u003ESpreek je Nederlands?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    Twitter is beschikbaar in het Nederlands. Klik om je taalinstelling te wijzigen.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003ETwitter gebruiken in het Nederlands.\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_pt: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003EVoc\\u00ea fala Portugu\\u00eas?\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u000a      Twitter est\\u00e1 dispon\\u00edvel em Portugu\\u00eas. Clique para alterar a configura\\u00e7\\u00e3o de idioma.\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action\\\"\\u003EUse o Twitter em Portugu\\u00eas\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_ru: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"ru\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003E\\u0412\\u044b \\u0433\\u043e\\u0432\\u043e\\u0440\\u0438\\u0442\\u0435 \\u043f\\u043e-\\u0440\\u0443\\u0441\\u0441\\u043a\\u0438?\\u003C/h2\\u003E\\u000a    \\u000a    \\u003Cp\\u003E\\u000a      \\u0422\\u0432\\u0438\\u0442\\u0442\\u0435\\u0440 \\u0434\\u043e\\u0441\\u0442\\u0443\\u043f\\u0435\\u043d \\u043d\\u0430 \\u0440\\u0443\\u0441\\u0441\\u043a\\u043e\\u043c \\u044f\\u0437\\u044b\\u043a\\u0435. \\u041d\\u0430\\u0436\\u043c\\u0438\\u0442\\u0435 \\u043d\\u0438\\u0436\\u0435, \\u0447\\u0442\\u043e\\u0431\\u044b \\u0441\\u043c\\u0435\\u043d\\u0438\\u0442\\u044c \\u044f\\u0437\\u044b\\u043a.\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\u041f\\u0435\\u0440\\u0435\\u0439\\u0442\\u0438 \\u043d\\u0430 \\u0440\\u0443\\u0441\\u0441\\u043a\\u0438\\u0439 \\u044f\\u0437\\u044b\\u043a\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_tr: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"tr\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003ET\\u00fcrk\\u00e7e biliyor musun?\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u000a      Twitter, T\\u00fcrk\\u00e7e kullan\\u0131labilir. Dil ayar\\u0131n\\u0131 de\\u011fi\\u015ftirmek i\\u00e7in t\\u0131kla.\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003ETwitter'\\u0131 T\\u00fcrk\\u00e7e kullan\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_zh_cn: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"zh-cn\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003E\\u4f60\\u7528\\u7b80\\u4f53\\u4e2d\\u6587\\u5417? \\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u000a       Twitter \\u6709\\u7b80\\u4f53\\u4e2d\\u6587\\u7248\\u672c\\u53ef\\u7528\\u3002 \\u70b9\\u51fb\\u4ee5\\u66f4\\u6539\\u8bed\\u8a00\\u8bbe\\u7f6e\\u3002\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\u4f7f\\u7528\\u7b80\\u4f53\\u4e2d\\u6587\\u7248 Twitter\\u3002\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_language_zh_tw: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt language\\\" data-language=\\\"zh-tw\\\"\\u003E\\u000a    \\u000a    \\u003Ch2\\u003E\\u4f60\\u4f7f\\u7528\\u7e41\\u9ad4\\u4e2d\\u6587\\u55ce\\uff1f\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      \\u000a      Twitter\\u7d42\\u65bc\\u6709\\u7e41\\u9ad4\\u4e2d\\u6587\\u4e86\\u3002\\u6309\\u9019\\u88e1\\u6539\\u8b8a\\u4f60\\u7684\\u8a9e\\u8a00\\u8a2d\\u5b9a\\u3002\\u000a    \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a    \\u000a    \\u003Cspan class=\\\"btn call-to-action set-language\\\"\\u003E\\u4f7f\\u7528\\u7e41\\u9ad4\\u4e2d\\u6587\\u7684Twitter\\u3002\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_lifeline_ja: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt lifeline-ja\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u30c4\\u30a4\\u30c3\\u30bf\\u30fc\\u3092\\u30e9\\u30a4\\u30d5\\u30e9\\u30a4\\u30f3\\u3068\\u3057\\u3066\\u6d3b\\u7528\\u3059\\u308b\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u707d\\u5bb3\\u6642\\u306b\\u7dca\\u6025\\u60c5\\u5831\\u3092\\u30c4\\u30a4\\u30fc\\u30c8\\u3059\\u308b\\u30a2\\u30ab\\u30a6\\u30f3\\u30c8\\u3092\\u30d5\\u30a9\\u30ed\\u30fc\\u3057\\u307e\\u3057\\u3087\\u3046\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"/#!/who_to_follow/lifeline\\\"\\u003E\\u30e9\\u30a4\\u30d5\\u30e9\\u30a4\\u30f3\\u30a2\\u30ab\\u30a6\\u30f3\\u30c8\\u3092\\u30c1\\u30a7\\u30c3\\u30af\\u3059\\u308b\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_mobile: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt mobile\\\"\\u003E\\u000a  \\u003Ch2\\u003ETake Twitter with you\\u003C/h2\\u003E\\u000a  \\u003Cdiv class=\\\"promptbird-image mobile-devices\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u000a    \\u000a    \\u000a    Get the Twitter app for your \\u003Ca href=\\\"{{android_path}}\\\" class=\\\"call-to-action\\\"\\u003EAndroid\\u003C/a\\u003E, \\u003Ca href=\\\"{{blackberry_path}}\\\" class=\\\"call-to-action\\\"\\u003EBlackberry\\u003C/a\\u003E, \\u003Ca href=\\\"{{iphone_path}}\\\" class=\\\"call-to-action\\\"\\u003EiPhone\\u003C/a\\u003E, \\u003Ca href=\\\"{{ipad_path}}\\\" class=\\\"call-to-action\\\"\\u003EiPad\\u003C/a\\u003E, or \\u003Ca href=\\\"{{wp7_path}}\\\" class=\\\"call-to-action\\\"\\u003EWindows Phone 7\\u003C/a\\u003E.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"{{mobile_gallery_path}}\\\"\\u003EDownload the app\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_olympics: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt olympics\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"promptbird-image olympics-image\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Ch2\\u003EThe #Olympics are here!\\u003C/h2\\u003E\\u000a  \\u003Cp class=\\\"olympics-copy\\\"\\u003E\\u000a    Dedication. Sacrifice. Guts. Glory.\\u000a    \\u003Cbr /\\u003E\\u000a    Get closer to the #Olympics on Twitter.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"/hashtag/olympics\\\"\\u003EView Tweets about #Olympics\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_one_click_import: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class='one-click-import'\\u003E\\u000a  \\u003Ch2 class='one-click-import-header'\\u003EFind your friends on Twitter\\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"prompt promptbird-action-bar\\\"\\u003E\\u000a  \\u003Cspan href=\\\"#\\\" class=\\\"one-click-import-button btn call-to-action\\\" data-email=\\\"{{email}}\\\"\\u003EImport your contacts from {{email}}\\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_profile: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt profile\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    Complete your profile\\u000a  \\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    It helps instantly identify you to those following you, and tells those who aren't more about you.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action js-nav\\\" href=\\\"{{settings_profile_path}}\\\"\\u003EComplete your profile\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_self_serve_ads: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt grow-your-presence\\\"\\u003E\\u000a  \\u003Ch2\\u003EWant to grow your presence on Twitter?\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    Grow your followers, reach more customers and track your progress.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"https://business.twitter.com/en/smallbiz/campaign/start-2a.html\\\"\\u003EGet started\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_sms: \"\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"sms\\\"\\u003E\\u000a  \\u003Ch2\\u003ETake Twitter with you\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003E\\u000a    Get notifications, follow people \\u2013 all the same great features, on your phone.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"promptbird-action-bar\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn call-to-action\\\" href=\\\"/settings/devices\\\"\\u003EAdd your mobile phone\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            prompt_vit_de: \"\\u000a\\u000a{{\\u003Edismiss_button}}\\u000a\\u003Cdiv class=\\\"prompt vit-de\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"text\\\"\\u003E\\u000a    \\u003Ch2\\u003E@tape_tv ist jetzt auf Twitter (\\u003Ca href=\\\"/tape_tv\\\"\\u003E@tape_tv\\u003C/a\\u003E)\\u003C/h2\\u003E\\u000a    \\u003Cimg class=\\\"vit_de_img\\\" src=\\\"//si0.twimg.com/profile_images/1104820344/Untitled-1_normal.jpg\\\"\\u003E\\u003C/img\\u003E\\u000a    \\u003Ch3\\u003E\\u000a      tape.tv ist Dein Musikfernsehen.  Hier gibt es Empfehlungen zu neuen, guten und alten Musikvideos.\\u000a    \\u003C/h3\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"buttons promptbird-action-bar\\\"\\u003E\\u000a    {{\\u003Ecombo_follow_button}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            promptbird: \"\\u003Cdiv class=\\\"promptbird {{css_format_class}}\\\" data-prompt-id=\\\"{{prompt_id}}\\\"\\u003E\\u000a  {{{prompt_contents}}}\\u000a\\u003C/div\\u003E\\u000a\",\n            protected_ancestor_tweet: \"\\u003Cdiv class=\\\"simple-tweet tweet js-stream-tweet js-actionable-tweet js-profile-popup-actionable\\\"\\u003E\\u000a  \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      {{\\u003Etweet_user_block}}\\u000a    \\u003C/div\\u003E\\u000a    {{#user}}\\u003Cp class=\\\"js-tweet-text\\\"\\u003E\\u003Cem\\u003E@{{screen_name}}'s account is protected.\\u003C/em\\u003E\\u003C/p\\u003E{{/user}}\\u000a    \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            protected_user: \"\\u003Cdiv class=\\\"stream-protected stream-placeholder\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003E@{{screen_name}}'s account is protected.\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003EOnly confirmed followers have access to @{{screen_name}}'s Tweets and complete profile. Click the \\\"Follow\\\" button to send a follow request.\\u003C/p\\u003E\\u000a    \\u003Ci class=\\\"watermark-lock\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            proxy_tweet: \"{{#rendering_on_server}}\\u000a  {{!\\u000a    When Swift dialogs open in response to a Tweet action, they copy the Tweet into the dialog.\\u000a    Some presentations of Tweets don't look right when inside of a dialog, so we include a\\u000a    standard stream Tweet, hidden inside of a proxy container, for use by the dialog.\\u000a  }}\\u000a  \\u003Cdiv class=\\\"proxy-tweet-container\\\"\\u003E\\u000a    {{\\u003Estream_tweet}}\\u000a  \\u003C/div\\u003E\\u000a{{/rendering_on_server}}\",\n            qunit_tests: \"\\u000a\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"en\\\"\\u003E\\u000a\\u003Chead\\u003E\\u000a  \\u003Cmeta charset=\\\"utf-8\\\"/\\u003E\\u000a  \\u003Ctitle\\u003E{{#is_t1}}T1 Tests{{/is_t1}}{{^is_t1}}Phoenix Tests{{/is_t1}}\\u003C/title\\u003E\\u000a\\u000a  \\u003Cstyle type=\\\"text/css\\\" media=\\\"screen\\\"\\u003E\\u000a    iframe {\\u000a      position: absolute;\\u000a      left: -9999em;\\u000a      top: -9999em;\\u000a    }\\u000a  \\u003C/style\\u003E\\u000a\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner_plugin_signal.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner_plugin_json.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner_plugin_css.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/js/tests/test_setup.js\\\"\\u003E\\u003C/script\\u003E\\u000a\\u000a  {{#qunit_css}}\\u000a    \\u003Clink rel=stylesheet href=\\\"{{file_name}}\\\" /\\u003E\\u000a  {{/qunit_css}}\\u000a\\u000a  \\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a    /* Degrade gracefully if the browser doesn't support console.log */\\u000a    {{{fake_console_js}}}\\u000a\\u000a    // Make these globally overrideable in IE\\u000a    window.setTimeout = window.setTimeout;\\u000a    window.setInterval = window.setInterval;\\u000a    window.clearTimeout = window.clearTimeout;\\u000a    window.clearInterval = window.clearInterval;\\u000a  \\u003C/script\\u003E\\u000a\\u000a  \\u003C!-- QUnit and other libraries --\\u003E\\u000a  \\u003Cscript src=\\\"/phoenix/external_resources/watch.js\\\" type=\\\"text/javascript\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript src=\\\"/phoenix/js/lib/qunit.js\\\" type=\\\"text/javascript\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript\\u003E\\u000a    testSetup.loadrunnerOptions('{{{loadrunner_modpath}}}');\\u000a\\u000a  // We always line bootstrap data in qunit since caching for logged out is not a concern here\\u000a  provide('boot/bootstrap_data', function(exports) {\\u000a    signal('\\u003EdeciderFeaturesFromBootstrap');\\u000a    exports({{{bootstrap_data_json}}});\\u000a  });\\u000a\\u000a  {{{inline_request_log}}}\\u000a\\u000a  {{#assets_from_cdn}}\\u000a    var bootData = {{{boot_data_json}}};\\u000a    using.bundles.push(bootData.loadrunnerAssets);\\u000a  {{/assets_from_cdn}}\\u000a\\u000a  // QUnit logging extensions\\u000a  var _qunitErrorLog = \\\"\\\",\\u000a      _qunitDone = false,\\u000a      _qunitFailures,\\u000a      _qunitTotal;\\u000a\\u000a  var twttr = {};\\u000a\\u000a  \\u003C/script\\u003E\\u000a\\u000a  \\u003Cscript src=\\\"/phoenix/external_resources/swift_reroute.js\\\" type=\\\"text/javascript\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript\\u003E\\u000a\\u000a  // used by bluejs\\u000a  window.isTestMode = true;\\u000a\\u000a  // Make sure to use precompiled scripts for Hogan testing\\u000a  function compileTemplates() {\\u000a     var func;\\u000a     for (var t in twttr.templates) {\\u000a       eval('func = ' + Mustache.twitterHogan.compile(twttr.templates[t], {asString: true, sectionTags:[{o: '_i', c: 'i'}]}));\\u000a       twttr.templates[t] = new Mustache.TwitterTemplate(func, \\\"\\\", Mustache.twitterHogan, {sectionTags:[{o: \\\"_i\\\", c: \\\"i\\\"}], disableLambda:true});\\u000a       var view = twttr.util.camelize(t);\\u000a       view = view.charAt(0).toUpperCase() + view.slice(1);\\u000a       twttr.views[view]._template = twttr.templates[t];\\u000a     }\\u000a  }\\u000a\\u000a  var useHogan = ~window.JSBNG__location.search.indexOf('hogan=force');\\u000a\\u000a  using(\\u000a      '/phoenix/js/run/qunitExtensions.js',\\u000a      '/phoenix/js/bluejs/test/helpers/shadow.js',\\u000a      '/phoenix/js/tests/test_helpers.js',\\u000a      'boot/bootstrap_data',\\u000a      function(data) {\\u000a\\u000a      testSetup.qunitOptions();\\u000a      localStorage && localStorage.clear();\\u000a      sessionStorage && sessionStorage.clear();\\u000a      testSetup.twttrGlobals(data, {{is_t1}}, {{expando}});\\u000a\\u000a      using(\\u000a        twttr.bundleCore,\\u000a        'requestLog', // only required for selenium and qunit tests\\u000a            function() {\\u000a              using(\\u000a                twttr.bundleMore,\\u000a                'phoenix/external_resources/admin.js',\\u000a                function() {\\u000a                  window.getFixtureData = function(fixture_name) {\\u000a                    var allFixtures = {{{json_fixtures}}};\\u000a                    return allFixtures[fixture_name] || {};\\u000a                  };\\u000a\\u000a                  testSetup.overwriteScribeAndDecider();\\u000a\\u000a                  using(\\u000a                    '/phoenix/js/bluejs/test/helpers/api_harness.js',\\u000a                    '/phoenix/js/bluejs/test/fixtures/fixtures.js',\\u000a                    '/phoenix/js/tests/fixtures/autocomplete_fixtures.js',\\u000a                    function() {\\u000a                    mockAPI();\\u000a                    signal('\\u003Epayload');\\u000a                    signal('\\u003Eapi_ready');\\u000a\\u000a                    var bundleFetchEndTime = new Date();\\u000a\\u000a                    testSetup.overwriteScribeAndDecider();\\u000a                    twttr.$win = $(window);\\u000a                    twttr.$doc = $(document);\\u000a                    var scripts = [];\\u000a\\u000a                    if (useHogan) {\\u000a                      scripts.push('/phoenix/js/lib/hogan.js');\\u000a                    }\\u000a\\u000a                    {{#phoenix_js_tests}}\\u000a                      scripts.push('{{file_name}}');\\u000a                      using(scripts, function() {\\u000a                        sanityCheckTestFile(\\\"{{file_name}}\\\");\\u000a                      });\\u000a                    {{/phoenix_js_tests}}\\u000a\\u000a                    using(scripts, function() {\\u000a                      if (useHogan) {\\u000a                        compileTemplates();\\u000a                      }\\u000a                      start();\\u000a                    });\\u000a                  });\\u000a                }\\u000a          );\\u000a        }\\u000a      );\\u000a    });\\u000a  \\u003C/script\\u003E\\u000a\\u000a\\u003C/head\\u003E\\u000a\\u003Cbody\\u003E\\u000a  \\u003Ch1 id=\\\"qunit-header\\\"\\u003E{{#is_t1}}T1 Tests{{/is_t1}}{{^is_t1}}Phoenix Tests{{/is_t1}}\\u003C/h1\\u003E\\u000a  \\u003Ch2 id=\\\"qunit-banner\\\"\\u003E\\u003C/h2\\u003E\\u000a  \\u003Ch2 id=\\\"qunit-userAgent\\\"\\u003E\\u003C/h2\\u003E\\u000a  \\u003Col id=\\\"qunit-tests\\\"\\u003E\\u003C/ol\\u003E\\u000a  \\u003Cdiv id='test-content'\\u003E\\u003C/div\\u003E\\u000a  \\u003C!-- This is (our version of) QUnit's default HTML fixture area --\\u003E\\u000a  \\u003Cdiv id='main'\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog-wrapper\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/body\\u003E\\u000a\\u003C/html\\u003E\\u000a\",\n            rate_limit_page: \"\\u003Cdiv class=\\\"four-twenty\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    \\u003Ch2\\u003EUh-oh! You're being rate-limited!\\u003C/h2\\u003E\\u000a\\u000a    \\u003Cp class='rate-limit-message'\\u003E\\u000a      While we appreciate your enthusiasm, in order to control abuse, we limit how often you can search.\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cp class='rate-limit-message'\\u003E\\u000a      For locations where many people share the same IP address (e.g., corporations and conferences), our rate limits may be too strict. If you believe you are using Twitter normally, please \\u003Ca href=\\\"{{support_path}}\\\"\\u003Elet us know\\u003C/a\\u003E.\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cp\\u003E{{\\u003Egeneric_footer}}\\u003C/p\\u003E\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\",\n            reactivated_banner: \"\\u003Cdiv class=\\\"banner-outer banner-border\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"banner-inside\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"account-reactivated\\\" class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Ca class='pane-close' href='#'\\u003EClose \\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EWelcome back!\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EIf you didn't mean to reactivate your account, you can deactivate it again from the \\u003Ca class=\\\"reactivate-settings-link\\\" href=\\\"{{settings_path}}\\\"\\u003Esettings page\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            recent_profile_activity: \"{{#show_following}}\\u000a  {{\\u003Efollowing_list_small}}\\u000a{{/show_following}}\\u000a\\u000a{{#show_following_full}}\\u000a  {{\\u003Efollowing_list_full}}\\u000a{{/show_following_full}}\\u000a\\u000a{{#show_followers}}\\u000a  {{\\u003Efollowers_list_small}}\\u000a{{/show_followers}}\\u000a\\u000a{{#show_wtf_links}}\\u000a  {{^following_nobody}}\\u000a    {{#positive_nooblevel}}\\u000a      {{\\u003Ewho_to_follow_links}}\\u000a    {{/positive_nooblevel}}\\u000a  {{/following_nobody}}\\u000a{{/show_wtf_links}}\",\n            recent_tweets: \"\\u003Cdiv class=\\\"recent-tweets\\\"\\u003E\\u000a  {{#items}}\\u000a    {{\\u003Esimple_tweet}}\\u000a  {{/items}}\\u000a\\u003C/div\\u003E\",\n            recently_followed: \"\\u003Cdiv class=\\\"recently-followed-users\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"followed clearfix {{#following_10}}following-10{{/following_10}}\\\"\\u003E\\u000a    {{#welcome_flow}}\\u000a      {{#screen_name}}\\u000a        \\u003Ch2\\u003EWelcome To Twitter @{{screen_name}}!\\u003C/h2\\u003E\\u000a      {{/screen_name}}\\u000a      {{^screen_name}}\\u000a        \\u003Ch2\\u003EWho do you want to follow?\\u003C/h2\\u003E\\u000a      {{/screen_name}}\\u000a\\u000a      \\u003Cp class=\\\"welcome-few-followers\\\"\\u003ETo get the most out of Twitter follow your first \\u003Cstrong\\u003E10 accounts\\u003C/strong\\u003E that are of interest to you.\\u003C/p\\u003E\\u000a      {{^abtest_timeline_copy_317_any_bucket}}\\u000a        \\u003Cp class=\\\"welcome-many-followers\\\"\\u003EAwesome, you've followed your first 10! As you follow more users, your timeline of updates will get better and better.\\u003C/p\\u003E\\u000a      {{/abtest_timeline_copy_317_any_bucket}}\\u000a      {{#abtest_timeline_copy_317_stream}}\\u000a        \\u003Cp class=\\\"welcome-many-followers\\\"\\u003EAwesome, you've followed your first 10! As you follow more users, your stream of updates will get better and better.\\u003C/p\\u003E\\u000a      {{/abtest_timeline_copy_317_stream}}\\u000a      \\u003Ch2 class=\\\"welcome-follow-count\\\"\\u003EYou follow \\u003Cspan\\u003E{{following_count}}\\u003C/span\\u003E\\u003C/h2\\u003E\\u000a    {{/welcome_flow}}\\u000a    {{^welcome_flow}}\\u000a        \\u003Ch2\\u003E\\u000a          You recently followed\\u000a          {{#user}}\\u000a            \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a            \\u003Ca class='view-all' href=\\\"{{user_following_path}}\\\"\\u003Eview all\\u003C/a\\u003E\\u000a          {{/user}}\\u000a        \\u003C/h2\\u003E\\u000a    {{/welcome_flow}}\\u000a\\u000a    {{#latest_friends}}\\u000a      {{\\u003Euser_thumb_list}}\\u000a    {{/latest_friends}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{#latest_friend}}\\u000a    \\u003Cdiv class=\\\"suggestions clearfix\\\"\\u003E\\u000a        \\u003Chr /\\u003E\\u000a        \\u003Cp\\u003ESimilar to \\u003Cspan\\u003E{{latest_friend}}\\u003C/span\\u003E\\u003C/p\\u003E\\u000a        \\u003Cul /\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/latest_friend}}\\u000a\\u003C/div\\u003E\\u000a\",\n            recently_viewed: \"\\u003Cdiv class=\\\"recently-viewed-users clearfix\\\"\\u003E\\u000a\\u000a  \\u003Ch2\\u003E\\u000a    You recently viewed\\u000a    \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a    \\u003Ca class='clear-all' href=\\\"#\\\"\\u003Eclear\\u003C/a\\u003E\\u000a  \\u003C/h2\\u003E\\u000a\\u000a  \\u003Cul\\u003E\\u000a    {{\\u003Euser_small_list}}\\u000a  \\u003C/ul\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            related_queries: \"\\u003Cdiv class=\\\"js-related-queries search-assist-related-queries\\\" data-component-term=\\\"related_queries\\\"\\u003E\\u000a  Related:\\u000a  {{#related_queries}}\\u000a    \\u003Ca href=\\\"{{url}}\\\" title=\\\"{{related_query}}\\\" data-query=\\\"{{query}}\\\" data-search-assistance=\\\"{{related_query}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E{{related_query}}\\u003C/a\\u003E{{delimiter}}\\u000a  {{/related_queries}}\\u000a\\u003C/div\\u003E\",\n            related_tweets_data_attributes: \"data-related-impression-id=\\\"{{related_impression_id}}\\\" data-related-group-name=\\\"{{related_group_name}}\\\" data-related-annotations=\\\"{{related_annotations}}\\\"\\u000a{{#ab_data_bucket}}\\u000a  data-ab-data-bucket=\\\"{{ab_data_bucket}}\\\" data-ab-data-experiment-key=\\\"{{ab_data_experiment_key}}\\\" data-ab-data-version=\\\"{{ab_data_version}}\\\"\\u000a{{/ab_data_bucket}}\",\n            replies: \"{{#rendering_on_server}}\\u000a  {{^on_permalink}}\\u000a    \\u003Cdiv class=\\\"replies js-conversation-replies\\\"\\u003E\\u000a  {{/on_permalink}}\\u000a\\u000a    {{#reply_tweet_box}}\\u000a      \\u003Cdiv class=\\\"inline-reply-tweetbox swift\\\"\\u003E\\u000a        {{#current_user}}\\u000a        \\u003Cimg class=\\\"inline-reply-user-image avatar size32\\\" src=\\\"{{profile_image_absolute_url}}\\\"\\u003E\\u000a        {{/current_user}}\\u000a\\u000a        {{#on_permalink}}\\u000a          {{\\u003Eswift_tweet_box}}\\u000a        {{/on_permalink}}\\u000a      \\u003C/div\\u003E\\u000a    {{/reply_tweet_box}}\\u000a{{/rendering_on_server}}\\u000a\\u000a{{#has_replies}}\\u000a  {{\\u003Ereplies_to}}\\u000a{{/has_replies}}\\u000a\\u000a{{^has_replies}}\\u000a  {{#swift}}\\u000a    {{\\u003Ereplies_to}}\\u000a  {{/swift}}\\u000a{{/has_replies}}\\u000a\\u000a{{#rendering_on_server}}\\u000a  {{^on_permalink}}\\u000a  \\u003C/div\\u003E\\u000a  {{/on_permalink}}\\u000a{{/rendering_on_server}}\\u000a\",\n            replies_to: \"\\u003Cdiv class=\\\"{{^has_replies}}hidden {{/has_replies}}replies-to{{#on_permalink}} permalink-inner permalink-replies{{/on_permalink}}{{#rendering_on_server}} swift{{/rendering_on_server}}\\\" {{\\u003Erelated_tweets_data_attributes}}\\u003E\\u000a  \\u003Cdiv class=\\\"tweets-wrapper\\\"\\u003E\\u000a    {{#has_replies}}\\u000a      {{#replies_html}}\\u000a        {{{replies_html}}}\\u000a      {{/replies_html}}\\u000a      {{^replies_html}}\\u000a        {{#descendant_tweet_views}}\\u000a          {{\\u003Esimple_tweet}}\\u000a        {{/descendant_tweet_views}}\\u000a        {{#fork_tweet_views}}\\u000a          {{\\u003Esimple_tweet}}\\u000a        {{/fork_tweet_views}}\\u000a      {{/replies_html}}\\u000a    {{/has_replies}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            reply_dialog_footer: \"\\u003Cdiv class=\\\"tweet twttr-dialog-reply-footer colored-links\\\"\\u003E\\u000a  \\u003Cimg src=\\\"{{profile_image_url}}\\\" title=\\\"{{screen_name}}\\\"/\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u003Cspan class=\\\"twttr-reply-screenname\\\"\\u003E{{screen_name}}\\u003C/span\\u003E\\u000a    \\u003Cp class=\\\"js-tweet-text\\\"\\u003E\\u000a    {{{text}}}\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            retweeters: \"\\u003Ch3 class='retweets_count'\\u003E{{{retweeted_by_count}}}\\u003C/h3\\u003E\\u000a\\u003Cdiv class=\\\"meta-links clearfix\\\"\\u003E\\u000a  \\u003Cul class='retweeters'\\u003E\\u000a    {{#retweeters}}\\u000a      {{\\u003Euser_thumb_list_item}}\\u000a    {{/retweeters}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            saved_search_button: \"\\u003Cdiv class=\\\"saved-search-container\\\"\\u003E\\u000a  {{#show_trashcan}}\\u000a    \\u003Cdiv class=\\\"delete-search\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"button delete-search-button\\\"\\u003E\\u000a        \\u003Cspan class=\\\"trashcan\\\"\\u003E\\u003C/span\\u003E \\u003Cstrong\\u003EDelete this saved search\\u003C/strong\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/show_trashcan}}\\u000a  {{^show_trashcan}}\\u000a    \\u003Cdiv class=\\\"save-search\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"button save-search-button\\\"\\u003E\\u000a        \\u003Cspan class=\\\"plus\\\"\\u003E\\u003C/span\\u003E \\u003Cstrong\\u003ESave this search\\u003C/strong\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/show_trashcan}}\\u000a\\u003Cdiv\\u003E\",\n            screen_name_followed_by: \"{{#followed_by}}\\u003Cspan class=\\\"screen-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/span\\u003E\\u003Csmall class=\\\"follow-status\\\"\\u003Efollows you\\u003C/small\\u003E{{/followed_by}}\\u000a{{^followed_by}}\\u003Cspan class=\\\"screen-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/span\\u003E{{/followed_by}}\\u000a\",\n            advanced: \"\\u003Cdiv class=\\\"main\\\"\\u003E\\u000a  {{\\u003Esearch_advanced}}\\u000a  \\u003Cdiv class=\\\"bottompart\\\"\\u003E\\u000a    {{\\u003Efooter}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            dashboard_search: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{^logged_in}}\\u000a    {{\\u003Enew_signup_call_out}}\\u000a  {{/logged_in}}\\u000a  \\u003Cdiv class=\\\"module\\\"\\u003E\\u000a    \\u003Cul class=\\\"js-nav-links\\\"\\u003E\\u000a      \\u003Cli class=\\\"{{#on_tweets}}active{{/on_tweets}}\\\"\\u003E\\u003Ca class=\\\"list-link\\\" href=\\\"{{search_path}}\\\"\\u003ETweets\\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E      \\u003Cli class=\\\"people {{#on_users}}active{{/on_users}}\\\"\\u003E\\u000a        \\u003Ca class=\\\"list-link\\\" href=\\\"{{search_users_path}}\\\" data-nav=\\\"people\\\"\\u003E\\u000a          People\\u000a          \\u003Ci class=\\\"chev-right\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/li\\u003E \\u000a      \\u003Cli class=\\\"media-thumbnails top-images\\\"\\u003E\\u003C/li\\u003E \\u000a      \\u003Cli class=\\\"media-thumbnails top-videos media-videos\\\"\\u003E\\u003C/li\\u003E \\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Edashboard_trends}}\\u000a  {{\\u003Efooter}}\\u000a\\u003C/div\\u003E\\u000a\",\n            search: \"{{\\u003Esearch/dashboard_search}}\\u000a{{\\u003Edialogs/trends_dialog_shell}}\\u000a\\u003Cdiv class=\\\"content-main\\\" id=\\\"timeline\\\" data-pixel-tracking-id=\\\"{{pixel_tracking_id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    {{\\u003Eswift_search_header}}\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Etimeline}}\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_onebox: \"{{#onebox}}\\u000a  {{\\u003Ediscover/story}}\\u000a{{/onebox}}\",\n            search_advanced: \"\\u003Cdiv class=\\\"search advanced-search\\\"\\u003E\\u000a  \\u003Ch1\\u003EAdvanced \\u003Cstrong\\u003ESearch\\u003C/strong\\u003E\\u003C/h1\\u003E\\u000a\\u000a  \\u003Cform class=\\\"twitter-form\\\"\\u003E\\u000a\\u000a    \\u003Cfieldset\\u003E\\u000a      \\u003Clegend\\u003E\\u003Cspan\\u003EWords\\u003C/span\\u003E\\u003C/legend\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EAll of these words\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"ands\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EThis exact phrase\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"phrase\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EAny of these words\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"ors\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003ENone of these words\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"nots\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EThese hashtags\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"tag\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EWritten in\\u003C/span\\u003E\\u000a          \\u003Cselect id=\\\"lang\\\" name=\\\"lang\\\"\\u003E\\u000a            \\u003Coption value=\\\"all\\\" selected=\\\"selected\\\"\\u003EAny Language\\u003C/option\\u003E\\u000a            {{#languages}}\\u000a              \\u003Coption value=\\\"{{code}}\\\"\\u003E{{localized_name}} ({{name}})\\u003C/option\\u003E\\u000a            {{/languages}}\\u000a          \\u003C/select\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u003Cfieldset\\u003E\\u000a      \\u003Clegend\\u003E\\u003Cspan\\u003EPeople\\u003C/span\\u003E\\u003C/legend\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EFrom these accounts\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"from\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003ETo these accounts\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"to\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EMentioning these accounts\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"ref\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u003Cfieldset class=\\\"geo\\\"\\u003E\\u000a      \\u003Clegend\\u003E\\u003Cspan\\u003EPlaces\\u003C/span\\u003E\\u003C/legend\\u003E\\u000a      \\u003Cdiv class=\\\"txt\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003ENear this place\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" name=\\\"near\\\" /\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"sel\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cspan class=\\\"td\\\"\\u003EWithin this distance\\u003C/span\\u003E\\u000a          \\u003Cselect name=\\\"within\\\"\\u003E\\u000a            \\u003Coption value=\\\"1\\\"\\u003E1\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"5\\\"\\u003E5\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"10\\\"\\u003E10\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"15\\\" selected=\\\"selected\\\"\\u003E15\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"25\\\"\\u003E25\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"50\\\"\\u003E50\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"100\\\"\\u003E100\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"500\\\"\\u003E500\\u003C/option\\u003E\\u000a            \\u003Coption value=\\\"1000\\\"\\u003E1000\\u003C/option\\u003E\\u000a          \\u003C/select\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Cspan class=\\\"rad\\\"\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"units\\\" type=\\\"radio\\\" value=\\\"mi\\\" checked=\\\"checked\\\" /\\u003E\\u003Cspan\\u003Emiles\\u003C/span\\u003E\\u003C/label\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"units\\\" type=\\\"radio\\\" value=\\\"km\\\" /\\u003E\\u003Cspan\\u003Ekilometers\\u003C/span\\u003E\\u003C/label\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u003Cfieldset\\u003E\\u000a      \\u003Clegend\\u003E\\u003Cspan\\u003EOther\\u003C/span\\u003E\\u003C/legend\\u003E\\u000a      \\u003Cdiv class=\\\"chk\\\"\\u003E\\u000a        \\u003Cspan class=\\\"td\\\"\\u003ESelect:\\u003C/span\\u003E\\u000a        \\u003Cspan class=\\\"chk-inner\\\"\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"attd\\\" type=\\\"checkbox\\\" value=\\\":)\\\" /\\u003E\\u003Cspan\\u003EPositive :)\\u003C/span\\u003E\\u003C/label\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"attd\\\" type=\\\"checkbox\\\" value=\\\":(\\\" /\\u003E\\u003Cspan\\u003ENegative :(\\u003C/span\\u003E\\u003C/label\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"attd\\\" type=\\\"checkbox\\\" value=\\\"?\\\" /\\u003E\\u003Cspan\\u003EQuestion ?\\u003C/span\\u003E\\u003C/label\\u003E\\u000a          \\u003Clabel\\u003E\\u003Cinput name=\\\"include\\\" type=\\\"checkbox\\\" value=\\\"retweets\\\" /\\u003E\\u003Cspan\\u003EInclude retweets\\u003C/span\\u003E\\u003C/label\\u003E\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u000a    \\u003Cdiv class=\\\"button btn primary-btn submit selected\\\"\\u003ESearch\\u003C/div\\u003E\\u000a\\u000a  \\u003C/form\\u003E\\u000a\\u000a\\u003C/div\\u003E\",\n            search_basic: \"\\u003Cdiv class=\\\"search basic-search\\\"\\u003E\\u000a  \\u003Ch1\\u003ESee what\\u2019s happening \\u003Cstrong\\u003Eright now\\u003C/strong\\u003E\\u003C/h1\\u003E\\u000a  \\u003Cform action=\\\"{{form_search_results_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a    \\u003Cinput value=\\\"\\\" name=\\\"q\\\" type=\\\"text\\\" placeholder=\\\"\\\" /\\u003E\\u000a    \\u003Cdiv\\u003E\\u000a      \\u000a      \\u003Cdiv class=\\\"button btn primary-btn submit selected\\\"\\u003ESearch\\u003C/div\\u003E\\u000a      {{\\u003Esearch_help_operators}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a  \\u003Cdiv class=\\\"trends-container\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            search_button: \"\\u003Cdiv class=\\\"combo-btn\\\"\\u003E\\u000a  \\u003Ca class=\\\"combo-btn-action\\\" href=\\\"#\\\"\\u003E\\u000a    Search\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cspan class=\\\"combo-btn-toggle\\\"\\u003E\\u000a    \\u003Cspan class=\\\"combo-btn-carrot\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/span\\u003E\\u000a  \\u003Cul class=\\\"combo-btn-dropdown\\\"\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"#\\\"\\u003ERefine results\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            search_header: \"\\u003Cdiv class=\\\"module header-module js-search-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cform class=\\\"search-header js-search-form\\\" action=\\\"/search\\\" method=\\\"GET\\\"\\u003E\\u000a      \\u003Ctable class=\\\"flex-table\\\"\\u003E\\u000a        \\u003Ctbody\\u003E\\u000a          \\u003Ctr\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"flex-table-form\\\"\\u003E\\u000a                \\u003Cinput class=\\\"flex-table-input search-query js-search-header-query\\\" name=\\\"q\\\" type=\\\"text\\\" placeholder=\\\"Search Twitter\\\"\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/td\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"btn-group flex-table-btn js-search-dropdown\\\"\\u003E\\u000a                \\u003Cbutton type=\\\"submit\\\" class=\\\"btn search-btn js-submit\\\"\\u003E\\u000a                  Search\\u000a                \\u003C/button\\u003E\\u000a                \\u003Cbutton type=\\\"button\\\" class=\\\"dropdown btn btn-search-actions js-search-dropdown-button\\\"\\u003E\\u000a                  \\u003Ci class=\\\"search-toggle\\\"\\u003E\\u003C/i\\u003E\\u000a                \\u003C/button\\u003E\\u000a                \\u003Cul class=\\\"dropdown-menu btn-group-dropdown js-combo-btn-dropdown-options\\\"\\u003E\\u000a                  \\u003Cli\\u003E\\u003Ca class=\\\"js-toggle-saved-search-link\\\" href=\\\"#\\\"\\u003ESave search\\u003C/a\\u003E\\u003C/li\\u003E\\u000a                  \\u003Cli\\u003E\\u003Ca href=\\\"{{search_advanced_path}}\\\"\\u003EAdvanced search\\u003C/a\\u003E\\u003C/li\\u003E\\u000a                  \\u000a                  \\u003Cli class=\\\"dropdown-caret right\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a                    \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a                  \\u003C/li\\u003E\\u000a                \\u003C/ul\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/td\\u003E\\u000a          \\u003C/tr\\u003E\\u000a        \\u003C/tbody\\u003E\\u000a      \\u003C/table\\u003E\\u000a    \\u003C/form\\u003E\\u000a    \\u003Ch2 class=\\\"js-search-title\\\"\\u003ESearch results\\u003C/h2\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            search_help_operators: \"\\u003Cp class=\\\"operators\\\"\\u003E\\u000a  {{^decider_advanced_search}}\\u000a    \\u003Cstrong\\u003ETip:\\u003C/strong\\u003E use \\u003Ca class=\\\"search-operators-link\\\" href=\\\"#\\\"\\u003Eoperators\\u003C/a\\u003E for advanced search.\\u000a  {{/decider_advanced_search}}\\u000a  {{#decider_advanced_search}}\\u000a    \\u003Cstrong\\u003ETip:\\u003C/strong\\u003E use \\u003Ca class=\\\"search-operators-link\\\" href=\\\"#\\\"\\u003Eoperators\\u003C/a\\u003E for \\u003Ca class=\\\"advanced-search\\\" href=\\\"{{search_advanced_path}}\\\"\\u003Eadvanced search\\u003C/a\\u003E.\\u000a  {{/decider_advanced_search}}\\u000a\\u003C/p\\u003E\",\n            search_home: \"\\u003Cdiv class=\\\"main\\\"\\u003E\\u000a\\u000a  {{#is_advanced}}\\u000a    {{\\u003Esearch_advanced}}\\u000a  {{/is_advanced}}\\u000a  {{^is_advanced}}\\u000a    {{\\u003Esearch_basic}}\\u000a  {{/is_advanced}}\\u000a\\u000a  \\u003Cdiv class=\\\"logged-out\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"bottompart\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\",\n            search_operators: \"\\u003Ctable class=\\\"modal-table modal-table-bordered\\\"\\u003E\\u000a  \\u003Cthead\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Cth\\u003EOperator\\u003C/th\\u003E\\u000a      \\u003Cth\\u003EFinds tweets...\\u003C/th\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003C/thead\\u003E\\u000a  \\u003Ctbody\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Etwitter search\\u003C/td\\u003E\\u003Ctd\\u003Econtaining both \\\"twitter\\\" and \\\"search\\\". This is the default operator.\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003E\\\"\\u003C/b\\u003Ehappy hour\\u003Cb\\u003E\\\"\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining the exact phrase \\\"happy hour\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Elove \\u003Cb\\u003EOR\\u003C/b\\u003E hate\\u003C/td\\u003E\\u003Ctd\\u003Econtaining either \\\"love\\\" or \\\"hate\\\" (or both).\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Ebeer \\u003Cb\\u003E-\\u003C/b\\u003Eroot\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"beer\\\" but not \\\"root\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003E#\\u003C/b\\u003Ehaiku\\u003C/td\\u003E\\u003Ctd\\u003Econtaining the hashtag \\\"haiku\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003Efrom:\\u003C/b\\u003Ealexiskold\\u003C/td\\u003E\\u003Ctd\\u003Esent from person \\\"alexiskold\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003Eto:\\u003C/b\\u003Etechcrunch\\u003C/td\\u003E\\u003Ctd\\u003Esent to person \\\"techcrunch\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003E@\\u003C/b\\u003Emashable\\u003C/td\\u003E\\u003Ctd\\u003Ereferencing person \\\"mashable\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\\"happy hour\\\" \\u003Cb\\u003Enear:\\u003C/b\\u003E\\\"san francisco\\\"\\u003C/td\\u003E\\u003Ctd\\u003Econtaining the exact phrase \\\"happy hour\\\" and sent near \\\"san francisco\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cb\\u003Enear:\\u003C/b\\u003ENYC \\u003Cb\\u003Ewithin:\\u003C/b\\u003E15mi\\u003C/td\\u003E\\u003Ctd\\u003Esent within 15 miles of \\\"NYC\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Esuperhero \\u003Cb\\u003Esince:\\u003C/b\\u003E2010-12-27\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"superhero\\\" and sent since date \\\"2010-12-27\\\" (year-month-day).\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Eftw \\u003Cb\\u003Euntil:\\u003C/b\\u003E2010-12-27\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"ftw\\\" and sent up to date \\\"2010-12-27\\\".\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Emovie -scary \\u003Cb\\u003E:)\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"movie\\\", but not \\\"scary\\\", and with a positive attitude.\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Eflight \\u003Cb\\u003E:(\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"flight\\\" and with a negative attitude.\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Etraffic \\u003Cb\\u003E?\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"traffic\\\" and asking a question.\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Ehilarious \\u003Cb\\u003Efilter:links\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"hilarious\\\" and linking to URLs.\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a    \\u003Ctr\\u003E\\u003Ctd\\u003Enews \\u003Cb\\u003Esource:twitterfeed\\u003C/b\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Econtaining \\\"news\\\" and entered via TwitterFeed\\u003C/td\\u003E\\u003C/tr\\u003E\\u000a  \\u003C/tbody\\u003E\\u000a\\u003C/table\\u003E\\u000a\",\n            search_page: \"{{\\u003Edashboard}}\\u000a{{\\u003Econtent}}\",\n            search_page_tabs: \"\\u003Cli class=\\\"stream-tab stream-tab-title\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"stream-tab-title-inner\\\"\\u003ETweets \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u003C/h2\\u003E\\u000a\\u003C/li\\u003E\\u000a\\u003Cli class=\\\"stream-tab stream-tab-dropdown\\\"\\u003E\\u000a  \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003E\\u000a    {{#top_mode}}\\u000a      Top\\u000a    {{/top_mode}}\\u000a    {{#all_mode}}\\u000a      All\\u000a    {{/all_mode}}\\u000a    {{#with_links_mode}}\\u000a      With links\\u000a    {{/with_links_mode}}\\u000a    \\u003Ci\\u003E\\u003C/i\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\\u003Cli class=\\\"stream-tab refine-search\\\"\\u003E\\u000a  \\u003Ca href=\\\"{{search_advanced_path}}\\\"\\u003ERefine results&#32;&raquo;\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            search_stream_title: \"\\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a  \\u003Cdiv class='delete-saved-search'\\u003E\\u000a    \\u003Ca href='#' class='delete-saved-search-x'\\u003E\\u003C/a\\u003E\\u000a    \\u003Ca href='#'\\u003ERemove saved search\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cli class=\\\"stream-tab stream-tab-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"stream-tab-title-inner\\\"\\u003E\\u000a    Search results for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"stream-tab stream-tab-dropdown\\\"\\u003E\\u000a    \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003E\\u000a      {{#top_mode}}\\u000a        Top\\u000a      {{/top_mode}}\\u000a      {{#all_mode}}\\u000a        All\\u000a      {{/all_mode}}\\u000a      {{#with_links_mode}}\\u000a        With links\\u000a      {{/with_links_mode}}\\u000a      \\u003Ci\\u003E\\u003C/i\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            search_stream_view_toggler: \"\\u003Ca class=\\\"toggle-item-1 {{#active1}}active{{/active1}}\\\" href=\\\"{{route1}}\\\" title=\\\"{{tip1}}\\\"\\u003E{{title1}}\\u003C/a\\u003E / \\u003Ca class=\\\"toggle-item-2 {{#active2}}active{{/active2}}\\\" href=\\\"{{route2}}\\\" title=\\\"{{tip2}}\\\"\\u003E{{title2}}\\u003C/a\\u003E{{#decider_blender_search_timeline}} / \\u003Ca class=\\\"toggle-item-3 {{#active3}}active{{/active3}}\\\" href=\\\"{{route3}}\\\" title=\\\"{{tip3}}\\\"\\u003E{{title3}}\\u003C/a\\u003E{{/decider_blender_search_timeline}}\",\n            send_message_box: \"\\u003Cdiv class=\\\"tweet-box condensed\\\"\\u003E\\u000a  \\u003Ch2\\u003ESend&nbsp;{{screen_name}} a message\\u003C/h2\\u003E\\u000a  \\u003Cdiv class=\\\"send-message-box\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            account: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#user}}\\u000a\\u000a\\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003EAccount\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"subheader\\\"\\u003EChange your basic account, language, Tweet privacy, and location settings.\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a    {{#accounts_page_disabled}}\\u000a      {{\\u003E settings/alert_partial}}\\u000a    {{/accounts_page_disabled}}\\u000a    {{^accounts_page_disabled}}\\u000a    \\u003Cform id=\\\"account-form\\\" class=\\\"form-horizontal requires-password\\\" method=\\\"POST\\\" action=\\\"{{form_url}}\\\"\\u003E\\u000a      {{\\u003E settings/alert_partial}}\\u000a      {{#user_verified?}}\\u000a        \\u003Cdiv class=\\\"alert\\\"\\u003E\\u000a          \\u003Cp\\u003EYour account has been verified. Any change to your username will remove your verification badge.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/user_verified?}}\\u000a      \\u003Cinput type=\\\"hidden\\\" value=\\\"PUT\\\" name=\\\"_method\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cfieldset id=\\\"username_fieldset\\\" class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_screen_name\\\" class=\\\"control-label\\\"\\u003EUsername\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cp id=\\\"username_notification\\\" class=\\\"notification\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cinput id=\\\"user_screen_name\\\" maxlength=\\\"15\\\" name=\\\"user[screen_name]\\\" type=\\\"text\\\" value=\\\"{{screen_name}}\\\"\\u003E\\u000a          \\u003Cp class=\\\"notification\\\"\\u003E{{username_url_base}}\\u003Cspan id=\\\"username_path\\\"\\u003E{{screen_name}}\\u003C/span\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      {{#email_pending}}\\u000a      \\u003Cdiv id=\\\"email-pending-group\\\" class=\\\"control-group\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cp\\u003E{{{settings_email_message}}}\\u003C/p\\u003E\\u000a          \\u003Cdiv id=\\\"email-confirmation\\\" class=\\\"resend-message\\\"\\u003E\\u000a            \\u003Cp\\u003E\\u000a              \\u003Ca href=\\\"{{resend_confirmation_email_path}}\\\" class=\\\"resend-confirmation-email\\\"\\u003EResend confirmation\\u003C/a\\u003E\\u000a              {{#email}}\\u000a              \\u003Cspan class=\\\"bullet\\\"\\u003E&middot; \\u003C/span\\u003E\\u000a              \\u003Ca href=\\\"{{cancel_pending_email_path}}\\\" class=\\\"cancel-pending-email\\\"\\u003ECancel this change\\u003C/a\\u003E\\u000a              {{/email}}\\u000a            \\u003C/p\\u003E\\u000a            \\u003Cspan class=\\\"activation resending-email\\\" style=\\\"display: none\\\"\\u003E\\u000a              Resending confirmation\\u000a              \\u003Cimg src=\\\"/images/spinner.gif\\\"  height=\\\"14\\\" width=\\\"14\\\"\\u003E\\u000a            \\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{/email_pending}}\\u000a\\u000a      \\u003Cfieldset id=\\\"email_fieldset\\\" class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_email\\\" class=\\\"control-label\\\"\\u003EEmail\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cp id=\\\"email_notification\\\" class=\\\"notification\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cinput id=\\\"user_email\\\" class=\\\"email-input\\\" name=\\\"user[email]\\\" type=\\\"text\\\" value=\\\"{{email}}\\\"\\u003E\\u000a          \\u003Cp\\u003EEmail will not be publicly displayed. \\u003Ca href=\\\"https://support.twitter.com/articles/15356\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a          \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a            \\u003Cinput id=\\\"user_discoverable_by_email\\\" name=\\\"user[discoverable_by_email]\\\" type=\\\"checkbox\\\" value=\\\"1\\\" {{#discoverable_by_email}}checked{{/discoverable_by_email}}\\u003E\\u000a            Let others find me by my email address\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[discoverable_by_email]\\\"\\u003E\\u000a          {{^email_discoverability_set}}\\u000a            \\u003Cp\\u003EReview and confirm your email setting by pressing 'Save'.\\u000a            \\u003Ca href=\\\"https://support.twitter.com/articles/14022\\\" target=\\\"_blank\\\" class=\\\"help-discover\\\"\\u003E\\u003C/a\\u003E\\u000a            \\u003C/p\\u003E\\u000a          {{/email_discoverability_set}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      \\u003Chr\\u003E\\u000a\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_lang\\\" class=\\\"control-label\\\"\\u003ELanguage\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cselect id=\\\"user_lang\\\" name=\\\"user[lang]\\\"\\u003E\\u000a             {{\\u003E shared/lang_select_options}}\\u000a          \\u003C/select\\u003E\\u000a          {{#new_translation_center_available}}\\u000a          \\u003Cp\\u003EInterested in helping translate Twitter? Check out the \\u003Ca href=\\\"http://translate.twttr.com\\\"\\u003ETranslation Center\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a          {{/new_translation_center_available}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_time_zone\\\"  class=\\\"control-label\\\"\\u003ETime zone\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cselect id=\\\"user_time_zone\\\" name=\\\"user[time_zone]\\\"\\u003E\\u000a            {{#time_zone_options}}\\u000a              \\u003Coption data-offset=\\\"{{offset}}\\\" value=\\\"{{zone_name}}\\\" {{#selected}}selected{{/selected}}\\u003E{{display}}\\u003C/option\\u003E\\u000a            {{/time_zone_options}}\\u000a          \\u003C/select\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      \\u003Chr\\u003E\\u000a\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_geo_enabled\\\" class=\\\"control-label\\\"\\u003ETweet location\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a            \\u003Cinput {{#geo_enabled}}checked{{/geo_enabled}} id=\\\"user_geo_enabled\\\" name=\\\"user[geo_enabled]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u003EAdd a location to my Tweets\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[geo_enabled]\\\"\\u003E\\u000a          \\u003Cp\\u003EWhen you tweet with a location, Twitter stores that location. You can switch location on/off before each Tweet. \\u003Ca href=\\\"https://support.twitter.com/articles/78525\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/p\\u003E\\u000a          \\u003Cdiv id=\\\"delete_geo_data\\\"\\u003E\\u000a            \\u003Cp\\u003E\\u003Ca class=\\\"delete-info btn\\\" id=\\\"geo_button\\\" href=\\\"#\\\"\\u003EDelete all location information\\u003C/a\\u003E\\u003C/p\\u003E\\u000a            \\u003Cp id=\\\"delete_geo_info\\\"\\u003EThis will delete all location information from past Tweets. This may take up to 30 minutes.\\u003C/p\\u003E\\u000a            \\u003Cp id=\\\"deleting_geo_data\\\" style=\\\"display: none;\\\"\\u003EDeleting all location information from your past Tweets... This may take up to 30 minutes. You may leave this page.\\u003C/p\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_nsfw_view\\\" class=\\\"control-label\\\"\\u003ETweet media\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a            \\u003Cinput {{#nsfw_view}}checked{{/nsfw_view}} id=\\\"user_nsfw_view\\\" name=\\\"user[nsfw_view]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u003E Display media that may contain sensitive content\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[nsfw_view]\\\"\\u003E\\u000a          {{#sensitive_editable}}\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput {{#nsfw_user}}checked{{/nsfw_user}} id=\\\"user_nsfw_user\\\" name=\\\"user[nsfw_user]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u003E Mark my media as containing sensitive content\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[nsfw_user]\\\"\\u003E\\u000a          {{/sensitive_editable}}\\u000a          {{^sensitive_editable}}\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput {{#nsfw_user}}checked{{/nsfw_user}} id=\\\"user_nsfw_admin\\\" name=\\\"user[nsfw_admin]\\\" type=\\\"checkbox\\\" disabled\\u003E Mark my media as containing sensitive content\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[nsfw_admin]\\\"\\u003E\\u000a          {{/sensitive_editable}}\\u000a          \\u003Cp\\u003EIf you tweet images or videos that may contain sensitive content, please check this box so that people can be warned before they see it. \\u003Ca href=\\\"https://support.twitter.com/articles/20169200\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      \\u003Cfieldset id=\\\"user_protected_fieldset\\\" class=\\\"control-group\\\"\\u003E\\u000a        {{\\u003Edialogs/protected_verified_dialog}}\\u000a        \\u003Clabel for=\\\"user_protected\\\" class=\\\"control-label\\\"\\u003ETweet privacy\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a            \\u003Cinput {{#user_protected}}checked{{/user_protected}} id=\\\"user_protected\\\" name=\\\"user[protected]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u003E Protect my Tweets\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[protected]\\\"\\u003E\\u000a          {{#user_protected}}\\u000a            \\u003Cp\\u003EYour Tweets are currently protected; only those you approve will receive your Tweets. Your future Tweets will not be available publicly. Tweets posted previously may still be publicly visible in some places. \\u003Ca href=\\\"https://support.twitter.com/articles/14016\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a          {{/user_protected}}\\u000a          {{^user_protected}}\\u000a            \\u003Cp\\u003EIf selected, only those you approve will receive your Tweets. Your future Tweets will not be available publicly. Tweets posted previously may still be publicly visible in some places. \\u003Ca href=\\\"https://support.twitter.com/articles/14016\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a          {{/user_protected}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      {{#personalization_settings_available}}\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Clabel class=\\\"control-label {{#personalization_settings_disabled}}personalization-settings-disabled{{/personalization_settings_disabled}}\\\"\\u003EPersonalization\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a\\u000a            {{^personalization_settings_disabled}}\\u000a              \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                \\u003Cinput {{#use_cookie_personalization}}checked{{/use_cookie_personalization}} id=\\\"use_cookie_personalization\\\" name=\\\"user[use_cookie_personalization]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u003E\\u000a                Tailor Twitter based on my recent website visits\\u000a                \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[use_cookie_personalization]\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"asked_cookie_personalization_setting\\\" value=\\\"1\\\"\\u003E\\u000a              \\u003C/label\\u003E\\u000a              \\u003Cp\\u003E\\u003Ca class=\\\"personalization-preview-link\\\" href=\\\"{{web_personalization_preview_path}}\\\" target=\\\"_blank\\\"\\u003EPreview\\u003C/a\\u003E suggestions tailored for you (not currently available to all users). \\u003Ca class=\\\"personalization-support-link\\\" href=\\\"https://support.twitter.com/articles/20169421\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E about how this works and your additional privacy controls.\\u003C/p\\u003E\\u000a            {{/personalization_settings_disabled}}\\u000a\\u000a            {{#personalization_settings_disabled}}\\u000a              \\u003Cdiv class=\\\"control-list\\\"\\u003E\\u000a                \\u003Cp\\u003EThe feature to tailor Twitter based on your recent website visits is not available to you.\\u003C/p\\u003E\\u000a              \\u003C/div\\u003E\\u000a            {{/personalization_settings_disabled}}\\u000a\\u000a            {{#has_do_not_track_header}}\\u000a              \\u003Clabel\\u003EDo Not Track \\u003Cimg src=\\\"/images/accept_small.gif\\\" id=\\\"do-not-track-check\\\"\\u003E\\u003C/label\\u003E\\u000a              \\u003Cp\\u003EWhile you have Do Not Track turned on, your visits to sites that feature Twitter are not available to personalize your experience.\\u003C/p\\u003E\\u000a            {{/has_do_not_track_header}}\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a      {{/personalization_settings_available}}\\u000a\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_ssl_only\\\" class=\\\"control-label\\\"\\u003EHTTPS only\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a            \\u003Cinput id=\\\"user_ssl_only\\\" name=\\\"user[ssl_only]\\\" type=\\\"checkbox\\\" value=\\\"1\\\" {{#ssl_only_enabled}}checked{{/ssl_only_enabled}} {{#disable_change_ssl_setting}}disabled{{/disable_change_ssl_setting}}\\u003EAlways use HTTPS\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cinput name=\\\"user[ssl_only]\\\" type=\\\"hidden\\\" value=\\\"0\\\"\\u003E\\u000a          \\u003Cp\\u003EUse a secure connection where possible.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a\\u000a      {{#no_username_only_password_reset_enabled}}\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel for=\\\"user_no_username_only_password_reset\\\" class=\\\"control-label\\\"\\u003EPassword reset\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"control-list\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput id=\\\"user_no_username_only_password_reset\\\" name=\\\"user[no_username_only_password_reset]\\\" type=\\\"checkbox\\\" value=\\\"1\\\" {{#no_username_only_password_reset}}checked{{/no_username_only_password_reset}}\\u003ERequire personal information to reset my password\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput name=\\\"user[no_username_only_password_reset]\\\" type=\\\"hidden\\\" value=\\\"0\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cp\\u003EBy default, you can initiate a password reset by entering only your @username. If you check this box, you will be prompted to enter your email address or phone number if you forget your password.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      {{/no_username_only_password_reset_enabled}}\\u000a      \\u003Chr\\u003E\\u000a\\u000a      {{#commercial_account_enabled}}\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Clabel for=\\\"user_can_receive_direct_messages_from_all_followers\\\" class=\\\"control-label\\\"\\u003EMessages\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput id=\\\"user_can_receive_direct_messages_from_all_followers\\\" name=\\\"user[can_receive_direct_messages_from_all_followers]\\\" type=\\\"checkbox\\\" value=\\\"1\\\"\\u000a              {{#can_receive_direct_messages_from_all_followers}}checked{{/can_receive_direct_messages_from_all_followers}}\\u000a              \\u003EReceive direct messages from any follower\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput name=\\\"user[can_receive_direct_messages_from_all_followers]\\\" type=\\\"hidden\\\" value=\\\"0\\\"\\u003E\\u000a            \\u003Cp\\u003EGenerally, you must follow someone before they have the ability to direct message you. If you check this option, any Twitter user that follows you will be able to send you a DM, regardless of whether you decide to follow them back.\\u003C/p\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a        \\u003Chr\\u003E\\u000a      {{/commercial_account_enabled}}\\u000a\\u000a      {{#per_country_takedown}}\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Clabel for=\\\"user_country\\\" class=\\\"control-label\\\"\\u003ECountry\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Cselect id=\\\"user_country\\\" name=\\\"user[country]\\\"\\u003E\\u000a              {{\\u003E shared/country_select_options}}\\u000a            \\u003C/select\\u003E\\u000a            \\u003Cp\\u003ESelect your country. This setting is saved to this browser.\\u003C/p\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a        \\u003Chr\\u003E\\u000a      {{/per_country_takedown}}\\u000a\\u000a      {{\\u003Esettings/save_button}}\\u000a      {{\\u003Edialogs/password_dialog}}\\u000a\\u000a      \\u003Chr\\u003E\\u000a\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          {{^deactivation_available}}\\u000a          \\u003Cp\\u003E\\u003Ca id=\\\"account_deactivate_link\\\" class=\\\"deactivated\\\" href=\\\"#\\\"\\u003EDeactivate my account\\u003C/a\\u003E\\u003C/p\\u003E\\u000a          {{/deactivation_available}}\\u000a          {{#deactivation_available}}\\u000a          {{^suspended?}}\\u000a          \\u003Cp\\u003E\\u003Ca id=\\\"account_deactivate_link\\\" href=\\\"{{confirm_deactivation_path}}\\\"\\u003EDeactivate my account\\u003C/a\\u003E\\u003C/p\\u003E\\u000a          {{/suspended?}}\\u000a          {{/deactivation_available}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a    \\u003C/form\\u003E\\u000a    {{/accounts_page_disabled}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/user}}\\u000a\",\n            alert_partial: \"\\u003Cdiv id=\\\"settings-alert-box\\\" class=\\\"alert\\\" {{^alerts}}style=\\\"display: none;\\\"{{/alerts}}\\u003E\\u000a  \\u003Ci id=\\\"settings-alert-close\\\" class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u000a  {{#alerts}}\\u000a    \\u003Ch4\\u003E{{first}}\\u003C/h4\\u003E\\u000a    \\u003Cdiv id=\\\"settings-alert-message\\\"\\u003E\\u000a      {{#rest}}\\u003Cp\\u003E{{{to_s}}}\\u003C/p\\u003E{{/rest}}\\u000a    \\u003C/div\\u003E\\u000a  {{/alerts}}\\u000a\\u003C/div\\u003E\\u000a\",\n            applications: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#user}}\\u000a  \\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a        \\u003Ch2\\u003EApplications\\u003C/h2\\u003E\\u000a        \\u003Cp class=\\\"subheader\\\"\\u003EThese are the apps that can access your Twitter account. \\u003Ca href=\\\"https://support.twitter.com/articles/76052\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{^has_apps}}\\u000a      \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Ch3 class=\\\"settings-header\\\"\\u003ENo applications have been approved to use your account.\\u003C/h3\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/has_apps}}\\u000a    {{#has_apps}}\\u000a      \\u003Cdiv class=\\\"stream\\\" id=\\\"apps-stream\\\"\\u003E\\u000a      {{#apps}}\\u000a        \\u003Cdiv id=\\\"{{id_attr}}\\\" class=\\\"stream-item oauth-application {{#suspended}}suspended{{/suspended}}\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"app\\\"\\u003E\\u000a            {{#ios_revoke}}\\u000a              \\u003Ca href=\\\"https://support.twitter.com/articles/20169494#remove-account\\\" target=\\\"_blank\\\" class=\\\"revoke ios-revoke-access\\\"\\u003ELearn how to revoke an iOS app.\\u003C/a\\u003E\\u000a            {{/ios_revoke}}\\u000a            {{^ios_revoke}}\\u000a              \\u003Ca class=\\\"revoke btn\\\" id=\\\"btn_{{id_attr}}\\\" type=\\\"button\\\" href=\\\"#\\\"\\u003ERevoke access\\u003C/a\\u003E\\u000a            {{/ios_revoke}}\\u000a            \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a              \\u003Cdiv\\u003E\\u000a                \\u003Cimg class=\\\"app-img\\\" src=\\\"{{img_url}}\\\" width=\\\"48\\\" height=\\\"48\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a                \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E{{#organization}}\\u003Cspan class=\\\"creator\\\"\\u003E by \\u003Ca href=\\\"{{organization_url}}\\\" class=\\\"oauth-organization\\\"\\u003E{{organization}}\\u003C/a\\u003E\\u003C/span\\u003E{{/organization}}\\u000a              \\u003C/div\\u003E\\u000a              {{#description}}\\u000a                \\u003Cp class=\\\"description\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a              {{/description}}\\u000a              \\u003Cp\\u003E\\u003Csmall class=\\\"metadata\\\"\\u003E{{access_type}} access\\u003C/small\\u003E\\u003C/p\\u003E\\u000a              \\u003Cp\\u003E\\u003Csmall class=\\\"metadata\\\"\\u003EApproved: {{approved}}\\u003C/small\\u003E\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/apps}}\\u000a      \\u003C/div\\u003E\\u000a      {{\\u003E stream_end}}\\u000a    {{/has_apps}}\\u000a  \\u003C/div\\u003E\\u000a{{/user}}\",\n            confirm_deactivation: \"{{#user}}\\u000a\\u003Cdiv id=\\\"confirm_deactivation_section\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003EIs this goodbye?\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"subheader\\\"\\u003E\\u000a        Are you sure you don't want to reconsider?\\u000a        Was it something we said? \\u003Ca href=\\\"http://support.twitter.com/forms/general\\\" id=\\\"support_feedback\\\"\\u003ETell us.\\u003C/a\\u003E\\u000a      \\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"deactivation-info\\\"\\u003E\\u000a      \\u003Ch3 class=\\\"deactivation-info-header\\\"\\u003EBefore you deactivate @{{screen_name}}, know this:\\u003C/h3\\u003E\\u000a      \\u003Cul\\u003E\\u000a        \\u003Cli\\u003E\\u003Cstrong\\u003EWe will only retain your user data for 30 days\\u003C/strong\\u003E and then it will be permanently deleted. You can reactivate your account at any point within 30 days of deactivation by logging back in.\\u003C/li\\u003E\\u000a        \\u003Cli\\u003EYou don't need to deactivate your account to \\u003Ca href=\\\"{{settings_link}}\\\"\\u003Echange your username or Twitter URL\\u003C/a\\u003E. You can change it on the \\u003Ca href=\\\"{{settings_link}}\\\"\\u003Esettings\\u003C/a\\u003E page. All @replies and followers will remain unchanged.\\u003C/li\\u003E\\u000a        \\u003Cli\\u003EIf you want to use this account's username or email address on another Twitter account, \\u003Ca href=\\\"http://support.twitter.com/articles/14609\\\"\\u003Echange it\\u003C/a\\u003E before you deactivate. Until the user data is permanently deleted, that information won't be available for use.\\u003C/li\\u003E\\u000a        \\u003Cli\\u003EYour account should be removed from Twitter within a few minutes, but some content may be viewable on twitter.com for a few days after deactivation.\\u003C/li\\u003E\\u000a        \\u003Cli\\u003EWe have no control over \\u003Ca href=\\\"http://support.twitter.com/articles/15349\\\"\\u003Econtent indexed by search engines\\u003C/a\\u003E like Google.\\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Chr\\u003E\\u000a    \\u003Cform id=\\\"confirm-deactivate-account-form\\\" class=\\\"form-horizontal requires-password\\\" name=\\\"f\\\" method=\\\"post\\\" action=\\\"{{deactivate_account_link}}\\\"\\u003E\\u000a      \\u003Cinput name=\\\"_method\\\" type=\\\"hidden\\\" value=\\\"delete\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"form-actions\\\"\\u003E\\u000a        \\u003Cbutton id=\\\"settings_save\\\" class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003EDeactivate @{{screen_name}}\\u003C/button\\u003E\\u000a        \\u003Ca href=\\\"{{settings_link}}\\\" id=\\\"deactivate_account_cancel\\\" class=\\\"btn\\\"\\u003ECancel\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{\\u003Edialogs/deactivation_password_dialog}}\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/user}}\",\n            confirmation_modal: \"\\u003C!-- Confirmation modal --\\u003E\\u000a\\u003Ch2 id=\\\"password_dialog_header\\\" style=\\\"display:none\\\"\\u003ESave account changes\\u003C/h2\\u003E\\u000a\\u003Cdiv id=\\\"password_dialog\\\" style=\\\"display: none\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"dialog-form\\\"\\u003E\\u000a    \\u003Cp\\u003ERe-enter your Twitter password to save changes to your account.\\u003C/p\\u003E\\u000a    \\u003Cfieldset class=\\\"common-form\\\"\\u003E\\u000a      \\u003Cul\\u003E\\u000a        \\u003Cli\\u003E\\u000a          \\u003Clabel for=\\\"auth_password\\\"\\u003EPassword\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"input-wrapper password-wrapper\\\"\\u003E\\u000a            \\u003Cinput id=\\\"auth_password\\\" name=\\\"auth_password\\\" type=\\\"password\\\"\\u003E\\u000a            \\u003Cdiv\\u003E\\u000a              \\u003Ca href=\\\"{{resend_password_path}}\\\" id=\\\"forgot_password\\\"\\u003EForgot your password?\\u003C/a\\u003E\\u000a              \\u003Cspan id=\\\"reminder_sent\\\" style=\\\"visibility: hidden\\\"\\u003EReminder sent!\\u003C/span\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv id=\\\"password_dialog_footer\\\" style=\\\"display:none;\\\"\\u003E\\u000a  \\u003Ca class=\\\"btn modal-submit\\\" id=\\\"save_password\\\"\\u003ESave changes\\u003C/a\\u003E\\u000a  \\u003Ca href=\\\"{{settings_path}}\\\" id=\\\"cancel_link\\\"\\u003ECancel\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Ch2 id=\\\"protected_dialog_header\\\" style=\\\"display:none;\\\"\\u003EWarning!\\u003C/h2\\u003E\\u000a\\u003Cdiv id=\\\"protected_dialog\\\" style=\\\"display: none;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"dialog-form\\\"\\u003E\\u000a    \\u003Cp\\u003EWe're sorry, Twitter only verifies public accounts. If you protect your account, you will lose your verified badge.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv id=\\\"protected_dialog_footer\\\" style=\\\"display:none\\\"\\u003E\\u000a  \\u003Ca id=\\\"stay_verified_link\\\" class=\\\"btn\\\" href=\\\"#\\\"\\u003EStay verified\\u003C/a\\u003E\\u000a  \\u003Ca id=\\\"protect_my_tweets_link\\\" class=\\\"btn\\\" href=\\\"#\\\"\\u003EProtect my Tweets\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            design: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#current_user}}\\u000a\\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003EDesign\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"subheader\\\"\\u003ECustomize the way Twitter looks for you and how your profile looks to others.\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a    \\u003Cform id=\\\"design-form\\\" class=\\\"form-horizontal\\\" method=\\\"post\\\" enctype=\\\"multipart/form-data\\\" action=\\\"{{form_url}}\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      {{\\u003E settings/alert_partial}}\\u000a      \\u003Ch3 class=\\\"settings-header\\\"\\u003EPick a premade theme\\u003C/h3\\u003E\\u000a      \\u003Cinput id=\\\"user_profile_theme\\\" name=\\\"profile_theme\\\" type=\\\"hidden\\\" value=\\\"{{profile_theme}}\\\"\\u003E\\u000a      \\u003Cinput id=\\\"user_profile_default\\\" name=\\\"user[profile_default]\\\" type=\\\"hidden\\\" value=\\\"{{profile_default}}\\\"\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Cul class=\\\"theme-list clearfix\\\"\\u003E\\u000a          {{#themes}}\\u000a          \\u003Cli class=\\\"theme-item\\\"\\u003E\\u000a            \\u003Clabel class=\\\"theme{{#active}} selected{{/active}}\\\" data-image=\\\"{{image}}\\\" data-id=\\\"{{id}}\\\" data-background_color=\\\"{{background_color}}\\\" data-link_color=\\\"{{link_color}}\\\" data-tiled=\\\"{{tiled}}\\\"\\u003E\\u000a              \\u003Cspan class=\\\"selected-border\\\"\\u003E\\u003C/span\\u003E\\u003Cimg class=\\\"theme-image\\\" src=\\\"{{ swatch }}\\\"\\u003E\\u000a            \\u003C/label\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/themes}}\\u000a        \\u003C/ul\\u003E\\u000a        \\u003Cdiv class=\\\"themeleon-callout\\\"\\u003E\\u000a          \\u003Cstrong\\u003E\\u000a            \\u003Ca href=\\\"http://www.colourlovers.com/themeleon/twitter\\\" target=\\\"_blank\\\" id=\\\"themeleon_link\\\"\\u003ECheck out Themeleon &raquo;\\u003C/a\\u003E\\u000a          \\u003C/strong\\u003E\\u000a          Thousands of background patterns &amp; color palettes available to customize your Twitter profile.\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Chr\\u003E\\u000a      \\u003Ch3 class=\\\"settings-header\\\"\\u003ECustomize your own\\u003C/h3\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Cp\\u003ESee your changes instantly; they're not saved until you click \\\"Save changes.\\\" \\u003Ca href=\\\"https://support.twitter.com/articles/15357\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      {{#profile_banner_settings_available}}\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Clabel class=\\\"control-label\\\"\\u003EHeader\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls header-settings\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"uploader-image uploader-background clearfix\\\"\\u003E\\u000a              \\u003Cspan id=\\\"image_preview\\\" class=\\\"image-preview bg-preview\\\" {{#profile_use_header_image}}style=\\\"background-image: url({{profile_header_image_url}})\\\"{{/profile_use_header_image}}\\u003E\\u003C/span\\u003E\\u000a              \\u003Cdiv class=\\\"uploader-tools\\\"\\u003E\\u000a                {{\\u003Eswift_photo_selector}}\\u000a                \\u003Cbutton class=\\\"btn-link\\\" id=\\\"remove_header\\\" type=\\\"button\\\" {{^profile_use_header_image}}style=\\\"display:none\\\"{{/profile_use_header_image}} \\u003ERemove header\\u003C/button\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a      {{/profile_banner_settings_available}}\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EBackground\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls background-settings\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"uploader-image uploader-background clearfix\\\"\\u003E\\u000a            \\u003Cspan id=\\\"image_preview\\\" class=\\\"image-preview bg-preview\\\" {{#profile_use_background_image}}style=\\\"background-image: url({{profile_background_image_url}})\\\"{{/profile_use_background_image}}\\u003E\\u003C/span\\u003E\\u000a            \\u003Cdiv class=\\\"uploader-tools\\\"\\u003E\\u000a              \\u003Cinput id=\\\"user_profile_use_background_image\\\" type=\\\"hidden\\\" name=\\\"user[profile_use_background_image]\\\" value=\\\"{{profile_use_background_image}}\\\"\\u003E\\u000a              {{\\u003Eswift_photo_selector}}\\u000a              {{^profile_banner_settings_available}}\\u003Cp\\u003EMaximum size of 800k. GIF, JPG, PNG.\\u003C/p\\u003E{{/profile_banner_settings_available}}\\u000a              \\u003Cbutton class=\\\"btn-link\\\" id=\\\"remove_background\\\" type=\\\"button\\\" {{^profile_use_background_image}}style=\\\"display:none\\\"{{/profile_use_background_image}} \\u003ERemove background\\u003C/button\\u003E\\u000a              \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                \\u003Cinput id=\\\"user_profile_background_tile\\\" name=\\\"user[profile_background_tile]\\\" type=\\\"checkbox\\\" value=\\\"1\\\" {{#profile_background_tile}}checked{{/profile_background_tile}}\\u003E\\u000a                \\u003Cinput name=\\\"user[profile_background_tile]\\\" type=\\\"hidden\\\" value=\\\"0\\\"\\u003E Tile background\\u003C/label\\u003E\\u000a              \\u003C/label\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EBackground color\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cdiv id=\\\"background_color\\\" class=\\\"color-preview\\\" style=\\\"background-color: #{{profile_background_color}};\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Cinput id=\\\"background_color_hex\\\" class=\\\"input-small input-color\\\" type=\\\"text\\\" data-type=\\\"background_color\\\" data-color=\\\"#{{profile_background_color}}\\\" value=\\\"#{{profile_background_color}}\\\" name=\\\"user[profile_background_color]\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003ELink color\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cdiv id=\\\"links_color\\\" class=\\\"color-preview\\\" style=\\\"background-color: #{{profile_link_color}};\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003Cinput id=\\\"links_color_hex\\\" class=\\\"input-small input-color\\\" data-type=\\\"links_color\\\" data-color=\\\"#{{profile_link_color}}\\\" type=\\\"text\\\" value=\\\"#{{profile_link_color}}\\\" name=\\\"user[profile_link_color]\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      {{#profile_banner_settings_available}}\\u000a        \\u003Cfieldset class=\\\"control-group overlay-color-group\\\"\\u003E\\u000a          \\u003Clabel class=\\\"control-label\\\"\\u003EOverlay\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Clabel class=\\\"radio\\\"\\u003E\\u003Cinput type=\\\"radio\\\" name=\\\"user[overlay_color]\\\" value=\\\"black\\\"\\u003E Black\\u003C/label\\u003E\\u000a            \\u003Clabel class=\\\"radio\\\"\\u003E\\u003Cinput type=\\\"radio\\\" name=\\\"user[overlay_color]\\\" value=\\\"white\\\"\\u003E White\\u003C/label\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a      {{/profile_banner_settings_available}}\\u000a      \\u003Chr\\u003E\\u000a      {{\\u003E settings/save_button}}\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/current_user}}\\u000a\",\n            email: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EMobile\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003ESet up your mobile phone with Twitter to receive notifications.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  \\u003Cform id=\\\"sms-email-form\\\" class=\\\"form-horizontal sms-form form-flush-actions\\\" method=\\\"post\\\" action=\\\"/settings/devices/enable/{{device_id}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a\\u000a    \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a      \\u003Clabel for=\\\"\\\" class=\\\"control-label\\\"\\u003EEmail Notification\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cp id=\\\"device-country-carrier\\\"\\u003E\\u000a          {{device_address}}\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    {{\\u003E settings/devices/notifications}}\\u000a    {{\\u003E settings/devices/sleep_settings}}\\u000a\\u000a    \\u003Chr\\u003E\\u000a\\u000a    {{\\u003E settings/save_button}}\\u000a    {{\\u003E dialogs/password_dialog}}\\u000a  \\u003C/form\\u003E\\u000a\\u000a  \\u003Cform id=\\\"sms-email-delete-form\\\" class=\\\"form-horizontal sms-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"_method\\\" value=\\\"delete\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"form-actions\\\" id=\\\"delete_device_link\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"btn-link\\\" id=\\\"delete_device\\\"\\u003EDelete my email address\\u003C/button\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\",\n            email_create: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EMobile\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003ESet up your mobile phone with Twitter to receive notifications.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  \\u003Cdiv class=\\\"email-create sms-form\\\"\\u003E\\u000a    \\u003Ch3 class=\\\"settings-header\\\"\\u003EEmail Notification\\u003C/h3\\u003E\\u000a    \\u003Cp\\u003E\\u000a      Twitter is more fun when used through your Keitai email. Set yours up! It's easy! Twitter does not charge for this service. Standard data rates may apply.\\u000a    \\u003C/p\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"email-create-list\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"email-create-list-item\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-header\\\"\\u003E1.\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-body\\\"\\u003E\\u000a          From your Keitai, Send a blank email to\\u003Cbr\\u003E\\u000a          \\u003Ccode\\u003E{{email_create_verify_address}}\\u003C/code\\u003E\\u003Cbr\\u003E\\u000a          to verify your email address.\\u000a          \\u003Cp\\u003EYou can send a blank email from this QR code.\\u003C/p\\u003E\\u000a\\u000a          \\u003Cdiv class=\\\"email-create-verify-qr-code\\\"\\u003E\\u000a            \\u003Cimg src=\\\"{{verify_qr_code_image_url}}\\\" width=\\\"136\\\" height=\\\"136\\\" alt=\\\"{{email_create_verify_address}}\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"email-create-list-item\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-header\\\"\\u003E2.\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-body\\\"\\u003E\\u000a          Twitter send a verification email to your Keitai.\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"email-create-list-item\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-header\\\"\\u003E3.\\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"email-create-list-body\\\"\\u003E\\u000a          Open a link on the verification email to complete your verification.\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            notifications: \"{{\\u003Edashboard_settings}}\\u000a{{#user}}\\u000a\\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003EEmail notifications\\u003C/h2\\u003E\\u000a      \\u003Cp class=\\\"subheader\\\"\\u003EControl when and how often Twitter sends emails to you. \\u003Ca href=\\\"https://support.twitter.com/articles/127860-how-to-change-your-email-preferences\\\" target=\\\"_blank\\\"\\u003ELearn more.\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-inner no-stream-end\\\" id=\\\"notifications-content\\\"\\u003E\\u000a    \\u003Cform id=\\\"notifications-form\\\" class=\\\"form-horizontal notifications-form\\\" method=\\\"POST\\\" action=\\\"{{form_url}}\\\"\\u003E\\u000a      {{\\u003E settings/alert_partial}}\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a      {{#show_send_email_vit_weekly}}\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Ch3 class=\\\"settings-header\\\"\\u003EFor Verified Accounts only\\u003C/h3\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a        \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a          \\u003Clabel class=\\\"control-label\\\"\\u003EEmail me\\u003C/label\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_email_vit_weekly\\\" name=\\\"user[send_email_vit_weekly]\\\" {{#send_email_vit_weekly}}checked{{/send_email_vit_weekly}}\\u003EWeekly reports for my account\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_email_vit_weekly]\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a        \\u003Chr\\u003E\\u000a      {{/show_send_email_vit_weekly}}\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"settings-header\\\"\\u003EActivity on you and your Tweets\\u003C/h3\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EEmail me when\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          {{#favorite_emails_available}}\\u000a            {{#send_favorited_email_data}}\\u000a              \\u003Cspan id=\\\"send-favorited-email-dropdown\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput type=\\\"checkbox\\\" value=\\\"{{default}}\\\" id=\\\"send_favorited_email\\\" name=\\\"user[send_favorited_email]\\\" {{#send_favorited_email}}checked{{/send_favorited_email}}\\u003EMy Tweets are marked as favorites\\u000a                \\u003C/label\\u003E\\u000a                {{\\u003Esettings/notifications_partials/tweet_notification_dropdown}}\\u000a              \\u003C/span\\u003E\\u000a            {{/send_favorited_email_data}}\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"{{off}}\\\" name=\\\"user[send_favorited_email]\\\"\\u003E\\u000a          {{/favorite_emails_available}}\\u000a          {{#retweet_emails_available}}\\u000a            {{#send_retweeted_email_data}}\\u000a              \\u003Cspan id=\\\"send-retweeted-email-dropdown\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput type=\\\"checkbox\\\" value=\\\"{{default}}\\\" id=\\\"send_retweeted_email\\\" name=\\\"user[send_retweeted_email]\\\" {{#send_retweeted_email}}checked{{/send_retweeted_email}}\\u003EMy Tweets are retweeted\\u000a                \\u003C/label\\u003E\\u000a                {{\\u003Esettings/notifications_partials/tweet_notification_dropdown}}\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" value=\\\"{{off}}\\\" name=\\\"user[send_retweeted_email]\\\"\\u003E\\u000a            {{/send_retweeted_email_data}}\\u000a          {{/retweet_emails_available}}\\u000a          {{#mention_emails_available}}\\u000a            {{#send_mention_email_data}}\\u000a              \\u003Cspan id=\\\"send-mention-email-dropdown\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput type=\\\"checkbox\\\" value=\\\"{{default}}\\\" id=\\\"send_mention_email\\\" name=\\\"user[send_mention_email]\\\" {{#send_mention_email}}checked{{/send_mention_email}}\\u003EMy Tweets get a reply or I'm mentioned on a Tweet\\u000a                \\u003C/label\\u003E\\u000a                {{\\u003Esettings/notifications_partials/tweet_notification_dropdown}}\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" value=\\\"{{off}}\\\" name=\\\"user[send_mention_email]\\\"\\u003E\\u000a            {{/send_mention_email_data}}\\u000a          {{/mention_emails_available}}\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_new_friend_email\\\" name=\\\"user[send_new_friend_email]\\\" {{#send_new_friend_email}}checked{{/send_new_friend_email}}\\u003EI'm followed by someone new\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_new_friend_email]\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_new_direct_text_email\\\" name=\\\"user[send_new_direct_text_email]\\\" {{#send_new_direct_text_email}}checked{{/send_new_direct_text_email}}\\u003EI'm sent a direct message\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_new_direct_text_email]\\\"\\u003E\\u000a          {{#listed_emails_available}}\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"2\\\" id=\\\"send_listed_email\\\" name=\\\"user[send_listed_email]\\\" {{#send_listed_email}}checked{{/send_listed_email}}\\u003E I'm added to a list\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_listed_email]\\\"\\u003E\\u000a          {{/listed_emails_available}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Chr/\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"settings-header\\\"\\u003EActivity from your network\\u003C/h3\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EEmail me with\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            {{#network_digest_schedule_data}}\\u000a              \\u003Cspan id=\\\"network-digest-schedule-dropdown\\\"\\u003E\\u000a                \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a                  \\u003Cinput type=\\\"checkbox\\\" value=\\\"{{DIGEST_SCHEDULE_DEFAULT}}\\\" id=\\\"network_digest_schedule\\\" name=\\\"user[network_digest_schedule]\\\" {{#network_digest_schedule}}checked{{/network_digest_schedule}}\\u003ETop Tweets and Stories\\u000a                \\u003C/label\\u003E\\u000a                {{#network_digest_schedule_options}}\\u000a                  \\u003Cselect class=\\\"email-preference\\\" data-attribute=\\\"{{field}}\\\"\\u003E\\u000a                    \\u003Coption value=\\\"{{DIGEST_SCHEDULE_WEEKLY}}\\\" {{^daily_checked}}selected=\\\"selected\\\"{{/daily_checked}}\\u003ESent as a weekly digest\\u003C/option\\u003E\\u000a                    \\u003Coption value=\\\"{{DIGEST_SCHEDULE_DAILY}}\\\" {{#daily_checked}}selected=\\\"selected\\\"{{/daily_checked}}\\u003ESent as a daily digest\\u003C/option\\u003E\\u000a                  \\u003C/select\\u003E\\u000a                {{/network_digest_schedule_options}}\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" value=\\\"{{off}}\\\" name=\\\"user[network_digest_schedule]\\\"\\u003E\\u000a            {{/network_digest_schedule_data}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Chr/\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"settings-header\\\"\\u003EUpdates from Twitter\\u003C/h3\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EEmail me with\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_email_newsletter\\\" name=\\\"user[send_email_newsletter]\\\" {{#send_email_newsletter}}checked{{/send_email_newsletter}}\\u003ENews about Twitter product and feature updates\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_email_newsletter]\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_account_updates_email\\\" name=\\\"user[send_account_updates_email]\\\" {{#send_account_updates_email}}checked{{/send_account_updates_email}}\\u003EService updates related to my Twitter account\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_account_updates_email]\\\"\\u003E\\u000a            \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" id=\\\"send_resurrection_email_1\\\" name=\\\"user[send_resurrection_email_1]\\\" {{#send_resurrection_email_1}}checked{{/send_resurrection_email_1}}\\u003EAccount suggestions from Twitter\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" value=\\\"0\\\" name=\\\"user[send_resurrection_email_1]\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/fieldset\\u003E\\u000a      \\u003Chr\\u003E\\u000a      {{\\u003E settings/save_button}}\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/user}}\\u000a\",\n            phone_create: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EAdd your mobile phone to your account\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003EExpand your experience, get closer, and stay current.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  \\u003Cform id=\\\"sms-phone-create-form\\\" class=\\\"form-horizontal sms-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/create\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"device_type\\\" value=\\\"phone\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a    \\u003Cfieldset\\u003E\\u000a      \\u003Ch3 class=\\\"app-promo\\\"\\u003E\\u003Ca href=\\\"https://www.twitter.com/download\\\" target=\\\"_blank\\\"\\u003EDownload Twitter mobile app\\u003C/a\\u003E\\u003C/h3\\u003E\\u000a      \\u003Cp\\u003EAvailable for iPhone, iPad, Android, BlackBerry, and Windows Phone 7.\\u003C/p\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a    \\u003Chr class=\\\"app-promo-spacing\\\"\\u003E\\u000a    \\u003Cfieldset class=\\\"control-group\\\" id=\\\"choose-country\\\"\\u003E\\u000a      \\u003Ch3 class=\\\"settings-header\\\"\\u003EActivate Twitter text messaging\\u003C/h3\\u003E\\u000a      \\u003Cp\\u003EIt\\u2019s fast and easy. Get new features and help protect your account.\\u003C/p\\u003E\\u000a      \\u003Cbr\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003ECountry/region\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cselect id=\\\"device_country_code\\\" name=\\\"device[country_code]\\\"\\u003E\\u000a          {{#regions_and_country_codes}}\\u000a            {{#is_region}}\\u000a              \\u003Coptgroup label=\\\"{{country_name}}\\\"\\u003E\\u000a                {{#countries}}\\u000a                  \\u003Coption value=\\\"{{country_code}}\\\" data-region=\\\"{{region}}\\\" {{#is_country_for_phone_device}}selected{{/is_country_for_phone_device}}\\u003E{{country_name}}\\u003C/option\\u003E\\u000a                {{/countries}}\\u000a              \\u003C/optgroup\\u003E\\u000a            {{/is_region}}\\u000a            {{^is_region}}\\u000a              \\u003Coption value=\\\"{{country_code}}\\\" {{#is_country_for_phone_device}}selected{{/is_country_for_phone_device}}\\u003E{{country_name}}\\u003C/option\\u003E\\u000a            {{/is_region}}\\u000a          {{/regions_and_country_codes}}\\u000a        \\u003C/select\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"device_country_intl_prefix\\\" id=\\\"device_country_intl_prefix\\\" value=\\\"+{{#device_country_code}}{{device_country_code}}{{/device_country_code}}{{^device_country_code}}1{{/device_country_code}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"device[region_country_code]\\\" id=\\\"region_country_code\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a    \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003EPhone number\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"input-prepend\\\"\\u003E\\u000a          \\u003Clabel class=\\\"add-on\\\" id=\\\"country_code_display\\\"\\u003E{{#device_country_code}}+{{device_country_code}}{{/device_country_code}}{{^device_country_code}}{{default_country_code}}{{/device_country_code}}\\u003C/label\\u003E\\u000a          \\u003Cinput class=\\\"input-medium\\\" type=\\\"text\\\" value=\\\"{{device_address}}\\\" name=\\\"device[address]\\\" id=\\\"device_address\\\"\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cp class=\\\"carrier-help-note\\\" id=\\\"carrier-message-jawwal-ps\\\"\\u003EUsers with either a +972 or +970 dialing code are able to subscribe to Twitter on this carrier. Example: if your mobile number is +97259XXXYYYY, please enter 59XXXYYYY as your phone number above.\\u003C/p\\u003E\\u000a        \\u003Cp class=\\\"carrier-help-note\\\" id=\\\"carrier-message-wataniya-ps\\\"\\u003EUsers with either a +972 or +970 dialing code are able to subscribe to Twitter on this carrier. Example: if your mobile number is +97256XXXYYYY, please enter 56XXXYYYY as your phone number above.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a    \\u003Cfieldset class=\\\"control-group\\\" id=\\\"choose-carrier\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003ECarrier\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"carrier_name\\\" id=\\\"device_carrier_name\\\"\\u003E\\u000a        \\u003Cselect id=\\\"device_carrier\\\" name=\\\"device[carrier]\\\"\\u003E\\u003C/select\\u003E\\u000a        \\u003Cp class=\\\"carrier-help-note\\\" id=\\\"carrier-message-no-mt\\\"\\u003ENote: This carrier only allows you to send messages to Twitter. Twitter will not be able to send you text message notifications.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a    \\u003Chr\\u003E\\u000a    \\u003Cdiv class=\\\"form-actions\\\"\\u003E\\u000a      \\u003Cbutton id=\\\"start\\\" class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003EActivate phone\\u003C/button\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            phone_deactivated: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EAdd your mobile phone to your account\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003EExpand your experience, get closer, and stay current.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"stream-placeholder content-placeholder\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  {{#phone_device}}\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Ch2 class=\\\"title\\\"\\u003EUpdate your mobile settings\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      We're unable to connect to your mobile phone at \\u003Cstrong\\u003E+{{device_country_code}} {{device_address}}\\u003C/strong\\u003E.\\u000a      Please reactivate or delete your current phone.\\u000a    \\u003C/p\\u003E\\u000a    \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a      \\u003Cform id=\\\"sms-phone-deactivated-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"_method\\\" value=\\\"delete\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"reactivation\\\" value=\\\"1\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"btn primary-btn\\\" id=\\\"reactivate_device\\\"\\u003EReactivate phone\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cform id=\\\"sms-phone-deactivated-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"_method\\\" value=\\\"delete\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"btn\\\" id=\\\"delete_device\\\"\\u003EDelete\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{/phone_device}}\\u000a\\u003C/div\\u003E\",\n            phone_duplicate: \"\\u003Cdiv class=\\\"content-no-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"no-header-inner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"content-placeholder\\\"\\u003E\\u000a      \\u003Ch3 class=\\\"title\\\"\\u003E\\u000a        Sorry, we can't activate your phone.\\u000a        Text \\u003Cstrong\\u003E{{stop_command}}\\u003C/strong\\u003E to \\u003Cstrong\\u003E{{device_short_code}}\\u003C/strong\\u003E to retry.\\u000a      \\u003C/h3\\u003E\\u000a      \\u003Cp\\u003EThe phone number you gave us, +{{device_country_code}} {{device_address}}, is currently used by another Twitter account. Only one account can be used with a mobile phone at a time.\\u003C/p\\u003E\\u000a\\u000a      \\u003Cform id=\\\"sms-phone-duplicate-form\\\" class=\\\"form-inline sms-form\\\" method=\\\"post\\\" action=\\\"{{retry_url}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"device_type\\\" value=\\\"phone\\\" /\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Cinput id=\\\"device_country_intl_prefix\\\" name=\\\"device_country_intl_prefix\\\" type=\\\"hidden\\\" value=\\\"+{{device_country_code}}\\\"\\u003E\\u000a        \\u003Cbutton id=\\\"retry_verification\\\" class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ERetry activation\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cform id=\\\"sms-phone-duplicate-destroy-form\\\" class=\\\"form-inline sms-form\\\" method=\\\"post\\\" action=\\\"{{cancel_url}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" value=\\\"DELETE\\\" name=\\\"_method\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"btn\\\" id=\\\"cancel_verification\\\"\\u003ECancel\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            phone_unsupported: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EAdd your mobile phone to your account\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003EExpand your experience, get closer, and stay current.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-inner no-stream-end\\\" id=\\\"sms-unsupported-carrier\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  \\u003Cform id=\\\"sms-phone-unsupported-form\\\" class=\\\"form-horizontal sms-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"_method\\\" value=\\\"delete\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"content-placeholder\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a        {{#device_carrier_disabled}}\\u000a          \\u003Ch3 class=\\\"title\\\"\\u003ESorry, we don't have a connection to your carrier yet!\\u003C/h3\\u003E\\u000a          \\u003Cp\\u003E\\u000a            Don't worry, we're on it and will let you know once things are set up. In the meantime, use one of our long codes.\\u000a            \\u003Ca href=\\\"https://support.twitter.com/articles/14226-how-to-find-your-twitter-short-code-or-long-code\\\" target=\\\"_blank\\\" id=\\\"sms_info\\\"\\u003ELearn more\\u003C/a\\u003E.\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a            \\u003Cbutton type=\\\"submit\\\" class=\\\"btn primary-btn\\\" id=\\\"delete_device\\\"\\u003ETry again\\u003C/button\\u003E\\u000a          \\u003C/p\\u003E\\u000a        {{/device_carrier_disabled}}\\u000a        {{^device_carrier_disabled}}\\u000a          \\u003Ch3 class=\\\"title\\\"\\u003EThanks for waiting! We now have a connection to your carrier!\\u003C/h3\\u003E\\u000a          \\u003Cp\\u003E\\u000a            Activate your phone to use Twitter on the go.\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a            \\u003Cbutton type=\\\"submit\\\" class=\\\"btn primary-btn\\\" id=\\\"delete_device\\\"\\u003EActivate phone\\u003C/button\\u003E\\u000a          \\u003C/p\\u003E\\u000a        {{/device_carrier_disabled}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\",\n            phone_verified: \"\\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a    \\u003Ch2\\u003EMobile\\u003C/h2\\u003E\\u000a    \\u003Cp class=\\\"subheader\\\"\\u003ECustomize Twitter for your mobile phone.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a  {{\\u003E settings/alert_partial}}\\u000a\\u000a  \\u003Cform id=\\\"sms-phone-verified-form\\\" class=\\\"form-horizontal sms-form form-flush-actions\\\" method=\\\"post\\\" action=\\\"/settings/devices/enable/{{device_id}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a\\u000a    \\u003Cfieldset class=\\\"app-promo-group\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003EMobile apps\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"app-promo-link\\\"\\u003E\\u000a          \\u003Ca href=\\\"https://www.twitter.com/download\\\" target=\\\"_blank\\\"\\u003EDownload Twitter mobile app\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cp\\u003EAvailable for iPhone, iPad, Android, BlackBerry, and Windows Phone 7.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    \\u003Chr\\u003E\\u000a\\u000a    \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003EMy phone\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cp id=\\\"device-country-carrier\\\"\\u003E\\u000a          +{{device_country_code}} {{device_address}} ({{device_country_name}})\\u000a        \\u003C/p\\u003E\\u000a        \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" id=\\\"user_mobile_discoverable\\\" name=\\\"user[discoverable_by_mobile_phone]\\\" value=\\\"1\\\" {{#discoverable_by_mobile_phone}}checked{{/discoverable_by_mobile_phone}}\\u003E Let others find me by my phone number.\\u000a          \\u003Cinput type=\\\"hidden\\\" id=\\\"user_mobile_discoverable_set\\\" name=\\\"user[discoverable_by_mobile_phone]\\\" value=\\\"0\\\"\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a\\u000a    {{#device_can_have_pin}}\\u000a    \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label\\\"\\u003EPIN\\u003C/label\\u003E\\u000a      \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a        \\u003Cinput type=\\\"input\\\" id=\\\"device_pin\\\" name=\\\"device[pin]\\\" maxlength=\\\"4\\\" value=\\\"{{#device_pin}}{{device_pin}}{{/device_pin}}\\\"\\u003E\\u000a        \\u003Cp\\u003E\\u000a          Help protect against someone spoofing your account.\\u000a          \\u003Ca href=\\\"https://support.twitter.com/articles/20169928\\\" target=\\\"_blank\\\" id=\\\"sms_info\\\"\\u003ELearn more\\u003C/a\\u003E.\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/fieldset\\u003E\\u000a    {{/device_can_have_pin}}\\u000a\\u000a    \\u000a    {{#device_notifications_enabled}}\\u000a      {{#device_delivers}}\\u000a        {{\\u003E settings/devices/notifications}}\\u000a        {{\\u003E settings/devices/sleep_settings}}\\u000a      {{/device_delivers}}\\u000a\\u000a      {{#device_address_for_sms_is_international_longcode}}\\u000a        \\u003Clabel class=\\\"control-label\\\"\\u003EHow to Tweet\\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a          \\u003Cp\\u003E\\u000a            To Tweet via text message, send a message to one of our \\u000a            \\u003Ca href=\\\"https://support.twitter.com/articles/14226-how-to-find-your-twitter-short-code-or-long-code\\\" target=\\\"_blank\\\" id=\\\"sms_info\\\"\\u003Elong codes\\u003C/a\\u003E.\\u000a            If you'd like to view Tweets, try using \\u003Ca href=\\\"http://m.twitter.com\\\"\\u003Em.twitter.com\\u003C/a\\u003E on your phone.\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp\\u003E\\u000a            Note: Your carrier may charge you an international text messaging tariff to send a Tweet.\\u000a            Twitter doesn\\u2019t charge for this service, but standard message and data rates may apply.\\u000a          \\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/device_address_for_sms_is_international_longcode}}\\u000a      {{^device_address_for_sms_is_international_longcode}}\\u000a        \\u003Cp class=\\\"education-promo\\\"\\u003E\\u000a          Want to know about all the things you can do with Twitter text messaging?\\u000a          \\u003Ca href=\\\"https://support.twitter.com/groups/34-apps-sms-and-mobile/topics/153-twitter-via-sms/articles/14020-twitter-for-sms-basic-features\\\" target=\\\"_blank\\\" id=\\\"sms_info\\\"\\u003ELearn more\\u003C/a\\u003E.\\u000a        \\u003C/p\\u003E\\u000a      {{/device_address_for_sms_is_international_longcode}}\\u000a    {{/device_notifications_enabled}}\\u000a    {{^device_notifications_enabled}}\\u000a      \\u003Cp\\u003ENote: This carrier only allows you to send messages to Twitter. Twitter will not be able to send you text message notifications. Try using \\u003Ca href=\\\"http://m.twitter.com\\\"\\u003Em.twitter.com\\u003C/a\\u003E on your phone to view your Tweets.\\u003C/p\\u003E\\u000a    {{/device_notifications_enabled}}\\u000a\\u000a    \\u003Chr\\u003E\\u000a\\u000a    {{\\u003E settings/save_button}}\\u000a\\u000a  \\u003C/form\\u003E\\u000a\\u000a  \\u003Cform id=\\\"sms-phone-delete-form\\\" class=\\\"form-horizontal sms-form\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"_method\\\" value=\\\"delete\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"form-actions\\\" id=\\\"delete_device_link\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"submit\\\" class=\\\"btn-link\\\" id=\\\"delete_device\\\"\\u003EDelete my phone\\u003C/button\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            phone_verify: \"\\u003Cform id=\\\"sms-phone-verify-form\\\" class=\\\"form-horizontal sms-form form-flush-actions\\\" method=\\\"post\\\" action=\\\"/settings/devices/destroy/{{device_id}}\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"device_type\\\" value=\\\"phone\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"device_id\\\" value=\\\"{{device_id}}\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"content-no-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"no-header-inner\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"content-placeholder\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"title\\\"\\u003E\\u000a          Text \\u003Cstrong\\u003E{{device_go_command}}\\u003C/strong\\u003E to \\u003Cstrong\\u003E{{device_short_code}}\\u003C/strong\\u003E.\\u000a        \\u003C/h3\\u003E\\u000a\\u000a        \\u003Cdiv id=\\\"settings-alert-box\\\" class=\\\"alert content-placeholder-alert\\\"\\u003E\\u000a          \\u003Cp\\u003E\\u000a            \\u003Cspan class=\\\"spinner-small\\\"\\u003E\\u003C/span\\u003E\\u000a            Waiting for your activation text from +{{device_country_code}}{{device_address}}...\\u000a          \\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a        \\u003Cp\\u003E\\u000a          If you have texted {{device_go_command}} to {{device_short_code}} and this page hasn't updated, try \\u003Ca href=\\\"\\\" id=\\\"reload\\\"\\u003Erefreshing\\u003C/a\\u003E this page or texting again.\\u000a          Twitter doesn\\u2019t charge for this service, but standard message and data rates may apply.\\u000a        \\u003C/p\\u003E\\u000a        \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a          \\u003Cbutton id=\\\"cancel_verification\\\" class=\\\"btn\\\" type=\\\"submit\\\"\\u003ECancel activation\\u003C/button\\u003E\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\",\n            sleep_settings: \"\\u003Cfieldset class=\\\"control-group sleep-settings\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\"\\u003ESleep settings\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Clabel class=\\\"checkbox sleep-settings-toggle\\\"\\u003E\\u000a      \\u003Cinput type=\\\"checkbox\\\" class=\\\"toggler user_scheduled_sleeping\\\" name=\\\"user[scheduled_sleeping]\\\" id=\\\"user_scheduled_sleeping\\\" value=\\\"1\\\" {{#user_scheduled_sleeping}}checked{{/user_scheduled_sleeping}}\\u003E Turn off updates during these hours\\u000a    \\u003C/label\\u003E\\u000a    \\u003Cselect class=\\\"toggleable\\\" {{^user_scheduled_sleeping}}disabled{{/user_scheduled_sleeping}} name=\\\"user[scheduled_sleep_start_hour]\\\" id=\\\"user_scheduled_sleep_start_hour\\\"\\u003E\\u000a      {{#hours}}\\u000a        \\u003Coption value=\\\"{{value}}\\\" {{#user_scheduled_sleep_start_hour}}selected{{/user_scheduled_sleep_start_hour}}\\u003E{{hour}}\\u003C/option\\u003E\\u000a      {{/hours}}\\u000a    \\u003C/select\\u003E\\u000a    to\\u000a    \\u003Cselect class=\\\"toggleable\\\" {{^user_scheduled_sleeping}}disabled{{/user_scheduled_sleeping}} name=\\\"user[scheduled_sleep_end_hour]\\\" id=\\\"user_scheduled_sleep_end_hour\\\"\\u003E\\u000a      {{#hours}}\\u000a        \\u003Coption value=\\\"{{value}}\\\" {{#user_scheduled_sleep_end_hour}}selected{{/user_scheduled_sleep_end_hour}}\\u003E{{hour}}\\u003C/option\\u003E\\u000a      {{/hours}}\\u000a    \\u003C/select\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\",\n            devices_main: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#user}}\\u000a\\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a  {{#phone_device_deactivated}}\\u000a    {{\\u003E settings/devices/phone_deactivated}}\\u000a  {{/phone_device_deactivated}}\\u000a  {{^phone_device_deactivated}}\\u000a    {{#phone_device}}\\u000a      {{#device_dupe}}\\u000a        {{\\u003E settings/devices/phone_duplicate}}\\u000a      {{/device_dupe}}\\u000a      {{^device_dupe}}\\u000a        {{#device_carrier_unsupported}}\\u000a          {{\\u003E settings/devices/phone_unsupported}}\\u000a        {{/device_carrier_unsupported}}\\u000a        {{^device_carrier_unsupported}}\\u000a          {{#device_verified}}\\u000a            {{\\u003E settings/devices/phone_verified}}\\u000a          {{/device_verified}}\\u000a          {{^device_verified}}\\u000a            {{\\u003E settings/devices/phone_verify}}\\u000a          {{/device_verified}}\\u000a        {{/device_carrier_unsupported}}\\u000a      {{/device_dupe}}\\u000a    {{/phone_device}}\\u000a\\u000a    {{^phone_device}}\\u000a      {{#phone_device_available}}\\u000a        {{\\u003E settings/devices/phone_create}}\\u000a      {{/phone_device_available}}\\u000a    {{/phone_device}}\\u000a\\u000a    {{^phone_device_verification_in_progress}}\\u000a      {{#email_device}}\\u000a        {{#phone_device}}\\u000a          \\u003Chr\\u003E\\u000a        {{/phone_device}}\\u000a        {{\\u003E settings/devices/email}}\\u000a      {{/email_device}}\\u000a\\u000a      {{^email_device}}\\u000a        {{#email_device_available}}\\u000a          {{\\u003E settings/devices/email_create}}\\u000a        {{/email_device_available}}\\u000a      {{/email_device}}\\u000a    {{/phone_device_verification_in_progress}}\\u000a  {{/phone_device_deactivated}}\\u000a\\u003C/div\\u003E\\u000a{{/user}}\\u000a\",\n            enhanced_profile: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#current_user}}\\u000a  \\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a        \\u003Ch2\\u003EEnhanced Profile\\u003C/h2\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a      \\u003Cform action=\\\"{{upload_banner_preview_path}}\\\" class=\\\"twitter-form {{form_class}}\\\" target=\\\"banner_upload_frame\\\" enctype=\\\"multipart/form-data\\\" method=\\\"POST\\\" id=\\\"profile_banner\\\"\\u003E\\u000a        {{\\u003E settings/alert_partial}}\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a        \\u003Ch3 class=\\\"settings-header\\\"\\u003EBanner Image\\u003C/h3\\u003E\\u000a        \\u003Cfieldset id=\\\"profile-banner-controls\\\" class=\\\"control-group\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u000a              \\u003Cdiv class=\\\"banner-preview-box  {{proxy_uploader_class}}\\\"\\u003E\\u000a                \\u003Cdiv class=\\\"banner-shadow\\\"\\u003E\\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"banner-preview-image\\\"\\u003E\\u000a                  {{{sample_banner}}}\\u000a                \\u003C/div\\u003E\\u000a                \\u003Cdiv class=\\\"preview-loading-overlay\\\"\\u003E\\u000a                  \\u003Cimg id=\\\"preview_spinner\\\" src=\\\"{{bigger_spinner_path}}\\\" /\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/div\\u003E\\u000a\\u000a              \\u003Cdiv class=\\\"avatar-upload banner-upload-input\\\"\\u003E\\u000a                \\u003Cinput id=\\\"brand_banner_uploaded_data\\\" name=\\\"brand_banner[image_data]\\\" size=\\\"15\\\" type=\\\"file\\\"\\u003E\\u000a                \\u003Cp class=\\\"help-block\\\"\\u003EUpload a JPG or PNG that is 835 pixels wide by 90 pixels tall.\\u003C/p\\u003E\\u000a\\u000a                \\u003Cinput class=\\\"btn primary-btn publish-banner-btn action-btn {{preview_class}}\\\" name=\\\"commit\\\" type=\\\"submit\\\" value=\\\"Publish Banner\\\"/\\u003E\\u000a                \\u003Cinput class=\\\"btn btn-gray delete-preview-btn action-btn {{preview_class}}\\\" name=\\\"commit\\\" type=\\\"submit\\\" value=\\\"Remove Preview\\\"/\\u003E\\u000a                \\u003Cinput class=\\\"btn btn-gray delete-banner-btn action-btn {{live_class}}\\\" name=\\\"commit\\\" type=\\\"submit\\\" value=\\\"Remove Banner\\\"/\\u003E\\u000a                \\u003Cimg alt=\\\"Spinner\\\" class=\\\"action-spinner\\\" src=\\\"{{spinner_path}}\\\" /\\u003E\\u000a              \\u003C/div\\u003E\\u000a            \\u003C/div\\u003E\\u000a            \\u003Ciframe id=\\\"banner_upload_frame\\\" name=\\\"banner_upload_frame\\\" style=\\\"width:1px;height:1px;border:0px;visibility:hidden\\\"\\u003E\\u003C/iframe\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/fieldset\\u003E\\u000a      \\u003C/form\\u003E\\u000a\\u000a      {{#show_promoted_tweets_section}}\\u000a        \\u003Chr\\u003E\\u000a        \\u003Ch3 class=\\\"settings-header\\\"\\u003E{{promoted_tweets_label}}\\u003C/h3\\u003E\\u000a        \\u003Ca href=\\\"{{promoted_tweets_link_href}}\\\"\\u003E{{promoted_tweets_link_text}}\\u003C/a\\u003E\\u000a      {{/show_promoted_tweets_section}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/current_user}}\\u000a\",\n            tweet_notification_dropdown: \"\\u003Cselect class=\\\"email-preference\\\" data-attribute=\\\"{{field}}\\\"\\u003E\\u000a  \\u003Coption value=\\\"{{EMAIL_NOTIFICATIONS_FOLLOWS}}\\\" {{^everybody_checked}}selected=\\\"selected\\\"{{/everybody_checked}}\\u003EBy people I follow\\u003C/option\\u003E\\u000a  \\u003Coption value=\\\"{{EMAIL_NOTIFICATIONS_EVERYBODY}}\\\" {{#everybody_checked}}selected=\\\"selected\\\"{{/everybody_checked}}\\u003EBy anyone\\u003C/option\\u003E\\u000a\\u003C/select\\u003E\\u000a\",\n            password: \"\\u003Cdiv id=\\\"password-match-pair\\\"\\u003E\\u000a  \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a    \\u003Clabel for=\\\"user_password\\\" class=\\\"control-label\\\"\\u003ENew password\\u003C/label\\u003E\\u000a    \\u003Cdiv id=\\\"password_strength\\\" class=\\\"controls\\\"\\u003E\\u000a      \\u003Cinput id=\\\"user_password\\\" type=\\\"password\\\" name=\\\"user_password\\\"\\u003E\\u000a      \\u003Csmall id=\\\"password_strength_feedback\\\" class=\\\"help-inline help-error\\\" style=\\\"display: none;\\\"\\u003E\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/fieldset\\u003E\\u000a  \\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a    \\u003Clabel for=\\\"user_password_confirmation\\\" class=\\\"control-label\\\"\\u003EVerify password\\u003C/label\\u003E\\u000a    \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a      \\u003Cinput id=\\\"user_password_confirmation\\\" type=\\\"password\\\" name=\\\"user_password_confirmation\\\"\\u003E\\u000a      \\u003Csmall id=\\\"password_match\\\" class=\\\"help-inline help-error\\\" style=\\\"display: none;\\\"\\u003EPasswords don't match\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/fieldset\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            password_confirmation: \"\\u003Cdiv class=\\\"content-narrow\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"error-page error-403 clearfix\\\"\\u003E\\u000a    \\u003Ch1 class=\\\"heading\\\"\\u003EWoo hoo! Your password has been changed!\\u003C/h1\\u003E\\u000a    {{#show_app_review}}\\u000a    \\u003Cp class=\\\"lead\\\"\\u003E\\u000a      {{#multiple_apps}}\\u000a        As a reminder, you have \\u003Cstrong\\u003E{{number_of_apps}}\\u003C/strong\\u003E applications that can access your account. Do you want to review them?\\u000a      {{/multiple_apps}}\\u000a      {{^multiple_apps}}\\u000a        As a reminder, you have an application that can access your account. Do you want to review it?\\u000a      {{/multiple_apps}}\\u000a    \\u003C/p\\u003E\\u000a    \\u003Ca class=\\\"primary-btn btn js-nav\\\" href=\\\"{{connections_path}}\\\"\\u003EReview applications\\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"btn js-nav\\\" href=\\\"{{home_path}}\\\"\\u003ENo thanks\\u003C/a\\u003E\\u000a    {{/show_app_review}}\\u000a    {{^show_app_review}}\\u000a      \\u003Cp\\u003E\\u003Ca class=\\\" js-nav\\\" href=\\\"{{home_path}}\\\"\\u003E&larr; Go to the homepage\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    {{/show_app_review}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            profile: \"{{\\u003Edashboard_settings}}\\u000a\\u000a{{#user}}\\u000a        \\u003Cdiv class=\\\"content-main\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a              \\u003Ch2\\u003EProfile\\u003C/h2\\u003E\\u000a              \\u003Cp class=\\\"subheader\\\"\\u003EThis information appears on your public profile, search results, and beyond.\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"content-inner no-stream-end\\\"\\u003E\\u000a            \\u003Cform id=\\\"profile-form\\\" class=\\\"form-horizontal\\\"  enctype=\\\"multipart/form-data\\\" method=\\\"POST\\\" action=\\\"{{form_url}}\\\"\\u003E\\u000a              {{\\u003E settings/alert_partial}}\\u000a              \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a              \\u003Cinput type=\\\"hidden\\\" value=\\\"PUT\\\" name=\\\"_method\\\"\\u003E\\u000a              {{#image_upload_available}}\\u000a              {{\\u003E settings/profile_image}}\\u000a              {{/image_upload_available}}\\u000a              \\u003Chr\\u003E\\u000a              {{\\u003E settings/profile_user}}\\u000a              \\u003Chr\\u003E\\u000a              {{\\u003E settings/save_button}}\\u000a            \\u003C/form\\u003E\\u000a\\u000a            {{\\u003E dialogs/in_product_help_dialog}}\\u000a\\u000a            {{#show_delete_image_link}}\\u000a              \\u003Cform id=\\\"profile_image_delete_form\\\" class=\\\"form-horizontal\\\" method=\\\"POST\\\" action=\\\"{{form_url}}\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" value=\\\"Delete\\\" name=\\\"_method\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a              \\u003C/form\\u003E\\u000a            {{/show_delete_image_link}}\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a{{/user}}\\u000a\",\n            profile_image: \"\\u003Cfieldset id=\\\"profile-image-controls\\\" class=\\\"control-group\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"profile_image_uploaded_data\\\"\\u003EPicture\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"uploader-avatar clearfix\\\"\\u003E\\u000a      \\u003Cimg class=\\\"avatar size73\\\" id=\\\"avatar_preview\\\" src=\\\"{{avatar}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"uploader-tools\\\"\\u003E\\u000a        {{\\u003Eswift_photo_selector}}\\u000a        \\u003Cp\\u003E\\u000a          Maximum size of 700k. JPG, GIF, PNG.\\u003Cbr\\u003E\\u000a          Need help uploading a profile image? \\u003Ca href={{{profile_learn_more_attrs}}} id=\\\"profile_image_help\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003Cbr\\u003E\\u000a          {{#show_delete_image_link}}\\u000a            \\u003Ca href=\\\"#\\\" id=\\\"delete-image\\\" class=\\\"delete-image btn-link\\\"\\u003EDelete this image\\u003C/a\\u003E\\u000a          {{/show_delete_image_link}}\\u000a        \\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\",\n            profile_user: \"\\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"user_name\\\"\\u003EName\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Cinput id=\\\"user_name\\\" maxlength=\\\"20\\\" type=\\\"text\\\" name=\\\"user[name]\\\" value=\\\"{{name}}\\\"\\u003E\\u000a    \\u003Cp\\u003EEnter your real name, so people you know can recognize you.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"user_location\\\"\\u003ELocation\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Cinput id=\\\"user_location\\\" name=\\\"user[location]\\\" type=\\\"text\\\" value=\\\"{{location}}\\\"\\u003E\\u000a    \\u003Cp\\u003EWhere in the world are you?\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\\u003Cfieldset id=\\\"user_web_fieldset\\\" class=\\\"control-group\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"user_url\\\"\\u003EWebsite\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Cinput id=\\\"user_url\\\" name=\\\"user[url]\\\" rel=\\\"{{url_display}}\\\" size=\\\"30\\\" type=\\\"text\\\" value=\\\"{{url_display}}\\\"\\u003E\\u000a    \\u003Cp\\u003EHave a homepage or a blog? Put the address here.\\u003C/p\\u003E\\u000a    \\u003Cp\\u003E \\u003Ca href=\\\"/goodies\\\" title=\\\"Put Twitter on your site!\\\" id=\\\"tfw_link\\\"\\u003EYou can also add Twitter to your site here.\\u003C/a\\u003E\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\\u003Cfieldset class=\\\"control-group\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"user_description\\\"\\u003EBio\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Ctextarea class=\\\"input-xlarge\\\" id=\\\"user_description\\\" maxlength=\\\"160\\\" name=\\\"user[description]\\\"\\u003E{{description}}\\u003C/textarea\\u003E\\u000a    \\u003Cp\\u003E{{{bio_description}}}\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\\u000a\\u003Chr\\u003E\\u000a\\u000a{{#facebook_available}}\\u000a\\u003Cdiv id=\\\"fb-button\\\" class=\\\"fb-button-or-iframe\\\"\\u003E\\u000a  \\u003Clabel class=\\\"control-label\\\" for=\\\"\\\"\\u003EFacebook\\u003C/label\\u003E\\u000a  \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a    \\u003Ciframe id=\\\"fb-iframe\\\" scrolling=\\\"no\\\" frameborder=\\\"0\\\" style=\\\"display: none;\\\"\\u003E\\u003C/iframe\\u003E\\u000a    \\u003Cp\\u003E\\u003Ca href=\\\"#\\\" id=\\\"fb-anchor\\\" class=\\\"btn\\\" style=\\\"display: none;\\\"\\u003E\\u003Cspan\\u003EPost your Tweets to Facebook\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003Cp\\u003EHaving trouble? \\u003Ca href=\\\"https://support.twitter.com/articles/31113\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/facebook_available}}\\u000a\",\n            save_button: \"\\u003Cdiv class=\\\"form-actions\\\"\\u003E\\u000a  \\u003Cbutton id=\\\"settings_save\\\" class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ESave changes\\u003C/button\\u003E\\u000a\\u003C/div\\u003E\",\n            captcha: \"\\u003Cscript\\u003E\\u000a  var RecaptchaOptions = {\\u000a    theme: 'white',\\u000a    lang: '{{lang}}'\\u000a  };\\u000a\\u003C/script\\u003E\\u000a\\u003Cscript type=\\\"text/javascript\\\" src=\\\"https://www.google.com/recaptcha/api/challenge?k=6LfbTAAAAAAAAE0hk8Vnfd1THHnn9lJuow6fgulO&lang={{lang}}\\\"\\u003E\\u003C/script\\u003E\\u000a\",\n            country_select_options: \"{{#takedown_country_options}}\\u000a  \\u003Coption value=\\\"{{code}}\\\" {{#selected}}selected{{/selected}}\\u003E{{name}}\\u003C/option\\u003E\\u000a{{/takedown_country_options}}\",\n            lang_select_options: \"\\u003Coption\\u003ESelect Language...\\u003C/option\\u003E\\u000a{{#available_language_options}}\\u000a  \\u003Coption value=\\\"{{code}}\\\" {{#selected_lang}}selected{{/selected_lang}}\\u003E{{display_name}}\\u003C/option\\u003E\\u000a{{/available_language_options}}\\u000a\",\n            signin_form: \"\\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"signin\\\" method=\\\"post\\\"\\u003E\\u000a  {{\\u003Esignin_form_textbox}}\\u000a  {{\\u003Esignin_form_subchck}}\\u000a  \\u003Cdiv class=\\\"divider\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u003Ca class=\\\"forgot\\\" href=\\\"{{resend_password_path}}\\\"\\u003EForgot password?\\u003C/a\\u003E\\u003Cbr /\\u003E\\u000a    \\u003Ca class=\\\"mobile has-sms\\\" href=\\\"{{mobile_complete_path}}\\\"\\u003EAlready using Twitter via text message?\\u003C/a\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            signin_form_subchck: \"\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u000a\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect_after_login\\\" value=\\\"{{redirect_after_login}}\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a  \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn\\\" tabindex=4\\u003ESign in\\u003C/button\\u003E\\u000a\\u000a  \\u003Cfieldset class=\\\"subchck\\\"\\u003E\\u000a    \\u003Clabel class=\\\"remember\\\"\\u003E\\u000a      \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" name=\\\"remember_me\\\" {{#remember_checked}}checked=\\\"checked\\\"{{/remember_checked}} tabindex=3\\u003E\\u000a      Remember me\\u000a    \\u003C/label\\u003E\\u000a  \\u003C/fieldset\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            signin_form_textbox: \"\\u003Cfieldset\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"clearfix holding{{#username_or_email}} hasome{{/username_or_email}}\\\"\\u003E\\u000a    \\u003Cspan class=\\\"username js-username holder\\\"\\u003EUsername or email\\u003C/span\\u003E\\u000a    \\u003Cinput class=\\\"js-username-field email-input\\\" type=\\\"text\\\" name=\\\"session[username_or_email]\\\" autocomplete=\\\"on\\\" value=\\\"{{username_or_email}}\\\" tabindex=1\\u003E\\u000a    \\u003Cp class=\\\"help-text-inline\\\"\\u003EForgot your \\u003Ca href=\\\"{{resend_password_path}}\\\" title=\\\"{{password_reset_title}}\\\" tabindex=\\\"-1\\\"\\u003Eusername\\u003C/a\\u003E?\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"clearfix holding\\\"\\u003E\\u000a    \\u003Cspan class=\\\"password holder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a    \\u003Cinput class=\\\"js-password-field\\\" type=\\\"password\\\" name=\\\"session[password]\\\" tabindex=2\\u003E\\u000a    \\u003Cp class=\\\"help-text-inline\\\"\\u003EForgot your \\u003Ca href=\\\"{{resend_password_path}}\\\" tabindex=\\\"-1\\\"\\u003Epassword\\u003C/a\\u003E?\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a\\u000a\\u003C/fieldset\\u003E\\u000a\",\n            signin_or_signup: \"\\u003Cdiv id=\\\"signin-or-signup\\\"\\u003E\\u000a\\u000a  {{#is_signup_only}}\\u000a    \\u003Cdiv class=\\\"signup-call-out\\\"\\u003E\\u000a      {{\\u003Epartial_signup_form}}\\u000a    \\u003C/div\\u003E\\u000a  {{/is_signup_only}}\\u000a\\u000a  {{^is_signup_only}}\\u000a    {{\\u003Esignin_form}}\\u000a    \\u003Cdiv class=\\\"signup\\\"\\u003E\\u000a      \\u003Ch2\\u003ENot on Twitter? Sign up, tune into the things you care about, and get updates as they happen.\\u003C/h2\\u003E\\u000a      {{\\u003Esignup_button}}\\u000a    \\u003C/div\\u003E\\u000a  {{/is_signup_only}}\\u000a\\u000a\\u003C/div\\u003E\",\n            front_page_signup_form: \"\\u003Cdiv class=\\\"front-signup js-front-signup front_page_full_signup_256\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u003Cstrong\\u003ESign up\\u003C/strong\\u003E\\u003C/h2\\u003E\\u000a  \\u000a  \\u003Cform id=\\\"phx-signup-form\\\" class=\\\"signup\\\" method=\\\"post\\\" action=\\\"{{account_create_path}}\\\" data-front_page_full_signup_256_bucket=\\\"{{front_page_full_signup_256_bucket}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"name\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"placeholding-input holding\\\" data-fieldname=\\\"name\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" class=\\\"text-input\\\" autocomplete=\\\"off\\\" name=\\\"user[name]\\\" maxlength=\\\"20\\\"\\u003E\\u000a        \\u003Cspan class=\\\"placeholder\\\"\\u003EFull name\\u003C/span\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank invalid error js-user-tipsy\\\" title=\\\"A name is required!\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"email\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"placeholding-input holding js-user-tipsy\\\" data-fieldname=\\\"email\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input\\\" autocomplete=\\\"off\\\" name=\\\"user[email]\\\"\\u003E\\u000a        \\u003Cspan class=\\\"placeholder\\\"\\u003EEmail\\u003C/span\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"checking\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error js-user-tipsy\\\" title=\\\"Doesn't look like a valid email.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error js-user-tipsy\\\" title=\\\"An email is required!\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"taken error js-user-tipsy\\\" title=\\\"This email is already registered.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"password\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"placeholding-input holding js-user-tipsy\\\" data-fieldname=\\\"password\\\"\\u003E\\u000a        \\u003Cinput type=\\\"password\\\" class=\\\"text-input\\\" name=\\\"user[user_password]\\\"\\u003E\\u000a        \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#password_error}}\\u000a          \\u003Cp class=\\\"active error js-user-tipsy\\\" title=\\\"{{password_error}}\\\"\\u003E\\u003C/p\\u003E\\u000a          {{/password_error}}\\u000a          \\u003Cp class=\\\"perfect isaok\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"weak isaok\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"weak error js-user-tipsy\\\" title=\\\"Password is not secure enough.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"obvious error js-user-tipsy\\\" title=\\\"Password is too obvious.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error js-user-tipsy\\\" title=\\\"Password must be at least 6 characters.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error js-user-tipsy\\\" title=\\\"Password cannot be blank!\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"score\\\"\\u003E\\u003Cspan\\u003E\\u003Cb class=\\\"fill\\\"\\u003E\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"username\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"placeholding-input holding js-user-tipsy\\\" data-fieldname=\\\"username\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" class=\\\"text-input\\\" name=\\\"user[screen_name]\\\"\\u003E\\u000a        \\u003Cspan class=\\\"placeholder\\\"\\u003EUsername\\u003C/span\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#screen_name_error}}\\u000a          \\u003Cp class=\\\"active error js-user-tipsy\\\" title=\\\"{{screen_name_error}}\\\"\\u003E\\u003C/p\\u003E\\u000a          {{/screen_name_error}}\\u000a          \\u003Cp class=\\\"ok isaok js-user-tipsy\\\" title=\\\"Username is available. You can change it later.\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"checking\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"taken error js-user-tipsy\\\" title=\\\"This username is already taken!\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error js-user-tipsy\\\" title=\\\"Invalid username! Alphanumerics only.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error js-user-tipsy\\\" title=\\\"A username is required! You can change it later.\\\" role=\\\"alert\\\"\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"suggestions\\\"\\u003ESuggestions: \\u003Cul\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"details\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"prompt rememberme\\\"\\u003E\\u000a        \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" checked=\\\"checked\\\" name=\\\"user[remember_me_on_signup]\\\" value=\\\"1\\\"\\u003E\\u000a          Keep me logged in\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      {{#ask_cookie_personalization}}\\u000a      \\u003Cdiv class=\\\"prompt optin\\\"\\u003E\\u000a        \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a          \\u003Cinput type=\\\"checkbox\\\" {{^do_not_track}}checked=\\\"checked\\\"{{/do_not_track}} name=\\\"user[use_cookie_personalization]\\\" value=\\\"1\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"asked_cookie_personalization_setting\\\" value=\\\"1\\\"\\u003E\\u000a          Tailor Twitter based on my recent website visits. \\u003Ca class=\\\"cookie-personalization-support\\\" href=\\\"https://support.twitter.com/articles/20169421\\\" target=\\\\\\\"_blank\\\\\\\"\\u003ELearn more\\u003C/a\\u003E.\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{/ask_cookie_personalization}}\\u000a\\u000a      \\u003Cdiv class=\\\"terms\\\"\\u003E\\u000a        \\u003Cp\\u003EBy creating an account, you are agreeing to the \\u003Ca href=\\\"/tos\\\" target=\\\"_blank\\\"\\u003ETerms of Service\\u003C/a\\u003E and \\u003Ca href=\\\"/privacy\\\" target=\\\"_blank\\\"\\u003EPrivacy Policy\\u003C/a\\u003E. Others will be able to find you by name, username or email. Your email will not be shown publicly. You can change your privacy settings at any time.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cinput type=\\\"submit\\\" class=\\\"button submit btn signup-btn\\\" value=\\\"Create my account\\\"\\u003E\\u000a\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" value=\\\"{{signup_source}}\\\" name=\\\"context\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" value=\\\"1\\\" name=\\\"front_page_full_signup_256\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\\u000a{{#front_page_full_signup_256_login_form_below}}\\u003Ca href=\\\"#\\\" id=\\\"back-to-login\\\"\\u003EDid you mean to log in?\\u003C/a\\u003E{{/front_page_full_signup_256_login_form_below}}\\u000a\",\n            signup: \"\\u003Clink href=\\\"{{signup_css_bundle}}\\\" rel=\\\"stylesheet\\\"\\u003E\\u000a\\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"signup-wrapper\\\"\\u003E\\u000a\\u000a    {{#event}}\\u000a      \\u003Ch1\\u003EJoin Twitter today.\\u003C/h1\\u003E\\u000a      \\u003Cp\\u003EComplete signup now to follow top accounts for \\u003Cstrong\\u003E{{event_hashtag}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a      \\u003Cdiv class=\\\"ambassador event-signup clearfix\\\"\\u003E\\u000a        {{#top_people}}\\u003Cimg src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" class=\\\"avatar size48\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a{{/top_people}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a    {{/event}}\\u000a    {{^event}}\\u000a      {{#ambassadors_exist}}\\u000a        {{#follow_many}}\\u000a          \\u003Ch1\\u003EIt's your turn. Join Twitter.\\u003C/h1\\u003E\\u000a        {{/follow_many}}\\u000a        {{^follow_many}}\\u000a          \\u003Ch1\\u003EJoin Twitter today.\\u003C/h1\\u003E\\u000a        {{/follow_many}}\\u000a\\u000a        \\u003Cdiv class=\\\"ambassador clearfix\\\"\\u003E\\u000a          {{#ambassadors}}\\u000a            \\u003Cimg src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" class=\\\"avatar size48\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a          {{/ambassadors}}\\u000a          {{#follow_many}}\\u000a            \\u003Cp\\u003EComplete signup now to receive updates from \\u003Cstrong\\u003E{{first_ambassador_name}}\\u003C/strong\\u003E and others. \\u003C/p\\u003E\\u000a          {{/follow_many}}\\u000a          {{^follow_many}}\\u000a            \\u003Cp\\u003EComplete signup now to receive updates from \\u003Cstrong\\u003E{{first_ambassador_name}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a          {{/follow_many}}\\u000a        \\u003C/div\\u003E\\u000a      {{/ambassadors_exist}}\\u000a      {{^ambassadors_exist}}\\u000a        \\u003Ch1\\u003E\\u000a          {{#user_found_by_device}}\\u000a          Complete your account.\\u000a          {{/user_found_by_device}}\\u000a          {{^user_found_by_device}}\\u000a          Join Twitter today.\\u000a          {{/user_found_by_device}}\\u000a        \\u003C/h1\\u003E\\u000a      {{/ambassadors_exist}}\\u000a    {{/event}}\\u000a\\u000a    {{\\u003Esignup/signup_form}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            signup_form: \"\\u003Cform id=\\\"phx-signup-form\\\" method=\\\"POST\\\" action=\\\"{{account_create_path}}\\\" class=\\\"{{#captcha_tryagain}}validated captcha-tryagain{{/captcha_tryagain}}{{#user_found_by_device}} device-complete{{/user_found_by_device}} {{#show_captcha}}validated captcha-show{{/show_captcha}}\\\"\\u003E\\u000a\\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\" /\\u003E\\u000a\\u000a{{#event}}\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{event}}\\\" name=\\\"event\\\" /\\u003E\\u000a{{/event}}\\u000a{{#follow_field}}\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{follow_handles}}\\\" name=\\\"follows\\\" /\\u003E\\u000a{{/follow_field}}\\u000a{{#oauth_token}}\\u000a  \\u003Cinput type=\\\"hidden\\\" value=\\\"{{oauth_token}}\\\" name=\\\"oauth_token\\\" /\\u003E\\u000a{{/oauth_token}}\\u000a\\u000a{{#signup_user}}\\u000a\\u000a  \\u003Cfieldset class=\\\"textbox\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"prompt name\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"holding {{#name}}hasome{{/name}}\\\" data-fieldname=\\\"name\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#name_error}}\\u000a            \\u003Cp class=\\\"active error\\\"\\u003E{{name_error}}\\u003C/p\\u003E\\u000a          {{/name_error}}\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003EName looks great.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"tip\\\"\\u003EEnter your first and last name.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank invalid error\\\" role=\\\"alert\\\"\\u003EA name is required!\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" autocomplete=\\\"off\\\" value=\\\"{{name}}\\\" name=\\\"user[name]\\\" maxlength=\\\"20\\\" aria-required=\\\"true\\\" /\\u003E\\u000a        \\u003Cspan class=\\\"holder\\\"\\u003EFull name\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"prompt email\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"holding {{#email}}hasome{{/email}}\\\" data-fieldname=\\\"email\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#email_error}}\\u000a            \\u003Cp class=\\\"active error\\\"\\u003E{{email_error}}\\u003C/p\\u003E\\u000a          {{/email_error}}\\u000a          \\u003Cp class=\\\"tip\\\"\\u003EWhat\\u2019s your email address?\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003EWe will email you a confirmation.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"checking\\\"\\u003EValidating...\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error\\\" role=\\\"alert\\\"\\u003EDoesn't look like a valid email.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error\\\" role=\\\"alert\\\"\\u003EAn email is required!\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"taken error\\\" role=\\\"alert\\\"\\u003EThis email is already registered. Want to \\u003Ca href=\\\"{{login_path}}\\\"\\u003Elogin\\u003C/a\\u003E or \\u003Ca href=\\\"{{resend_password_path}}\\\"\\u003Erecover your password\\u003C/a\\u003E?\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"domain tip {{#abtest_autocorrect_email_domain_266_enabled}}ddg-autocorrect_email_domain_266_enabled{{/abtest_autocorrect_email_domain_266_enabled}}\\\"\\u003EDid you mean \\u003Cem\\u003E\\u003Ca class=\\\"js-email-correction\\\" href=\\\"#\\\"\\u003E\\u003C/a\\u003E\\u003C/em\\u003E?\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cinput class=\\\"email-input\\\" type=\\\"text\\\" autocomplete=\\\"off\\\" value=\\\"{{email}}\\\" name=\\\"user[email]\\\" aria-required=\\\"true\\\" /\\u003E\\u000a        \\u003Cspan class=\\\"holder\\\"\\u003EEmail\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"prompt password\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"holding {{#password}}hasome{{/password}}\\\" data-fieldname=\\\"password\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#password_error}}\\u000a            \\u003Cp class=\\\"active error\\\"\\u003E{{password_error}}\\u003C/p\\u003E\\u000a          {{/password_error}}\\u000a          \\u003Cp class=\\\"tip\\\"\\u003E6 characters or more! Be tricky.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"perfect isaok\\\"\\u003EPassword is perfect!\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003EPassword is okay.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"weak isaok\\\"\\u003EPassword could be more secure.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"weak error\\\" role=\\\"alert\\\"\\u003EPassword is not secure enough.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"obvious error\\\" role=\\\"alert\\\"\\u003EPassword is too obvious.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error\\\" role=\\\"alert\\\"\\u003EPassword must be at least 6 characters.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error\\\" role=\\\"alert\\\"\\u003EPassword cannot be blank!\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cinput type=\\\"password\\\" value=\\\"{{password}}\\\" name=\\\"user[user_password]\\\" aria-required=\\\"true\\\" /\\u003E\\u000a        \\u003Cspan class=\\\"holder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{#decider_phoenix_signup_show_password_score}}\\u000a      \\u003Cdiv class=\\\"score\\\"\\u003E\\u003Cspan\\u003E\\u003Cb\\u003E\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u000a      {{/decider_phoenix_signup_show_password_score}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"prompt username\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"holding {{#screen_name}}hasome{{/screen_name}}\\\" data-fieldname=\\\"username\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a          {{#screen_name_error}}\\u000a            \\u003Cp class=\\\"active error\\\"\\u003E{{screen_name_error}}\\u003C/p\\u003E\\u000a          {{/screen_name_error}}\\u000a          \\u003Cp class=\\\"ok isaok\\\"\\u003EUsername is available.\\u003Cbr\\u003EYou can change it later.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"tip\\\"\\u003EDon't worry, you can change it later.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"checking\\\"\\u003EValidating...\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"taken error\\\" role=\\\"alert\\\"\\u003EThis username is already taken!\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"invalid error\\\" role=\\\"alert\\\"\\u003EInvalid username! Alphanumerics only.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"blank error\\\" role=\\\"alert\\\"\\u003EA username is required!\\u003Cbr\\u003EYou can change it later.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" autocomplete=\\\"off\\\" value=\\\"{{screen_name}}\\\" data-pre-input-value=\\\"{{screen_name}}\\\" name=\\\"user[screen_name]\\\" maxlength=\\\"15\\\" aria-required=\\\"true\\\" /\\u003E\\u000a        \\u003Cspan class=\\\"holder\\\"\\u003EUsername\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"suggestions\\\"\\u003ESuggestions:&#32;\\u003Cul\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"prompt rememberme\\\"\\u003E\\u000a      \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a        \\u003Cinput type=\\\"checkbox\\\" {{#remember_me_on_signup}}checked=\\\"checked\\\"{{/remember_me_on_signup}} name=\\\"user[remember_me_on_signup]\\\" value=\\\"1\\\" /\\u003E\\u000a        \\u003Cspan\\u003EKeep me signed-in on this computer.\\u003C/span\\u003E\\u000a      \\u003C/label\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"user[remember_me_on_signup]\\\" value=\\\"\\\" /\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#ask_cookie_personalization}}\\u000a    \\u003Cdiv class=\\\"prompt optin\\\"\\u003E\\u000a      \\u003Clabel class=\\\"checkbox\\\"\\u003E\\u000a        \\u003Cinput type=\\\"checkbox\\\" {{^do_not_track}}checked=\\\"checked\\\"{{/do_not_track}} name=\\\"user[use_cookie_personalization]\\\" value=\\\"1\\\" /\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"asked_cookie_personalization_setting\\\" value=\\\"1\\\" /\\u003E\\u000a        \\u003Cspan\\u003ETailor Twitter based on my recent website visits. \\u003Ca class=\\\"cookie-personalization-support\\\" href=\\\"https://support.twitter.com/articles/20169421\\\" target=\\\\\\\"_blank\\\\\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a      \\u003C/label\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/ask_cookie_personalization}}\\u000a\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"context\\\" value=\\\"{{signup_context}}\\\" /\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"ad_ref\\\" value=\\\"{{ad_ref}}\\\" /\\u003E\\u000a\\u000a  \\u003C/fieldset\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"tos\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"sidetip\\\"\\u003E\\u000a      \\u003Cp class=\\\"active tip\\\"\\u003EPrintable versions:\\u003Cbr/\\u003E\\u003Ca href=\\\"{{tos_path}}\\\" target=\\\"_blank\\\"\\u003ETerms of Service\\u003C/a\\u003E &middot; \\u003Ca href=\\\"{{privacy_path}}\\\" target=\\\"_blank\\\"\\u003EPrivacy Policy\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Etos_scroller}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{#captcha_available}}\\u000a    \\u003Cdiv class=\\\"captcha-container\\\"\\u003E\\u000a      {{^captcha_tryagain}}\\u000a        \\u003Ch6\\u003EAre you human?\\u003C/h6\\u003E\\u000a      {{/captcha_tryagain}}\\u000a      {{#captcha_tryagain}}\\u000a        \\u003Ch6\\u003EPlease try again&hellip;\\u003C/h6\\u003E\\u000a      {{/captcha_tryagain}}\\u000a      \\u003Cdiv class=\\\"embed\\\"\\u003E\\u000a        \\u003Cnoscript\\u003E\\u000a          \\u003Cp\\u003EYou will need to enable JavaScript to answer the CAPTCHA and complete signup.\\u003C/p\\u003E\\u000a        \\u003C/noscript\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/captcha_available}}\\u000a\\u000a  \\u003Cdiv class=\\\"standby\\\"\\u003E\\u000a    \\u003Cp\\u003ECreating your account&hellip;\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cfieldset class=\\\"doit\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"sign-up-box\\\"\\u003E\\u003Cinput class=\\\"submit button promotional\\\" type=\\\"submit\\\" value=\\\"{{^user_found_by_device}}Create my account{{/user_found_by_device}}{{#user_found_by_device}}Complete my account{{/user_found_by_device}}\\\" /\\u003E\\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"befound\\\"\\u003E\\u000a      {{#decider_phoenix_signup_show_befound}}\\u000a      \\u003Cp\\u003E\\u000a        Let friends find you by email address?\\u003Cbr /\\u003E\\u000a        \\u003Cem\\u003EYour name will always be publicly searchable.\\u003C/em\\u003E\\u000a      \\u003C/p\\u003E\\u000a      \\u003Cdiv class=\\\"radios\\\"\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"user[discoverable_by_email]\\\" value=\\\"1\\\" {{#discoverable_by_email}}checked=\\\"checked\\\"{{/discoverable_by_email}} /\\u003E\\u000a          \\u003Cspan\\u003EYes\\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Clabel\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"user[discoverable_by_email]\\\" value=\\\"\\\" {{^discoverable_by_email}}checked=\\\"checked\\\"{{/discoverable_by_email}} /\\u003E\\u000a          \\u003Cspan\\u003ENo\\u003C/span\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/decider_phoenix_signup_show_befound}}\\u000a    {{^decider_phoenix_signup_show_befound}}\\u000a      \\u003Cp\\u003E\\u000a        Note: Others will be able to find you by name, username or email. Your email will not be shown publicly. You can change your privacy settings at any time.\\u000a      \\u003C/p\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"user[discoverable_by_email]\\\" value=\\\"1\\\" /\\u003E\\u000a    {{/decider_phoenix_signup_show_befound}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#decider_phoenix_signup_show_newsletter}}\\u000a    \\u003Cp class=\\\"newsletter\\\"\\u003E\\u000a      \\u003Clabel\\u003E\\u000a        \\u003Cinput type=\\\"checkbox\\\" name=\\\"user[send_email_newsletter]\\\" value=\\\"1\\\" {{#send_email_newsletter}}checked=\\\"checked\\\"{{/send_email_newsletter}} /\\u003E\\u000a        \\u003Cspan\\u003ESign up for our email newsletter\\u003C/span\\u003E\\u000a      \\u003C/label\\u003E\\u000a    \\u003C/p\\u003E\\u000a    {{/decider_phoenix_signup_show_newsletter}}\\u000a    {{^decider_phoenix_signup_show_newsletter}}\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"user[send_email_newsletter]\\\" value=\\\"1\\\" /\\u003E\\u000a    {{/decider_phoenix_signup_show_newsletter}}\\u000a\\u000a    {{#show_captcha}}\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"captcha_shown\\\" value=\\\"1\\\"\\u003E\\u000a    {{/show_captcha}}\\u000a  \\u003C/fieldset\\u003E\\u000a\\u000a{{/signup_user}}\\u000a\\u003C/form\\u003E\\u000a\",\n            signup_button: \"\\u003Cform action=\\\"{{signup_path}}\\\" class=\\\"signup\\\" method=\\\"get\\\"\\u003E\\u000a  {{#screen_name}}\\u000a    \\u003Cinput name=\\\"follow\\\" type=\\\"hidden\\\" value=\\\"{{screen_name}}\\\"\\u003E\\u000a  {{/screen_name}}\\u000a  {{#signup_source}}\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"context\\\" value=\\\"{{signup_source}}\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a  {{/signup_source}}\\u000a  \\u003Cbutton class=\\\"btn promotional signup-btn\\\" type=\\\"submit\\\"\\u003ESign up &raquo;\\u003C/button\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            download: \"\\u000a\\u003Cdiv class=\\\"content-no-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"no-header-inner promptbox\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"content-placeholder\\\"\\u003E\\u000a        \\u003Cform method=\\\"post\\\" action=\\\"{{signup_download_create_path}}\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a          \\u003Ch3 class=\\\"title\\\"\\u003EWhat's your phone number?\\u003C/h3\\u003E\\u000a          \\u003Cp\\u003EWe'll send you a link to download the Twitter app. We\\u2019ll also activate Twitter text messaging so you can tweet by texting. Standard message rates apply. Others will be able to find you by your phone number.\\u003C/p\\u003E\\u000a          \\u003Cbr\\u003E\\u000a          \\u003Cdiv id=\\\"settings-alert-box\\\" class=\\\"alert\\\" {{^alerts}}style=\\\"display: none;\\\"{{/alerts}}\\u003E\\u000a            {{#alerts}}\\u000a              \\u003Ch4\\u003E{{first}}\\u003C/h4\\u003E\\u000a              \\u003Cdiv id=\\\"settings-alert-message\\\"\\u003E\\u000a                {{#rest}}\\u003Cp\\u003E{{{to_s}}}\\u003C/p\\u003E{{/rest}}\\u000a              \\u003C/div\\u003E\\u000a            {{/alerts}}\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"input-prepend\\\"\\u003E\\u000a            \\u003Clabel class=\\\"add-on\\\" id=\\\"country_code_display\\\"\\u003E+1\\u003C/label\\u003E\\u000a            \\u003Cinput class=\\\"input-medium\\\" type=\\\"text\\\" value=\\\"{{device_address}}\\\" name=\\\"device[address]\\\" id=\\\"device_address\\\" placeholder=\\\"xxx-xxx-xxxx\\\"\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a            \\u003Cinput class=\\\"btn primary-btn next\\\" type=\\\"submit\\\" value=\\\"Send link to my phone\\\"\\u003E\\u000a            \\u003Ca class=\\\"btn skip\\\" href={{welcome_url}}\\u003ESkip\\u003C/a\\u003E\\u000a          \\u003C/p\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"cover\\\"\\u003E\\u003C/div\\u003E\\u000a{{\\u003Ewelcome_learn_flow_background}}\\u000a\",\n            verify: \"\\u000a\\u003Cdiv class=\\\"content-no-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"no-header-inner promptbox\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"content-placeholder\\\"\\u003E\\u000a      {{#error}}\\u000a        {{#unsupported_carrier}}\\u000a        \\u003Ch3 class=\\\"title\\\"\\u003EWe couldn\\u2019t send you a text message.\\u003C/h3\\u003E\\u000a        \\u003Cp\\u003EWe do not yet support your mobile carrier. Not to worry, you can \\u003Ca href=\\\"{{signup_download_url}}\\\" class=\\\"try_different_number\\\"\\u003Etry a different number\\u003C/a\\u003E or get the Twitter app later. Let's continue building your Twitter on this computer.\\u003C/p\\u003E\\u000a        \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a          \\u003Ca class=\\\"btn primary-btn next\\\" href=\\\"{{welcome_url}}\\\"\\u003EContinue\\u003C/a\\u003E\\u000a        \\u003C/p\\u003E\\u000a        {{/unsupported_carrier}}\\u000a        {{^unsupported_carrier}}\\u000a          \\u003Ch3 class=\\\"title\\\"\\u003EHmm, something seems to have gone wrong.\\u003C/h3\\u003E\\u000a          \\u003Cp\\u003EWe weren\\u2019t able to verify your device. Not to worry, you can \\u003Ca href=\\\"{{signup_download_url}}\\\" class=\\\"try_again\\\"\\u003Etry again\\u003C/a\\u003E  or get the Twitter app later. Let's continue building your Twitter on this computer.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a            \\u003Ca class=\\\"btn primary-btn next\\\" href=\\\"{{welcome_url}}\\\"\\u003EContinue\\u003C/a\\u003E\\u000a          \\u003C/p\\u003E\\u000a        {{/unsupported_carrier}}\\u000a      {{/error}}\\u000a      {{^error}}\\u000a        {{^verified}}\\u000a          \\u003Cform id=\\\"sms-phone-verify-form\\\"\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" name=\\\"device_id\\\" value=\\\"{{device_id}}\\\"\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a            \\u003Cinput type=\\\"hidden\\\" name=\\\"awaiting_verification\\\" value=\\\"true\\\"\\u003E\\u000a            \\u003Ch3 class=\\\"title\\\"\\u003EIs our text message on your phone yet?\\u003C/h3\\u003E\\u000a            \\u003Cp\\u003E\\u000a             \\u003Cspan class=\\\"spinner-small\\\"\\u003E\\u003C/span\\u003E\\u000a             When the text message arrives, open it and click on the link to download the Twitter app. If the message does not come soon, you can \\u003Ca href=\\\"{{welcome_url}}\\\" class=\\\"continue\\\"\\u003Econtinue\\u003C/a\\u003E building your Twitter on this computer.\\u000a            \\u003C/p\\u003E\\u000a          \\u003C/form\\u003E\\u000a        {{/verified}}\\u000a        {{#verified}}\\u000a          \\u003Ch3 class=\\\"title\\\"\\u003EGreat, your phone is verified!\\u003C/h3\\u003E\\u000a          \\u003Cp\\u003ENow download the Twitter app on your phone, and login as \\u003Cstrong\\u003E{{username}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a          \\u003Cp\\u003EWhile the app is downloading, let's continue building your Twitter on this computer.\\u003C/p\\u003E\\u000a          \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a            \\u003Ca class=\\\"btn primary-btn next\\\" href=\\\"{{welcome_url}}\\\"\\u003EContinue\\u003C/a\\u003E\\u000a          \\u003C/p\\u003E\\u000a        {{/verified}}\\u000a      {{/error}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"cover\\\"\\u003E\\u003C/div\\u003E\\u000a{{\\u003Ewelcome_learn_flow_background}}\\u000a\",\n            similar_to_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{^logged_in}}\\u000a      {{#profile_user}}\\u000a        {{\\u003Esign_up_call_out}}\\u000a      {{/profile_user}}\\u000a    {{/logged_in}}\\u000a    {{#profile_user}}\\u000a      {{\\u003Eprofile_similar_to_header}}\\u000a    {{/profile_user}}\\u000a    {{\\u003Estream_manager}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a{{\\u003Eprofile_dashboard}}\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            simple_tweet: \"{{^render_withheld}}\\u000a\\u000a  \\u000a  {{#is_current_user_withheld}}\\u000a    {{\\u003Ewithheld_message}}\\u000a  {{/is_current_user_withheld}}\\u000a\\u000a  \\u003Cdiv class=\\\"simple-tweet tweet js-stream-tweet js-hover js-actionable-tweet js-profile-popup-actionable {{#is_slideshow}}slideshow-tweet{{/is_slideshow}} {{\\u003Ecommon_tweet_classes}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a\\u000a    \\u000a    \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a\\u000a    \\u000a    \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a        {{\\u003Etweet_timestamp}}\\u000a        {{\\u003Etweet_user_block}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a        \\u000a        \\u000a\\u000a        \\u000a        \\u003Ca class=\\\"details with-icn js-details\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a          \\u003Cspan class=\\\"details-icon js-icon-container\\\"{{#place_name}} data-placename=\\\"{{place_name}}\\\"{{/place_name}}\\u003E\\u000a            {{#rendering_on_server}}\\u000a            {{#has_embedded_photo}}\\u000a              \\u003Ci class=\\\"sm-image\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_photo}}\\u000a            {{#has_embedded_summary}}\\u000a              \\u003Ci class=\\\"sm-embed\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_summary}}\\u000a            {{#has_embedded_player}}\\u000a              \\u003Ci class=\\\"sm-video\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_player}}\\u000a            {{#has_strong_geo}}\\u000a              \\u003Ci class=\\\"sm-geo\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_strong_geo}}\\u000a            {{/rendering_on_server}}\\u000a          \\u003C/span\\u003E\\u000a          \\u003Cb\\u003E\\u000a            \\u003Cspan class=\\\"simple-details-link\\\"\\u003EDetails\\u003C/span\\u003E\\u000a            \\u003Cspan class=\\\"expand-stream-item js-view-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{expand_callout_text}}\\u000a                {{^expand_callout_text}}\\u000a                  \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                    Expand\\u000a                  \\u003C/span\\u003E\\u000a                {{/expand_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                  Expand\\u000a                \\u003C/span\\u003E\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a            \\u003Cspan class=\\\"collapse-stream-item js-hide-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{collapse_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                Collapse\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a          \\u003C/b\\u003E\\u000a        \\u003C/a\\u003E\\u000a\\u000a        \\u000a        {{\\u003Etweet_actions}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{\\u003Estream_tweet_expansion}}\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a{{/render_withheld}}\\u000a\",\n            simple_tweet_large: \"\\u003Cdiv class=\\\"stream-item-content tweet js-actionable-tweet stream-tweet simple-tweet\\\"\\u000a  data-tweet-id=\\\"{{id}}\\\" {{{tweet_impression_id}}} {{#current_user_retweet}}data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}} data-item-id=\\\"{{id}}\\\" {{#was_retweeted}}{{#retweeting_status}}data-retweet-id=\\\"{{id}}\\\"{{/retweeting_status}}{{/was_retweeted}} {{#user}}data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"{{/user}} {{#protected}}data-protected=\\\"true\\\"{{/protected}} {{#is_sponsored}}data-promoted=\\\"true\\\"{{/is_sponsored}}\\u003E\\u000a  {{\\u003Etweet_dogear}}\\u000a  \\u003Cdiv class=\\\"tweet-image\\\"\\u003E\\u000a      {{\\u003Etweet_user_image_48}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Etweet_user_name}}\\u000a      \\u003Cdiv class=\\\"tweet-corner\\\"\\u003E\\u000a        {{\\u003Etweet_meta}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Etweet_text}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            single_tweet: \"{{^render_withheld}}\\u000a  \\u000a  \\u003Cdiv class=\\\"permalink-inner permalink-tweet-container\\\"\\u003E\\u000a\\u000a    {{#is_current_user_withheld}}\\u000a      {{\\u003Ewithheld_message}}\\u000a    {{/is_current_user_withheld}}\\u000a\\u000a    \\u003Cdiv class=\\\"tweet permalink-tweet js-actionable-user js-hover js-actionable-tweet {{\\u003Ecommon_tweet_classes}} {{#logged_in}}logged-in{{/logged_in}} preexpanded\\\" data-associated-tweet-id=\\\"{{id}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a\\u000a      \\u000a      \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"content clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"permalink-header\\\"\\u003E\\u000a          {{#user}}\\u000a            {{\\u003Eprofile_actions}}\\u000a          {{/user}}\\u000a          {{\\u003Etweet_user_block}}\\u000a          \\u000a          {{\\u003Etweet_timestamp}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      \\u003Cp class=\\\"js-tweet-text tweet-text {{#is_rtl_tweet}} tweet-text-rtl{{/is_rtl_tweet}}\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a        \\u000a        {{\\u003Etweet_context}}\\u000a\\u000a        \\u000a        {{\\u003Etweet_actions}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cdiv class=\\\"permalink-footer\\\"\\u003E\\u000a        {{\\u003Estream_tweet_expansion}}\\u000a        {{\\u003Etweet_details}}\\u000a        {{\\u003Eproxy_tweet}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a  \\u003C/div\\u003E\\u000a{{/render_withheld}}\\u000a{{#render_withheld}}\\u000a  {{\\u003Esingle_tweet_withheld}}\\u000a{{/render_withheld}}\\u000a\",\n            single_tweet_withheld: \"\\u003Cdiv class=\\\"tweet js-actionable-tweet permalink-tweet permalink-tweet-withheld {{css_classes}}\\\" data-tweet-id=\\\"{{id}}\\\" data-item-id=\\\"{{id}}\\\" {{#current_user_retweet}}data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}} data-screen-name='{{#user}}{{screen_name}}{{/user}}'\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-user-withheld\\\"\\u003E\\u000a        Tweet withheld\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a    {{\\u003Etweet_text_large}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            slideshow_tweet: \"\\u003Cdiv class=\\\"tweet slideshow-tweet js-actionable-tweet\\\" data-tweet-id=\\\"{{id}}\\\" data-item-id=\\\"{{id}}\\\" {{#current_user_retweet}}data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}} {{#was_retweeted}}{{#retweeting_status}}data-retweet-id=\\\"{{id}}\\\"{{/retweeting_status}}{{/was_retweeted}} {{#user}}data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\"{{/user}} {{#protected}}data-protected=\\\"true\\\"{{/protected}} {{#is_sponsored}}data-promoted=\\\"true\\\"{{/is_sponsored}}\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-image\\\"\\u003E\\u000a      {{\\u003Etweet_user_image_48}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Etweet_user_name}}\\u000a      {{\\u003Etweet_timestamp}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Etweet_text}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row stream-item-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"details with-icn js-details\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a        \\u003Cb\\u003E\\u003Cspan class=\\\"simple-details-link\\\"\\u003EDetails\\u003C/span\\u003E\\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a      {{\\u003Etweet_actions}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-row\\\"\\u003E\\u000a      {{\\u003Etweet_labels}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Eproxy_tweet}}\\u000a\\u003C/div\\u003E\\u000a\",\n            slow_load_banner: \"\\u003Cdiv class=\\\"banner-outer\\\" id=\\\"slow-load-banner\\\" style=\\\"display:none;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"banner-inside slow-warning\\\"\\u003E\\u000a      \\u003Ch5\\u003ETwitter.com is loading slowly.\\u003C/h5\\u003E\\u000a      \\u003Cspan class=\\\"warning\\\"\\u003EHmm, this seems to be taking a while. If problems persist, \\u003Ca href=\\\"javascript:window.JSBNG__location.reload(true);\\\"\\u003Eplease reload\\u003C/a\\u003E to try again.\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            small_follow_button: \"{{%TRANSLATION-HINT mode=actions}}\\u000a\\u003Cdiv class=\\\"follow-combo btn-group js-actionable-user {{#blocking}}blocked{{/blocking}}{{^blocking}}{{^following}}not-following{{/following}}{{#following}}following{{/following}}{{#follow_request_sent}} follow-request-sent{{/follow_request_sent}}{{#protected}} protected{{/protected}}{{#following}}{{#want_retweets}} including{{/want_retweets}}{{#notifications}} notifying{{/notifications}}{{/following}}{{#can_dm}} can-dm{{/can_dm}}{{/blocking}}\\\" data-user-id=\\\"{{id}}\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E\\u000a  \\u003Ca class=\\\"small follow-btn btn js-combo-btn js-recommended-item\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-follow follow-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003E\\u000a      Follow\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"following-text\\\"\\u003E\\u000a      Following\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow unfollow-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Unfollow\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"block-text\\\"\\u003E\\u000a      Blocked\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unblock unblock-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Unblock\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"pending-text\\\"\\u003E\\u000a      Pending\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-action-unfollow cancel-req-text\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      Cancel\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cspan href=\\\"#\\\" class=\\\"small btn btn-user-actions\\\"\\u003E\\u000a    \\u003Ci class=\\\"account-arrow\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cul class=\\\"js-combo-btn-dropdown-options dropdown-menu btn-group-dropdown\\\"\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-action-mention is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003EMention {{screen_name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-direct-message-action can-send-dm\\\" href=\\\"#\\\"\\u003ESend a direct message\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-action-add-to-list is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003EAdd/Remove from lists\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-action-block is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003EBlock {{screen_name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-action-unblock is-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003EUnblock {{screen_name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-action-spam is-not-blocked\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003EReport {{screen_name}} for spam\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"is-following divider\\\"\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-retweet-setting is-not-including\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003ETurn on Retweets\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-retweet-setting is-including\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003ETurn off Retweets\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-device-notifications is-not-notifying\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003ETurn on mobile notifications\\u003C/a\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u003Ca class=\\\"js-device-notifications is-notifying\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003ETurn off mobile notifications\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            sms_follow: \"{{#show_sms_prompt}}\\u000a  \\u003Cdiv class=\\\"sms-follow\\\"\\u003E\\u000a    \\u003Cspan class=\\\"icon\\\"\\u003E\\u003C/span\\u003E {{{sms_follow_text}}}\\u000a  \\u003C/div\\u003E\\u000a{{/show_sms_prompt}}\",\n            sms_follow_prompt: \"{{#show_sms_prompt}}\\u000a  \\u003Cdiv class=\\\"sms-follow\\\"\\u003E\\u000a    \\u003Cspan class=\\\"icon\\\"\\u003E\\u003C/span\\u003E\\u000a    {{#show_detailed_command}}\\u000a      Text \\u003Cstrong\\u003Efollow {{screen_name}}\\u003C/strong\\u003E to \\u003Cstrong\\u003E{{number}}\\u003C/strong\\u003E in \\u003Ca href=\\\"{{sms_codes_link}}\\\" class=\\\"sms-codes-link\\\"\\u003E{{where}}\\u003C/a\\u003E\\u000a    {{/show_detailed_command}}\\u000a    {{^show_detailed_command}}\\u000a      Text \\u003Cstrong\\u003Efollow {{screen_name}}\\u003C/strong\\u003E to \\u003Ca href=\\\"{{sms_codes_link}}\\\" class=\\\"sms-codes-link\\\"\\u003Eyour carrier's shortcode\\u003C/a\\u003E\\u000a    {{/show_detailed_command}}\\u000a  \\u003C/div\\u003E\\u000a{{/show_sms_prompt}}\",\n            soccer_matched_event: \"{{#home_team}}\\u000a\\u003Cspan class=\\\"home-team\\\"\\u003E\\u000a  \\u003Ca class=\\\"account-group js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"team\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"fullname\\\"\\u003E{{team_name}} \\u003C/div\\u003E\\u000a    {{#user}}\\u000a    \\u003Cdiv class=\\\"follow-team\\\"\\u003E\\u000a      {{#show_follow}}\\u000a        Follow\\u000a      {{/show_follow}}\\u000a      {{^show_follow}}\\u000a        @{{screen_name}}\\u000a      {{/show_follow}}\\u000a    \\u003C/div\\u003E\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cimg class=\\\"team-logo\\\" src=\\\"{{team_logo_url}}\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/span\\u003E\\u000a{{/home_team}}\\u000a\\u000a\\u003Cspan class=\\\"score\\\"\\u003E\\u000a  {{#score}}\\u000a  \\u003Ca class=\\\"matched-score live\\\" href=\\\"{{search_path}}\\\"\\u003E\\u000a    \\u003Cspan class=\\\"home-score\\\"\\u003E{{home}}\\u003C/span\\u003E\\u003Cspan class=\\\"divider\\\"\\u003E\\u003Ci class=\\\"dot\\\"\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"dot\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"away-score\\\"\\u003E{{away}}\\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a  {{/score}}\\u000a  {{#preview}}\\u000a  \\u003Cspan class=\\\"preview\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"scheduled-time\\\"\\u003E\\u000a      \\u003Cspan\\u003E{{time}}\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#url}}\\u000a    \\u003Cdiv class=\\\"detail\\\"\\u003E\\u000a      \\u003Ca target=\\\"_blank\\\" href=\\\"{{url}}\\\"\\u003EView details\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/url}}\\u000a  \\u003C/span\\u003E\\u000a  {{/preview}}\\u000a  \\u003Cdiv class=\\\"time-status\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{search_path}}\\\" class=\\\"hashtag\\\" data-hashtag=\\\"{{hashtag}}\\\"\\u003E{{hashtag}}\\u003C/a\\u003E\\u000a    {{#match_state}}\\u000a    \\u003Cspan class=\\\"bullet\\\"\\u003E&sdot;\\u003C/span\\u003E\\u000a    {{#current_period_string}}\\u000a    \\u003Cspan class=\\\"half\\\"\\u003E{{current_period_string}}\\u003C/span\\u003E\\u000a    {{/current_period_string}}\\u000a    {{#show_time_elapsed_time}}\\u000a    \\u003Cspan class=\\\"elapsed_time\\\"\\u003E{{current_period_elapsed_time_string}}\\u003C/span\\u003E\\u000a    {{/show_time_elapsed_time}}\\u000a    {{/match_state}}\\u000a    {{#recap}}{{#url}}\\u000a    \\u003Cspan class=\\\"bullet\\\"\\u003E&sdot;\\u003C/span\\u003E \\u003Ca class=\\\"recap\\\" target=\\\"_blank\\\" href=\\\"{{url}}\\\"\\u003EView recap &raquo;\\u003C/a\\u003E\\u000a    {{/url}}{{/recap}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/span\\u003E\\u000a\\u000a{{#away_team}}\\u000a\\u003Cspan class=\\\"away-team\\\"\\u003E\\u000a  \\u003Ca class=\\\"account-group js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"team\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"fullname\\\"\\u003E {{team_name}}\\u003C/div\\u003E\\u000a    {{#user}}\\u000a    \\u003Cdiv class=\\\"follow-team\\\"\\u003E\\u000a      {{#show_follow}}\\u000a        Follow\\u000a      {{/show_follow}}\\u000a      {{^show_follow}}\\u000a        @{{screen_name}}\\u000a      {{/show_follow}}\\u000a    \\u003C/div\\u003E\\u000a    {{/user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cimg class=\\\"team-logo\\\" src=\\\"{{team_logo_url}}\\\"\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/span\\u003E\\u000a{{/away_team}}\\u000a\",\n            soccer_ticker: \"{{#preview}}\\u000a  {{#user}}\\u000a  Follow \\u003Ca class=\\\"follow-news js-follow-news js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E{{name}}\\u003C/a\\u003E \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E for game updates.\\u000a  \\u003Ca class=\\\"follow-news js-follow-news js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003EFollow\\u003C/a\\u003E\\u000a  {{/user}}\\u000a{{/preview}}\\u000a{{^preview}}\\u000a  \\u003Cul class=\\\"ticker\\\"\\u003E\\u000a    {{#ticker_list}}\\u000a      \\u003Cli class='event-item' event_id={{event_id}}\\u003E\\u000a        \\u003Ca class=\\\"ticker-event\\\" href=\\\"{{search_path}}\\\" data-hashtag=\\\"{{hashtag}}\\\"\\u003E\\u000a        \\u003Cspan class=\\\"ticker-team\\\"\\u003E{{home_name}}\\u003C/span\\u003E\\u000a          \\u003Cspan class=\\\"ticker-score {{#live}}live{{/live}}\\\"\\u003E {{#score}} {{home}} : {{away}} {{/score}} \\u003C/span\\u003E\\u000a        \\u003Cspan class=\\\"ticker-team\\\"\\u003E{{away_name}}\\u003C/span\\u003E\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/li\\u003E\\u000a    {{/ticker_list}}\\u000a  \\u003C/ul\\u003E\\u000a{{/preview}}\\u000a\",\n            social_context_narrow: \"{{#following_followers_of}}\\u000a  {{^is_plural}}\\u000a    You follow an account that follows @{{screen_name}}\\u000a  {{/is_plural}}\\u000a  {{#is_plural}}\\u000a    You follow accounts that follow @{{screen_name}}\\u000a  {{/is_plural}}\\u000a{{/following_followers_of}}\\u000a{{^following_followers_of}}\\u000a  {{^is_plural}}\\u000a    You both follow this account\\u000a  {{/is_plural}}\\u000a  {{#is_plural}}\\u000a    You both follow these accounts\\u000a  {{/is_plural}}\\u000a{{/following_followers_of}}\\u000a\\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E \\u003Ca href=\\\"{{{view_all}}}\\\" class=\\\"view-all\\\"\\u003Eview\\u003C/a\\u003E\",\n            spelling_corrections: \"\\u003Cdiv class=\\\"module js-spelling-corrections search-assist-spelling\\\" data-component-term=\\\"spelling_corrections\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module-inner\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"dismiss js-action-dismiss\\\" data-query=\\\"{{query}}\\\" data-search-assistance=\\\"{{correction}}\\\"\\u003E\\u000a        \\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cspan class=\\\"search-spelling-suggestions\\\"\\u003E\\u000a        \\u003Cspan class=\\\"label\\\"\\u003EDid you mean:\\u003C/span\\u003E\\u000a        \\u003Ca href=\\\"{{url}}\\\" class=\\\"corrected-query\\\" data-query=\\\"{{query}}\\\" data-search-assistance=\\\"{{correction}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u000a          \\u000a          {{#partitions}}\\u000a            {{nonhighlighted}}{{#highlighted}}\\u003Cem\\u003E{{highlighted}}\\u003C/em\\u003E{{/highlighted}}\\u000a          {{/partitions}}\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stork_pip_icon: \"\\u003Cdiv class=\\\"js-pip stork-pip stork-pip-right\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stork-pulse\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Ci class=\\\"stork-icon {{icon}}\\\"\\u003E\\u003C/i\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stork_pip_text: \"\\u003Cdiv class=\\\"js-pip module stork stork-open\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"contrast-flex-module\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"contrast-module-header\\\"\\u003E\\u000a      {{{contents}}}\\u000a      {{#dismiss}}\\u000a      \\u003Cdiv\\u003E\\u000a        \\u003Ca href=\\\"#\\\" class=\\\"stork-dismiss js-dismiss\\\"\\u003EDismiss\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{/dismiss}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"pointer\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"contrast-module-footer\\\"\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\",\n            story_item: \"{{{card_view_html}}}\",\n            stream_end_bird: \"\",\n            stream_end: \"\\u003Cdiv class=\\\"stream-end\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    {{#show_stream_end_bird}}\\u000a      \\u003Ci class=\\\"bird-etched\\\"\\u003E\\u003C/i\\u003E\\u000a    {{/show_stream_end_bird}}\\u000a    {{#swift}}\\u000a      \\u003Cp class=\\\"empty-text\\\"\\u003E{{empty_text}}\\u003C/p\\u003E\\u000a      {{\\u003Eback_to_top}}\\u000a    {{/swift}}\\u000a    {{#end_text}}\\u000a      {{^abtest_timeline_copy_317_any_bucket}}\\u000a        \\u003Cp\\u003E{{{end_text}}}\\u003C/p\\u003E\\u000a      {{/abtest_timeline_copy_317_any_bucket}}\\u000a      {{#abtest_timeline_copy_317_stream}}\\u000a        \\u003Cp\\u003E\\u000a          {{{end_text_timeline_copy_experiment}}}\\u000a          {{^end_text_timeline_copy_experiment}}\\u000a            {{{end_text}}}\\u000a          {{/end_text_timeline_copy_experiment}}\\u000a        \\u003C/p\\u003E\\u000a      {{/abtest_timeline_copy_317_stream}}\\u000a    {{/end_text}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_follower_request: \"\\u003Cdiv class=\\\"js-follower-request js-actionable-user account {{#promoted_content}}promoted-account{{/promoted_content}}\\\" data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  \\u003Cdiv class=\\\"friend-actions btn-group\\\"\\u003E\\u000a    \\u003Ca class=\\\"btn js-action-accept\\\"\\u003E\\u000a      \\u003Cspan class=\\\"active-btn-text\\\"\\u003EAccept\\u003C/span\\u003E\\u000a      \\u003Cspan class=\\\"pending-btn-text\\\"\\u003EAccepting\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"btn js-action-deny\\\"\\u003E\\u000a      \\u003Cspan class=\\\"active-btn-text\\\"\\u003EDecline\\u003C/span\\u003E\\u000a      \\u003Cspan class=\\\"pending-btn-text\\\"\\u003EDeclining\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{#swift}}\\u000a    \\u003Cdiv class=\\\"js-profile-actions\\\" style=\\\"display: none\\\"\\u003E\\u000a      {{\\u003Eprofile_actions}}\\u000a    \\u003C/div\\u003E\\u000a  {{/swift}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-user-profile-link account-group\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a        \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"/\\u003E\\u000a        \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a        \\u003Cspan class=\\\"username\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a    \\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_header_people_search: \"{{\\u003Estream_header}}\\u000a{{\\u003Epeople_search}}\",\n            stream_interest_category: \"\\u003Cdiv class=\\\"interest-category\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\"\\u003E\\u003Cstrong\\u003E{{interest_name}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a      \\u003Cspan class=\\\"metadata\\\"\\u003E{{size}} suggestions\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{#user_sample}}\\u000a      \\u003Cdiv class=\\\"large avatar-row\\\"\\u003E\\u000a        {{\\u003Euser_static_list}}\\u000a      \\u003C/div\\u003E\\u000a    {{/user_sample}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stream_link: \"\\u003Cli class=\\\"stream-link\\\" data-item-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Ca title='{{name}}' href=\\\"{{{href}}}\\\"\\u003E\\u000a    {{#icon_class}}\\u000a      \\u003Cspan class=\\\"{{icon_class}}\\\"\\u003E\\u003C/span\\u003E\\u000a    {{/icon_class}}\\u000a    \\u003Cb class=\\\"item-name\\\"\\u003E\\u000a      {{name}}\\u000a    \\u003C/b\\u003E\\u000a    {{#show_delete}}\\u000a      \\u003Cspan title=\\\"{{delete_title}}\\\" class=\\\"delete-icon\\\"\\u003E\\u003C/span\\u003E\\u000a    {{/show_delete}}\\u000a    {{#is_private}}\\u000a      \\u003Cspan title=\\\"Private List\\\" class=\\\"lock-icon\\\"\\u003E\\u003C/span\\u003E\\u000a    {{/is_private}}\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            stream_list: \"\\u003Cdiv class=\\\"list js-list js-profile-popup-actionable\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\" data-list-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-list-link\\\" href=\\\"{{user_list_path}}\\\"\\u003E\\u000a        \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a      \\u000a      {{#user}}\\u000a        \\u003Ca class=\\\"js-user-profile-link\\\"\\u003E\\u000a          \\u003Cimg class=\\\"avatar size32\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a        \\u003C/a\\u003E{{^is_own_list}}\\u003Cspan class=\\\"username\\\"\\u003E by \\u003Ca class=\\\"js-user-profile-link\\\" href=\\\"{{profile_path}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/span\\u003E{{/is_own_list}}\\u000a      {{/user}}\\u000a      {{^is_public}}\\u003Ci title=\\\"Private List\\\" class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E{{/is_public}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{description}}\\u003C/p\\u003E\\u000a    {{^swift}}\\u000a      \\u003Cp class=\\\"metadata\\\"\\u003E{{member_count}} members\\u003C/p\\u003E\\u000a    {{/swift}}\\u000a    {{#swift}}\\u000a      \\u003Cp class=\\\"metadata\\\"\\u003E\\u000a        {{#member_count_one}}{{member_count}} member{{/member_count_one}}\\u000a        {{#member_count_other}}{{member_count}} members{{/member_count_other}}\\u000a      \\u003C/p\\u003E\\u000a    {{/swift}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_saved_search: \"\\u003Cdiv class=\\\"saved-search\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{saved_search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u000a      \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stream_suggestion_category: \"\\u003Cdiv class=\\\"stream-suggestion-category\\\"\\u003E\\u000a\\u000a  \\u003Ch3 class=\\\"category-title\\\"\\u003E\\u000a    {{category_name}}\\u000a    \\u003Ca class=\\\"category-count\\\" href=\\\"{{category_link}}\\\"\\u003E\\u003Cstrong\\u003E{{size}}\\u003C/strong\\u003E suggestions\\u003C/a\\u003E\\u000a    \\u003Ca class=\\\"view-all\\\" href=\\\"{{category_link}}\\\"\\u003EView all &rarr;\\u003C/a\\u003E\\u000a  \\u003C/h3\\u003E\\u000a  {{#user_sample}}\\u000a  \\u003Cul\\u003E\\u000a    {{\\u003Euser_static_list}}\\u000a  \\u003C/ul\\u003E\\u000a  {{/user_sample}}\\u000a\\u000a\\u003C/div\\u003E\",\n            stream_tweet_hidden: \"\\u003Cdiv id=\\\"hidden-tweet-template\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"hidden-tweet\\\"\\u003E\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"undo-hide-action\\\"\\u003EUndo\\u003C/a\\u003E\\u000a    \\u003Cdiv class=\\\"spam-message\\\"\\u003E\\u000a      \\u003Cstrong\\u003E\\u003Cspan class=\\\"hidden-name\\\"\\u003E\\u003C/span\\u003E\\u003C/strong\\u003E\\u000a      \\u003Csmall class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cspan class=\\\"hidden-screen-name\\\"\\u003E\\u003C/span\\u003E was reported spam\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"block-message\\\"\\u003E\\u000a      \\u003Cstrong\\u003E\\u003Cspan class=\\\"hidden-name\\\"\\u003E\\u003C/span\\u003E\\u003C/strong\\u003E\\u000a      \\u003Csmall class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cspan class=\\\"hidden-screen-name\\\"\\u003E\\u003C/span\\u003E was blocked\\u003C/small\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stream_user: \"{{#is_withheld}}\\u000a  {{\\u003Estream_user_withheld}}\\u000a{{/is_withheld}}\\u000a{{^is_withheld}}\\u000a\\u000a\\u003Cdiv class=\\\"account {{#promoted_content}}promoted-account {{/promoted_content}} js-actionable-user js-profile-popup-actionable {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}\\\" data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}} {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}\\u003E\\u000a  {{^for_activity}}\\u000a    {{\\u003Eprofile_actions}}\\u000a  {{/for_activity}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"account-group js-user-profile-link\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u000a        \\u003Cimg class=\\\"avatar js-action-profile-avatar {{avatar_size_class}}\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"{{#embedded_by_activity}} title=\\\"{{name}}\\\"{{/embedded_by_activity}}/\\u003E\\u000a        \\u003Cstrong class=\\\"fullname js-action-profile-name\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a        \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        \\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E\\u000a        {{#protected}}\\u000a          \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a        {{/protected}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{^with_followers_count}}\\u000a      \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}\\u003C/p\\u003E\\u000a    {{/with_followers_count}}\\u000a    {{#with_followers_count}}\\u000a      \\u003Cdiv class=\\\"followers-count\\\"\\u003E{{{follower_stat}}}\\u003C/div\\u003E\\u000a    {{/with_followers_count}}\\u000a    {{#for_activity}}\\u000a      {{\\u003Eprofile_actions}}\\u000a    {{/for_activity}}\\u000a    {{#socialcontext}}\\u000a      \\u003Cp class=\\\"metadata\\\"\\u003E{{{socialcontext}}}\\u003C/p\\u003E\\u000a    {{/socialcontext}}\\u000a    {{#is_sponsored}}\\u000a      \\u003Cspan class=\\\"metadata with-icn\\\"\\u003E\\u000a        \\u003Ca class=\\\"js-promoted-badge js-user-profile-link js-tooltip js-disclosure\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003EPromoted\\u003C/a\\u003E\\u000a      \\u003C/span\\u003E\\u000a    {{/is_sponsored}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{/is_withheld}}\\u000a\",\n            stream_user_buttons: \"{{%TRANSLATION-HINT mode=actions}}\\u000a\\u003Cdiv class=\\\"stream-user-buttons\\\"\\u003E\\u000a  {{^is_current_user}}\\u000a    {{^following}}\\u000a      {{#follow_request_sent}}\\u000a        {{\\u003Efollow_request_sent_button}}\\u000a      {{/follow_request_sent}}\\u000a      {{^follow_request_sent}}\\u000a        {{\\u003Efollow_button}}\\u000a      {{/follow_request_sent}}\\u000a    {{/following}}\\u000a    {{#following}}\\u000a      {{\\u003Eunfollow_button}}\\u000a    {{/following}}\\u000a  {{/is_current_user}}\\u000a\\u000a  {{#logged_in}}\\u000a    {{^in_home_page}}\\u000a      {{^is_current_user}}\\u000a        {{^is_onebox}}\\u000a          \\u003Cdiv class=\\\"button user-profile-actions-button js-action-profilemenu\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a            \\u003Cspan class=\\\"user-actions\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"down-arrow\\\"\\u003E\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a        {{/is_onebox}}\\u000a      {{/is_current_user}}\\u000a      {{#dismissable}}\\u000a        \\u003Cdiv class=\\\"dismiss\\\"\\u003E\\u000a          \\u003Ca class=\\\"dismiss js-action-dismiss\\\" href=\\\"#\\\" title=\\\"Hide this suggestion\\\"\\u003E&times; Hide\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/dismissable}}\\u000a    {{/in_home_page}}\\u000a  {{/logged_in}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_user_withheld: \"\\u003Cdiv class=\\\"account {{#promoted_content}}promoted-account {{/promoted_content}} js-actionable-user js-profile-popup-actionable {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}} withheld-user\\\" data-screen-name=\\\"{{screen_name}}\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Cspan class=\\\"account-group\\\"\\u003E\\u000a        \\u003Cstrong class=\\\"fullname js-action-profile-name\\\"\\u003E@{{screen_name}} withheld\\u003C/strong\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        {{#protected}}\\u000a          \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a        {{/protected}}\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"bio {{#description_is_rtl}}bio-description-rtl{{/description_is_rtl}}\\\"\\u003E{{{linkified_description}}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a    {{#following}}\\u003Cspan class=\\\"js-follow-state follow-action\\\"\\u003E &middot; \\u003Ca href=\\\"#\\\" class=\\\"js-action-unfollow js-link\\\" data-user-id=\\\"{{id}}\\\"\\u003EUnfollow @{{screen_name}}\\u003C/a\\u003E\\u003C/span\\u003E{{/following}}\\u003C/p\\u003E\\u000a    {{#socialcontext}}\\u000a      \\u003Cp class=\\\"metadata\\\"\\u003E{{{socialcontext}}}\\u003C/p\\u003E\\u000a    {{/socialcontext}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_view_toggler: \"\\u003Ca class=\\\"toggle-item-1 {{#active1}}active{{/active1}}\\\" href=\\\"{{route1}}\\\"\\u003E{{title1}}\\u003C/a\\u003E / \\u003Ca class=\\\"toggle-item-2 {{#active2}}active{{/active2}}\\\" href=\\\"{{route2}}\\\"\\u003E{{title2}}\\u003C/a\\u003E\",\n            stream_whale_end: \"\\u003Cdiv class=\\\"js-stream-whale-end stream-whale-end stream-placeholder centered-placeholder\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Ch2 class=\\\"title\\\"\\u003E{{{stream_fail_header}}}\\u003C/h2\\u003E\\u000a    \\u003Cp\\u003E\\u000a      Twitter may be over capacity or experiencing a momentary hiccup. \\u003Ca href=\\\"#\\\" class=\\\"try-again-after-whale\\\"\\u003ETry again\\u003C/a\\u003E or visit \\u003Ca target=\\\"_blank\\\" href=\\\"{{status_path}}\\\"\\u003ETwitter Status\\u003C/a\\u003E for more information.\\u000a    \\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            subscribe_button: \"\\u003Ca class=\\\"btn subscribe-btn not-subscribed\\\" href=\\\"#\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"subscribe-text\\\"\\u003E\\u000a    \\u003Ci class=\\\"subscribe\\\"\\u003E\\u003C/i\\u003E\\u000a    Subscribe\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"remove-text\\\"\\u003E\\u000a    Unsubscribe from list\\u000a  \\u003C/div\\u003E\\u000a\\u003C/a\\u003E\",\n            suspended_banner: \"\\u003Cdiv class=\\\"module module-banner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    \\u003Cdiv id=\\\"account-suspended\\\" class=\\\"first-banner-row\\\"\\u003E\\u000a      \\u003Cspan class=\\\"title\\\"\\u003EYour account (@{{screen_name}}) is currently suspended.\\u003C/span\\u003E\\u000a      \\u003Cspan\\u003EFor more information, please visit \\u003Ca href=\\\"{{suspended_help_path}}\\\"\\u003ESuspended Accounts\\u003C/a\\u003E.\\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            suspended_error_message: \"{{#is_dm}}\\u000a  Your account is suspended and is not permitted to send messages.\\u000a{{/is_dm}}\\u000a{{^is_dm}}\\u000a  {{#is_tweet}}\\u000a    Your account is suspended and is not permitted to send Tweets.\\u000a  {{/is_tweet}}\\u000a  {{^is_tweet}}\\u000a    {{#is_follow}}\\u000a      Your account is suspended and is not permitted to follow users.\\u000a    {{/is_follow}}\\u000a    {{^is_follow}}\\u000a      Your account is suspended and is not permitted to perform this action.\\u000a    {{/is_follow}}\\u000a  {{/is_tweet}}\\u000a{{/is_dm}}\\u000a\\u003Ca href=\\\"{{suspended_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a\",\n            suspended_user_page: \"\\u003Cdiv class=\\\"content-narrow\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"error-page error-403 clearfix\\\"\\u003E\\u000a    {{#render_page_content}}\\u000a      \\u003Ch1 class=\\\"heading\\\"\\u003EAccount suspended\\u003C/h1\\u003E\\u000a      \\u003Cp class=\\\"lead\\\"\\u003EThe profile you are trying to view has been suspended.\\u003C/p\\u003E\\u000a      \\u003Cp\\u003E\\u003Ca href=\\\"{{home_path}}\\\"\\u003E&larr; Go to the homepage\\u003C/a\\u003E\\u003C/p\\u003E\\u000a    {{/render_page_content}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            swift_autocomplete_dropdown: \"\\u003Cul class=\\\"dropdown-menu autocomplete-results\\\"\\u003E\\u000a  \\u003Cli class=\\\"dropdown-link dropdown-account template-row autocomplete-item\\\"\\u003E\\u000a    \\u003Cimg width=\\\"24\\\" height=\\\"24\\\" class=\\\"avatar size24\\\"\\u003E\\u000a    \\u003Cstrong class=\\\"fullname\\\"\\u003E\\u003C/strong\\u003E\\u000a    \\u003Cspan class=\\\"pretty-link\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb class=\\\"username\\\"\\u003E\\u003C/b\\u003E\\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            swift_dm_box: \"\\u003Cform class=\\\"dm-tweetbox tweet-form\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a    {{#with_unique_id}}\\u000a      \\u003Clabel class=\\\"hidden-elements\\\" for=\\\"tweet-box-{{unique_id}}\\\"\\u003ETweet text\\u003C/label\\u003E\\u000a      \\u003Ctextarea id=\\\"tweet-box-{{unique_id}}\\\" class=\\\"tweet-box\\\"\\u003E\\u003C/textarea\\u003E\\u000a    {{/with_unique_id}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-button\\\"\\u003E\\u000a    \\u003Cspan class=\\\"spinner\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"tweet-counter\\\"\\u003E140\\u003C/span\\u003E\\u000a    \\u003Cbutton class=\\\"btn tweet-action primary-btn disabled\\\" type=\\\"submit\\\"\\u003ESend message\\u003C/button\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"dm-delete-confirm js-dm-delete-confirm\\\"\\u003E\\u000a    {{\\u003Edirect_message_delete_confirm}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\",\n            swift_empty_timeline_recommendations: \"\\u003Cdiv class=\\\"component wtf-module\\\" id=\\\"empty-timeline-recommendations\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-main empty-timeline big-avatar-list breakable\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"header-inner empty-timeline-header\\\"\\u003E\\u000a        \\u003Csmall class=\\\"pull-right\\\"\\u003E\\u003Ca href=\\\"#\\\" class=\\\"js-done disabled\\\"\\u003EClose\\u003C/a\\u003E\\u003C/small\\u003E\\u000a        \\u003Ch2 class=\\\"header-text\\\"\\u003E\\u000a          Here are some people you might enjoy following.\\u000a        \\u003C/h2\\u003E\\u000a        \\u003Csmall\\u003E\\u000a          \\u003Ca href=\\\"#\\\" class=\\\"js-refresh-suggestions\\\"\\u003ERefresh\\u003C/a\\u003E &middot;\\u000a          \\u003Ca href=\\\"{{who_to_follow_suggestions_path}}\\\"\\u003EView all\\u003C/a\\u003E\\u000a        \\u003C/small\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"empty-timeline-footer content-no-header\\\"\\u003E\\u000a      \\u003Cul class=\\\"clearfix js-recommended-followers\\\"\\u003E\\u000a        {{\\u003Euser_large_list}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            swift_layout: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"{{lang}}\\\"\\u003E\\u000a  \\u003Chead\\u003E\\u000a    \\u003Cmeta charset=\\\"utf-8\\\"\\u003E\\u000a    \\u000a    \\u003Cscript\\u003Edocument.domain='twitter.com'\\u003C/script\\u003E\\u000a\\u000a    {{#content_view}}\\u000a      \\u003Ctitle\\u003E{{env_warning}}{{page_title}}\\u003C/title\\u003E\\u000a    {{/content_view}}\\u000a\\u000a    {{\\u003Elayout/browser}}\\u000a    {{\\u003Elayout/css}}\\u000a    {{\\u003Elayout/head_scripts}}\\u000a  \\u003C/head\\u003E\\u000a  \\u003Cbody class=\\\"{{#content_view}}{{body_class_names}}{{/content_view}}\\\"\\u000a    {{#locale_is_rtl}}\\u000a    dir=\\\"rtl\\\"\\u000a    {{/locale_is_rtl}}\\u000a    \\u003E\\u000a    \\u003Cdiv id=\\\"doc\\\" class=\\\"{{#content_view}}{{#route_name}}route-{{route_name}}{{/route_name}}{{/content_view}}\\\"\\u003E\\u000a      {{#include_standard_chrome}}\\u000a        {{\\u003Et1_global_nav}}\\u000a        \\u003Cdiv id=\\\"page-outer\\\"\\u003E\\u000a          \\u003Cdiv id=\\\"page-container\\\" class=\\\"{{#content_view}}{{page_container_class}} {{#page_name}}wrapper-{{page_name}}{{/page_name}}{{/content_view}}\\\"\\u003E\\u000a            {{#current_user}}\\u000a              {{#suspended}}{{\\u003Esuspended_banner}}{{/suspended}}\\u000a              {{^suspended}}\\u000a                {{#pending_email}}{{\\u003Everify_email_banner}}{{/pending_email}}\\u000a                {{#current_bouncing}}{{\\u003Ebouncing_email_banner}}{{/current_bouncing}}\\u000a                {{#detached}}{{\\u003Edetached_email_banner}}{{/detached}}\\u000a              {{/suspended}}\\u000a            {{/current_user}}\\u000a            {{#swift}} \\u000a              {{\\u003Emessage_drawer_outer}}\\u000a            {{/swift}}\\u000a            {{{content_for_layout}}}\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/include_standard_chrome}}\\u000a      {{^include_standard_chrome}}\\u000a        {{{content_for_layout}}}\\u000a      {{/include_standard_chrome}}\\u000a      {{#track_ttft}}{{#content_view}}\\u000a      \\u003Cscript\\u003E\\u000a        if(window.ttft){window.ttft.recordMilestone('page','{{page_name}}');\\u000a        window.ttft.recordMilestone('client_record_time',new Date().getTime())}\\u000a      \\u003C/script\\u003E\\u000a      {{/content_view}}{{/track_ttft}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a    {{\\u003Elayout/dialogs}}\\u000a  \\u003C/body\\u003E\\u000a\\u003C/html\\u003E\\u000a{{\\u003Elayout/boot}}\\u000a\",\n            swift_photo_selector: \"\\u003Cdiv class=\\\"photo-selector\\\"\\u003E\\u000a  \\u003Cbutton class=\\\"btn\\\" type=\\\"button\\\" disabled=\\\"true\\\"\\u003EChoose file\\u003C/button\\u003E\\u000a  \\u003Cspan class=\\\"photo-file-name\\\"\\u003ENo file selected\\u003C/span\\u003E\\u000a  \\u003Cdiv class=\\\"image-selector\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"media_file_name\\\" class=\\\"file-name\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" name=\\\"media_data_empty\\\" class=\\\"file-data\\\"\\u003E\\u000a    \\u003Cinput type=\\\"file\\\" name=\\\"media_empty\\\" class=\\\"file-input\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"swf-container\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            swift_saved_searches: \"\\u003Cul class=\\\"typeahead-items saved-searches-list\\\"\\u003E\\u000a  \\u000a  \\u003Cli class=\\\"saved-search-item search-item\\\"\\u003E\\u003Ca href=\\\"\\\" data-search-query=\\\"\\\" data-query-source=\\\"\\\" data-ds=\\\"saved_search\\\"\\u003E\\u003Ci class=\\\"generic-search\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            swift_search_header: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"search-header swift-search-header js-search-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"btn-group flex-table-btn js-search-dropdown\\\"\\u003E\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"dropdown btn btn-search-actions js-search-dropdown-button\\\"\\u003E\\u000a        \\u003Ci class=\\\"search-toggle\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/button\\u003E\\u000a      \\u003Cul class=\\\"dropdown-menu btn-group-dropdown js-combo-btn-dropdown-options\\\"\\u003E\\u000a        \\u003Cli\\u003E\\u000a          {{#saved_search}}\\u000a            \\u003Ca class=\\\"js-toggle-saved-search-link js-saved-search\\\" href=\\\"#\\\" data-id=\\\"{{id_str}}\\\" data-query=\\\"{{query}}\\\"\\u003ERemove saved search\\u003C/a\\u003E\\u000a          {{/saved_search}}\\u000a          {{^saved_search}}\\u000a            \\u003Ca class=\\\"js-toggle-saved-search-link js-unsaved-search\\\" href=\\\"#\\\" data-query=\\\"{{query}}\\\"\\u003ESave search\\u003C/a\\u003E\\u000a          {{/saved_search}}\\u000a        \\u003C/li\\u003E\\u000a        \\u003Cli\\u003E\\u000a          \\u003Ca href=\\\"{{search_advanced_path}}\\\" class=\\\"js-nav\\\"\\u003EAdvanced search\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a        \\u000a        \\u003Cli class=\\\"dropdown-caret right\\\"\\u003E\\u000a          \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a          \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a        \\u003C/li\\u003E\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#saved_search}}\\u000a      \\u003Ch2 class=\\\"search-title\\\"\\u003ESaved search: \\u003Cstrong class=\\\"search-query\\\"\\u003E{{query}}\\u003C/strong\\u003E\\u003C/h2\\u003E\\u000a    {{/saved_search}}\\u000a    {{^saved_search}}\\u000a      \\u003Ch2 class=\\\"search-title\\\"\\u003EResults for \\u003Cstrong class=\\\"search-query\\\"\\u003E{{query}}\\u003C/strong\\u003E\\u003C/h2\\u003E\\u000a    {{/saved_search}}\\u000a  \\u003C/div\\u003E\\u000a  {{\\u003Esearch/swift_onebox}}\\u000a  \\u003Ch2 class=\\\"js-timeline-title\\\"\\u003ETweets\\u000a    \\u003Csmall class=\\\"view-toggler js-view-toggler\\\"\\u003E\\u000a      \\u003Ca class=\\\"toggle-item-1{{#on_relevant_search}} active{{/on_relevant_search}}\\\" href=\\\"{{search_path}}\\\" title=\\\"Find the most relevant tweets\\\"\\u003ETop\\u003C/a\\u003E /\\u000a      \\u003Ca class=\\\"toggle-item-2{{#on_realtime_search}} active{{/on_realtime_search}}\\\" href=\\\"{{realtime_path}}\\\" title=\\\"Find the most recent tweets\\\"\\u003EAll\\u003C/a\\u003E\\u000a      {{#logged_in}}\\u000a        / \\u003Ca class=\\\"toggle-item-2{{#on_timeline_search}} active{{/on_timeline_search}}\\\" href=\\\"{{timeline_path}}\\\" title=\\\"Find tweets from people you follow\\\"\\u003EPeople you follow\\u003C/a\\u003E\\u000a      {{/logged_in}}\\u000a    \\u003C/small\\u003E\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            activity_stream_items: \"{{#activity_items}}\\u000a  \\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}} js-activity js-activity-{{event}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"activity\\\" data-item-key=\\\"{{activity_key}}\\\" id=\\\"stream-item-activity-{{item_id}}\\\"\\u003E\\u000a    {{#should_wrap}}\\u000a      \\u003Cdiv class=\\\"stream-item-content clearfix stream-item-activity stream-item-{{event}} {{#is_your_activity}}stream-item-activity-me{{/is_your_activity}}{{^is_your_activity}}stream-item-activity-network{{/is_your_activity}}\\\"\\u000a         data-activity-type=\\\"{{event}}\\\"\\u000a         data-activity-min-position=\\\"{{min_position}}\\\"\\u000a         data-activity-max-position=\\\"{{max_position}}\\\"\\u003E\\u000a         {{\\u003Eactivities/activity_item_content}}\\u000a      \\u003C/div\\u003E\\u000a    {{/should_wrap}}\\u000a    {{^should_wrap}}\\u000a      {{\\u003Eactivities/activity_item_content}}\\u000a    {{/should_wrap}}\\u000a  \\u003C/div\\u003E\\u000a{{/activity_items}}\",\n            all_stream_items: \"{{\\u003Eswift_stream_items/tweet_stream_items}}\\u000a{{\\u003Eswift_stream_items/user_stream_items}}\\u000a{{\\u003Eswift_stream_items/follower_request_stream_items}}\\u000a{{\\u003Eswift_stream_items/activity_stream_items}}\\u000a\\u000a\\u000a\\u000a{{{items_html}}}\",\n            follower_request_stream_items: \"{{#follower_request_items}}\\u000a  \\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"user\\\" id=\\\"stream-item-user-{{item_id}}\\\"\\u003E\\u000a    {{#follower_request_view}}\\u000a      {{\\u003Estream_follower_request}}\\u000a    {{/follower_request_view}}\\u000a  \\u003C/div\\u003E\\u000a{{/follower_request_items}}\",\n            json_stream_items: \"{{#timeline}}\\u000a  {{\\u003Eswift_stream_items/all_stream_items}}\\u000a{{/timeline}}\",\n            tweet_stream_items: \"{{#tweet_items}}\\u000a  \\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"tweet\\\" id=\\\"stream-item-tweet-{{item_id}}\\\"\\u003E\\u000a    {{#tweet_view}}\\u000a      {{\\u003Estream_tweet}}\\u000a    {{/tweet_view}}\\u000a  \\u003C/div\\u003E\\u000a{{/tweet_items}}\",\n            user_stream_items: \"{{#user_items}}\\u000a  \\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"user\\\" id=\\\"stream-item-user-{{item_id}}\\\"\\u003E\\u000a    {{#user_view}}\\u000a      {{\\u003Estream_user}}\\u000a    {{/user_view}}\\u000a  \\u003C/div\\u003E\\u000a{{/user_items}}\",\n            swift_tweet_box: \"\\u003Cform class=\\\"tweet-form {{^preexpand_tweetbox}}condensed{{/preexpand_tweetbox}}\\\" method=\\\"post\\\" target=\\\"tweet-post-iframe\\\" action=\\\"//{{upload_domain}}/i/tweet/create_with_media.iframe\\\" enctype=\\\"multipart/form-data\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"post_authenticity_token\\\" class=\\\"auth-token\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"iframe_callback\\\" class=\\\"iframe-callback\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"in_reply_to_status_id\\\" class=\\\"in-reply-to-status-id\\\"\\u003E\\u000a  \\u003Cinput type=\\\"hidden\\\" name=\\\"impression_id\\\" class=\\\"impression-id\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"tweet-content\\\"\\u003E\\u000a\\u000a    {{#with_unique_id}}\\u000a      \\u003Clabel class=\\\"hidden-elements\\\" for=\\\"tweet-box-{{unique_id}}\\\"\\u003ETweet text\\u003C/label\\u003E\\u000a      \\u003Ctextarea class=\\\"tweet-box\\\" name=\\\"status\\\" id=\\\"tweet-box-{{unique_id}}\\\"\\u003E\\u003C/textarea\\u003E\\u000a    {{/with_unique_id}}\\u000a\\u000a    {{\\u003Eswift_autocomplete_dropdown}}\\u000a\\u000a    \\u000a    \\u003Cdiv class=\\\"thumbnail-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"preview\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"dismiss\\\"\\u003E\\u000a          \\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cspan class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"preview-message\\\"\\u003EImage will appear as a link\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"tweet-box-extras\\\"\\u003E\\u000a\\u000a    {{#include_image_picker}}\\u000a    \\u003Cdiv class=\\\"photo-selector\\\"\\u003E\\u000a      \\u003Cbutton class=\\\"btn\\\" type=\\\"button\\\" tabindex=\\\"-1\\\"\\u003E\\u000a        \\u003Ci class=\\\"tweet-camera\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/button\\u003E\\u000a      \\u003Cdiv class=\\\"image-selector\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"media_data_empty\\\" class=\\\"file-data\\\"\\u003E\\u000a        \\u003Cinput type=\\\"file\\\" name=\\\"media_empty\\\" class=\\\"file-input\\\" tabindex=\\\"-1\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"swf-container\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/include_image_picker}}\\u000a\\u000a    {{#include_geo_picker}}\\u000a      {{\\u003Egeo/geo_picker}}\\u000a    {{/include_geo_picker}}\\u000a\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-button\\\"\\u003E\\u000a    \\u003Cspan class=\\\"link-message single\\\"\\u003ELink will appear shortened\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"link-message plural\\\"\\u003ELinks will appear shortened\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"spinner\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"tweet-counter\\\"\\u003E140\\u003C/span\\u003E\\u000a    \\u003Cbutton class=\\\"btn primary-btn tweet-action disabled\\\" type=\\\"button\\\"\\u003ETweet\\u003C/button\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            swift_typeahead_accounts: \"\\u003Cdiv class=\\\"typeahead-accounts js-typeahead-accounts\\\"\\u003E\\u000a  \\u003Cul class=\\\"typeahead-items\\\"\\u003E\\u000a    \\u000a    \\u003Cli data-user-id=\\\"\\\" data-user-screenname=\\\"\\\" data-remote=\\\"true\\\" data-score=\\\"\\\" class=\\\"typeahead-item typeahead-account-item js-selectable\\\"\\u003E\\u000a      \\u000a      \\u003Ca data-query-source=\\\"typeahead_click\\\" data-search-query=\\\"\\\" data-ds=\\\"account\\\"\\u003E\\u000a        \\u003Cimg src=\\\"\\\" width=\\\"24\\\" height=\\\"24\\\" class=\\\"avatar size24\\\"\\u003E\\u000a        \\u003Cspan class=\\\"fullname\\\"\\u003E\\u003C/span\\u003E\\u000a        \\u003Ci class=\\\"verified hidden\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E\\u003C/b\\u003E\\u003C/span\\u003E\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a    \\u003Cli class=\\\"js-selectable typeahead-accounts-shortcut js-shortcut\\\"\\u003E\\u003Ca href=\\\"\\\" data-search-query=\\\"\\\" data-query-source=\\\"typeahead_click\\\" data-shortcut=\\\"true\\\" data-ds=\\\"account_search\\\"\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            swift_typeahead_dropdown: \"\\u003Cdiv class=\\\"dropdown-menu typeahead\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"caret-outer\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"caret-inner\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"dropdown-inner js-typeahead-results\\\"\\u003E\\u000a    {{\\u003Eswift_saved_searches}}\\u000a    {{\\u003Eswift_typeahead_topics}}\\u000a    {{\\u003Eswift_typeahead_accounts}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            t1_anatomy_experiment: \"\",\n            swift_typeahead_topics: \"\\u003Cul class=\\\"typeahead-items topics-list\\\"\\u003E\\u000a  \\u000a  \\u003Cli class=\\\"topics-item search-item\\\"\\u003E\\u003Ca href=\\\"\\\" data-search-query=\\\"\\\" data-query-source=\\\"typeahead_click\\\" data-ds=\\\"topics\\\"\\u003E\\u003Ci class=\\\"generic-search\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            t1_body: \"\\u003Cbody class=\\\"t1 {{#logged_in}} logged-in user-style-{{style_namespace}}{{/logged_in}}{{^logged_in}} logged-out {{#no_script}} front-page {{/no_script}} {{/logged_in}} {{t1_front_page_image_class}} {{locale_css}} {{ms_windows_class}}\\\"\\u000a  {{#locale_is_rtl}}\\u000a    dir=\\\"rtl\\\"\\u000a  {{/locale_is_rtl}}\\u000a\\u003E\\u000a  \\u003Cdiv id=\\\"doc\\\"\\u003E\\u000a    {{\\u003Et1_global_nav}}\\u000a    \\u003Cdiv id=\\\"page-outer\\\"\\u003E\\u000a      {{^logged_in}}\\u000a        {{#home_page}}\\u000a          {{\\u003Et1_front_page}}\\u000a        {{/home_page}}\\u000a      {{/logged_in}}\\u000a      \\u003Cdiv id=\\\"page-container\\\" class=\\\"wrapper\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"new-js-banners\\\"\\u003E\\u003C/div\\u003E\\u000a        {{#tweets}}\\u000a          \\u003Cdiv id=\\\"page-node-{{page_name_underscore}}\\\"\\u003E\\u000a            {{\\u003Epage}}\\u000a          \\u003C/div\\u003E\\u000a        {{/tweets}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog-wrapper\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a  {{#include_more_css}}\\u000a    {{^include_more_css_early}}{{\\u003Emore_css}}{{/include_more_css_early}}\\u000a  {{/include_more_css}}\\u000a\\u000a  {{\\u003Ejavascript_includes}}\\u000a\\u003C/body\\u003E\\u000a\",\n            t1_for_mockview_unit_test: \"{{happy_feet}}!\",\n            t1_front_page: \"\\u003Cdiv class=\\\"front-container {{#front_page_full_signup_256}}front-container-full-signup{{/front_page_full_signup_256}}  {{#front_page_full_signup_256_login_form_below}}front_page_full_signup_256_login_form_below{{/front_page_full_signup_256_login_form_below}}\\\" id=\\\"front-container\\\"\\u003E\\u000a  \\u003Cnoscript\\u003E\\u000a    \\u003Cdiv class=\\\"front-warning\\\"\\u003E\\u000a      \\u003Ch3\\u003ETwitter.com makes heavy use of JavaScript\\u003C/h3\\u003E\\u000a      \\u003Cp\\u003EIf you cannot enable it in your browser's preferences, you may have a better experience on our \\u003Ca href=\\\"http://m.twitter.com\\\"\\u003Emobile site\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/noscript\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"front-warning\\\" id=\\\"front-no-cookies-warn\\\"\\u003E\\u000a    \\u003Ch3\\u003ETwitter.com makes heavy use of browser cookies\\u003C/h3\\u003E\\u000a    \\u003Cp\\u003EPlease enable cookies in your browser preferences before signing in.\\u003C/p\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{#front_page_full_signup_256}}\\u000a  \\u003Cdiv class=\\\"front-bg\\\"\\u003E\\u000a    \\u003Cimg class=\\\"front-image\\\" src=\\\"{{front_page_full_signup_256_image_url}}\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{/front_page_full_signup_256}}\\u000a\\u000a  {{#olympics_homepage}}\\u000a    \\u003Cdiv class=\\\"front-bg\\\"\\u003E\\u000a      \\u003Cimg class=\\\"front-image\\\" src=\\\"{{t1_front_page_image}}\\\"\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"front-card event-takeover\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"front-welcome-text\\\"\\u003E\\u000a        \\u003Cp\\u003E\\u000a\\u0009\\u0009\\u0009\\u0009\\u0009\\u003Ca href=\\\"/#olympics\\\"\\u003E\\u003Cimg src=\\\"t1/img/front_page/web_logged_out_nbc.png\\\"\\u003E\\u003Cimg src=\\\"t1/img/front_page/web_logged_out_usot.png\\\"\\u003E\\u003Cimg src=\\\"t1/img/front_page/web_logged_out_rings.png\\\"\\u003E\\u003C/a\\u003E\\u000a        \\u003C/p\\u003E\\u000a        \\u003Ch1\\u003EDedication. Sacrifice. Guts. Glory.\\u003C/h1\\u003E\\u000a        \\u003Cp\\u003EGet closer to the \\u003Ca href=\\\"/hashtag/olympics\\\" class=\\\"hashtag\\\"\\u003E\\u003Cs\\u003E#\\u003C/s\\u003E\\u003Cb\\u003EOlympics\\u003C/b\\u003E\\u003C/a\\u003E on Twitter.\\u003C/p\\u003E\\u000a        \\u003Cp class=\\\"call-to-action\\\"\\u003E\\u003Ca href=\\\"/hashtag/olympics\\\"\\u003ECheck it out now.\\u003C/a\\u003E\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/olympics_homepage}}\\u000a\\u000a  \\u003Cdiv class=\\\"front-card\\\"\\u003E\\u000a    {{^swift_events}}\\u000a      \\u003Cdiv class=\\\"front-welcome\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"front-welcome-text\\\"\\u003E\\u000a          \\u003Ch1\\u003EWelcome to Twitter.\\u003C/h1\\u003E\\u000a          \\u003Cp\\u003EFind out what&#8217;s happening, right now, with the people and organizations you care about.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/swift_events}}\\u000a\\u000a    {{#swift_events}}\\u000a      {{#nascar_homepage}}\\u000a        \\u003Ca href=\\\"/hashtag/nascar\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"front-welcome\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"front-welcome-text\\\"\\u003E\\u000a              \\u003Ch1\\u003EHappening now: #NASCAR\\u003C/h1\\u003E\\u000a              \\u003Cp\\u003EEvery turn. Every Angle.\\u003C/p\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/a\\u003E\\u000a      {{/nascar_homepage}}\\u000a    {{/swift_events}}\\u000a\\u000a    {{#olympics_homepage}}\\u000a    \\u003Cdiv class=\\\"front-signin js-front-signin\\\"\\u003E\\u000a      \\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"signin\\\" method=\\\"post\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"placeholding-input username\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input\\\" name=\\\"session[username_or_email]\\\" title=\\\"Username or email\\\" autocomplete=\\\"on\\\" tabindex=1\\u003E\\u000a            \\u003Cspan class=\\\"placeholder\\\"\\u003EUsername or email\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a        \\u003Ctable class=\\\"flex-table password-signin\\\"\\u003E\\u000a          \\u003Ctbody\\u003E\\u000a            \\u003Ctr\\u003E\\u000a              \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a                \\u003Cdiv class=\\\"placeholding-input password flex-table-form\\\"\\u003E\\u000a                  \\u003Cinput type=\\\"password\\\" class=\\\"text-input flex-table-input\\\" name=\\\"session[password]\\\" title=\\\"Password\\\" tabindex=2\\u003E\\u000a                  \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a                \\u003C/div\\u003E\\u000a              \\u003C/td\\u003E\\u000a              \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a                \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn flex-table-btn js-submit\\\" tabindex=4\\u003ESign in\\u003C/button\\u003E\\u000a              \\u003C/td\\u003E\\u000a            \\u003C/tr\\u003E\\u000a          \\u003C/tbody\\u003E\\u000a        \\u003C/table\\u003E\\u000a\\u000a        \\u003Cdiv class=\\\"remember-forgot\\\"\\u003E\\u000a          \\u003Clabel class=\\\"remember\\\"\\u003E\\u000a            \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" name=\\\"remember_me\\\" tabindex=3\\u003E\\u000a            \\u003Cspan\\u003ERemember me\\u003C/span\\u003E\\u000a          \\u003C/label\\u003E\\u000a          \\u003Cspan class=\\\"separator\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a          \\u003Ca class=\\\"forgot\\\" href=\\\"{{resend_password_path}}\\\"\\u003EForgot password?\\u003C/a\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a        {{#is_ssl}}\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"return_to_ssl\\\" value=\\\"true\\\"\\u003E\\u000a        {{/is_ssl}}\\u000a\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect_after_login\\\" value=\\\"{{redirect_after_login}}\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"front-signup js-front-signup\\\"\\u003E\\u000a      \\u003Ch2\\u003E\\u003Cstrong\\u003ENew to Twitter?\\u003C/strong\\u003E Sign up\\u003C/h2\\u003E\\u000a\\u000a      \\u003Cform action=\\\"{{signup_path}}\\\" class=\\\"signup\\\" method=\\\"post\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" class=\\\"text-input\\\" autocomplete=\\\"off\\\" name=\\\"user[name]\\\" maxlength=\\\"20\\\"\\u003E\\u000a          \\u003Cspan class=\\\"placeholder\\\"\\u003EFull name\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input\\\" autocomplete=\\\"off\\\" name=\\\"user[email]\\\"\\u003E\\u000a          \\u003Cspan class=\\\"placeholder\\\"\\u003EEmail\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a          \\u003Cinput type=\\\"password\\\" class=\\\"text-input\\\" name=\\\"user[user_password]\\\"\\u003E\\u000a          \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a        \\u003C/div\\u003E\\u000a\\u000a        \\u003Cinput type=\\\"hidden\\\" value=\\\"{{signup_source}}\\\" name=\\\"context\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"btn signup-btn\\\"\\u003E\\u000a          Sign up for Twitter\\u000a        \\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{/olympics_homepage}}\\u000a    {{^olympics_homepage}}\\u000a      {{#front_page_full_signup_256_login_form_below}}\\u000a        {{\\u003Esignup/front_page_signup_form}}\\u000a      {{/front_page_full_signup_256_login_form_below}}\\u000a\\u000a      {{#front_page_full_signup_256_old_login_form}}\\u000a      \\u003Cdiv class=\\\"front-signin js-front-signin\\\"\\u003E\\u000a        {{#front_page_full_signup_256_login_form_below}}\\u003Ch2\\u003E\\u003Cstrong\\u003ELog in\\u003C/strong\\u003E\\u003C/h2\\u003E{{/front_page_full_signup_256_login_form_below}}\\u000a        \\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"signin\\\" method=\\\"post\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"placeholding-input username\\\"\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input\\\" name=\\\"session[username_or_email]\\\" title=\\\"Username or email\\\" autocomplete=\\\"on\\\" tabindex=1\\u003E\\u000a              \\u003Cspan class=\\\"placeholder\\\"\\u003EUsername or email\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a\\u000a          \\u003Ctable class=\\\"flex-table password-signin\\\"\\u003E\\u000a            \\u003Ctbody\\u003E\\u000a              \\u003Ctr\\u003E\\u000a                \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u000a                  \\u003Cdiv class=\\\"placeholding-input password flex-table-form\\\"\\u003E\\u000a                    \\u003Cinput type=\\\"password\\\" class=\\\"text-input flex-table-input\\\" name=\\\"session[password]\\\" title=\\\"Password\\\" tabindex=2\\u003E\\u000a                    \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/td\\u003E\\u000a                \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a                  \\u003Cbutton type=\\\"submit\\\" class=\\\"submit btn primary-btn flex-table-btn js-submit\\\" tabindex=4\\u003E\\u000a                    {{#front_page_full_signup_256_login_form_below}}Log in{{/front_page_full_signup_256_login_form_below}}\\u000a                    {{^front_page_full_signup_256_login_form_below}}Sign in{{/front_page_full_signup_256_login_form_below}}\\u000a                  \\u003C/button\\u003E\\u000a                \\u003C/td\\u003E\\u000a              \\u003C/tr\\u003E\\u000a            \\u003C/tbody\\u003E\\u000a          \\u003C/table\\u003E\\u000a\\u000a          \\u003Cdiv class=\\\"remember-forgot\\\"\\u003E\\u000a            \\u003Clabel class=\\\"remember\\\"\\u003E\\u000a              \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" name=\\\"remember_me\\\" tabindex=3\\u003E\\u000a              \\u003Cspan\\u003ERemember me\\u003C/span\\u003E\\u000a            \\u003C/label\\u003E\\u000a            \\u003Cspan class=\\\"separator\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a            \\u003Ca class=\\\"forgot\\\" href=\\\"{{resend_password_path}}\\\"\\u003EForgot password?\\u003C/a\\u003E\\u000a          \\u003C/div\\u003E\\u000a\\u000a          {{#is_ssl}}\\u000a            \\u003Cinput type=\\\"hidden\\\" name=\\\"return_to_ssl\\\" value=\\\"true\\\"\\u003E\\u000a          {{/is_ssl}}\\u000a\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect_after_login\\\" value=\\\"{{redirect_after_login}}\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{/front_page_full_signup_256_old_login_form}}\\u000a\\u000a      {{#front_page_full_signup_256_old_signup_form}}\\u000a      \\u003Cdiv class=\\\"front-signup js-front-signup\\\"\\u003E\\u000a        \\u003Ch2\\u003E\\u003Cstrong\\u003ENew to Twitter?\\u003C/strong\\u003E Sign up\\u003C/h2\\u003E\\u000a\\u000a        \\u003Cform action=\\\"{{signup_path}}\\\" class=\\\"signup\\\" method=\\\"post\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" class=\\\"text-input\\\" autocomplete=\\\"off\\\" name=\\\"user[name]\\\" maxlength=\\\"20\\\"\\u003E\\u000a            \\u003Cspan class=\\\"placeholder\\\"\\u003EFull name\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a            \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input\\\" autocomplete=\\\"off\\\" name=\\\"user[email]\\\"\\u003E\\u000a            \\u003Cspan class=\\\"placeholder\\\"\\u003EEmail\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a            \\u003Cinput type=\\\"password\\\" class=\\\"text-input\\\" name=\\\"user[user_password]\\\"\\u003E\\u000a            \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"{{signup_source}}\\\" name=\\\"context\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"\\u003E\\u000a          \\u003Cbutton type=\\\"submit\\\" class=\\\"btn signup-btn\\\"\\u003E\\u000a            Sign up for Twitter\\u000a          \\u003C/button\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a      {{/front_page_full_signup_256_old_signup_form}}\\u000a\\u000a      {{^front_page_full_signup_256_login_form_below}}\\u000a        {{^front_page_full_signup_256_old_signup_form}}\\u000a          {{\\u003Esignup/front_page_signup_form}}\\u000a        {{/front_page_full_signup_256_old_signup_form}}\\u000a      {{/front_page_full_signup_256_login_form_below}}\\u000a    {{/olympics_homepage}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{\\u003Egeneric_footer}}\\u000a\\u000a  {{#remember_default}}\\u000a    \\u003Cdiv id=\\\"remember_default_checked\\\" style=\\\"display:none;\\\"\\u003E\\u003C/div\\u003E\\u000a  {{/remember_default}}\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            t1_global_nav: \"\\u003Cdiv class=\\\"push-loader\\\" id=\\\"pushStateSpinner\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"topbar js-topbar\\\"\\u003E\\u000a  \\u003Cdiv id=\\\"banners\\\" class=\\\"js-banners\\\"\\u003E\\u000a    {{#noscript_banner}}\\u003Cnoscript\\u003E{{\\u003Enoscript_banner}}\\u003C/noscript\\u003E{{/noscript_banner}}\\u000a    {{#logged_in}}{{\\u003Eslow_load_banner}}{{/logged_in}}\\u000a    {{#became_user}}{{\\u003Ebecame_user_banner}}{{/became_user}}\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"global-nav\\\" data-section-term=\\\"top_nav\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"global-nav-inner\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"container\\\"\\u003E\\u000a      {{^current_user}}\\u000a        \\u000a      {{/current_user}}\\u000a      {{#current_user}}\\u000a        \\u003Cul class=\\\"nav js-global-actions\\\" id=\\\"global-actions\\\"\\u003E\\u000a          \\u003Cli id=\\\"global-nav-home\\\" class=\\\"home{{#content_view}}{{#home_page}}{{#rendering_on_server}} active{{/rendering_on_server}}{{/home_page}}{{/content_view}}\\\" data-global-action=\\\"home\\\"\\u003E\\u000a            \\u003Ca class=\\\"js-hover js-nav\\\" href=\\\"{{home_path}}\\\" data-component-term=\\\"home_nav\\\" data-nav=\\\"home\\\"\\u003E\\u000a              \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-home\\\"\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E Home\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"people{{#content_view}}{{#connect_page}}{{#rendering_on_server}} active{{/rendering_on_server}}{{/connect_page}}{{/content_view}}\\\" data-global-action=\\\"connect\\\"\\u003E\\u000a            \\u003Ca class=\\\"js-hover js-nav\\\" href=\\\"{{#enable_activity}}{{interactions_path}}{{/enable_activity}}{{^enable_activity}}{{mentions_path}}{{/enable_activity}}\\\" data-component-term=\\\"connect_nav\\\" data-nav=\\\"connect\\\"\\u003E\\u000a              \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-people\\\"\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E Connect\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"topics{{#content_view}}{{#discover_page}}{{#rendering_on_server}} active{{/rendering_on_server}}{{/discover_page}}{{/content_view}}\\\" data-global-action=\\\"discover\\\"\\u003E\\u000a            \\u003Ca class=\\\"js-hover js-nav\\\" href=\\\"{{discover_path}}\\\" data-component-term=\\\"discover_nav\\\" data-nav=\\\"discover\\\"\\u003E\\u000a              \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-topics\\\"\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E Discover\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          {{#site_header_with_profile_tab}}\\u000a            \\u003Cli class=\\\"profile{{#content_view}}{{#profile_page}}{{#rendering_on_server}} active{{/rendering_on_server}}{{/profile_page}}{{/content_view}}\\\" data-global-action=\\\"profile\\\"\\u003E\\u000a              \\u003Ca class=\\\"js-hover js-nav\\\" href=\\\"{{profile_path}}\\\" data-component-term=\\\"profile_nav\\\" data-nav=\\\"profile\\\"\\u003E\\u000a                \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-me\\\"\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E Me\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/li\\u003E\\u000a          {{/site_header_with_profile_tab}}\\u000a        \\u003C/ul\\u003E\\u000a        \\u003Ci class=\\\"bird-topbar-etched\\\"\\u003E\\u003C/i\\u003E\\u000a\\u000a        \\u003Cdiv class=\\\"pull-right\\\"\\u003E\\u000a          {{^tweet_button_disabled}}\\u000a          \\u003Cdiv class=\\\"well topbar-tweet-btn\\\"\\u003E\\u000a            \\u003Cbutton id=\\\"global-new-tweet-button\\\" type=\\\"button\\\" class=\\\"btn btn-tweet js-global-new-tweet js-hover js-tooltip\\\" data-placement=\\\"bottom\\\" data-component-term=\\\"new_tweet_button\\\" title=\\\"Compose new Tweet\\\"\\u003E\\u000a              \\u003Ci class=\\\"nav-tweet\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003ECompose new Tweet\\u003C/span\\u003E\\u003C/i\\u003E\\u000a            \\u003C/button\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Ci class=\\\"topbar-divider\\\"\\u003E\\u003C/i\\u003E\\u000a          {{/tweet_button_disabled}}\\u000a\\u000a          \\u003Cul class=\\\"nav\\\"\\u003E\\u000a            \\u003Cli class=\\\"me dropdown session js-session\\\" data-global-action=\\\"t1me\\\" id=\\\"user-dropdown\\\"\\u003E\\u000a            \\u003Ca class=\\\"dropdown-toggle js-dropdown-toggle js-hover\\\" href=\\\"#\\\" id=\\\"user-dropdown-toggle\\\"\\u003E\\u000a              {{#site_header_with_profile_tab}}\\u000a                \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-session\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003ESettings and help\\u003C/span\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E \\u003Cspan class=\\\"caret\\\"\\u003E\\u003C/span\\u003E\\u000a              {{/site_header_with_profile_tab}}\\u000a              {{^site_header_with_profile_tab}}\\u000a                \\u003Cspan class=\\\"new-wrapper\\\"\\u003E\\u003Ci class=\\\"nav-me\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003ESettings and help\\u003C/span\\u003E\\u003C/i\\u003E\\u003Ci class=\\\"nav-new\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E \\u003Cspan class=\\\"caret\\\"\\u003E\\u003C/span\\u003E\\u000a              {{/site_header_with_profile_tab}}\\u000a            \\u003C/a\\u003E\\u000a            {{\\u003Et1_user_dropdown}}\\u000a            \\u003C/li\\u003E\\u000a          \\u003C/ul\\u003E\\u000a\\u000a          \\u003Ci class=\\\"topbar-divider\\\"\\u003E\\u003C/i\\u003E\\u000a          {{\\u003Et1_global_nav_search}}\\u000a\\u000a        \\u003C/div\\u003E\\u000a        {{#is_vit_layout}}\\u000a          {{#is_mobile}}\\u000a          \\u003Cdiv class=\\\"vit-onboarding-title\\\"\\u003E\\u000a            \\u003Ca class=\\\"nav-logo-link\\\" href=\\\"/\\\" data-nav=\\\"front\\\"\\u003E\\u000a              \\u003Ci class=\\\"bird-topbar-blue\\\"\\u003E\\u003C/i\\u003E\\u000a            \\u003C/a\\u003E\\u000a            \\u003Cspan\\u003E\\u003Ci class=\\\"nav-home-vit\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u000a            Verification\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cdiv class=\\\"vit-onboarding-nav\\\"\\u003E\\u000a            \\u003Cbutton class=\\\"btn cancel skip hidden\\\" type=\\\"cancel\\\"\\u003ESkip\\u003C/button\\u003E\\u000a            \\u003Cbutton class=\\\"btn next primary-btn hidden\\\" type=\\\"submit\\\"\\u003ENext\\u003C/button\\u003E\\u000a          \\u003C/div\\u003E\\u000a          {{/is_mobile}}\\u000a        {{/is_vit_layout}}\\u000a      {{/current_user}}\\u000a\\u000a      {{^current_user}}\\u000a        \\u003Cul class=\\\"nav js-global-actions\\\"\\u003E\\u000a          \\u003Cli class=\\\"home\\\" data-global-action=\\\"t1home\\\"\\u003E\\u000a            {{^custom_nav_title}}\\u000a              \\u003Ca class=\\\"nav-logo-link\\\" href=\\\"/\\\" data-nav=\\\"front\\\"\\u003E\\u000a                \\u003Ci class=\\\"bird-topbar-blue\\\"\\u003E\\u003C/i\\u003E\\u000a              \\u003C/a\\u003E\\u000a            {{/custom_nav_title}}\\u000a            {{#custom_nav_title}}\\u000a              \\u003Ca href=\\\"/\\\" class=\\\"event-nav-link\\\" data-nav=\\\"front\\\"\\u003E\\u000a                \\u003Cspan\\u003E\\u003Ci class=\\\"bird-topbar-blue\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u000a                \\u003Cspan class=\\\"event-nav-title\\\"\\u003ETwitter.com/\\u003C/span\\u003E\\u003Cspan class=\\\"event-nav-hashtag\\\"\\u003E{{custom_nav_title}}\\u003C/span\\u003E\\u000a              \\u003C/a\\u003E\\u000a            {{/custom_nav_title}}\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a        \\u003Cul class=\\\"nav secondary-nav session-dropdown\\\" id=\\\"session\\\"\\u003E\\u000a          \\u003Cli class=\\\"dropdown js-session\\\"\\u003E\\u000a            \\u003Ca class=\\\"dropdown-toggle dropdown-signin\\\" id=\\\"signin-link\\\" href=\\\"#\\\" data-nav=\\\"login\\\"\\u003E\\u000a              \\u003Csmall\\u003EHave an account?\\u003C/small\\u003E Sign in \\u003Cspan class=\\\"caret\\\"\\u003E\\u003C/span\\u003E\\u000a            \\u003C/a\\u003E\\u000a            \\u003Ca class=\\\"dropdown-signup\\\" id=\\\"signup-link\\\" href=\\\"{{signup_path}}?context=login\\\" data-nav=\\\"signup\\\"\\u003E\\u000a              \\u003Csmall\\u003ENew to Twitter?\\u003C/small\\u003E\\u003Cspan class=\\\"emphasize\\\"\\u003E Join Today &raquo;\\u003C/span\\u003E\\u000a            \\u003C/a\\u003E\\u000a            \\u003Cul class=\\\"dropdown-menu dropdown-form\\\" id=\\\"signin-dropdown\\\"\\u003E\\u000a              \\u003Cli class=\\\"dropdown-caret right\\\"\\u003E\\u000a                \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a                \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a              \\u003C/li\\u003E\\u000a              \\u003Cli\\u003E\\u000a                {{\\u003Et1_signin_form}}\\u000a              \\u003C/li\\u003E\\u000a            \\u003C/ul\\u003E\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a\\u000a        \\u000a        {{#front_page_full_signup_256_inline_signin}}\\u000a          \\u003Cdiv class=\\\"js-front-signin nav-signin\\\"\\u003E\\u000a            \\u003Cform action=\\\"{{sessions_path}}\\\" method=\\\"post\\\"\\u003E\\u000a              \\u003Cul class=\\\"nav secondary-nav\\\"\\u003E\\u000a                \\u003Cli\\u003E\\u000a                  \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a                    \\u003Cinput type=\\\"text\\\" class=\\\"text-input email-input js-username-field\\\" name=\\\"session[username_or_email]\\\" autocomplete=\\\"on\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"placeholder\\\"\\u003EUsername or email\\u003C/span\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/li\\u003E\\u000a                \\u003Cli\\u003E\\u000a                  \\u003Cdiv class=\\\"placeholding-input\\\"\\u003E\\u000a                    \\u003Cinput type=\\\"password\\\" class=\\\"text-input js-password-field\\\" name=\\\"session[password]\\\"\\u003E\\u000a                    \\u003Cspan class=\\\"placeholder\\\"\\u003EPassword\\u003C/span\\u003E\\u000a                  \\u003C/div\\u003E\\u000a                \\u003C/li\\u003E\\u000a                \\u003Cli\\u003E\\u003Cbutton type=\\\"submit\\\" class=\\\"btn primary-btn submit\\\"\\u003ESign in\\u003C/button\\u003E\\u003C/li\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect_after_login\\\" value=\\\"{{redirect_after_login}}\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"remember_me\\\" value=\\\"0\\\"\\u003E\\u000a              \\u003C/ul\\u003E\\u000a            \\u003C/form\\u003E\\u000a            \\u003Ci class=\\\"topbar-divider\\\"\\u003E\\u003C/i\\u003E\\u000a          \\u003C/div\\u003E\\u000a        {{/front_page_full_signup_256_inline_signin}}\\u000a\\u000a        \\u003Cul class=\\\"nav secondary-nav language-dropdown\\\"\\u003E\\u000a          \\u003Cli class=\\\"dropdown js-language-dropdown\\\"\\u003E\\u000a            \\u003Ca class=\\\"dropdown-toggle\\\" href=\\\"javascript:;\\\"\\u003E\\u000a              \\u003Csmall\\u003ELanguage:\\u003C/small\\u003E\\u000a              \\u003Cspan class=\\\"js-current-language\\\"\\u003E{{current_language_name}}\\u003C/span\\u003E\\u000a              \\u003Cb class=\\\"caret\\\"\\u003E\\u003C/b\\u003E\\u000a            \\u003C/a\\u003E\\u000a            \\u003Cul class=\\\"dropdown-menu\\\"\\u003E\\u000a              \\u003Cli class=\\\"dropdown-caret right\\\"\\u003E\\u000a                \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a                \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a              \\u003C/li\\u003E\\u000a              {{#dropdown_languages}}\\u000a                \\u003Cli\\u003E\\u003Ca href=\\\"?lang={{code}}\\\" data-lang-code=\\\"{{code}}\\\" title=\\\"{{localized_name}}\\\" class=\\\"js-language-link\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a              {{/dropdown_languages}}\\u000a            \\u003C/ul\\u003E\\u000a            \\u003Cdiv class=\\\"js-front-language\\\"\\u003E\\u000a              \\u003Cform action=\\\"{{change_locale_path}}\\\" class=\\\"language\\\" method=\\\"POST\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"lang\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"redirect\\\"\\u003E\\u000a                \\u003Cinput type=\\\"hidden\\\" name=\\\"authenticity_token\\\" value=\\\"{{form_authenticity_token}}\\\"\\u003E\\u000a              \\u003C/form\\u003E\\u000a            \\u003C/div\\u003E\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a        \\u000a        {{#do_not_render_pctd_logged_out}}\\u000a        {{#phoenix_pctd}}\\u000a          \\u003Cul class=\\\"nav secondary-nav country-dropdown\\\"\\u003E\\u000a            \\u003Cli class=\\\"dropdown js-country-dropdown\\\"\\u003E\\u000a              \\u003Ca class=\\\"dropdown-toggle\\\" href=\\\"javascript:;\\\"\\u003E\\u000a                \\u003Csmall\\u003ECountry:\\u003C/small\\u003E\\u000a                \\u003Cspan class=\\\"js-current-country\\\"\\u003E{{current_country_name}}\\u003C/span\\u003E\\u000a                \\u003Cspan class=\\\"caret\\\"\\u003E\\u003C/span\\u003E\\u000a              \\u003C/a\\u003E\\u000a              \\u003Cul class=\\\"dropdown-menu\\\"\\u003E\\u000a                \\u003Cli class=\\\"dropdown-caret right\\\"\\u003E\\u000a                  \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a                  \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a                \\u003C/li\\u003E\\u000a                {{#dropdown_countries}}\\u000a                  \\u003Cli\\u003E\\u003Ca href=\\\"javascript:;\\\" data-country-code=\\\"{{code}}\\\" title=\\\"{{name}}\\\" class=\\\"js-country-link\\\"\\u003E{{name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a                {{/dropdown_countries}}\\u000a              \\u003C/ul\\u003E\\u000a            \\u003C/li\\u003E\\u000a          \\u003C/ul\\u003E\\u000a        {{/phoenix_pctd}}\\u000a        {{/do_not_render_pctd_logged_out}}\\u000a        \\u003Cdiv class=\\\"pull-right\\\"\\u003E\\u000a          {{\\u003Et1_global_nav_search}}\\u000a        \\u003C/div\\u003E\\u000a      {{/current_user}}\\u000a\\u000a        \\u000a        \\u003Ca id=\\\"close-all-button\\\" class=\\\"close-all-tweets js-close-all-tweets\\\" href=\\\"#\\\" title=\\\"Close all open Tweets\\\"\\u003E\\u000a          \\u003Ci class=\\\"nav-breaker\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{^swift}} \\u000a    {{\\u003Emessage_drawer_outer}}\\u000a  {{/swift}}\\u000a\\u003C/div\\u003E\\u000a\",\n            t1_global_nav_search: \"\\u003Cform class=\\\"form-search js-search-form {{search_page_global_search_box_255_class}}\\\" action=\\\"{{search_path}}\\\" id=\\\"global-nav-search\\\"\\u003E\\u000a  \\u003Cspan class=\\\"search-icon js-search-action\\\"\\u003E\\u000a    \\u003Ci class=\\\"nav-search\\\" tabindex=\\\"0\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003C/span\\u003E\\u000a  \\u003Clabel class=\\\"hidden-elements\\\" for=\\\"search-query\\\"\\u003ESearch\\u003C/label\\u003E\\u000a  \\u003Cinput class=\\\"search-input\\\" type=\\\"text\\\" id=\\\"search-query\\\" {{#swift}}value=\\\"{{#content_view}}{{search_query}}{{/content_view}}\\\"{{/swift}} placeholder=\\\"{{#content_view}}{{search_text}}{{/content_view}}{{^content_view}}Search{{/content_view}}\\\" name=\\\"q\\\" autocomplete=\\\"off\\\" spellcheck=\\\"false\\\" tabindex=\\\"-1\\\"\\u003E\\u000a  \\u003Cinput disabled=\\\"disabled\\\" class=\\\"search-input search-hinting-input\\\" type=\\\"text\\\" id=\\\"search-query-hint\\\" autocomplete=\\\"off\\\" spellcheck=\\\"false\\\"\\u003E\\u000a  {{#swift_typeahead}}\\u000a    {{\\u003Eswift_typeahead_dropdown}}\\u000a  {{/swift_typeahead}}\\u000a\\u003C/form\\u003E\\u000a\",\n            t1_mock_js: \"\\u003Cscript\\u003E\\u000a\\u000a$(document).ready(function() {\\u000a\\u000a  // Global nav\\u000a  $('.global-nav .home a').attr('href', '/mockview?html=home.ss');\\u000a  $('.global-nav .topics a').attr('href', '/mockview?html=discover.ss');\\u000a  $('.global-nav .people a').attr('href', '/mockview?html=connect.ss');\\u000a\\u000a  // Make the global nav search bar do it's thing\\u000a  $('.global-nav input').focus(function() {\\u000a    $(this).addClass('focus'); // For IE7\\u000a    $(this).parent().addClass('focus'); // For targeting the search icon on focus of input field\\u000a  });\\u000a  $('.global-nav input').blur(function() {\\u000a    $(this).removeClass('focus'); // For IE7\\u000a    $(this).parent().removeClass('focus'); // For targeting the search icon on focus of input field\\u000a  });\\u000a\\u000a  var expandedTweet,\\u000a  prevExpandedTweet,\\u000a  nextExpandedTweet\\u000a\\u000a  // Hacky display of inline expansion\\u000a  $('.stream-item .tweet').click(function(e) {\\u000a    e.preventDefault();\\u000a    expandedTweet = $(this).closest('.stream-item');\\u000a    expandedTweet.toggleClass('open');\\u000a    expandedTweet.find('.replies').slideToggle(300);\\u000a    expandedTweet.find('.in-reply-to').slideToggle(300);\\u000a    var expando = expandedTweet.find('.expanded-content');\\u000a\\u000a    if(!expandedTweet.hasClass('open')) {\\u000a      expando.animate({ height: 0 })\\u000a    } else {\\u000a      expando.animate({ height: expando.children().height()+20 })\\u000a    }\\u000a\\u000a    if(expandedTweet.hasClass('open')) {\\u000a      expandedTweet.animate({\\u000a        \\\"margin-top\\\" : \\\"10px\\\",\\u000a        \\\"margin-bottom\\\" : \\\"10px\\\"\\u000a      }, 150)\\u000a    } else {\\u000a      expandedTweet.animate({\\u000a        \\\"margin-top\\\" : \\\"0px\\\",\\u000a        \\\"margin-bottom\\\" : \\\"0px\\\"\\u000a      }, 150)\\u000a    }\\u000a    prevExpandedTweet = expandedTweet\\u000a      .prev()\\u000a    nextExpandedTweet = expandedTweet\\u000a      .next()\\u000a    if(prevExpandedTweet.not('open') || prevExpandedTweet.not('before-expanded')) {\\u000a      prevExpandedTweet.toggleClass('before-expanded')\\u000a    }\\u000a    if(nextExpandedTweet.not('open') || nextExpandedTweet.not('after-expanded')) {\\u000a      nextExpandedTweet.toggleClass('after-expanded')\\u000a    }\\u000a  });\\u000a\\u000a  // Dropdowns\\u000a  $('body').bind('click', function (e) {\\u000a    $('.js-dropdown-toggle').parent().removeClass('open');\\u000a    $('.combo-btn-toggle').parent().removeClass('open');\\u000a  });\\u000a  $('.dropdown-toggle').click(function (e) {\\u000a    $(this).parent().toggleClass('open');\\u000a    return false;\\u000a  });\\u000a\\u000a  // Throwaway Extensible modal\\u000a  $('[data-modal]').live('click', function(e) {\\u000a    e.preventDefault();\\u000a    var modalClass = $(this).attr('data-modal');\\u000a    $('.'+modalClass).show();\\u000a  });\\u000a\\u000a  // Use the js- class for this one\\u000a  $('.js-new-tweet').live('click', function(e) {\\u000a    e.preventDefault();\\u000a    $('.new-tweet').show();\\u000a  });\\u000a\\u000a  // Close modal\\u000a  $('.modal .js-dismiss').click(function(e) {\\u000a    e.preventDefault();\\u000a    $(this).parents('.modal-overlay').hide();\\u000a  });\\u000a  // Ghetto esc key close for modals\\u000a  document.JSBNG__onkeydown = function(evt) {\\u000a    evt = evt || window.event;\\u000a    if (evt.keyCode == 27) {\\u000a      $('.modal-overlay').hide();\\u000a    }\\u000a  };\\u000a\\u000a  // Modal: adding/removing prople from lists\\u000a  $('.membership label').click(function(e) {\\u000a    e.preventDefault();\\u000a    if ($(this).children('input').attr('checked')) {\\u000a      $(this).children('input').attr('checked',false);\\u000a      $(this).removeClass('checked');\\u000a    } else {\\u000a      $(this).children('input').attr('checked',true);\\u000a      $(this).addClass('checked');\\u000a    }\\u000a  });\\u000a\\u000a  // Follow button dropdown\\u000a  $('.follow-btn').live(\\\"click\\\", function(e) {\\u000a    e.preventDefault();\\u000a    $(this).toggleClass('following');\\u000a    $(this).toggleClass('not-following');\\u000a  });\\u000a\\u000a  // Follow button dropdown\\u000a  $('.btn-user-actions').live(\\\"click\\\", function(e) {\\u000a    e.preventDefault();\\u000a    $(this).find('.btn-group-dropdown').toggleClass('open')\\u000a  });\\u000a\\u000a  // Search button dropdown\\u000a  $('.btn-search-actions').live(\\\"click\\\", function(e) {\\u000a    e.preventDefault();\\u000a    $(this).find('.btn-group-dropdown').toggleClass('open')\\u000a  });\\u000a\\u000a  // Save button 'saved' state\\u000a  $('.save-btn').click(function(e) {\\u000a    e.preventDefault();\\u000a    $(this).toggleClass('saved');\\u000a    $(this).toggleClass('not-saved');\\u000a  });\\u000a\\u000a});\\u000a\\u003C/script\\u003E\",\n            t1_mockview: \"\\u003C!DOCTYPE html\\u003E\\u000a\\u003Chtml lang=\\\"en\\\"\\u003E\\u000a\\u003Chead\\u003E\\u000a  \\u003Cmeta charset=\\\"utf-8\\\"/\\u003E\\u000a  \\u003Ctitle\\u003EMustache Template Viewer\\u003C/title\\u003E\\u000a\\u000a  \\u003Clink rel=\\\"stylesheet\\\" href=\\\"{{t1_core_css_bundle}}\\\" type=\\\"text/css\\\" media=\\\"screen\\\" /\\u003E\\u000a\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner_plugin_signal.js\\\"\\u003E\\u003C/script\\u003E\\u000a  \\u003Cscript type=\\\"text/javascript\\\" src=\\\"/phoenix/external_resources/loadrunner_plugin_json.js\\\"\\u003E\\u003C/script\\u003E\\u000a\\u000a  \\u003Cscript\\u003E\\u000a    using.path = '/phoenix/js';\\u000a\\u000a    var twttr = {};\\u000a\\u000a    twttr.proto = window.JSBNG__location.protocol.match(/s\\\\:$/) ? 'https' : 'http';\\u000a\\u000a    twttr.domains = {\\u000a      local: 'localhost.twitter.com:3000',\\u000a      remote: 'api.localhost.twitter.com:3000'\\u000a    };\\u000a\\u000a    twttr.hosts = {\\u000a      local: twttr.proto + \\\"://\\\" + twttr.domains.local,\\u000a      remote: twttr.proto + \\\"://\\\" + twttr.domains.remote\\u000a    };\\u000a\\u000a    twttr.isSSL = function () {\\u000a      return twttr.proto === 'https';\\u000a    };\\u000a\\u000a    twttr.API = {\\u000a      _requestCache: {\\u000a        get: function(path) {\\u000a          return {};\\u000a        }\\u000a      }\\u000a    };\\u000a\\u000a    twttr.templates = {};\\u000a\\u000a    // Prevent overloading templates from bundles (they have #mockview stripped out of them)\\u000a    twttr.isMockview = true;\\u000a\\u000a    twttr.development = true;\\u000a\\u000a    twttr.isT1 = true;\\u000a\\u000a    {{{fake_console_js}}}\\u000a\\u000a    using('\\u003Edecider', function() {\\u000a      twttr.decider._updateFeatures({\\u000a      });\\u000a      signal('\\u003EdeciderFeaturesFromBootstrap');\\u000a    });\\u000a\\u000a    using('bundle/t1-core', function() {\\u000a      // Overwrite the templates with all of them (even those excluded from the bundles)\\u000a      // This has to be done after core has been loaded and 'run/defaultViews' has\\u000a      // built the views for the core templates.  'multiGlobals/more_views' will build\\u000a      // any remaining missing default views at the very end.\\u000a      twttr.templates = {{{json_all_server_side_templates}}};\\u000a      using([\\u000a        '/account/templates_t1_more.js',\\u000a        'multiGlobals/more_views',\\u000a        'multiGlobals/more_views_t1'],\\u000a      function() {\\u000a        var mockHtmls = {{{json_all_mockview_htmls}}};\\u000a        var mockFixtures = {{{json_all_mockview_fixtures}}};\\u000a        var mockJsons = {{{json_all_mockview_jsons}}};\\u000a        var $body = $(\\\"body\\\");\\u000a\\u000a        //sub in fixture data in mock JSONs\\u000a        for (var name in mockJsons) {\\u000a          var matches = mockJsons[name].match(/\\\\{\\\\{\\u003E.*?\\\\}\\\\}/g);\\u000a          if (matches && matches.length) {\\u000a            for (var i = 0; i \\u003C matches.length; i++) {\\u000a              var fixtureName = matches[i].substr(3, matches[i].length - 5);\\u000a              mockJsons[name] = mockJsons[name].split(matches[i]).join(mockFixtures[fixtureName]);\\u000a            }\\u000a          }\\u000a        }\\u000a\\u000a        renderMustache(twttr.util.params().mustache) || renderHtml(twttr.util.params().html) || renderIndex();\\u000a\\u000a        twttr.themes.loadCurrentUserStyle();\\u000a\\u000a        function renderIndex() {\\u000a          var $node = $(\\\"\\u003Cdiv style='background-color: rgba(255,255,255,.9); width: 30%; padding: 30px; text-shadow: 0 1px 0 rgba(255,255,255,.5);' /\\u003E\\\").appendTo($body);\\u000a          appendList($node, \\\"HTML Simulations\\\", mockHtmls, 'html');\\u000a          appendList($node, \\\"T1 Templates\\\", twttr.templates, 'mustache');\\u000a        }\\u000a\\u000a        function appendList($node, title, items, paramName) {\\u000a          var $list = $(\\\"\\u003Cul style='list-style-type:none; margin: 0 10px;'/\\u003E\\\");\\u000a          var keys = [];\\u000a          $.each(items, function(key, value) { keys.push(key); });\\u000a          $.each(keys.sort(), function(i, key) {\\u000a            var params = {};\\u000a            params[paramName] = key;\\u000a            var $a = $(\\\"\\u003Ca /\\u003E\\\").text(key).attr('href', '?' + $.param(params)).attr('target', '_blank');\\u000a            $list.append($(\\\"\\u003Cli /\\u003E\\\").html($a));\\u000a          });\\u000a          $node.append($(\\\"\\u003Ch2 style='margin: 10px 10px 0 10px;'/\\u003E\\\").text(title));\\u000a          $node.append($list);\\u000a        }\\u000a\\u000a        function renderMustache(mockViewMustache) {\\u000a          var html = mustacheToHtmlOrNull(mockViewMustache);\\u000a          if (html === null) {\\u000a            return false;\\u000a          } else {\\u000a            replaceBody($(\\\"\\u003Cdiv/\\u003E\\\").html(html));\\u000a            return true;\\u000a          }\\u000a        }\\u000a\\u000a        function mustacheToHtmlOrNull(mustacheName, contextJson) {\\u000a          if (mustacheName) {\\u000a            var context = $.parseJSON(contextJson || mockJsons[mustacheName] || mockFixtures[mustacheName] || '{}');\\u000a            // TODO: Remove this when nobody is making json wrapped in obj wrapped in an enigma\\u000a            if (context.obj) {\\u000a              context = context.obj;\\u000a            }\\u000a            // twttr.views.BaseAPI.attach will use either the attributes sub-object or\\u000a            // the outer object as the context\\u000a            if (context.attributes) {\\u000a              context.attributes.is_mockview = true;\\u000a            } else {\\u000a              context.is_mockview = true;\\u000a            }\\u000a            var ViewClass = twttr.views[twttr.util.capitalize(twttr.util.camelize(mustacheName))];\\u000a            if (ViewClass) {\\u000a              return (new ViewClass(context)).html();\\u000a            } else if (twttr.templates[mustacheName]) {\\u000a              return Mustache.to_html(twttr.templates[mustacheName], context, twttr.templates);\\u000a            }\\u000a          }\\u000a          return null;\\u000a        }\\u000a\\u000a        function renderHtml(mockViewHtml) {\\u000a          var html = mockHtmls[mockViewHtml];\\u000a          if (!html) {\\u000a            return false;\\u000a          }\\u000a          var $container = $(\\\"\\u003Cdiv/\\u003E\\\").html(html);\\u000a          $container.find(\\\"mustache\\\").each(function() {\\u000a            var $mustache = $(this);\\u000a            var src = $mustache.attr('src');\\u000a            var json = $mustache.attr('json');\\u000a            var context = $mustache.html() || mockJsons[json] || mockFixtures[json];\\u000a\\u000a            var content = mustacheToHtmlOrNull(src, context);\\u000a            if (content === null) {\\u000a              content = \\\"\\u003Cdiv\\u003EInvalid &lt;mustache&gt; src attribute\\u003C/div\\u003E\\\";\\u000a            }\\u000a            $mustache.replaceWith(content);\\u000a          });\\u000a          replaceBody($container);\\u000a          return true;\\u000a        }\\u000a\\u000a        function replaceBody($container) {\\u000a          var $mockviewBody = $container.find(\\\"body\\\");\\u000a          if ($mockviewBody.length === 1) {\\u000a            $body.replaceWith($mockviewBody);\\u000a          } else {\\u000a            $body.empty().append($container.contents());\\u000a          }\\u000a        }\\u000a      });\\u000a    });\\u000a  \\u003C/script\\u003E\\u000a\\u000a\\u003C/head\\u003E\\u000a\\u003Cbody\\u003E\\u000a\\u003C/body\\u003E\\u000a\\u003C/html\\u003E\\u000a\",\n            t1_signin_form: \"\\u003Cform action=\\\"{{sessions_path}}\\\" class=\\\"js-signin signin\\\" method=\\\"post\\\"\\u003E\\u000a  {{\\u003Et1_signin_form_textbox}}\\u000a  {{\\u003Et1_signin_form_subchck}}\\u000a  \\u003Cdiv class=\\\"divider\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cp\\u003E\\u000a    \\u003Ca class=\\\"forgot\\\" href=\\\"{{resend_password_path}}\\\"\\u003EForgot password?\\u003C/a\\u003E\\u003Cbr /\\u003E\\u000a    \\u003Ca class=\\\"mobile has-sms\\\" href=\\\"{{mobile_complete_path}}\\\"\\u003EAlready using Twitter via text message?\\u003C/a\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            t1_signin_form_subchck: \"\\u003Cfieldset class=\\\"subchck\\\"\\u003E\\u000a  \\u003Clabel class=\\\"remember\\\"\\u003E\\u000a    \\u003Cinput type=\\\"checkbox\\\" value=\\\"1\\\" name=\\\"remember_me\\\" {{#remember_checked}}checked=\\\"checked\\\"{{/remember_checked}}\\u003E\\u000a    \\u003Cspan\\u003ERemember me\\u003C/span\\u003E\\u000a  \\u003C/label\\u003E\\u000a  \\u003Cbutton type=\\\"submit\\\" class=\\\"btn submit\\\"\\u003ESign in\\u003C/button\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\\u000a\\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a\\u003Cinput type=\\\"hidden\\\" name=\\\"redirect_after_login\\\" value=\\\"{{redirect_after_login}}\\\"\\u003E\\u000a\\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a\",\n            t1_signin_form_textbox: \"\\u003Cfieldset class=\\\"textbox\\\"\\u003E\\u000a  \\u003Clabel class=\\\"username js-username\\\"\\u003E\\u000a    \\u003Cspan\\u003EUsername or email\\u003C/span\\u003E\\u000a    \\u003Cinput class=\\\"js-username-field email-input\\\" type=\\\"text\\\" name=\\\"session[username_or_email]\\\" autocomplete=\\\"on\\\"\\u003E\\u000a  \\u003C/label\\u003E\\u000a  \\u003Clabel class=\\\"password js-password\\\"\\u003E\\u000a    \\u003Cspan\\u003EPassword\\u003C/span\\u003E\\u000a    \\u003Cinput class=\\\"js-password-field\\\" type=\\\"password\\\" value=\\\"\\\" name=\\\"session[password]\\\"\\u003E\\u000a  \\u003C/label\\u003E\\u000a\\u003C/fieldset\\u003E\\u000a\",\n            t1_signup: \"\\u003Cbody class=\\\"t1 {{locale_css}} logged-out {{ms_windows_class}}\\\"\\u000a{{#locale_is_rtl}}\\u000a  dir=\\\"rtl\\\"\\u000a{{/locale_is_rtl}}\\u000a\\u003E\\u000a  \\u003Cdiv id=\\\"doc\\\" class=\\\"phx-signup\\\"\\u003E\\u000a    {{\\u003Et1_global_nav}}\\u000a    \\u003Cdiv id=\\\"page-outer\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"page-container\\\" class=\\\"wrapper\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"page-canvas\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"signup-wrapper\\\"\\u003E\\u000a            {{#event}}\\u000a              \\u003Ch1\\u003EJoin Twitter today.\\u003C/h1\\u003E\\u000a              \\u003Cp\\u003EComplete signup now to follow top accounts for \\u003Cstrong\\u003E{{event_hashtag}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a              \\u003Cdiv class=\\\"ambassador event-signup clearfix\\\"\\u003E\\u000a                {{#top_people}}\\u003Cimg src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" class=\\\"avatar size48\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a{{/top_people}}\\u000a              \\u003C/div\\u003E\\u000a\\u000a            {{/event}}\\u000a            {{^event}}\\u000a              {{#ambassadors_exist}}\\u000a                {{#follow_many}}\\u000a                  \\u003Ch1\\u003EIt's your turn. Join Twitter.\\u003C/h1\\u003E\\u000a                {{/follow_many}}\\u000a                {{^follow_many}}\\u000a                  \\u003Ch1\\u003EJoin Twitter today.\\u003C/h1\\u003E\\u000a                {{/follow_many}}\\u000a\\u000a                \\u003Cdiv class=\\\"ambassador clearfix\\\"\\u003E\\u000a                  {{#ambassadors}}\\u000a                    \\u003Cimg src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" class=\\\"avatar size48\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a                  {{/ambassadors}}\\u000a                  {{#follow_many}}\\u000a                    \\u003Cp\\u003EComplete signup now to receive updates from \\u003Cstrong\\u003E{{first_ambassador_name}}\\u003C/strong\\u003E and others. \\u003C/p\\u003E\\u000a                  {{/follow_many}}\\u000a                  {{^follow_many}}\\u000a                    \\u003Cp\\u003EComplete signup now to receive updates from \\u003Cstrong\\u003E{{first_ambassador_name}}\\u003C/strong\\u003E.\\u003C/p\\u003E\\u000a                  {{/follow_many}}\\u000a                \\u003C/div\\u003E\\u000a              {{/ambassadors_exist}}\\u000a              {{^ambassadors_exist}}\\u000a                \\u003Ch1\\u003E\\u000a                  {{#user_found_by_device}}\\u000a                  Complete your account.\\u000a                  {{/user_found_by_device}}\\u000a                  {{^user_found_by_device}}\\u000a                  Join Twitter today.\\u000a                  {{/user_found_by_device}}\\u000a                \\u003C/h1\\u003E\\u000a              {{/ambassadors_exist}}\\u000a            {{/event}}\\u000a\\u000a            {{\\u003Esignup_form}}\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{\\u003Ebanned_passwords}}\\u000a\\u000a  \\u003Cscript type=\\\"text/javascript\\\"\\u003E\\u000a  twttr.loggedIn = false;\\u000a  {{\\u003Emini_scribe}}\\u000a  {{{loadrunner_script}}}\\u000a  {{{loadrunner_plugin_json}}}\\u000a  {{{loadrunner_plugin_css}}}\\u000a  {{{loadrunner_plugin_signal}}}\\u000a\\u000a  using.path = '{{{loadrunner_modpath}}}';\\u000a  using.autoLoad = {{{loadrunner_autoload}}};\\u000a  {{#assets_from_cdn}}\\u000a  using.bundles.push({{{loadrunner_versions}}});\\u000a  {{/assets_from_cdn}}\\u000a  using('bundle/signup').load();\\u000a  twttr.insertGAScriptElement();\\u000a  \\u003C/script\\u003E\\u000a\\u000a  \\u003C!--[if lte IE 6]\\u003E\\u000a  \\u003Cscript\\u003Eusing('bundle/ie6').load();\\u003C/script\\u003E\\u000a  \\u003C![endif]--\\u003E\\u000a\\u000a\\u003C/body\\u003E\\u000a\",\n            test_template: \"\",\n            t1_user_dropdown: \"\\u003Cul class=\\\"dropdown-menu\\\"\\u003E\\u000a  \\u003Cli class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u000a  \\u003Cli class=\\\"current-user\\\" data-name=\\\"profile\\\"\\u003E\\u000a    {{\\u003Emini_current_user}}\\u000a  \\u003C/li\\u003E\\u000a\\u000a  \\u003Cli class=\\\"dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a  \\u000a  {{^site_header_with_profile_tab}}\\u000a  {{#contributor_account_info}}\\u000a    {{#include_direct_message_dialog}}\\u000a    \\u003Cli class=\\\"messages\\\" data-name=\\\"messages\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-dm-dialog\\\" href=\\\"/#!/\\\" data-nav=\\\"messages\\\"\\u003E\\u000a        \\u003Cspan class=\\\"js-direct-message-count count\\\"\\u003E\\u003C/span\\u003E\\u000a        Direct messages\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a    {{/include_direct_message_dialog}}\\u000a    {{^include_direct_message_dialog}}\\u000a    \\u003Cli class=\\\"messages\\\" data-name=\\\"messages\\\"\\u003E\\u000a      \\u003Ca href=\\\"/#!/inbox\\\" data-nav=\\\"messages\\\"\\u003EDirect messages\\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a    {{/include_direct_message_dialog}}\\u000a    \\u003Cli data-name=\\\"lists\\\"\\u003E\\u003Ca href=\\\"{{user_lists_path}}\\\" data-nav=\\\"all_lists\\\"\\u003ELists\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli class=\\\"dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a  {{/contributor_account_info}}\\u000a  {{/site_header_with_profile_tab}}\\u000a\\u000a  \\u000a  \\u003Cli\\u003E\\u003Ca href=\\\"{{support_path}}\\\" data-nav=\\\"help_center\\\"\\u003EHelp\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u000a  {{^hide_keyboard_shortcuts_link}}\\u000a    \\u000a    \\u003Cli\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"js-keyboard-shortcut-trigger\\\" data-nav=\\\"shortcuts\\\"\\u003E\\u000a        Keyboard shortcuts\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/hide_keyboard_shortcuts_link}}\\u000a\\u000a  \\u000a  {{#twitter_ads_link_url}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{twitter_ads_link_url}}\\\" target=\\\"{{twitter_ads_link_target}}\\\" data-nav=\\\"ads\\\"\\u003E{{twitter_ads_link_title}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  {{/twitter_ads_link_url}}\\u000a\\u000a  \\u000a  {{#is_translator}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{translation_tool_path}}\\\" data-nav=\\\"translate\\\"\\u003ETranslate\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  {{/is_translator}}\\u000a\\u000a  \\u000a  {{#contributor_account_info}}\\u000a    {{#is_admin}}\\u000a      \\u003Cli class=\\\"admin-panel-link\\\"\\u003E\\u003Ca href=\\\"{{admin_home_path}}\\\" title=\\\"Admin panel\\\"\\u003EAdmin panel\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/is_admin}}\\u000a  {{/contributor_account_info}}\\u000a\\u000a  {{#content_view}}\\u000a    {{#profile_user}}\\u000a      {{#is_admin}}\\u000a        {{#can_investigate}}\\u000a          \\u003Cli class=\\\"user-admin-tools\\\"\\u003E\\u003Ca href=\\\"{{admin_investigate_path}}\\\" title=\\\"Investigate!\\\" target=\\\"_blank\\\"\\u003EInvestigate @{{screen_name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        {{/can_investigate}}\\u000a      {{/is_admin}}\\u000a    {{/profile_user}}\\u000a  {{/content_view}}\\u000a\\u000a  \\u000a  {{#contributor_account_info}}\\u000a    {{#can_contribute}}\\u000a      \\u003Cli class=\\\"dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"label\\\"\\u003ESwitch accounts\\u003C/li\\u003E\\u000a      \\u000a      \\u003Cli class=\\\"contributors\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"contributors-inner\\\"\\u003E\\u000a          {{#is_contributing}}\\u000a            {{#real_identity}}\\u000a              \\u003Cspan class=\\\"contributor-account-link\\\"\\u003E\\u000a                \\u003Ca class=\\\"dropdown-link contributor-link\\\" href=\\\"/account_switch/destroy\\\"\\u003E\\u000a                  \\u003Cimg class=\\\"avatar size20\\\" src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" alt=\\\"{{screen_name}}\\\"\\u003E\\u000a                  {{screen_name}}\\u000a                \\u003C/a\\u003E\\u000a              \\u003C/span\\u003E\\u000a            {{/real_identity}}\\u000a          {{/is_contributing}}\\u000a          {{#contributable_accounts}}\\u000a            \\u003Cspan class=\\\"contributor-account-link\\\"\\u003E\\u000a              \\u003Ca class=\\\"dropdown-link contributor-link\\\" class=\\\"contributor-link\\\" href=\\\"/account_switch/create/{{id}}\\\"\\u003E\\u000a                \\u003Cimg class=\\\"avatar size20\\\" src=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\" alt=\\\"{{screen_name}}\\\"\\u003E\\u000a                {{screen_name}}\\u000a              \\u003C/a\\u003E\\u000a            \\u003C/span\\u003E\\u000a          {{/contributable_accounts}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/li\\u003E\\u000a    {{/can_contribute}}\\u000a  {{/contributor_account_info}}\\u000a  \\u003Cli class=\\\"dropdown-divider\\\"\\u003E\\u003C/li\\u003E\\u000a\\u000a  {{#can_access_oldtwitter}}\\u000a  {{^is_contributing}}\\u000a    \\u003Cli\\u003E\\u000a      \\u003Cform method=\\\"post\\\" action=\\\"{{turn_phx_off_path}}\\\" class=\\\"turn-phx-off-form\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"setting\\\" value=\\\"false\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" name=\\\"format\\\" value=\\\"html\\\"\\u003E\\u000a        \\u003Cinput type=\\\"hidden\\\" value=\\\"\\\" name=\\\"authenticity_token\\\" class=\\\"authenticity_token\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"submit\\\" class=\\\"dropdown-link disable-phx\\\"\\u003ESwitch to Old Twitter\\u003C/button\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/is_contributing}}\\u000a  {{/can_access_oldtwitter}}\\u000a\\u000a  \\u000a  {{#contributor_account_info}}\\u000a    {{^is_contributing}}\\u000a      \\u003Cli\\u003E\\u003Ca href=\\\"{{settings_path}}\\\" data-nav=\\\"settings\\\" class=\\\"{{#content_view}}js-nav{{/content_view}}\\\"\\u003ESettings\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/is_contributing}}\\u000a    {{#is_contributing}}\\u000a      \\u003Cli class=\\\"label\\\"\\u003E\\u000a        \\u003Cspan class=\\\"settings-disabled\\\" title=\\\"Settings disabled while contributing.\\\"\\u003ESettings\\u003C/span\\u003E\\u000a      \\u003C/li\\u003E\\u000a    {{/is_contributing}}\\u000a  {{/contributor_account_info}}\\u000a\\u000a\\u000a  \\u000a  \\u003Cli\\u003E\\u000a    \\u003Ca class=\\\"js-signout-button\\\" id=\\\"signout-button\\\" href=\\\"#\\\" data-nav=\\\"logout\\\"\\u003ESign out\\u003C/a\\u003E\\u000a    \\u003Cform class=\\\"dropdown-link-form signout-form\\\" id=\\\"signout-form\\\" action=\\\"{{logout_action_path}}\\\" method=\\\"POST\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\" class=\\\"authenticity_token\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"reliability_event\\\" class=\\\"js-reliability-event\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"scribe_log\\\"\\u003E\\u000a    \\u003C/form\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u000a\\u003C/ul\\u003E\\u000a\",\n            the_grid: \"\\u003Cdiv class=\\\"the-grid\\\"\\u003E\\u000a\\u003Cdiv class=\\\"grid-bottom\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            thumbnail: \"\\u003Ca href=\\\"{{url}}\\\" data-url=\\\"{{url}}\\\" class=\\\"media-thumbnail\\\" style=\\\"width:{{width}}px; height:{{height}}px; line-height:{{lineHeight}}px;\\\"\\u003E\\u000a  \\u003Cdiv class='thumbnail-wrapper' data-url=\\\"{{url}}\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/a\\u003E\",\n            thumbnail_facet: \"\\u003Ca href=\\\"{{url}}\\\" data-url=\\\"{{url}}\\\" class=\\\"media-thumbnail\\\" style=\\\"width:{{width}}px; height:{{height}}px; line-height:{{lineHeight}}px;\\\"\\u003E\\u000a  \\u003Cdiv class='thumbnail-wrapper' data-url=\\\"{{url}}\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Ci class=\\\"play\\\"\\u003E\\u003C/i\\u003E\\u000a\\u003C/a\\u003E\",\n            thumbnail_viewer: \"\\u003Cdiv class=\\\"thumbnail-viewer\\\"\\u003E\\u000a  \\u003Ca href=\\\"#\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"thumbnail-viewer-nav thumbnail-viewer-prev\\\"\\u003E\\u003Cspan class=\\\"thumbnail-viewer-button thumbnail-viewer-back-button\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a  \\u003Cdiv class=\\\"thumbnail-viewer-container js-thumbnail-viewer-container\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"thumbnail-viewer-images js-thumbnail-viewer-images\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Ca href=\\\"#\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"thumbnail-viewer-nav thumbnail-viewer-next\\\"\\u003E\\u003Cspan class=\\\"thumbnail-viewer-button thumbnail-viewer-next-button\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            thumbnail_viewer_facet: \"\\u003Cdiv class=\\\"js-thumbnail-viewer-container media-row media-videos\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"js-thumbnail-viewer-images\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            timeline: \"{{#timeline}}\\u000a  \\u003Cdiv class=\\\"stream-container\\\"\\u000a    {{#tweet_pagination}}data-max-id=\\\"{{max_id}}\\\" data-since-id=\\\"{{since_id}}\\\"{{/tweet_pagination}}\\u000a    {{#cursor_pagination}}data-cursor=\\\"{{cursor}}\\\"{{/cursor_pagination}}\\u003E\\u000a    \\u003Cdiv class=\\\"stream {{#page_name_underscore}}{{page_name_underscore}}-stream{{/page_name_underscore}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream-items\\\" id=\\\"stream-items-id\\\"\\u003E{{\\u003Eswift_stream_items/all_stream_items}}\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"stream-footer\\\"\\u003E{{\\u003Etimeline_end}}\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"stream-fail-container\\\"\\u003E\\u000a        {{\\u003Estream_whale_end}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"stream-autoplay-marker\\\"\\u003E\\u000a        \\u003Ci class=\\\"arrow\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cspan class=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  {{#tweet_spam_experiment_enabled}}\\u000a    {{\\u003Estream_tweet_hidden}}\\u000a  {{/tweet_spam_experiment_enabled}}\\u000a  {{#include_flag_confirmation_dialog}}\\u000a    {{\\u003Edialogs/sensitive_flag_confirmation}}\\u000a  {{/include_flag_confirmation_dialog}}\\u000a{{/timeline}}\",\n            timeline_account_list: \"\\u003Ch2\\u003E\\u003Cspan class=\\\"dashboard-component-title\\\"\\u003EFollow the people in @{{screen_name}}&rsquo;s timeline\\u003C/span\\u003E\\u003C/h2\\u003E\\u000a\\u003Cul\\u003E\\u003C/ul\\u003E\\u000a\\u000a\",\n            timeline_end: \"\\u003Cdiv class='timeline-end {{#has_items}}has-items{{/has_items}} {{#has_more_items}}has-more-items{{/has_more_items}}'\\u003E\\u000a  {{\\u003Estream_end}}\\u000a  {{\\u003Estream_loading}}\\u000a\\u003C/div\\u003E\",\n            tipsy: \"\\u003Cdiv class=\\\"tooltip\\\"\\u003E\\u000a  \\u003Cb\\u003E\\u000a    {{title}}\\u000a  \\u003C/b\\u003E\\u000a\\u003C/div\\u003E\",\n            too_long_error_message: \"{{#is_dm}}\\u000a  Your message was over 140 characters. You'll have to be more clever.\\u000a{{/is_dm}}\\u000a{{^is_dm}}\\u000a  Your Tweet was over 140 characters. You'll have to be more clever.\\u000a{{/is_dm}}\\u000a\",\n            too_long_list_description_error_message: \"Oops! List descriptions cannot exceed 100 characters.\\u000a\",\n            too_long_list_name_error_message: \"Oops! List names cannot exceed 25 characters.\\u000a\\u003Ca href=\\\"{{list_name_error_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\",\n            too_many_lists_for_user_error_message: \"Oops! You cannot have more than {{max_lists}} lists.\",\n            top_content: \"\\u003Cdiv class=\\\"js-content-top\\\"\\u003E\\u003C/div\\u003E\",\n            top_people_stream_end: \"\\u003Cdiv class=\\\"stream-end\\\"\\u003E\\u000a  \\u003Ca class=\\\"js-full-results-link full-results-link\\\" href=\\\"#\\\" data-query=\\\"{{query}}\\\"\\u003EShow all results\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tos_scroller: \"\\u003Cdiv class=\\\"scroller\\\"\\u003E\\u000a  \\u003Cp class=\\\"header\\\"\\u003EBy clicking the button, you agree to the terms below:\\u003C/p\\u003E\\u000a  \\u003Cdiv class=\\\"import\\\"\\u003E {{{tos_html}}} \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            trend_item: \"\\u003Cli class=\\\"js-trend-item {{#is_event}}event-trend{{/is_event}} {{#promoted_content}}promoted-trend{{/promoted_content}}\\\" data-trend-name=\\\"{{name}}\\\" {{#promoted_content}}data-promoted-trend-id=\\\"{{promoted_trend_id}}\\\"{{/promoted_content}}\\u003E\\u000a  {{#is_sponsored}}\\u000a    \\u003Ca class=\\\"promoted pretty-link\\\" href=\\\"{{trend_search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E \\u003Cspan class=\\\"with-icn js-disclosure js-tooltip\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb class=\\\"promoted-text\\\"\\u003EPromoted\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a  {{/is_sponsored}}\\u000a  {{#is_event}}\\u000a    \\u003Ca class=\\\"pretty-link\\\" href=\\\"{{trend_search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E \\u003Cspan class=\\\"with-icn js-disclosure js-tooltip\\\"\\u003E\\u003Ci class=\\\"{{event_class}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb class=\\\"promoted-text\\\"\\u003E{{event_title}}\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a  {{/is_event}}\\u000a  {{^is_sponsored}}\\u000a    {{^is_event}}\\u000a      \\u003Ca href=\\\"{{trend_search_path}}\\\" data-query-source=\\\"{{search_query_source}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a    {{/is_event}}\\u000a  {{/is_sponsored}}\\u000a\\u003C/li\\u003E\",\n            trends_dialog_breadcrumbs: \"{{#decider_personalized_trends}}\\u000a  {{#is_personalized}}\\u000a    If you want to stop seeing tailored Trends, choose a new location now.\\u000a  {{/is_personalized}}\\u000a  {{^is_personalized}}\\u000a    Trends set to:\\u000a  {{/is_personalized}}\\u000a{{/decider_personalized_trends}}\\u000a{{#breadcrumbs}}\\u000a  {{#decider_personalized_trends}}\\u000a    {{#is_last}}\\u000a      \\u003Cstrong class=\\\"trend-breadcrumb-location selected\\\"\\u003E{{name}} \\u003Ci class=\\\"checkmark\\\"\\u003E\\u003C/i\\u003E\\u003C/strong\\u003E\\u000a    {{/is_last}}\\u000a    {{^is_last}}\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"trend-breadcrumb-location js-trend-link\\\" data-woeid=\\\"{{woeid}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a      \\u003Cspan class=\\\"separator\\\"\\u003E/\\u003C/span\\u003E\\u000a    {{/is_last}}\\u000a  {{/decider_personalized_trends}}\\u000a  {{^decider_personalized_trends}}\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"trend-breadcrumb-location js-trend-link\\\" data-woeid=\\\"{{woeid}}\\\"\\u003E{{name}}\\u003C/a\\u003E\\u000a    {{^is_last}}\\u000a      \\u003Cspan class=\\\"separator\\\"\\u003E/\\u003C/span\\u003E\\u000a    {{/is_last}}\\u000a  {{/decider_personalized_trends}}\\u000a{{/breadcrumbs}}\",\n            trends_dialog_footer: \"\\u003Cbutton type=\\\"button\\\" class=\\\"btn select-personalized\\\"\\u003EGet tailored Trends\\u003C/button\\u003E\\u000a\\u003Cbutton type=\\\"button\\\" class=\\\"btn primary-btn done\\\"\\u003EDone\\u003C/button\\u003E\",\n            trends_inner: \"\\u003Cdiv class=\\\"flex-module-header\\\"\\u003E\\u000a  \\u000a  \\u003Ch3\\u003E\\u000a    \\u003Cspan class=\\\"js-trend-location\\\"\\u003E\\u000a      {{#location}}\\u000a        {{location}}\\u000a      {{/location}}\\u000a      {{^location}}\\u000a        Worldwide trends\\u000a      {{/location}}\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/h3\\u003E\\u000a  \\u003Csmall\\u003E&middot; \\u003Ca href=\\\"#\\\" data-modal=\\\"change-trends\\\" class=\\\"change-trends js-trend-toggle\\\"\\u003EChange\\u003C/a\\u003E\\u003C/small\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"flex-module-inner{{#rendering_on_server}} pre-rendered-stub{{/rendering_on_server}}\\\"\\u003E\\u000a  \\u003Cul class=\\\"trend-items js-trends\\\"\\u003E\\u000a    {{#trends}}\\u000a      {{\\u003Etrend_item}}\\u000a    {{/trends}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            trends_page: \"\\u003Cdiv class=\\\"trends-page{{#decider_local_trends}} trends-page-loading{{/decider_local_trends}}\\\"\\u003E\\u000a  {{^decider_local_trends}}\\u000a    \\u003Cdiv class=\\\"trends-disabled\\\"\\u003E\\u000a      Sorry, local trends are temporarily unavailable.\\u000a    \\u003C/div\\u003E\\u000a  {{/decider_local_trends}}\\u000a  \\u003Cdiv class=\\\"logged-out\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"bottompart\\\" /\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            trends_personalized_dialog: \"\\u003Cdiv class=\\\"trends-personalized content-placeholder\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"title\\\"\\u003ETrends tailored just for you.\\u003C/h2\\u003E\\u000a  \\u003Cp\\u003ETrends offer a unique way to get closer to what you care about. Trends are tailored for you based on your location and who you follow.\\u003C/p\\u003E\\u000a  \\u003Cp class=\\\"placeholder-actions\\\"\\u003E\\u000a    \\u003Cbutton type=\\\"button\\\" class=\\\"btn customize-by-location\\\"\\u003EChange\\u003C/button\\u003E\\u000a    \\u003Cbutton type=\\\"button\\\" class=\\\"btn primary-btn done\\\"\\u003EKeep tailored Trends\\u003C/button\\u003E\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            tweet_activity: \"{{^is_activity_empty}}\\u000a\\u003Cdiv class='tweet-activity-lists clearfix'\\u003E\\u000a\\u000a  {{^is_favorites_empty}}\\u000a  \\u003Cdiv class='activity-list-container favorites'\\u003E\\u000a    \\u003Cb class=\\\"type\\\" title=\\\"Who favorited this Tweet\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a    {{{favorites_list}}}\\u000a    {{#show_favorites_count}}{{{favorites_count}}}{{/show_favorites_count}}\\u000a  \\u003C/div\\u003E\\u000a  {{/is_favorites_empty}}\\u000a\\u000a  {{^is_retweets_empty}}\\u000a  \\u003Cdiv class='activity-list-container retweets'\\u003E\\u000a    \\u003Cb class=\\\"type\\\" title=\\\"Who retweeted this Tweet\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a    {{{retweets_list}}}\\u000a    {{#show_retweets_count}}{{{retweets_count}}}{{/show_retweets_count}}\\u000a  \\u003C/div\\u003E\\u000a  {{/is_retweets_empty}}\\u000a\\u000a  {{^is_replies_empty}}\\u000a  \\u003Cdiv class='activity-list-container replies'\\u003E\\u000a    \\u003Cb class=\\\"type\\\" title=\\\"Who replied to this Tweet\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/b\\u003E\\u000a    {{{replies_list}}}\\u000a    {{#show_replies_count}}{{{replies_count}}}{{/show_replies_count}}\\u000a  \\u003C/div\\u003E\\u000a  {{/is_replies_empty}}\\u000a\\u000a\\u003C/div\\u003E\\u000a{{/is_activity_empty}}\",\n            tweet_activity_count: \"\\u003Cdiv class='tweet-activity-count-container'\\u003E\\u000a  \\u003Cspan class='tweet-activity-count'\\u003E\\u000a    {{#is_retweets}}{{length}} retweets{{/is_retweets}}\\u000a    {{#is_favorites}}{{length}} favorites{{/is_favorites}}\\u000a  \\u003C/span\\u003E &middot; \\u003Ca href='#' class='tweet-activity-view-all'\\u003EView more &raquo;\\u003C/a\\u003E\\u000a\\u003C/div\\u003E\",\n            tweet_box: \"\\u003Cdiv class=\\\"tweet-box condensed\\\"\\u003E\\u000a  {{#show_title}}\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      {{#name}}\\u003Ch2\\u003ETweet to {{name}}\\u003C/h2\\u003E{{/name}}\\u000a      {{^name}}\\u003Ch2\\u003E{{title}}\\u003C/h2\\u003E{{/name}}\\u000a    \\u003C/div\\u003E\\u000a  {{/show_title}}\\u000a  \\u003Cdiv class=\\\"text-area\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"text-area-editor\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-button-container\\\"\\u003E\\u000a    {{#show_geo}}\\u000a      {{\\u003Egeo_control}}\\u000a    {{/show_geo}}\\u000a    \\u003Cdiv class=\\\"tweet-button-sub-container\\\"\\u003E\\u000a      \\u003Cimg src=\\\"/images/spinner.gif\\\" class=\\\"tweet-spinner\\\" style=\\\"display: none;\\\" /\\u003E\\u000a      \\u003Cinput class=\\\"tweet-counter\\\" value=\\\"140\\\" disabled=\\\"disabled\\\"/\\u003E\\u000a      {{\\u003Etweet_button}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_button: \"\\u003Ca href=\\\"#\\\" class=\\\"tweet-button btn\\\"\\u003E{{button_text}}\\u003C/a\\u003E\",\n            tweet_command: \"{{#dm_recipient}}\\u000a  Your message to @{{dm_recipient}} has been sent!\\u000a{{/dm_recipient}}\\u000a{{^dm_recipient}}\\u000a  {{message_for_flash}}\\u003Cbr\\u003E\\u000a  \\\"{{tweet_command}}\\\" is a command, not a Tweet.\\u000a  \\u003Ca href=\\\"{{sms_commands_learn_more_path}}\\\" target=\\\"_blank\\\" class=\\\"learn-more\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a{{/dm_recipient}}\\u000a\",\n            tweet_details: \"\\u003Cdiv class=\\\"js-tweet-details-fixer tweet-details-fixer\\\"\\u003E\\u000a  {{^rendering_on_server}}\\u000a    \\u003Cdiv class=\\\"js-tweet-media-container\\\"\\u003E\\u003C/div\\u003E\\u000a  {{/rendering_on_server}}\\u000a  {{#rendering_on_server}}\\u000a    {{#possibly_sensitive}}\\u000a      {{\\u003Emedia_not_displayed}}\\u000a    {{/possibly_sensitive}}\\u000a    {{#cards}}\\u000a      \\u003Cdiv class=\\\"cards-media-container {{#possibly_sensitive}} hidden{{/possibly_sensitive}}\\\"\\u003E{{\\u003Ecards_base}}\\u003C/div\\u003E\\u000a    {{/cards}}\\u000a    \\u003Cdiv class=\\\"js-tweet-media-container {{#possibly_sensitive}} hidden{{/possibly_sensitive}}\\\"\\u003E\\u003C/div\\u003E\\u000a    {{^cards}}\\u000a      \\u003Cdiv class=\\\"entities-media-container {{#possibly_sensitive}} hidden{{/possibly_sensitive}}\\\" style=\\\"min-height:{{embedded_photos_min_height}}px\\\"\\u003E\\u000a      {{#embedded_photos}}\\u000a        {{\\u003Eembedded_pic_twitter}}\\u000a      {{/embedded_photos}}\\u000a    \\u003C/div\\u003E\\u000a    {{/cards}}\\u000a  {{/rendering_on_server}}\\u000a  \\u003Cdiv class=\\\"js-machine-translated-tweet-container\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"js-tweet-stats-container tweet-stats-container {{#has_retweet_count}}{{^preexpanded}}already-open{{/preexpanded}}{{/has_retweet_count}}\\\"\\u003E\\u000a    {{#tweet_stats}}\\u000a      {{\\u003Etweet_stats}}\\u000a    {{/tweet_stats}}\\u000a  \\u003C/div\\u003E\\u000a  {{#show_geo_icon}}\\u003Cdiv class=\\\"geo js-tiny-geo\\\"\\u003E\\u003C/div\\u003E{{/show_geo_icon}}\\u000a  {{#rendering_on_server}}\\u000a    \\u003Cdiv class=\\\"geo-container tweet-geo-text{{#has_strong_geo}} geo-strong{{/has_strong_geo}}{{#has_weak_geo}} geo-weak{{/has_weak_geo}}\\\"\\u003E\\u000a      {{#geo_with_map}}\\u000a        {{\\u003Eexpanded/geo_with_map}}\\u000a      {{/geo_with_map}}\\u000a    \\u003C/div\\u003E\\u000a  {{/rendering_on_server}}\\u000a  \\u003Cdiv class=\\\"client-and-actions\\\"\\u003E\\u000a    {{^rendering_on_server}}{{\\u003Etweet_geo_text}}{{/rendering_on_server}}\\u000a    \\u003Cspan class=\\\"metadata\\\"\\u003E\\u000a      \\u003Cspan title=\\\"{{explicit_timestamp}}\\\"\\u003E{{explicit_timestamp}}\\u003C/span\\u003E\\u000a\\u000a      {{\\u003Etweet_contributor}} {{\\u003Etweet_source}}\\u000a\\u000a      {{#include_embed_link}}\\u000a        &middot; \\u003Ca class=\\\"embed-link\\\" href=\\\"{{embed_dialog_permalink_path}}\\\"\\u003EEmbed this Tweet\\u003C/a\\u003E\\u000a      {{/include_embed_link}}\\u000a\\u000a      {{^include_embed_link}}\\u000a        {{^is_permalink}} \\u000a          &middot; \\u003Ca class=\\\"permalink-link js-permalink\\\" href=\\\"{{permalink_path}}\\\" {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\" data-send-impression-cookie=\\\"true\\\"{{/impression_cookie}}\\u003EDetails\\u003C/a\\u003E\\u000a        {{/is_permalink}}\\u000a      {{/include_embed_link}}\\u000a\\u000a      {{#media_cards_enabled}}\\u000a        {{#cards}}\\u000a          {{#photos}}{{\\u003Ecards_flag_media}}{{/photos}}\\u000a          {{#summaries}}{{\\u003Ecards_flag_media}}{{/summaries}}\\u000a          {{#players}}{{\\u003Ecards_flag_media}}{{/players}}\\u000a        {{/cards}}\\u000a        {{^cards}}{{^rendering_on_server}} \\u000a          {{#coerce_native_media_to_cards}}\\u000a            {{#entities}}{{#media}}\\u000a              {{\\u003Ecards_flag_media}}\\u000a            {{/media}}{{/entities}}\\u000a          {{/coerce_native_media_to_cards}}\\u000a        {{/rendering_on_server}}{{/cards}}\\u000a      {{/media_cards_enabled}}\\u000a\\u000a    \\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_geo: \"\",\n            tweet_not_found_error_message: \"Tweet does not exist.\\u000a\",\n            tweet_posted: \"{{#in_reply_to_screen_name}}\\u000a  Your Tweet to @{{in_reply_to_screen_name}} has been sent!\\u000a{{/in_reply_to_screen_name}}\\u000a{{^in_reply_to_screen_name}}\\u000a  Your Tweet was posted!\\u000a{{/in_reply_to_screen_name}}\",\n            tweet_related_results_forbidden_error_message: \"You are not authorized to look up related results for that Tweet.\\u000a\",\n            tweet_search_stream_header: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  {{#is_new_search_header_available}}\\u000a    \\u003Cdiv class=\\\"search-header ddg-192-new-header js-search-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"btn-group pull-right js-search-dropdown\\\"\\u003E\\u000a        \\u003Cbutton type=\\\"button\\\" class=\\\"dropdown btn btn-search-actions js-search-dropdown-button\\\"\\u003E\\u000a          \\u003Ci class=\\\"search-toggle\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003C/button\\u003E\\u000a        \\u003Cul class=\\\"dropdown-menu btn-group-dropdown js-combo-btn-dropdown-options\\\"\\u003E\\u000a          \\u003Cli\\u003E\\u003Ca class=\\\"js-toggle-saved-search-link\\\" href=\\\"#\\\"\\u003ESave search\\u003C/a\\u003E\\u003C/li\\u003E\\u000a          \\u003Cli\\u003E\\u003Ca href=\\\"{{search_advanced_path}}\\\"\\u003EAdvanced search\\u003C/a\\u003E\\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Ch2 class=\\\"search-title js-search-title\\\"\\u003EResults for \\u003Cstrong class=\\\"search-query\\\"\\u003E{{pretty_query}}\\u003C/strong\\u003E\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/is_new_search_header_available}}\\u000a\\u000a  {{\\u003Eonebox}}\\u000a\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Cspan class=\\\"content-header-buttons js-header-button-container\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u000a    \\u000a    \\u003Cspan class=\\\"js-stream-title\\\"\\u003E\\u003C/span\\u003E&nbsp;\\u003Csmall class=\\\"view-toggler js-view-toggler\\\"\\u003E\\u003C/small\\u003E\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_spam_menu: \"{{^is_my_tweet}}\\u000a  {{#user}}\\u000a    \\u000a    \\u000a    \\u003Cdiv class=\\\"tweet-spam-experiment {{tweet_experiment_spam_threat_class}}\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"tweet-user-actions\\\"\\u003E\\u000a        {{\\u003Euser_actions}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/user}}\\u000a{{/is_my_tweet}}\",\n            tweet_stats: \"{{%TRANSLATION-HINT mode=user_stats}}\\u000a\\u000a\\u003Cul class=\\\"stats{{^include_activity_popup}} no-activity-popup{{/include_activity_popup}}\\\"\\u003E\\u000a  {{#has_retweets}}\\u000a    \\u003Cli class=\\\"js-stat-count js-stat-retweets stat-count\\\"\\u003E\\u000a      \\u003Ca\\u000a        {{#include_activity_popup}}\\u000a          class=\\\"request-retweeted-popup\\\"\\u000a          data-activity-popup-title=\\\"{{\\u003Edialogs/retweeted_popup_title}}\\\"\\u000a        {{/include_activity_popup}}\\u000a      \\u003E\\u000a        \\u000a          {{#retweeters_length_one}}\\u003Cstrong\\u003E{{retweets_count}}\\u003C/strong\\u003E Retweet{{/retweeters_length_one}}\\u000a          {{#retweeters_length_other}}\\u003Cstrong\\u003E{{retweets_count}}\\u003C/strong\\u003E Retweets{{/retweeters_length_other}}\\u000a        \\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/has_retweets}}\\u000a\\u000a  {{#has_favorites}}\\u000a    \\u003Cli class=\\\"js-stat-count js-stat-favorites stat-count\\\"\\u003E\\u000a      \\u003Ca\\u000a        {{#include_activity_popup}}\\u000a          class=\\\"request-favorited-popup\\\"\\u000a          data-activity-popup-title=\\\"{{\\u003Edialogs/favorited_popup_title}}\\\"\\u000a        {{/include_activity_popup}}\\u000a      \\u003E\\u000a        {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a          \\u000a            {{#favoriters_length_one}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Favorite{{/favoriters_length_one}}\\u000a            {{#favoriters_length_other}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Favorites{{/favoriters_length_other}}\\u000a          \\u000a        {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_like}}\\u000a          \\u000a            {{#favoriters_length_one}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Like{{/favoriters_length_one}}\\u000a            {{#favoriters_length_other}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Likes{{/favoriters_length_other}}\\u000a          \\u000a        {{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_star}}\\u000a          \\u000a            {{#favoriters_length_one}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Star{{/favoriters_length_one}}\\u000a            {{#favoriters_length_other}}\\u003Cstrong\\u003E{{favorites_count}}\\u003C/strong\\u003E Stars{{/favoriters_length_other}}\\u000a          \\u000a        {{/australian_fav_to_star}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/has_favorites}}\\u000a\\u000a  \\u003Cli class=\\\"avatar-row js-face-pile-container\\\"\\u003E\\u000a    {{#face_pile}}\\u000a      {{\\u003Euser_avatar_link_24}}\\u000a    {{/face_pile}}\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            tweet_text_large: \"\\u003Cdiv class='tweet-text tweet-text-large'\\u003E{{{linkified_text}}}\\u003C/div\\u003E\",\n            typeahead: \"\\u003Cdiv class=\\\"dropdown-menu typeahead\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"dropdown-caret\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"caret-outer\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"caret-inner\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"dropdown-inner js-typeahead-results\\\"\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            typeahead_account_item: \"\\u003Cli data-user-id=\\\"{{id}}\\\" data-user-screenname=\\\"{{screen_name}}\\\" data-remote=\\\"true\\\" data-score=\\\"{{score}}\\\" class=\\\"typeahead-item js-selectable\\\"\\u003E\\u000a  \\u003Ca href=\\\"#\\\"{{{debug_info}}}\\u003E\\u000a    \\u003Cimg src=\\\"{{avatar}}\\\" width=\\\"24\\\" height=\\\"24\\\" class=\\\"avatar size24\\\"\\u003E\\u000a    \\u003Cspan class=\\\"fullname\\\"\\u003E{{name}}\\u003C/span\\u003E\\u000a    {{{verified}}}\\u000a    \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a  \\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            typeahead_accounts: \"\\u003Cdiv class=\\\"typeahead-accounts js-typeahead-accounts\\\"\\u003E\\u000a  \\u003Cul class=\\\"typeahead-items\\\"\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            typeahead_accounts_shortcut: \"\\u003Cli class=\\\"js-selectable js-shortcut\\\"\\u003E\\u003Ca href=\\\"{{user_search_path}}\\\" data-search-query=\\\"{{query}}\\\" data-query-source=\\\"{{search_query_source}}\\\" data-shortcut=\\\"true\\\"\\u003ESearch all people for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\",\n            typeahead_saved_searches: \"\\u003Cdiv class=\\\"js-typeahead-saved-searches\\\"\\u003E\\u000a  \\u003Cul class=\\\"typeahead-items typeahead-searches\\\"\\u003E\\u000a  {{#searches}}\\u000a    {{\\u003Etypeahead_saved_search_item}}\\u000a  {{/searches}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            typeahead_search_item: \"\\u003Cli class=\\\"js-selectable search-item\\\" data-hint=\\\"{{name}}\\\"\\u003E\\u000a  \\u003Ca href=\\\"{{search_results_path}}\\\" data-search-query=\\\"{{query}}\\\" data-query-source=\\\"{{search_query_source}}\\\"{{{debug_info}}}\\u003E\\u003Ci class=\\\"generic-search\\\"\\u003E\\u003C/i\\u003E{{name}}\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\",\n            typeahead_search_shortcut_items: \"{{#query}}\\u000a  \\u003Cli class=\\\"js-selectable {{^jump_to_profile}}selected{{/jump_to_profile}}\\\"\\u003E\\u003Ca href=\\\"{{search_results_path}}\\\" data-search-query=\\\"{{query}}\\\" data-query-source=\\\"{{search_query_source}}\\\" data-shortcut=\\\"true\\\"\\u003ESearch for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a{{/query}}\",\n            typeahead_search_shortcuts: \"\\u003Cdiv class=\\\"typeahead-shortcuts js-typeahead-shortcuts\\\"\\u003E\\u000a  \\u003Cul class=\\\"typeahead-items\\\"\\u003E\\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            unable_to_send_error_message: \"{{#message_for_flash}}\\u000a  {{message_for_flash}}\\u000a{{/message_for_flash}}\\u000a{{^message_for_flash}}\\u000a  Your message could not be sent.\\u000a{{/message_for_flash}}\\u000a\",\n            unclickable_tweet: \"\\u003Cdiv class=\\\"unfocusable-stream-item stream-item\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweet js-unclickable-tweet unclickable-tweet {{\\u003Ecommon_tweet_classes}}\\\"\\u000a    {{\\u003Etweet_data}}\\u003E\\u000a    \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a        {{#user}}\\u000a          \\u003Cspan class=\\\"account-group\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a            \\u003Cstrong class=\\\"fullname\\\"\\u003E{{name}}\\u003C/strong\\u003E\\u000a            \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a            {{#protected}}\\u000a              \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/protected}}\\u000a          \\u003C/span\\u003E\\u000a        {{/user}}\\u000a        \\u003Csmall class=\\\"time\\\"\\u003E\\u000a          {{short_timestamp}}\\u000a        \\u003C/small\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cp\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a      \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a        {{\\u003Etweet_context}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            unfollow_button: \"{{%TRANSLATION-HINT mode=actions}}\\u000a\\u003Cdiv class=\\\"button js-action-unfollow js-button unfollow-button\\\" data-user-id=\\\"{{id}}\\\" {{{account_impression_id}}}\\u003E\\u000a  \\u003Cspan class=\\\"you-follow\\\" /\\u003E\\u000a  \\u003Cem class=\\\"wrapper\\\"\\u003E\\u000a    \\u003Cb class=\\\"unfollow\\\"\\u003EUnfollow\\u003C/b\\u003E\\u000a    \\u003Cb\\u003EFollowing\\u003C/b\\u003E\\u000a  \\u003C/em\\u003E\\u000a\\u003C/div\\u003E\",\n            unfollow_link: \"\\u003Ca href=\\\"#\\\" class=\\\"user-unfollow-link js-action-unfollow js-link unfollow-action\\\" data-user-id=\\\"{{id}}\\\"\\u003EUnfollow\\u003C/a\\u003E\",\n            user: \"\\u003Cimg src='{{profile_image_url}}' alt='{{name}}' class='thumb user-profile-link' data-user-id='{{id}}'/\\u003E\\u000a\\u003Cspan class='user-name'\\u003E\\u000a  \\u003Ca class='user-profile-link' data-user-id='{{id}}' href='#' title='{{name}}'\\u003E\\u003Cstrong\\u003E{{screen_name}}\\u003C/strong\\u003E\\u003C/a\\u003E\\u000a  \\u003Cspan class='full-name'\\u003E{{name}}\\u003C/span\\u003E\\u000a\\u003C/span\\u003E\\u000a\",\n            user_actions: \"\\u003Cdiv class=\\\"user-actions btn-group {{follow_state}} {{#dismissable}}dismissable{{/dismissable}}\\\" data-user-id=\\\"{{id}}\\\"\\u000a    data-screen-name=\\\"{{screen_name}}\\\" data-name=\\\"{{name}}\\\" data-protected=\\\"{{protected_string}}\\\"\\u003E\\u000a\\u000a  {{#swapped_user_actions}}\\u000a    {{^follow_button_only}}\\u000a      {{\\u003Euser_actions_dropdown}}\\u000a    {{/follow_button_only}}\\u000a\\u000a    {{^menu_follow_actions}}\\u000a      {{\\u003Euser_actions_follow_button}}\\u000a    {{/menu_follow_actions}}\\u000a  {{/swapped_user_actions}}\\u000a\\u000a  {{^swapped_user_actions}}\\u000a    {{^menu_follow_actions}}\\u000a      {{\\u003Euser_actions_follow_button}}\\u000a    {{/menu_follow_actions}}\\u000a\\u000a    {{^follow_button_only}}\\u000a      {{\\u003Euser_actions_dropdown}}\\u000a    {{/follow_button_only}}\\u000a  {{/swapped_user_actions}}\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            user_actions_dropdown: \"{{%TRANSLATION-HINT mode=actions}}\\u000a{{#logged_in}}\\u000a  \\u003Cspan class=\\\"user-dropdown js-link{{^user_dropdown_icon_only}} btn{{/user_dropdown_icon_only}}\\\"\\u003E\\u000a    \\u003Ci class=\\\"account-arrow\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Ci class=\\\"mark-as-spam-silhouette\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Ci class=\\\"mark-as-spam-flag\\\"\\u003E\\u003C/i\\u003E\\u000a    \\u003Csmall class=\\\"mark-as-spam-text\\\"\\u003ESpam?\\u003C/small\\u003E\\u000a    \\u003Cul class=\\\"dropdown-menu\\\"\\u003E\\u000a      \\u003Cli class=\\\"dropdown-caret\\\"\\u003E\\u000a        \\u003Cspan class=\\\"caret-outer\\\"\\u003E\\u003C/span\\u003E\\u000a        \\u003Cspan class=\\\"caret-inner\\\"\\u003E\\u003C/span\\u003E\\u000a      \\u003C/li\\u003E\\u000a      {{#menu_follow_actions}}\\u000a        \\u003Cli class=\\\"unfollow-text pretty-link dropdown-link\\\"\\u003EUnfollow \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"cancel-text pretty-link dropdown-link\\\"\\u003ECancel Follow Request\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"dropdown-divider pending is-following\\\"\\u003E\\u000a      {{/menu_follow_actions}}\\u000a      \\u003Cli class=\\\"mention-text pretty-link dropdown-link not-blocked\\\"\\u003ETweet to \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/li\\u003E\\u000a      {{#include_direct_message_dialog}}\\u003Cli class=\\\"dm-text dropdown-link\\\"\\u003ESend a Direct Message\\u003C/li\\u003E{{/include_direct_message_dialog}}\\u000a      \\u003Cli class=\\\"list-text pretty-link dropdown-link not-blocked\\\"\\u003EAdd or remove from lists&hellip;\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"dropdown-divider not-blocked\\\"\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"block-text pretty-link dropdown-link not-blocked\\\"\\u003EBlock \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"unblock-text pretty-link dropdown-link\\\"\\u003EUnblock \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"report-spam-text pretty-link dropdown-link\\\"\\u003EReport \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}} for spam\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"hide-suggestion-text dropdown-link\\\"\\u003EHide this suggestion\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"dropdown-divider is-following\\\"\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"retweet-on-text dropdown-link\\\"\\u003ETurn on Retweets\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"retweet-off-text dropdown-link\\\"\\u003ETurn off Retweets\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"device-notifications-on-text dropdown-link\\\"\\u003ETurn on mobile notifications\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"device-notifications-off-text dropdown-link\\\"\\u003ETurn off mobile notifications\\u003C/li\\u003E\\u000a      {{#spam_threat}}\\u000a        \\u003Cli class=\\\"dropdown-divider not-spam-divider\\\"\\u003E\\u003C/li\\u003E\\u000a        \\u003Cli class=\\\"not-spam-text pretty-link dropdown-link\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}} is not spam\\u003C/li\\u003E\\u000a      {{/spam_threat}}\\u000a      {{#menu_follow_actions}}\\u000a        \\u003Cli class=\\\"follow-text pretty-link dropdown-link\\\"\\u003EFollow \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u003C/li\\u003E\\u000a      {{/menu_follow_actions}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/span\\u003E\\u000a{{/logged_in}}\\u000a\",\n            user_actions_follow_button: \"{{%TRANSLATION-HINT mode=actions}}\\u000a\\u003Cbutton class=\\\"js-follow-btn follow-button btn\\\" type=\\\"button\\\"\\u003E\\u000a  \\u003Cspan class=\\\"button-text follow-text\\\"\\u003E\\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003EFollow\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text following-text\\\"\\u003EFollowing\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text unfollow-text\\\"\\u003EUnfollow\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text blocked-text\\\"\\u003EBlocked\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text unblock-text\\\"\\u003EUnblock\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text pending-text\\\"\\u003EPending\\u003C/span\\u003E\\u000a  \\u003Cspan class=\\\"button-text cancel-text\\\"\\u003ECancel\\u003C/span\\u003E\\u000a\\u003C/button\\u003E\",\n            user_admin_tools: \"\\u000a{{#become_users}}\\u000a  \\u003Cli class=\\\"user-admin-tools\\\"\\u003E\\u003Cform class=\\\"dropdown-link-form become-user-form\\\" action=\\\"{{become_user_path}}\\\" method=\\\"POST\\\"\\u003E\\u003Ca class=\\\"become-user-button\\\" href=\\\"#\\\"\\u003EBecome @{{screen_name}}\\u003C/a\\u003E\\u003C/form\\u003E\\u003C/li\\u003E\\u000a{{/become_users}}\\u000a\\u000a{{#can_investigate}}\\u000a  \\u003Cli class=\\\"user-admin-tools\\\"\\u003E\\u003Ca href=\\\"{{admin_find_path}}\\\" title=\\\"Investigate!\\\" target=\\\"_blank\\\"\\u003EInvestigate @{{screen_name}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a{{/can_investigate}}\",\n            user_avatar_link_24: \"\\u003Ca class=\\\"js-profile-popup-actionable js-user-tipsy\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\" original-title=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a  \\u003Cimg class=\\\"avatar size24 js-user-profile-link js-tooltip\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" title=\\\"{{name}}\\\"\\u003E\\u000a\\u003C/a\\u003E\",\n            user_detailed_list: \"{{#items}}\\u000a  {{\\u003Euser_detailed_list_item}}\\u000a{{/items}}\",\n            user_detailed_list_item: \"\\u003Cli class=\\\"user-detailed-list-item js-actionable-user\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  \\u003Ca href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\" class=\\\"user-profile-link user-thumb\\\"\\u003E\\u003Cimg src='{{profile_image_url}}' alt=\\\"{{screen_name}}\\\" /\\u003E\\u003C/a\\u003E\\u000a  \\u003Cdiv class=\\\"user-details {{lang}}\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"user-name-info\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-recommend-link user-profile-link user-screen-name\\\" data-user-id=\\\"{{id}}\\\" href='{{profile_path}}'\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a      \\u003Cspan class=\\\"user-full-name-and-action\\\"\\u003E\\u000a        \\u003Cspan class=\\\"user-full-name\\\"\\u003E{{name}}\\u003C/span\\u003E\\u000a        {{#verified}}\\u000a          \\u003Cspan class=\\\"verified-icon-small\\\" title=\\\"Verified Account\\\"\\u003E\\u003C/span\\u003E\\u000a        {{/verified}}\\u000a        {{#protected}}\\u000a          \\u003Cimg src=\\\"/phoenix/img/protected_small.gif\\\" /\\u003E\\u000a        {{/protected}}\\u000a        {{\\u003Euser_item_action}}\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#location}}\\u000a      \\u003Cdiv class=\\\"location\\\"\\u003E\\u000a        Location:&nbsp;\\u003Cspan class=\\\"location\\\"\\u003E{{location}}\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/location}}\\u000a    {{#linkified_description}}\\u000a      \\u003Cdiv class=\\\"bio\\\"\\u003E\\u000a        \\u003Cspan class=\\\"bio\\\"\\u003E{{{linkified_description}}}\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/linkified_description}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            user_dropdown: \"\\u003Cul class=\\\"user-dropdown\\\"\\u003E\\u000a  {{#twitter_ads_link_url}}\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{twitter_ads_link_url}}\\\" target=\\\"{{twitter_ads_link_target}}\\\"\\u003E{{twitter_ads_link_title}}\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  {{/twitter_ads_link_url}}\\u000a\\u000a  {{#is_translator}}\\u000a     \\u003Cli\\u003E\\u003Ca href=\\\"{{translation_tool_path}}\\\"\\u003ETranslate\\u003C/a\\u003E\\u003C/li\\u003E\\u000a  {{/is_translator}}\\u000a\\u000a  {{#contributor_account_info}}\\u000a    {{^is_contributing}}\\u000a      \\u003Cli\\u003E\\u003Ca href=\\\"{{settings_path}}\\\"\\u003ESettings\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/is_contributing}}\\u000a\\u000a    {{#is_contributing}}\\u000a      \\u003Cli\\u003E\\u003Cspan class=\\\"settings-disabled\\\" title=\\\"Settings disabled while contributing.\\\"\\u003ESettings\\u003C/span\\u003E\\u003C/li\\u003E\\u000a    {{/is_contributing}}\\u000a\\u000a    \\u003Cli\\u003E\\u003Ca href=\\\"{{support_path}}\\\"\\u003EHelp\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u000a    {{#can_access_oldtwitter}}\\u000a    {{^is_contributing}}\\u000a      \\u003Cli\\u003E\\u000a        \\u003Cform method=\\\"post\\\" action=\\\"{{turn_phx_off_path}}\\\" class=\\\"turn-phx-off-form\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"setting\\\" value=\\\"false\\\"\\u003E\\u000a          \\u003Cinput type=\\\"hidden\\\" name=\\\"format\\\" value=\\\"html\\\"\\u003E\\u000a          \\u003Cinput type='hidden' value='' name='authenticity_token' class='authenticity_token'\\u003E\\u000a          \\u003Cbutton type=\\\"submit\\\" class=\\\"turn-phx-off-button\\\"\\u003ESwitch to Old Twitter\\u003C/button\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/li\\u003E\\u000a    {{/is_contributing}}\\u000a    {{/can_access_oldtwitter}}\\u000a\\u000a    \\u003Cli\\u003E\\u000a      \\u003Cform id=\\\"signout-form\\\" action=\\\"{{logout_action_path}}\\\" method=\\\"POST\\\"\\u003E\\u000a        \\u003Ca class=\\\"signout-button js-signout-button\\\" href=\\\"#\\\"\\u003ESign out\\u003C/a\\u003E\\u000a        \\u003Cinput type='hidden' value='' name='authenticity_token' class='authenticity_token' /\\u003E\\u000a        \\u003Cinput type='hidden' name='reliability_event' class='js-reliability-event'\\u003E\\u000a        \\u003Cinput type='hidden' name='scribe_log' /\\u003E\\u000a      \\u003C/form\\u003E\\u000a    \\u003C/li\\u003E\\u000a\\u000a    {{#is_admin}}\\u000a      \\u003Cli\\u003E\\u003Cspan\\u003EAdmin Tools\\u003C/span\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli class=\\\"admin-panel-link\\\"\\u003E\\u003Ca href=\\\"{{admin_home_path}}\\\" title=\\\"Admin panel\\\"\\u003EAdmin panel\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/is_admin}}\\u000a\\u000a    {{#can_contribute}}\\u000a      \\u003Cli\\u003E\\u003Cspan\\u003ESwitch Account\\u003C/span\\u003E\\u003C/li\\u003E\\u000a      {{#is_contributing}}\\u000a        {{#real_identity}}\\u000a          \\u003Cli class=\\\"contributor-account-link\\\" data-profile-image-url=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\"\\u003E\\u000a            \\u003Ca href=\\\"/account_switch/destroy\\\"\\u003E\\u000a              \\u003Cimg width=\\\"20\\\" height=\\\"20\\\" /\\u003E{{screen_name}}\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/real_identity}}\\u000a      {{/is_contributing}}\\u000a      {{#contributable_accounts}}\\u000a        \\u003Cli class=\\\"contributor-account-link\\\" data-profile-image-url=\\\"{{#is_ssl}}{{profile_image_url_https}}{{/is_ssl}}{{^is_ssl}}{{profile_image_url}}{{/is_ssl}}\\\"\\u003E\\u000a          \\u003Ca href=\\\"/account_switch/create/{{id}}\\\"\\u003E\\u000a            \\u003Cimg width=\\\"20\\\" height=\\\"20\\\" /\\u003E{{screen_name}}\\u000a          \\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a      {{/contributable_accounts}}\\u000a    {{/can_contribute}}\\u000a  {{/contributor_account_info}}\\u000a\\u003C/ul\\u003E\\u000a\",\n            user_dropdown_item: \"\\u003Cli class=\\\"{{className}} profactions\\\"\\u003E\\u000a  {{#checkbox}}\\u000a    \\u003Cinput id=\\\"{{id}}\\\" type=\\\"checkbox\\\" style=\\\"float:left\\\" {{#isChecked}}checked{{/isChecked}}/\\u003E\\u000a  {{/checkbox}}\\u000a  {{#icon}}\\u000a    \\u003Cspan class=\\\"list {{icon}}\\\"\\u003E\\u003C/span\\u003E\\u000a  {{/icon}}\\u000a  \\u003Cb class=\\\"item-name\\\"\\u003E{{{label}}}\\u003C/b\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            user_full_name: \"\\u003Cspan class=\\\"user\\\" data-user-id='{{id}}'\\u003E{{name}}\\u003C/span\\u003E\",\n            user_image_128: \"\\u000a\\u003Cimg height=\\\"128\\\" width=\\\"128\\\" src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\" class=\\\"avatar size128 js-action-profile-avatar\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a\",\n            user_image_16: \"\\u003Cimg height=\\\"16\\\" width=\\\"16\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" title=\\\"{{screen_name}}\\\" class=\\\"avatar size16 user-profile-link\\\" data-user-id=\\\"{{id}}\\\"\\u003E\",\n            user_image_24: \"\\u003Cimg height=\\\"24\\\" width=\\\"24\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" title=\\\"{{screen_name}}\\\" class=\\\"avatar size24\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a\",\n            user_image_32: \"\\u003Cimg height=\\\"32\\\" width=\\\"32\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\" title=\\\"{{screen_name}}\\\" class=\\\"avatar size32\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a\",\n            user_item_action: \"{{#swift}}\\u000a  \\u003Cspan class=\\\"user-actions {{follow_state}}\\\" data-user-id=\\\"{{id}}\\\" {{#protected}}data-protected=\\\"true\\\"{{/protected}}\\u003E\\u000a    \\u003Ca href=\\\"#\\\" class=\\\"follow-link\\\"\\u003E\\u000a      \\u003Cspan class=\\\"link-text follow-text\\\"\\u003EFollow\\u003C/span\\u003E\\u000a      \\u003Cspan class=\\\"link-text unfollow-text\\\"\\u003EUnfollow\\u003C/span\\u003E\\u000a      \\u003Cspan class=\\\"link-text cancel-text\\\"\\u003ECancel\\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/span\\u003E\\u000a{{/swift}}\\u000a{{^swift}}\\u000a  \\u003Cspan class=\\\"js-follow-state follow-state\\\"\\u003E\\u000a    {{^following}}\\u000a      {{^is_current_user}}\\u000a        \\u003Ca href=\\\"#\\\" class=\\\"js-action-follow js-link\\\" data-user-id=\\\"{{id}}\\\"\\u003EFollow\\u003C/a\\u003E\\u000a      {{/is_current_user}}\\u000a      {{#is_current_user}}\\u000a        \\u003Ca href=\\\"{{settings_profile_path}}\\\" class=\\\"js-thats-you js-link\\\" data-user-id=\\\"{{id}}\\\"\\u003EEdit profile\\u003C/a\\u003E\\u000a      {{/is_current_user}}\\u000a    {{/following}}\\u000a    {{#following}}\\u003Cspan\\u003EFollowing\\u003C/span\\u003E{{/following}}\\u000a  \\u003C/span\\u003E\\u000a{{/swift}}\\u000a\",\n            user_large_list: \"{{#items}}\\u000a  {{\\u003Ebig_avatar_list_item}}\\u000a{{/items}}\\u000a\",\n            user_media_not_displayed: \"\\u003Cli class=\\\"user-media-not-displayed facets-media-not-displayed list-link\\\"\\u003E\\u000a \\u003Cdiv\\u003E\\u000a   \\u003Ca class=\\\"header\\\"\\u003ERecent images\\u003C/a\\u003E\\u000a   \\u003Cp class=\\\"not-displayed-text metadata\\\"\\u003E{{{reason}}}\\u003C/p\\u003E\\u000a   \\u003Ca class=\\\"btn small display-this-media\\\"\\u003E\\u000a     Display media\\u000a   \\u003C/a\\u003E &middot;\\u000a   {{#logged_in}}\\u000a   \\u003Ca href=\\\"#\\\" class=\\\"always-display-media\\\"\\u003EAlways display media\\u003C/a\\u003E\\u000a   {{/logged_in}}\\u000a \\u003C/div\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            user_not_found_error_message: \"{{#dm_recipient}}\\u000a  The user @{{dm_recipient}} does not exist.\\u000a{{/dm_recipient}}\\u000a{{^dm_recipient}}\\u000a  This user does not exist.\\u000a{{/dm_recipient}}\\u000a\",\n            user_recommendations_dropdown: \"\\u003Cdiv class=\\\"js-user-dropdown user-rec-dropdown profile-actions\\\"\\u003E\\u000a  \\u003Ca href=\\\"#\\\" class=\\\"js-user-dropdown-dismiss dismiss\\\"\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    You might also want to follow:\\u000a  \\u003C/h2\\u003E\\u000a  \\u003Cul class=\\\"recommended-followers user-rec-component\\\"\\u003E\\u000a    {{#recommended_followers}}\\u000a      {{\\u003Euser_small_list}}\\u000a    {{/recommended_followers}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\",\n            user_similarities_dashboard_list: \"\\u000a\\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"js-users-list stream-items \\\"\\u003E\\u000a    {{#rendering_on_server}}\\u000a      {{#items}}\\u000a        \\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a          {{\\u003Estream_user}}\\u000a        \\u003C/div\\u003E\\u000a      {{/items}}\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            user_similarities_list: \"\\u000a\\u003Cdiv class=\\\"content-main user-similarities-list breakable\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Csmall class=\\\"pull-right\\\"\\u003E\\u003Ca href=\\\"#\\\" class=\\\"js-close\\\"\\u003EClose\\u003C/a\\u003E\\u003C/small\\u003E\\u000a      \\u003Ch2\\u003E\\u000a        You might also want to follow:\\u000a      \\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-users-list stream-items\\\"\\u003E\\u000a      {{#rendering_on_server}}\\u000a        {{#items}}\\u000a          \\u003Cdiv class=\\\"stream-item{{#last_item}} stream-end-item{{/last_item}}\\\"\\u003E\\u000a            {{\\u003Estream_user}}\\u000a          \\u003C/div\\u003E\\u000a        {{/items}}\\u000a      {{/rendering_on_server}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            user_small_list: \"{{#items}}\\u000a  {{\\u003Euser_small_list_item}}\\u000a{{/items}}\\u000a\",\n            user_small_list_item: \"{{#is_withheld}}\\u000a  {{\\u003Euser_small_list_item_withheld}}\\u000a{{/is_withheld}}\\u000a{{^is_withheld}}\\u000a\\u003Cdiv class=\\\"js-account-summary account-summary js-actionable-user{{#promoted_content}} promoted-account js-profile-popup-actionable{{/promoted_content}}{{#small_avatar}} account-summary-small{{/small_avatar}}{{#protected}} js-protected{{/protected}}\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}} {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}\\u003E\\u000a  {{#dismissable}}\\u000a  \\u003Cdiv class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003C/div\\u003E\\u000a  {{/dismissable}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-recommend-link js-user-profile-link user-thumb\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u000a      \\u003Cimg class=\\\"avatar js-action-profile-avatar {{#small_avatar}}size32{{/small_avatar}}\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a      \\u003Cspan class=\\\"account-group-inner js-action-profile-name\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a        \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a        \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cspan class=\\\"js-username\\\"\\u003E{{screen_name}}\\u003C/span\\u003E\\u003C/span\\u003E\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a\\u000a    \\u003Csmall class=\\\"metadata social-context\\\"\\u003E\\u000a      {{#rendering_on_server}}\\u000a        {{#first_connection}}\\u000a          \\u000a            {{#connections_count_one}}\\u000a              Followed by \\u003Ca class='pretty-link user-profile-link js-user-profile-link' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E{{name}}\\u003C/a\\u003E\\u000a            {{/connections_count_one}}\\u000a            {{#connections_count_other}}\\u000a              Followed by \\u003Ca class='pretty-link user-profile-link js-user-profile-link' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E{{name}}\\u003C/a\\u003E and \\u003Ca href=\\\"{{followers_you_follow_path}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003Eothers\\u003C/b\\u003E\\u003C/a\\u003E\\u000a            {{/connections_count_other}}\\u000a          \\u000a        {{/first_connection}}\\u000a      {{/rendering_on_server}}\\u000a      {{^rendering_on_server}}\\u000a        {{{socialcontext}}}\\u000a      {{/rendering_on_server}}\\u000a    \\u003C/small\\u003E\\u000a\\u000a    {{#is_sponsored}}\\u000a      \\u003Csmall class=\\\"metadata with-icn js-disclosure js-tooltip\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"js-promoted-badge js-user-profile-link\\\"\\u003E\\u000a          \\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003EPromoted\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/small\\u003E &middot;\\u000a    {{/is_sponsored}}\\u000a    {{\\u003Euser_item_action}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{/is_withheld}}\\u000a\",\n            user_small_list_item_sponsored: \"  \\u003Ca class=\\\"icon-link tweet-context promoted-arrow js-promoted-badge js-user-profile-link {{#socialcontext}}socialcontext{{/socialcontext}}\\\" href=\\\"{{profile_path}}\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u000a    {{\\u003Epromoted_icon}}\\u000a  \\u003C/a\\u003E\\u000a  {{#socialcontext}}\\u000a     &middot;\\u000a    {{{socialcontext}}}\\u000a  {{/socialcontext}}\\u000a\",\n            user_small_list_item_withheld: \"\\u003Cdiv class=\\\"js-account-summary account-summary js-actionable-user{{#promoted_content}} promoted-account js-profile-popup-actionable{{/promoted_content}}{{#small_avatar}} account-summary-small{{/small_avatar}}{{#protected}} js-protected{{/protected}}\\\" data-user-id=\\\"{{id}}\\\" {{{feedback_token}}} {{{account_impression_id}}}\\u003E\\u000a  {{#dismissable}}\\u000a  \\u003Cdiv class=\\\"dismiss js-action-dismiss\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003C/div\\u003E\\u000a  {{/dismissable}}\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Ca class=\\\"account-group js-recommend-link js-user-profile-link user-thumb\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a      \\u000a      \\u003Cspan class=\\\"account-group-inner js-action-profile-name\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a        \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a        {{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E{{/verified}}\\u000a        \\u003Cs\\u003E@\\u003C/s\\u003E{{screen_name}}\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/a\\u003E\\u000a\\u000a    \\u003Csmall class=\\\"metadata social-context\\\"\\u003E{{{socialcontext}}}\\u003C/small\\u003E\\u000a\\u000a    {{#is_sponsored}}\\u000a      \\u003Csmall class=\\\"metadata with-icn js-disclosure js-tooltip\\\" title=\\\"{{#promoted_content}}{{disclosure_text}}{{/promoted_content}}\\\"\\u003E\\u000a        \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"js-promoted-badge js-user-profile-link\\\"\\u003E\\u000a          \\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003EPromoted\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/small\\u003E &middot;\\u000a    {{/is_sponsored}}\\u000a    {{\\u003Euser_item_action}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            user_static_list: \"{{#items}}\\u000a  {{\\u003Euser_static_list_item}}\\u000a{{/items}}\",\n            user_static_list_item: \"\\u003Ca class=\\\"user-static-list-item\\\" href=\\\"#\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a  \\u003Cspan class=\\\"user-thumb\\\"\\u003E\\u000a    \\u003Cimg class=\\\"avatar size64 js-user-tipsy\\\" src=\\\"{{bigger_profile_image_url}}\\\" alt=\\\"{{name}}\\\" original-title=\\\"{{name}}\\\"\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/a\\u003E\\u000a\",\n            user_stats: \"\\u003Cul class='user-stats clearfix'\\u003E\\u000a    {{#can_view}}\\u000a      \\u003Cli\\u003E\\u003Ca class='user-stats-count user-stats-tweets' href=\\\"{{profile_path}}\\\"\\u003E{{statuses_count_commaized}}\\u003Cspan class='user-stats-stat'\\u003ETweets\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    {{/can_view}}\\u000a    \\u003Cli\\u003E\\u003Ca class='user-stats-count user-stats-following' href=\\\"{{user_following_path}}\\\"\\u003E{{friends_count_commaized}}\\u003Cspan class='user-stats-stat'\\u003EFollowing\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca class='user-stats-count user-stats-followers' href=\\\"{{user_followers_path}}\\\"\\u003E{{followers_count_commaized}}\\u003Cspan class='user-stats-stat'\\u003EFollowers\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a    \\u003Cli\\u003E\\u003Ca class='user-stats-count user-stats-listed' href=\\\"{{user_memberships_path}}\\\"\\u003E{{listed_count_commaized}}\\u003Cspan class='user-stats-stat'\\u003EListed\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            user_thumb_list: \"\\u003Cul class='inline-list'\\u003E\\u000a  {{#items}}\\u000a    {{\\u003Euser_thumb_list_item}}\\u000a  {{/items}}\\u000a\\u003C/ul\\u003E\\u000a\",\n            user_thumb_list_item: \"\\u003Cli class=\\\"user-thumb-list-member {{#is_hidden}}hidden{{/is_hidden}}\\\"\\u003E\\u000a  \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"user-profile-link\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cimg src=\\\"{{mini_profile_image_url}}\\\" height=\\\"24\\\" width=\\\"24\\\" title=\\\"{{screen_name}}\\\" /\\u003E\\u003C/a\\u003E\\u000a\\u003C/li\\u003E\\u000a\",\n            verify_email_banner: \"\\u003Cdiv class=\\\"module module-banner\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module\\\"\\u003E\\u000a    {{#pending_new}}\\u000a      \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EConfirm your email address to access all of Twitter's features.\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EA confirmation message was sent to \\u003Cstrong\\u003E{{pending_email}}\\u003C/strong\\u003E.\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"second-banner-row\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn resend-confirmation-email-link\\\" href=\\\"#\\\"\\u003EResend confirmation\\u003C/a\\u003E\\u000a        \\u003Ca href=\\\"{{change_email_path}}\\\"\\u003EUpdate email address\\u003C/a\\u003E &middot;\\u000a        \\u003Ca href=\\\"{{email_help_path}}\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/pending_new}}\\u000a    {{#pending_changed}}\\u000a      \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EYou still need to confirm your email change.\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EA confirmation email was sent to \\u003Cstrong\\u003E{{pending_email}}\\u003C/strong\\u003E. Your email will not be changed until you complete this step!\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"second-banner-row\\\"\\u003E\\u000a        \\u003Ca class=\\\"btn resend-confirmation-email-link\\\" href=\\\"#\\\"\\u003EResend confirmation\\u003C/a\\u003E\\u000a        \\u003Ca href=\\\"{{change_email_path}}\\\"\\u003ECancel or update this email address\\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/pending_changed}}\\u000a    {{#pending_bouncing}}\\u000a      \\u003Cdiv class=\\\"first-banner-row\\\"\\u003E\\u000a        \\u003Cspan class=\\\"title\\\"\\u003EWhoops, we haven't been able to send email to your new address!\\u003C/span\\u003E\\u000a        \\u003Cspan\\u003EWe've tried sending confirmation emails to \\u003Cstrong\\u003E{{pending_email}}\\u003C/strong\\u003E but they are not getting delivered.\\u003C/span\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"second-banner-row\\\"\\u003E\\u000a        You can \\u003Ca href=\\\"{{change_email_path}}\\\"\\u003Echange to a different address\\u003C/a\\u003E or we can \\u003Ca href=\\\"#\\\" class=\\\"resend-confirmation-email-link\\\"\\u003Etry again\\u003C/a\\u003E.\\u000a      \\u003C/div\\u003E\\u000a    {{/pending_bouncing}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            verify_email_dialog: \"\\u003Cdiv {{#container_id}}id=\\\"{{container_id}}\\\" {{/container_id}}class=\\\"twttr-dialog-container\\\" style=\\\"visibility: hidden;\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"twttr-dialog\\\" style=\\\"top: 142px\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"twttr-dialog-inside\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"twttr-dialog-body clearfix\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"twttr-dialog-content twttr-dialog-verify-email\\\"\\u003E\\u000a          {{#abtest_email_verification_18_modal_dialog}}\\u000a            \\u003Ch2 class=\\\"verify-email\\\"\\u003EPlease verify your email address\\u003C/h2\\u003E\\u000a          {{/abtest_email_verification_18_modal_dialog}}\\u000a          {{#abtest_email_verification_18_overlay}}\\u000a            \\u003Ch2 class=\\\"verify-email\\\"\\u003EAlmost there!\\u003C/h2\\u003E\\u000a          {{/abtest_email_verification_18_overlay}}\\u000a          \\u003Cp class=\\\"verify-email-text\\\"\\u003E\\u000a            Twitter has sent an email to \\u003Cstrong\\u003E{{email}}\\u003C/strong\\u003E to verify your email address. You must \\u003Cstrong\\u003Eclick the link in the email\\u003C/strong\\u003E in order to verify your address and finish signing up on Twitter.\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp\\u003E\\u000a            If you do not receive this message in the next hour, you can \\u003Ca href=\\\"#\\\" class=\\\"send-verify-email\\\"\\u003Erequest another verification email\\u003C/a\\u003E or \\u003Ca href=\\\"{{change_email_path}}\\\" class=\\\"change-email\\\"\\u003Echange your email address\\u003C/a\\u003E.\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cdiv class=\\\"button ok-thanks\\\"\\u003E\\u003Cstrong\\u003EOK, thanks!\\u003C/strong\\u003E\\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            answer1: \"Live-tweeting a relevant event can increase your daily follower rate by 260%.\\u000a\",\n            answer2: \"Your audience loves to interact with you. Invite questions for a Twitter Q&A to increase your followers and engagement!\\u000a\",\n            answer3: \"Your followers will love your photos. Take pictures and share them via Twitter to help boost your engagement.\\u000a\",\n            blackberry: \"\\u003Cul class=\\\"page-canvas verification-list {{#is_mobile}}mobile{{/is_mobile}}\\\"\\u003E\\u000a  \\u003Cli class=\\\"verification-item active\\\" data-step=\\\"0\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"callout\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a      \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a        \\u003Cspan class=\\\"welcome\\\"\\u003E\\u000a          Sorry, this page is not yet supported on your device.  Please open the link on a different mobile device or desktop web browser.\\u000a        \\u003C/span\\u003E\\u000a      \\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\\u000a\",\n            callout: \"\\u003Cdiv class=\\\"callout\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a    \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a      \\u003Cspan class=\\\"{{^is_badged}}vit-step-not-verified{{/is_badged}}{{#is_badged}}vit-step-verified{{/is_badged}}\\\"\\u003E0\\u003C/span\\u003E\\u000a      {{#user_view}}\\u000a        {{^is_badged}}\\u000a          Hi {{name}}! You are three quick steps away from earning your verified badge.\\u000a        {{/is_badged}}\\u000a        {{#is_badged}}\\u000a          Hi {{name}}. Now that your account is verified, check out these tips:\\u000a        {{/is_badged}}\\u000a      {{/user_view}}\\u000a      \\u003Cspan class=\\\"help\\\"\\u003E\\u000a        Let us know if you need \\u003Ca href=\\\"{{{vit_help_link}}}\\\"\\u003Ehelp\\u003C/a\\u003E.\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/h2\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cspan class=\\\"{{^is_badged}}vit-step-not-verified{{/is_badged}}{{#is_badged}}vit-step-verified{{/is_badged}}\\\"\\u003E0\\u003C/span\\u003E\\u000a  \\u003Cdiv class=\\\"vit-onboarding-section-content movable\\\"\\u003E\\u000a    \\u003Cp\\u003ETwitter's verified badge is our way of making sure that this is you.\\u000a    \\u003Cspan class=\\\"verification-reason\\\"\\u003E\\u000a      Verified badges appear on your profile and here is why you may want one:\\u000a    \\u003C/span\\u003E\\u000a    \\u003C/p\\u003E\\u000a    \\u003Cul class=\\\"vit-onboarding-benefits-list clearfix\\\"\\u003E\\u000a      \\u003Cli\\u003E\\u000a      \\u003Ch2 class=\\\"benefits-heading\\\"\\u003EVerified accounts appear on top of search results\\u003C/h2\\u003E\\u000a      \\u003Cp\\u003EMake sure when people search for you, they find you.\\u003C/p\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u000a      \\u003Ch2 class=\\\"benefits-heading\\\"\\u003EVerified accounts are exclusive\\u003C/h2\\u003E\\u000a      \\u003Cp\\u003EOnly a select few people get the badge.\\u003C/p\\u003E\\u000a      \\u003C/li\\u003E\\u000a      \\u003Cli\\u003E\\u000a      \\u003Ch2 class=\\\"benefits-heading\\\"\\u003EYour followers know to follow the right you\\u003C/h2\\u003E\\u000a      \\u003Cp\\u003EDon't let fake accounts take away from your message.\\u003C/p\\u003E\\u000a      \\u003C/li\\u003E\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-footer movable\\\"\\u003E\\u000a  \\u003Cbutton class=\\\"btn primary-btn next start next-step\\\" type=\\\"submit\\\"\\u003EGet started\\u003C/button\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            learn_step: \"\\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"vit-step-number\\\" id=\\\"step-1\\\"\\u003E1\\u003C/span\\u003E\\u000a    Learn how to tweet effectively\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv id=\\\"learn-step\\\" class=\\\"vit-onboarding-section-content movable\\\"\\u003E\\u000a  \\u003Cul class=\\\"questions {{#is_badged}}step1-landing{{/is_badged}}\\\"\\u003E\\u000a    \\u003Cli class=\\\"question current\\\" id=\\\"1\\\"\\u003E\\u000a      \\u003Cp class=\\\"question-text\\\"\\u003EWhich Tweet will help double your rate of new followers for the day?\\u003C/p\\u003E\\u000a      \\u003Cform name=\\\"question-1\\\" class=\\\"vit-onboarding-answer-options\\\"\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option1\\\" for=\\\"ques1-opt1\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-1\\\" id=\\\"ques1-opt1\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_1}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EWatching the \\u003Ca href=\\\"\\\" onclick=\\\"return false;\\\"\\u003E#Oscars\\u003C/a\\u003E right now and I\\u2019m loving the fashion on the red carpet.\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-1\\\"\\u003E\\u000a          \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer1}}\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option2\\\" for=\\\"ques1-opt2\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-2\\\" id=\\\"ques1-opt2\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_2}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EI watched the \\u003Ca href=\\\"\\\" onclick=\\\"return false;\\\"\\u003E#Oscars\\u003C/a\\u003E last night.\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-1\\\"\\u003E\\u000a        \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer1}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/li\\u003E\\u000a\\u000a    \\u003Cli class=\\\"question\\\" id=\\\"2\\\"\\u003E\\u000a      \\u003Cp class=\\\"question-text\\\"\\u003EWhich Tweet will more of your followers engage with?\\u003C/p\\u003E\\u000a      \\u003Cform name=\\\"question-2\\\" class=\\\"vit-onboarding-answer-options\\\"\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option1\\\" for=\\\"ques2-opt1\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-1\\\" id=\\\"ques2-opt1\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_1}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EHi everybody, I have a few spare minutes to answer some questions. Who has one? \\u003Ca href=\\\"\\\" onclick=\\\"return false;\\\"\\u003E{{vit_example_hashtag}}\\u003C/a\\u003E\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-2\\\"\\u003E\\u000a          \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer2}}\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option2\\\" for=\\\"ques2-opt2\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-2\\\" id=\\\"ques2-opt2\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_2}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EI want to hear from you. What do you have to say?\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-2\\\"\\u003E\\u000a        \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer2}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/li\\u003E\\u000a\\u000a    \\u003Cli class=\\\"question last\\\" id=\\\"3\\\"\\u003E\\u000a      \\u003Cp class=\\\"question-text\\\"\\u003EWhich Tweet will get more clicks, favorites and retweets from your followers?\\u003C/p\\u003E\\u000a      \\u003Cform name=\\\"question-1\\\" class=\\\"vit-onboarding-answer-options\\\"\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option1\\\" for=\\\"ques3-opt1\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-1\\\" id=\\\"ques3-opt1\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_1}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EI\\u2019m backstage at the Grammys. See? It\\u2019s \\u003Ca href=\\\"\\\" onclick=\\\"return false;\\\"\\u003E@taylorswift13\\u003C/a\\u003E: \\u003Ca href=\\\"\\\" onclick=\\\"return false;\\\"\\u003Epic.twitter.com/...\\u003C/a\\u003E\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a        \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-3\\\"\\u003E\\u000a          \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer3}}\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u003Clabel class=\\\"vit-onboarding-sample-tweet option2\\\" for=\\\"ques3-opt2\\\"\\u003E\\u000a          \\u003Cinput type=\\\"radio\\\" name=\\\"answers\\\" value=\\\"option-2\\\" id=\\\"ques3-opt2\\\"\\u003E\\u000a          {{\\u003Evit/vit_example_2}}\\u000a          \\u003Cp class=\\\"tweet-text\\\"\\u003EBackstage at the Grammys, standing next to Taylor Swift.\\u003C/p\\u003E\\u000a        \\u003C/label\\u003E\\u000a      \\u003C/form\\u003E\\u000a      \\u003Cdiv class=\\\"vit-onboarding-answer\\\" id=\\\"answer-3\\\"\\u003E\\u000a        \\u003Cp class=\\\"answer-text\\\"\\u003E{{\\u003Evit/answer3}}\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-footer movable\\\"\\u003E\\u000a  \\u003Cbutton class=\\\"btn answer\\\" type=\\\"submit\\\"\\u003ESee answer\\u003C/button\\u003E\\u000a  \\u003Cbutton class=\\\"btn cancel skip\\\" type=\\\"cancel\\\"\\u003ESkip\\u003C/button\\u003E\\u000a  \\u003Cbutton class=\\\"btn next hidden next-step\\\" type=\\\"submit\\\"\\u003E\\u000a    \\u003Cspan class=\\\"next-step\\\"\\u003ENext step\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"continue\\\"\\u003EContinue\\u003C/span\\u003E\\u000a  \\u003C/button\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            JSBNG__onboarding: \"\\u003Cdiv id=\\\"vit-onboarding\\\"\\u003E\\u000a  {{#is_blackberry}}\\u000a    {{\\u003Evit/blackberry}}\\u000a  {{/is_blackberry}}\\u000a  {{^is_blackberry}}\\u000a  \\u003Cul class=\\\"page-canvas verification-list {{#is_mobile}}mobile{{/is_mobile}}\\\"\\u003E\\u000a\\u000a    \\u003Cli class=\\\"verification-item {{^is_badged}}active{{/is_badged}}{{#is_badged}}visited{{/is_badged}}\\\" data-step=\\\"0\\\"\\u003E\\u000a    {{\\u003Evit/callout}}\\u000a    \\u003C/li\\u003E\\u000a\\u000a    \\u003Cli class=\\\"verification-item {{#is_badged}}active visited{{/is_badged}}\\\" data-step=\\\"1\\\"\\u003E\\u000a    {{\\u003Evit/learn_step}}\\u000a    \\u003C/li\\u003E\\u000a\\u000a    \\u003Cli class=\\\"verification-item {{#is_badged}}visited{{/is_badged}}\\\" data-step=\\\"2\\\"\\u003E\\u000a    {{\\u003Evit/vits_to_follow}}\\u000a    \\u003C/li\\u003E\\u000a\\u000a    \\u003Cli class=\\\"verification-item last-verification-item {{#is_badged}}visited{{/is_badged}}\\\" data-step=\\\"3\\\"\\u003E\\u000a    {{\\u003Evit/phone_verification_step}}\\u000a    \\u003C/li\\u003E\\u000a\\u000a  \\u003C/ul\\u003E\\u000a  {{/is_blackberry}}\\u000a\\u003C/div\\u003E\\u000a\",\n            phone_verification_step: \"\\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"vit-step-number\\\" id=\\\"step-3\\\"\\u003E3\\u003C/span\\u003E\\u000a    Protect your account\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-content movable\\\"\\u003E\\u000a  \\u003Cp class=\\\"phone-merit\\\"\\u003EPhone numbers allow us to contact you in case there is security issue with your account:\\u003C/p\\u003E\\u000a  \\u003Cform id=\\\"phone-verify-form\\\" method=\\\"post\\\" action=\\\"/vit_onboard/verification_done\\\"\\u003E\\u000a    \\u003Cinput type=\\\"hidden\\\" value=\\\"{{form_authenticity_token}}\\\" name=\\\"authenticity_token\\\"/\\u003E\\u000a    \\u003Cdiv class=\\\"vit-onboarding-control-group\\\"\\u003E\\u000a      {{#phone_device}}\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"device[id]\\\" value=\\\"{{id}}\\\"\\u003E\\u000a      {{/phone_device}}\\u000a      \\u003Cdiv class=\\\"phone-number-field\\\"\\u003E\\u000a      \\u003Clabel class=\\\"phone-label\\\"\\u003E\\u003Cstrong\\u003EPhone\\u003C/strong\\u003E\\u003C/label\\u003E\\u000a      \\u003Cinput class=\\\"input-large vit-onboarding-tel-input\\\" type=\\\"tel\\\" value=\\\"{{#phone_device}}{{address}}{{/phone_device}}\\\" name=\\\"device[address]\\\" id=\\\"device_address\\\" placeholder=\\\"Phone number\\\"\\u003E\\u000a      \\u003Clabel class=\\\"control-label muted\\\"\\u003EIncluding country code\\u003C/label\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cp class=\\\"muted privacy-terms\\\"\\u003EWe will never distribute your personal information, nor use it for any other reason than to contact you in case of a security breach.\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/form\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-footer movable\\\"\\u003E\\u000a  \\u003Cbutton id=\\\"save-phone-number\\\" class=\\\"btn primary-btn\\\" type=\\\"submit\\\"\\u003ESave phone number to profile\\u003C/button\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            verification_done: \"\\u003Cdiv id=\\\"vit-onboarding\\\" class=\\\"verification-done\\\"\\u003E\\u000a  \\u003Cul class=\\\"page-canvas verification-list\\\"\\u003E\\u000a    \\u003Cli class=\\\"verification-item active last-verification-item\\\"\\u003E\\u000a    {{#user_view}}\\u000a      \\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a        \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a          \\u003Cspan class=\\\"vit-step-verified\\\"\\u003E&#10003;\\u003C/span\\u003E\\u000a          Congratulations, {{name}}! Your Twitter account is now verified.\\u000a        \\u003C/h2\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"vit-onboarding-section-content\\\"\\u003E\\u000a        {{\\u003Eprofiles/swift_profile_header}}\\u000a        \\u003Cdiv class=\\\"email-disclaimer\\\"\\u003E\\u000a        With your newly verified account, you will receive weekly activity reports with information about the number of people following you, and simple tips about how to increase that number. Stop getting the report by choosing \\\"unsubscribe\\\" in the email footer, or uncheck the box in your email notification settings in your profile settings.\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"vit-onboarding-section-footer\\\"\\u003E\\u000a        {{^is_mobile}}\\u000a          \\u003Ca class=\\\"btn next primary-btn\\\" href=\\\"{{profile_path}}\\\"\\u003E\\u000a            View your Twitter profile page\\u000a          \\u003C/a\\u003E\\u000a        {{/is_mobile}}\\u000a        {{#is_mobile}}\\u000a          \\u003Ch2 class=\\\"mobile-app-download-description muted\\\"\\u003ESimplify your mobile experience.\\u003C/h2\\u003E\\u000a          \\u003Ca class=\\\"btn next primary-btn\\\" href=\\\"/download\\\"\\u003E\\u000a            Download the Twitter app\\u000a          \\u003C/a\\u003E\\u000a        {{/is_mobile}}\\u000a      \\u003C/div\\u003E\\u000a    {{/user_view}}\\u000a    \\u003C/li\\u003E\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            vit_example_1: \"\\u003Cdiv class=\\\"tweet-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"avatar\\\"\\u003E\\u003C/div\\u003E\\u000a  {{#vit_example_1}}\\u000a    \\u003Cstrong class=\\\"fullname\\\"\\u003E{{fullname}}\\u003C/strong\\u003E\\u000a    \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{username}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a  {{/vit_example_1}}\\u000a\\u003C/div\\u003E\\u000a\",\n            vit_example_2: \"\\u003Cdiv class=\\\"tweet-header\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"avatar\\\"\\u003E\\u003C/div\\u003E\\u000a  {{#vit_example_2}}\\u000a    \\u003Cstrong class=\\\"fullname\\\"\\u003E{{fullname}}\\u003C/strong\\u003E\\u000a    \\u003Cspan class=\\\"username\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{username}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a  {{/vit_example_2}}\\u000a\\u003C/div\\u003E\\u000a\",\n            vits_to_follow: \"\\u003Cdiv class=\\\"vit-onboarding-section-header\\\"\\u003E\\u000a  \\u003Ch2 class=\\\"step-title\\\"\\u003E\\u000a    \\u003Cspan class=\\\"vit-step-number\\\" id=\\\"step-2\\\"\\u003E2\\u003C/span\\u003E\\u000a    Connect with other interesting Twitter users\\u000a  \\u003C/h2\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-content movable\\\"\\u003E\\u000a  \\u003Cp class=\\\"follow-merit\\\"\\u003EIncrease your trustworthiness by following other verified users:\\u003Cp\\u003E\\u000a  \\u003Cul class=\\\"vit-onboarding-stream-item-list stream-items\\\"\\u003E\\u000a    {{#vits_to_follow}}\\u000a    \\u003Cli class=\\\"vit-onboarding-stream-item stream-item\\\"\\u003E\\u000a    {{\\u003Estream_user}}\\u000a    \\u003C/li\\u003E\\u000a    {{/vits_to_follow}}\\u000a  \\u003C/ul\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"vit-onboarding-section-footer movable\\\"\\u003E\\u000a  \\u003Cbutton class=\\\"btn primary-btn next\\\" type=\\\"submit\\\"\\u003ENext step\\u003C/button\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            web_personalization_preview: \"\",\n            web_personalization_results: \"{{#has_recs}}\\u000a  \\u003Cdiv class=\\\"flex-module web-personalization-inner js-results\\\"\\u003E\\u000a    \\u003Cp\\u003EHere are some tailored suggestions. {{#logged_in}}In this preview, you may see some people you already follow.{{/logged_in}}\\u003C/p\\u003E\\u000a    \\u003Cul class=\\\"clearfix big-avatar-list\\\"\\u003E\\u000a      {{#items}}\\u000a        {{\\u003Ebig_avatar_list_item}}\\u000a      {{/items}}\\u000a    \\u003C/ul\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/has_recs}}\\u000a\\u000a{{^has_recs}}\\u000a  \\u003Cdiv class=\\\"flex-module web-personalization-inner web-personalization-empty js-results\\\"\\u003E\\u000a    \\u003Cp\\u003EIf you don&#8217;t see any suggestions here yet, that&#8217;s okay. It may take a little time. Check back in a few days.\\u003C/p\\u003E\\u000a    \\u003Ca href=\\\"{{home_path}}\\\" class=\\\"btn primary-btn\\\"\\u003E\\u000a      {{^abtest_timeline_copy_317_any_bucket}}\\u000a        {{#logged_in}}Back to timeline{{/logged_in}}\\u000a      {{/abtest_timeline_copy_317_any_bucket}}\\u000a      {{#abtest_timeline_copy_317_stream}}\\u000a        {{#logged_in}}Back to stream{{/logged_in}}\\u000a      {{/abtest_timeline_copy_317_stream}}\\u000a      {{^logged_in}}Twitter home{{/logged_in}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/has_recs}}\",\n            web_personalization_settings: \"\\u003Cdiv class=\\\"module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module web-personalization-header\\\"\\u003E\\u000a    {{^do_not_track}}\\u000a\\u000a      {{#logged_in}}\\u000a        \\u003Ch1\\u003ETailor Twitter to your interests\\u003C/h1\\u003E\\u000a      {{/logged_in}}\\u000a\\u000a      {{^logged_in}}\\u000a        \\u003Ch1\\u003EWelcome to Twitter\\u003C/h1\\u003E\\u000a      {{/logged_in}}\\u000a\\u000a    {{/do_not_track}}\\u000a\\u000a    {{#do_not_track}}\\u000a      \\u003Ch1\\u003ETwitter cannot provide tailored suggestions\\u003C/h1\\u003E\\u000a    {{/do_not_track}}\\u000a  \\u003C/div\\u003E\\u000a\\u000a  {{^loading}}\\u000a    {{^show_results}}\\u000a      {{^do_not_track}}\\u000a        \\u003Cdiv class=\\\"flex-module web-personalization-inner\\\"\\u003E\\u000a\\u000a          {{#logged_in}}\\u000a            \\u003Cp\\u003EPeople on Twitter are talking about things you care about. Now we\\u2019ve made it easier for you to find them. We\\u2019ve tailored our suggestions based on websites you\\u2019ve recently visited that have Twitter buttons or widgets.\\u003C/p\\u003E\\u000a          {{/logged_in}}\\u000a\\u000a          {{^logged_in}}\\u000a            \\u003Cp\\u003ETwitter connects people with the things they care about, and now we\\u2019ve made them even easier to find. Check out our suggestions for you based on websites you\\u2019ve recently visited that have Twitter buttons or widgets.\\u003C/p\\u003E\\u000a          {{/logged_in}}\\u000a\\u000a          \\u003Cp\\u003EFor example, if you visit sports websites, we might suggest teams and players that are popular and widely followed by other Twitter users that visit those sports websites.\\u003C/p\\u003E\\u000a          \\u003Cp\\u003E\\u003Ca href=\\\"{{cookie_personalization_learn_more_path}}\\\"\\u003ELearn more\\u003C/a\\u003E about how this works and your additional privacy controls.\\u003C/p\\u003E\\u000a\\u000a        \\u003C/div\\u003E\\u000a      {{/do_not_track}}\\u000a\\u000a      {{#do_not_track}}\\u000a        \\u003Cdiv class=\\\"flex-module web-personalization-inner\\\"\\u003E\\u000a          \\u003Cp\\u003E\\u000a            {{#in_eu}}Tailored suggestions are not currently available to you, and your visits to websites that have Twitter buttons or widgets are not collected to tailor your experience.{{/in_eu}}\\u000a            {{^in_eu}}Your browser has Do Not Track turned on. While Do Not Track is on, Twitter cannot provide tailored suggestions.{{/in_eu}}\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp\\u003E\\u003Ca href=\\\"{{cookie_personalization_learn_more_path}}\\\"\\u003ELearn more\\u003C/a\\u003E about how this works and your additional privacy controls.\\u003C/p\\u003E\\u000a          \\u003Cp\\u003E\\u000a            \\u003Ca href=\\\"{{home_path}}\\\" class=\\\"btn primary-btn\\\"\\u003E\\u000a              {{^abtest_timeline_copy_317_any_bucket}}\\u000a                {{#logged_in}}Back to timeline{{/logged_in}}\\u000a              {{/abtest_timeline_copy_317_any_bucket}}\\u000a              {{#abtest_timeline_copy_317_stream}}\\u000a                {{#logged_in}}Back to stream{{/logged_in}}\\u000a              {{/abtest_timeline_copy_317_stream}}\\u000a              {{^logged_in}}Twitter home{{/logged_in}}\\u000a            \\u003C/a\\u003E\\u000a          \\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/do_not_track}}\\u000a\\u000a      {{^do_not_track}}\\u000a        \\u003Cdiv class=\\\"flex-module web-personalization-footer\\\"\\u003E\\u000a          \\u003Cp\\u003E\\u000a            \\u003Cbutton class=\\\"js-web-personalization-allow btn primary-btn\\\"\\u003EOK\\u003C/button\\u003E\\u000a            \\u003Cbutton class=\\\"js-web-personalization-disallow btn\\\"\\u003ETurn off\\u003C/button\\u003E\\u000a          \\u003C/p\\u003E\\u000a          \\u003Cp\\u003EIf you don\\u2019t want tailored suggestions, you can turn off this feature. Then your visits to websites that have Twitter buttons or widgets will no longer be collected to tailor your experience.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/do_not_track}}\\u000a    {{/show_results}}\\u000a\\u000a    {{#show_results}}\\u000a      {{^results_loading}}\\u000a        {{#results}}\\u000a          {{\\u003Eweb_personalization_results}}\\u000a        {{/results}}\\u000a      {{/results_loading}}\\u000a      {{#results_loading}}\\u000a        \\u003Cdiv class=\\\"flex-module web-personalization-inner js-results\\\"\\u003E\\u000a          \\u003Cp\\u003E\\u003Cspan class=\\\"spinner\\\" title=\\\"Loading...\\\"\\u003E\\u003C/span\\u003E\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a      {{/results_loading}}\\u000a\\u000a      \\u003Cdiv class=\\\"flex-module web-personalization-footer\\\"\\u003E\\u000a        \\u003Cp\\u003E\\u000a          \\u003Cbutton class=\\\"js-web-personalization-turnoff btn\\\"\\u003ETurn off\\u003C/button\\u003E\\u000a        \\u003C/p\\u003E\\u000a        \\u003Cp\\u003EIf you don\\u2019t want tailored suggestions, you can turn off this feature. Then your visits to websites that have Twitter buttons or widgets will no longer be collected to tailor your experience. \\u003Ca href=\\\"{{cookie_personalization_learn_more_path}}\\\"\\u003ELearn more\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/show_results}}\\u000a  {{/loading}}\\u000a\\u000a  {{#loading}}\\u000a    \\u003Cdiv class=\\\"flex-module web-personalization-inner\\\"\\u003E\\u000a      \\u003Cp\\u003E\\u003Cspan class=\\\"spinner\\\" title=\\\"Loading...\\\"\\u003E\\u003C/span\\u003E\\u003C/p\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/loading}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{^loading}}\\u000a  {{#show_results}}\\u000a    {{^logged_in}}\\u000a      \\u003Cdiv class=\\\"module\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"flex-module web-personalization-signup js-web-personalization-signup\\\"\\u003E\\u000a          \\u003Ch2\\u003EJoin Twitter today\\u003C/h2\\u003E\\u000a          {{\\u003Epartial_signup_form}}\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    {{/logged_in}}\\u000a  {{/show_results}}\\u000a{{/loading}}\\u000a\",\n            welcome_ambassador: \"\\u003Cdiv class=\\\"user-details clearfix {{lang}}\\\"\\u003E\\u000a  \\u003Cimg src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"/\\u003E\\u000a  \\u003Ch4\\u003E\\u000a    You are now following \\u003Cstrong\\u003E{{name}}\\u003C/strong\\u003E\\u000a    {{#verified}}\\u000a      \\u003Cspan class=\\\"verified-icon\\\"\\u003E\\u003C/span\\u003E\\u000a    {{/verified}}\\u000a  \\u003C/h4\\u003E\\u000a  \\u003Cdiv\\u003E\\u000a    \\u003Cspan class=\\\"user-screen-name\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E\\u000a    \\u003Cspan class=\\\"location\\\"\\u003E{{location}}\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            welcome_device_follow: \"\\u003Cdiv class=\\\"twttr-dialog-device-follow\\\"\\u003E\\u000a  \\u003Cdiv\\u003EFollow these instructions to receive device notifications when your local lifeline account posts Tweets. It takes less than 2 minutes.\\u003C/div\\u003E\\u000a  \\u003Cdiv\\u003ESee \\u003Ca href=\\\"https://support.twitter.com/articles/20169887\\\" target=\\\"_blank\\\"\\u003Ethis\\u003C/a\\u003E for Smartphones.\\u003C/div\\u003E\\u000a  \\u003Cdiv\\u003E\\u000a    \\u003Col class=\\\"instructions\\\"\\u003E\\u000a      \\u003Cli\\u003EFrom your device, email \\u003Cstrong\\u003Everify@twtr.jp\\u003C/strong\\u003E or scan the QR code.\\u003Cimg class=\\\"qr-code\\\" src=\\\"/images/verify_at_twtrjp.png\\\" alt=\\\"twtrjp QR code\\\"\\u003E\\u003C/li\\u003E\\u000a      \\u003Cli\\u003EWe&#8217;ll send you an email with a link to confirm your device.\\u003C/li\\u003E\\u000a      \\u003Cli\\u003EClick on the link in the email and login.\\u003C/li\\u003E\\u000a    \\u003C/ol\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv\\u003EThat&#8217;s it! You&#8217;ll begin to receive notifications on your phone when the lifeline accounts sends Tweets.\\u003C/div\\u003E\\u000a  \\u003Cbutton type=\\\"button\\\" class=\\\"btn button device-follow-done-button\\\"\\u003EDone\\u003C/button\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            welcome_learn_flow: \"\\u003Cdiv class=\\\"dashboard js-dashboard\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"module welcome-header-module js-flow-step\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"module welcome-dashboard js-welcome-dashboard\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"js-welcome-stream-header\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"js-welcome-zipcode-search content-searchbar\\\" style=\\\"display: none;\\\"\\u003E\\u000a        \\u003Cform class=\\\"js-zipcode-search\\\" action=\\\"/#!/welcome/lifeline/search\\\" method=\\\"GET\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" value=\\\"\\\" name=\\\"q\\\" placeholder=\\\"Enter Your ZIP Code\\\"\\u003E\\u000a        \\u003Ci class=\\\"input-search js-submit\\\" style=\\\"display:block\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cp class=\\\"search-note\\\"\\u003EYour ZIP Code is used only for this search.\\u003C/p\\u003E\\u000a        \\u003C/form\\u003E\\u000a        \\u003Ca class=\\\"follow-btn btn small js not-following follow-all-btn\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"js-action-follow-all-listed follow-text\\\"\\u003E\\u000a            \\u003Ci class=\\\"follow\\\"\\u003E\\u003C/i\\u003EFollow all\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/a\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"js-welcome-search content-searchbar\\\" style=\\\"display: none;\\\"\\u003E\\u000a        \\u003Cform class=\\\"js-who-to-follow-search\\\" action=\\\"{{welcome_search_form_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a          \\u003Cspan class=\\\"input-search js-submit\\\"\\u003E\\u003Ci class=\\\"nav-search\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u000a          \\u003Cinput type=\\\"text\\\" value=\\\"\\\" name=\\\"q\\\" placeholder=\\\"Search for...\\\"\\u003E\\u000a        \\u003C/form\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"js-back-to-stream back-to-stream\\\"\\u003E\\u000a        \\u003Cspan class=\\\"js-button btn\\\"\\u003EBack \\u003C/span\\u003E\\u000a\\u000a        \\u003Ch3 class=\\\"js-dashboard-stream-title dashboard-stream-title\\\"\\u003E\\u003C/h3\\u003E\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"js-stream-header dashboard-stream-header\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"stream js-stream-manager-container stream-manager-container\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-content-container\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-back-to-import back-to-import\\\"\\u003E\\u003Ca href=\\\"{{welcome_import_path}}\\\"\\u003ETry another service\\u003C/a\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"js-welcome-dashboard-footer welcome-dashboard-footer\\\"\\u003E\\u000a      \\u003Ca class=\\\"js-skip-link skip-link\\\" href=\\\"{{welcome_recommendations_path}}\\\"\\u003ESkip this step &raquo;\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"content-main js-content-main breakable\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"content-header js-content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003E\\u000a        Preview\\u000a      \\u003C/h2\\u003E\\u000a      \\u003Cdiv class=\\\"example-tweet-info subheader\\\"\\u003E\\u000a        Examples of Tweets from people you choose to follow appear here. You&#8217;ll see your full timeline once you&#8217;re all set up.\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"js-tweet-preview-container\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"welcome-faux-tweet-stream js-welcome-faux-tweet-stream\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item stream-item js-intro-tweet\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"tweet js-unclickable-tweet unclickable-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a            \\u003Cspan class=\\\"account-group js-account-group js-action-profile\\\"\\u003E\\u000a              \\u003Cspan class=\\\"avatar-group\\\" \\u003E\\u000a                \\u003Cspan class=\\\"avatar {{^abtest_localized_image_welcome_flow_235_any_bucket}}welcome-teacher{{/abtest_localized_image_welcome_flow_235_any_bucket}}{{#abtest_localized_image_welcome_flow_235_japan_photo}}welcome-teacher-ab-photo{{/abtest_localized_image_welcome_flow_235_japan_photo}}{{#abtest_localized_image_welcome_flow_235_japan_drawing}}welcome-teacher-ab-drawing{{/abtest_localized_image_welcome_flow_235_japan_drawing}}\\\"/\\u003E\\u000a                \\u003Cspan class=\\\"avatar-well size48\\\"\\u003E\\u003C/span\\u003E\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cstrong class=\\\"fullname\\\"\\u003EThe Twitter Teacher\\u003C/strong\\u003E\\u000a            \\u003C/span\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E\\u000a              1 min\\u000a            \\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cp\\u003EThis is a Tweet. Tweets are short messages that have up to 140 characters and can contain links like \\u003Ca\\u003Ehttp://twitter.com\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u000a\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"component js-stream-end\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-end\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a        \\u003Ci class=\\\"bird-etched\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            welcome_learn_flow_background: \"\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"module welcome-header-module js-flow-step\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"flex-module header-half\\\"\\u003E\\u000a      \\u003Ch2\\u003EBuild your Twitter.\\u003C/h2\\u003E\\u000a      \\u003Cdiv class=\\\"subheading\\\"\\u003EGet started in less than 60 seconds.\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"flex-module progress-half\\\"\\u003E\\u000a      \\u003Ctable class=\\\"flex-table\\\"\\u003E\\u000a        \\u003Ctbody\\u003E\\u000a          \\u003Ctr\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-primary\\\"\\u003E\\u003C/td\\u003E\\u000a            \\u003Ctd class=\\\"flex-table-secondary\\\"\\u003E\\u000a              \\u003Ca href=\\\"#\\\" class=\\\"btn js-next-btn\\\"\\u003ENext\\u003C/a\\u003E\\u000a            \\u003C/td\\u003E\\u000a          \\u003C/tr\\u003E\\u000a        \\u003C/tbody\\u003E\\u000a      \\u003C/table\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"left-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"content-main js-content-main breakable\\\"\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"content-header js-content-header\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a      \\u003Ch2\\u003ETweets\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"js-tweet-preview-container\\\"\\u003E\\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"welcome-faux-tweet-stream js-welcome-faux-tweet-stream\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item stream-item js-intro-tweet\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"tweet js-unclickable-tweet unclickable-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a            \\u003Cspan class=\\\"account-group js-account-group js-action-profile\\\"\\u003E\\u000a              \\u003Cspan class=\\\"avatar-group\\\"\\u003E\\u000a                \\u003Cspan class=\\\"avatar {{^abtest_localized_image_welcome_flow_235_any_bucket}}welcome-teacher{{/abtest_localized_image_welcome_flow_235_any_bucket}}{{#abtest_localized_image_welcome_flow_235_japan_photo}}welcome-teacher-ab-photo{{/abtest_localized_image_welcome_flow_235_japan_photo}}{{#abtest_localized_image_welcome_flow_235_japan_drawing}}welcome-teacher-ab-drawing{{/abtest_localized_image_welcome_flow_235_japan_drawing}}\\\"/\\u003E\\u000a              \\u003C/span\\u003E\\u000a              \\u003Cstrong class=\\\"fullname\\\"\\u003EThe Twitter Teacher\\u003C/strong\\u003E\\u000a            \\u003C/span\\u003E\\u000a            \\u003Csmall class=\\\"time\\\"\\u003E\\u000a              1 min\\u000a            \\u003C/small\\u003E\\u000a          \\u003C/div\\u003E\\u000a          \\u003Cp\\u003EThis is a Tweet. Tweets are short messages that have up to 140 characters and can contain links like \\u003Ca\\u003Ehttp://twitter.com\\u003C/a\\u003E.\\u003C/p\\u003E\\u000a        \\u003C/div\\u003E\\u000a        \\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u000a\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"unfocusable-stream-item\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"faux-tweet\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"component\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-end\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a        \\u003Ci class=\\\"bird-etched\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a\\u003C/div\\u003E\\u000a\",\n            welcome_learn_game: \"\\u003Cdiv class=\\\"js-tweet-game welcome-game module\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"flex-module clearfix\\\"\\u003E\\u000a    \\u003Ch1\\u003EWhich Tweet do you like more?\\u003C/h1\\u003E\\u000a\\u000a    \\u003Ch3\\u003EHi, {{name}}. Let\\u2019s kickstart your Twitter\\u003Cbr\\u003E experience by building you a great timeline.\\u003C/h3\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"js-tweets-container welcome-game-tweets-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"js-tweet-1 welcome-game-tweet-container\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"js-tweet-separator welcome-game-tweet-separator\\\"\\u003Eor\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"js-tweet-2 welcome-game-tweet-container\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"welcome-game-skip\\\"\\u003E\\u000a      \\u003Ca href=\\\"#\\\" class=\\\"js-skip-tweets\\\"\\u003ESkip this pair\\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"contrast-flex-module\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"progressbar-well\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"ui-progressbar js-progressbar\\\"\\u003E\\u003C/div\\u003E\\u000a      \\u003Cdiv class=\\\"progress-label js-progress-label\\\"\\u003E\\u000a        \\u003Cspan class=\\\"js-current-round current-round\\\"\\u003E{{current_round}}\\u003C/span\\u003E / {{total_rounds}}\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            welcome_learn_game_tweet: \"\\u003Cdiv class=\\\"js-game-tweet js-unclickable-tweet welcome-game-tweet unclickable-tweet\\\" href=\\\"#\\\" data-tweet-id=\\\"{{id}}\\\"\\u003E\\u000a  {{#user}}\\u000a    \\u003Cdiv class=\\\"mini-profile\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"account-summary account-summary-small\\\"\\u003E\\u000a        \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a          \\u003Cdiv class=\\\"account-group\\\"\\u003E\\u000a            \\u003Cimg class=\\\"avatar size32\\\" alt=\\\"{{name}}\\\" src=\\\"{{profile_image_url}}\\\"\\u003E\\u000a            \\u003Cb class=\\\"fullname\\\"\\u003E{{name}}\\u003C/b\\u003E\\u000a            \\u003Cspan class=\\\"username\\\"\\u003E@{{screen_name}}\\u003C/span\\u003E\\u000a          \\u003C/div\\u003E\\u000a        \\u003C/div\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/user}}\\u000a\\u000a  \\u003Cp\\u003E{{{linkified_text}}}\\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            welcome_learn_header: \"\\u003Cdiv class=\\\"flex-module header-half {{#no_nav}} header-whole {{/no_nav}}\\\"\\u003E\\u000a  \\u003Ch2\\u003E{{title}}\\u003C/h2\\u003E\\u000a  \\u003Cdiv class=\\\"subheading\\\"\\u003E{{{subtitle}}}\\u003C/div\\u003E\\u000a  {{#ad_referal}}\\u000a    {{#ad_parlor}}\\u000a      \\u003Cimg src='https://fbads.adparlor.com/conversion.php?adid=1193' alt='AP_pixel' height='1' width='1' /\\u003E\\u000a    {{/ad_parlor}}\\u000a  {{/ad_referal}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{^no_nav}}\\u000a\\u003Cdiv class=\\\"flex-module progress-half\\\"\\u003E\\u000a  \\u000a  \\u003Ctable cellspacing=\\\"0\\\" cellpadding=\\\"0\\\" border=\\\"0\\\" width=\\\"100%\\\"\\u003E\\u000a    \\u003Ctr\\u003E\\u000a      \\u003Ctd width=\\\"99%\\\"\\u003E\\u000a        {{#show_progress}}\\u000a          \\u003Cdiv class=\\\"progressbar-well\\\"\\u003E\\u000a            \\u003Cdiv class=\\\"ui-progressbar js-progressbar\\\"\\u003E\\u003C/div\\u003E\\u000a            \\u003Cdiv class=\\\"progress-label js-progress-label\\\"\\u003E\\u003C/div\\u003E\\u000a          \\u003C/div\\u003E\\u000a        {{/show_progress}}\\u000a      \\u003C/td\\u003E\\u000a\\u000a      {{#edit_enabled}}\\u000a        \\u003Ctd width=\\\"1%\\\" style=\\\"padding-right: 8px;\\\"\\u003E\\u000a          \\u003Ca href=\\\"{{welcome_edit_path}}\\\" class=\\\"btn js-edit-btn\\\"\\u003EEdit\\u003C/a\\u003E\\u000a        \\u003C/td\\u003E\\u000a      {{/edit_enabled}}\\u000a\\u000a      \\u003Ctd width=\\\"1%\\\"\\u003E\\u000a        {{#next_enabled}}\\u000a          \\u003Ca href=\\\"{{continue_route}}\\\" class=\\\"btn js-next-btn {{#last_step}} last-step {{/last_step}} {{#next_highlighted}} primary-btn {{/next_highlighted}}\\\"\\u003E{{button_text}}\\u003C/a\\u003E\\u000a        {{/next_enabled}}\\u000a        {{^next_enabled}}\\u000a          \\u003Ca class=\\\"btn disabled js-next-btn\\\"\\u003E{{button_text}}\\u003C/a\\u003E\\u000a        {{/next_enabled}}\\u000a      \\u003C/td\\u003E\\u000a    \\u003C/tr\\u003E\\u000a  \\u003C/table\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/no_nav}}\\u000a\\u000a{{#stream_arrow}}\\u000a  \\u003Cdiv class=\\\"down-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a{{/stream_arrow}}\\u000a\\u000a{{^stream_arrow}}\\u000a  \\u003Cdiv class=\\\"left-arrow\\\"\\u003E\\u003C/div\\u003E\\u000a{{/stream_arrow}}\\u000a\",\n            welcome_learn_profile: \"\\u003Cdiv class=\\\"form-vertical js-profile-form\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"image-error clearfix js-image-error\\\"\\u003E\\u000a    \\u003Ca class=\\\"dismiss js-dismiss\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a    \\u003Cspan class=\\\"js-image-error-text\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"control-group\\\"\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"js-current-profile-picture-wrapper profile-form-image-wrapper avatar size96\\\"\\u003E\\u000a      \\u003Cimg class=\\\"js-current-profile-picture profile-form-image avatar size96\\\" src=\\\"{{reasonably_small_profile_image_url}}\\\" alt=\\\"Profile photo thumbnail\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"spinner\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cform method=\\\"post\\\" action=\\\"{{api_url}}/1/account/update_profile_image.iframe\\\" enctype=\\\"multipart/form-data\\\" class=\\\"js-upload-form profile-image-upload-form\\\" target=\\\"welcomeProfilePhotoUpload\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"file-input-wrapper\\\"\\u003E\\u000a        \\u003Cbutton class=\\\"js-upload-btn btn\\\" href=\\\"#\\\"\\u003E\\u000a          Upload image\\u000a        \\u003C/button\\u003E\\u000a        \\u003Cinput class=\\\"js-profile-image-input\\\" type=\\\"file\\\" name=\\\"image\\\"\\u003E\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u003Cp\\u003EMaximum size of 700K. JPG, GIF, PNG.\\u003C/p\\u003E\\u000a\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"iframe_callback\\\" value=\\\"window.JSBNG__top.twttr.components.pages.WelcomeLearnFlow.profileImageUploadCallback\\\"\\u003E\\u000a      \\u003Cinput type=\\\"hidden\\\" name=\\\"post_authenticity_token\\\" value=\\\"{{post_authenticity_token}}\\\"\\u003E\\u000a    \\u003C/form\\u003E\\u000a    \\u003Ciframe class=\\\"turkey-post-target\\\" name=\\\"welcomeProfilePhotoUpload\\\"\\u003E\\u003C/iframe\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u000a  \\u003Cdiv class=\\\"control-group\\\"\\u003E\\u000a    \\u003Clabel class=\\\"control-label\\\" for=\\\"welcomeProfileBio\\\"\\u003EBio\\u003C/label\\u003E\\u000a    \\u003Cdiv class=\\\"bio-count\\\"\\u003E\\u003Cspan class=\\\"js-bio-count\\\"\\u003E0\\u003C/span\\u003E / 160\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"controls\\\"\\u003E\\u000a      \\u003Ctextarea id=\\\"welcomeProfileBio\\\" class=\\\"welcome-profile-bio\\\" name=\\\"description\\\" placeholder=\\\"Rocket ship builder, pizza expert, loves the Giants, parent.\\\"\\u003E{{description}}\\u003C/textarea\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u000a\\u003C/div\\u003E\\u000a\\u000a\",\n            welcome_to_phoenix_banner: \"\\u003Cdiv class=\\\"welcome-banner-outer banner-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"welcome-banner banner\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"welcome-banner-inside banner-inside\\\"\\u003E\\u000a      \\u003Ca class='pane-close' href='#'\\u003EClose&nbsp;\\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a      \\u003Cspan\\u003E\\u000a        Welcome to \\u003Ca href=\\\"{{welcome_search_results_path}}\\\"\\u003E#NewTwitter\\u003C/a\\u003E! Read up on \\u003Ca target=\\\"_blank\\\" href=\\\"{{whats_new_path}}\\\"\\u003Ewhat\\u2019s new\\u003C/a\\u003E.\\u000a      \\u003C/span\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            who_to_follow: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    \\u003Cdiv class=\\\"page-header who-to-follow-header\\\"\\u003E\\u000a\\u000a      \\u003Cform class=\\\"who-to-follow-search\\\" action=\\\"{{who_to_follow_search_form_path}}\\\" method=\\\"GET\\\"\\u003E\\u000a        \\u003Cinput type=\\\"text\\\" value=\\\"\\\" name=\\\"q\\\" placeholder=\\\"Search by name or topic\\\" /\\u003E\\u000a        \\u003Cdiv class=\\\"submit button\\\"\\u003ESearch\\u003C/div\\u003E\\u000a      \\u003C/form\\u003E\\u000a\\u000a      \\u003Ch1\\u003EWho to follow\\u003C/h1\\u003E\\u000a\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a  {{#logged_in}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-suggestions {{#active_tab_suggestions}}active{{/active_tab_suggestions}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='View Suggestions' href=\\\"{{who_to_follow_suggestions_path}}\\\"\\u003EView Suggestions\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a  {{/logged_in}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-interests {{#active_tab_interests}}active{{/active_tab_interests}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='Browse Interests' href=\\\"{{who_to_follow_interests_path}}\\\"\\u003EBrowse Interests\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a  {{#decider_contact_import}}\\u000a  {{#logged_in}}\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-import {{#active_tab_import}}active{{/active_tab_import}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='Find Friends' href=\\\"{{who_to_follow_import_path}}\\\"\\u003EFind Friends\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a  {{/logged_in}}\\u000a  {{/decider_contact_import}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a\\u000a    \\u003Cdiv class=\\\"who-to-follow-stream\\\"\\u003E\\u000a      {{\\u003Estream_manager}}\\u000a    \\u003C/div\\u003E\\u000a\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            who_to_follow_links: \"\\u003Cp class=\\\"wtf-links\\\"\\u003E\\u000a  \\u003Cspan\\u003EFind accounts to follow:\\u003C/span\\u003E\\u000a  \\u003Ca href=\\\"{{who_to_follow_interests_path}}\\\"\\u003EBrowse interests\\u003C/a\\u003E\\u000a  {{#decider_contact_import}}\\u000a  \\u003Cspan class=\\\"dot\\\"\\u003E&middot;\\u003C/span\\u003E\\u000a  \\u003Ca href=\\\"{{who_to_follow_import_path}}\\\"\\u003EFind friends\\u003C/a\\u003E\\u000a  {{/decider_contact_import}}\\u000a\\u003C/p\\u003E\\u000a\",\n            activity_modal: \"\\u003Cdiv id='activity-modal' style='display: none'\\u003E\\u000a  \\u003Cdiv class='left-pointer'\\u003E\\u003C/div\\u003E\\u000a  \\u003Ca class='dismiss' title=\\\"Hide\\\"\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Cp class='header'\\u003E\\u003Cspan class='new'\\u003ENew!\\u003C/span\\u003E Activity and @{{current_user_screen_name}}\\u003C/p\\u003E\\u000a  \\u003Cp class='desc'\\u003E\\u000a      View favorites, follows, retweets and more by people you follow in \\u003Cstrong\\u003EActivity\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a  \\u003Cp class='extra-blurb desc'\\u003E\\u000a    View your mentions, tweets that were retweeted and more in \\u003Cstrong\\u003E@{{current_user_screen_name}}\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            details_pane: \"\\u003Cdiv class=\\\"inner-pane\\\"\\u003E\\u000a  \\u003Cdiv class='pane-toolbar pane-built-in'\\u003E\\u000a    {{#popable}}\\u000a      \\u003Ca class='pane-back toolbar-control' href='#'\\u003E\\u003Cspan\\u003E&larr;\\u003C/span\\u003E {{back_label}}\\u003C/a\\u003E\\u000a    {{/popable}}\\u000a    {{#closable}}\\u000a      \\u003Ca class='pane-close toolbar-control' href='#'\\u003Eclose \\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a    {{/closable}}\\u000a    \\u003Cbr style='clear: both' /\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"pane-components\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"pane-components-inner\\\"\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            details_pane_container: \"\\u003Cdiv id=\\\"details-pane-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"details-pane-shell\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"details-pane\\\"\\u003E\\u000a      {{{pane}}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            home_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    \\u003Cdiv class=\\\"page-header home-header\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"main-tweet-box\\\"\\u003E\\u000a        {{\\u003Eposting_tweet_box}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-home {{#active_tab_home}}active{{/active_tab_home}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='All you follow' href=\\\"{{index_path}}\\\"\\u003ETimeline\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        {{#decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-your_activity {{#active_tab_your_activity}}active{{/active_tab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='@{{current_user_screen_name}}' href=\\\"{{your_activity_path}}\\\"\\u003E@{{current_user_screen_name}}\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Activity' href=\\\"{{activity_path}}\\\"\\u003EActivity\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        {{^decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-mentions {{#active_tab_mentions}}active{{/active_tab_mentions}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Mentions' href=\\\"{{mentions_path}}\\\"\\u003E@Mentions\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-retweets dropdown-link {{#active_tab_retweets}}active{{/active_tab_retweets}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ERetweets\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-searches dropdown-link {{#active_tab_searches}}active{{/active_tab_searches}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ESearches\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-lists dropdown-link {{#active_tab_lists}}active{{/active_tab_lists}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ELists\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a        {{#decider_network_discovery}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-discovery activity-subtabs {{#active_tab_network_discovery}}active{{/active_tab_network_discovery}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Discover' href=\\\"{{discovery_path}}\\\"\\u003EDiscover\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_network_discovery}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#decider_activity_read}}\\u000a      {{#activity_subtabs}}\\u000a        \\u003Cul class=\\\"stream-subtabs stream-subtabs-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-your_activity {{#active_subtab_your_activity}}active{{/active_subtab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{your_activity_path}}\\\"\\u003Eabout you\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-separator\\\"\\u003E&middot;\\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-activity {{#active_subtab_activity}}active{{/active_subtab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{activity_path}}\\\"\\u003Eby people you follow\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a      {{/activity_subtabs}}\\u000a    {{/decider_activity_read}}\\u000a    {{\\u003Estream_manager}}\\u000a    {{#rendering_on_server}}\\u003Cscript\\u003Etwttr.tweetsVisibleTime = new Date();if (window.ttft) window.ttft.serverRendered('home');twttr.keynoteTTFTPing();\\u003C/script\\u003E{{/rendering_on_server}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#current_user}}\\u000a      {{\\u003Ehome_dashboard}}\\u000a    {{/current_user}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            message_drawer: \"\\u003Cdiv class=\\\"message {{^rendering_on_server}}{{type}}{{/rendering_on_server}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"message-inside\\\"\\u003E\\u000a    \\u003Cspan class=\\\"message-text\\\"\\u003E{{{text}}}\\u003C/span\\u000a    \\u003E{{#close_button}}\\u003Ca class=\\\"dismiss\\\" href=\\\"#\\\"\\u003E&times;\\u003C/a\\u003E{{/close_button}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            message_notification: \"{{#message}}\\u000a\\u003Cdiv data-sender-id='{{sender_screen_name}}' data-message-id=\\\"{{id}}\\\" class='notification'\\u003E\\u000a  \\u003Ca class='dismiss' href='#'\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Ch1\\u003ENew Message from {{{sender_screen_name}}}\\u003C/h1\\u003E\\u000a  \\u003Cdiv class='message-text'\\u003E{{{text}}}\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"message-notification-reply-box\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-editor\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-button button\\\"\\u003ESend\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/message}}\",\n            pill_css: \"\\u000a.profile-style-{{screen_name}} a {\\u000a  {{#profile_link_color}}\\u000a    color: #{{profile_link_color}} !important;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000aa:hover .geo-pin, body.user-style-{{screen_name}} .stream-item:hover .geo-pin {\\u000a  background-color: #{{profile_link_color}};\\u000a}\",\n            posting_tweet_box: \"\\u003Cform method=\\\"post\\\" action=\\\"/status/update\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-box condensed\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      \\u003Ch2\\u003EWhat\\u2019s happening?\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"text-area\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"text-area-editor twttr-editor\\\"\\u003E\\u000a        \\u003Ctextarea class=\\\"twitter-anywhere-tweet-box-editor\\\" name=\\\"status\\\" style=\\\"width: 482px; height: 36px;\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            stream_activity: \"\\u003Cspan class='stream-activity-line'\\u003E\\u003Ci\\u003E\\u003C/i\\u003E{{{sentence}}}\\u003C/span\\u003E\",\n            tweet_contributor: \"{{#contributor}}\\u000a  \\u003Cspan class=\\\"tweet-contributors\\\"\\u003Eby \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"user-profile-link\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E{{screen_name}}\\u003C/a\\u003E\\u003C/span\\u003E\\u000a{{/contributor}}\",\n            tweet_dogear: \"\\u003Cdiv class=\\\"tweet-dogear\\\"\\u003E\\u003C/div\\u003E\",\n            tweet_labels: \"{{#is_top_tweet}}\\u000a    \\u003Cspan class=\\\"tweet-context icon-link\\\"\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-top\\\"\\u003E\\u003C/i\\u003E{{#retweet_count}}Retweeted {{retweet_count}} times{{/retweet_count}}{{^retweet_count}}Top Tweet{{/retweet_count}}\\u003C/span\\u003E\\u000a{{/is_top_tweet}}\\u000a\\u000a{{#is_sponsored}}\\u000a  \\u003Ca href=\\\"{{#retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}{{^retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}\\\" class=\\\"icon-link promoted-arrow tweet-context user-profile-link js-action-profile-promoted\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\" title=\\\"{{disclosure_text}}\\\"\\u003E\\u003Cspan\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-{{disclosure_type}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003EPromoted by {{advertiser_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u000a  {{#in_home_page}}\\u000a    {{^rendering_on_server}}\\u000a      \\u003Ca class=\\\"icon-link tweet-feedback dismiss-action js-action-dismiss\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cb\\u003EDismiss\\u003C/b\\u003E\\u003C/a\\u003E\\u000a    {{/rendering_on_server}}\\u000a    {{{social_context}}}\\u000a  {{/in_home_page}}\\u000a{{/is_sponsored}}\",\n            tweet_meta: \"\\u003Cdiv class='tweet-meta'\\u003E\\u000a  \\u003Cspan class='icons'\\u003E\\u000a    {{#is_sponsored}}\\u000a      {{#retweet_count}}\\u000a        \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E \\u003Cem\\u003E{{retweet_count_text}}\\u003C/em\\u003E\\u000a      {{/retweet_count}}\\u000a    {{/is_sponsored}}\\u000a\\u000a    {{^decider_activity_read}}\\u000a      {{^is_sponsored}}\\u000a        {{#was_retweeted}}\\u000a          {{#retweeting_status}}\\u000a            \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E {{#user}}\\u003Cem\\u003Eby {{screen_name}}\\u003C/em\\u003E{{/user}}\\u000a          {{/retweeting_status}}\\u000a        {{/was_retweeted}}\\u000a      {{/is_sponsored}}\\u000a    {{/decider_activity_read}}\\u000a\\u000a    \\u003Cdiv class=\\\"extra-icons\\\"\\u003E\\u000a      {{^can_expand}}\\u000a        {{#is_reply}}\\u000a          \\u003Cspan class='reply-icon icon js-reply-notice'\\u003E@\\u003C/span\\u003E\\u000a        {{/is_reply}}\\u000a        \\u003Cspan class=\\\"inlinemedia-icons js-icon-container\\\"\\u003E\\u003C/span\\u003E\\u000a        {{#show_geo_icon}}\\u003Cspan class=\\\"geo-pin\\\"\\u003E\\u003C/span\\u003E{{/show_geo_icon}}\\u000a      {{/can_expand}}\\u000a      {{#can_expand}}\\u000a        {{\\u003Etweet_timestamp}}\\u000a      {{/can_expand}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{#can_expand}}\\u000a  {{\\u003Etweet_actions}}\\u000a{{/can_expand}}\",\n            tweet_source: \"\\u003Cspan class=\\\"tweet-source\\\"\\u003Evia {{{source}}}\\u003C/span\\u003E\",\n            tweet_text: \"\\u003Cdiv class=\\\"tweet-text js-tweet-text\\\"\\u003E\\u000a  {{\\u003Elinked_tweet}}\\u000a\\u003C/div\\u003E\",\n            tweet_user_image_48: \"{{#user}}\\u000a\\u003Cimg height=\\\"48\\\" width=\\\"48\\\" src='{{profile_image_url}}' alt='{{name}}' class='user-profile-link js-action-profile-avatar' data-user-id='{{id}}'/\\u003E\\u000a{{/user}}\\u000a\",\n            tweet_user_name: \"{{#user}}\\u000a\\u003Cspan class='tweet-user-name'\\u003E\\u000a  \\u003Ca class='tweet-screen-name user-profile-link js-action-profile-name' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a  \\u003Cspan class='tweet-full-name'\\u003E{{name}}\\u003C/span\\u003E\\u000a  {{#show_follow_action}}\\u000a    {{^is_current_user}}\\u000a    \\u003Cspan class=\\\"tweet-user-follow\\\"\\u003E\\u000a    \\u003C/span\\u003E\\u000a    {{/is_current_user}}\\u000a  {{/show_follow_action}}\\u000a\\u003C/span\\u003E\\u000a{{/user}}\",\n            user_css_p1: \"\\u000a\\u003Cstyle id=\\\"user-style-{{screen_name}}\\\"\\u003E\\u000a  body.user-style-{{screen_name}} {\\u000a    {{#profile_use_background_image}}\\u000a      background-position: left 40px;\\u000a      background-attachment: fixed;\\u000a      {{^profile_background_tile}}\\u000a        background-repeat: no-repeat;\\u000a      {{/profile_background_tile}}\\u000a    {{/profile_use_background_image}}\\u000a    {{#profile_background_color}}\\u000a      background-color: #{{profile_background_color}};\\u000a    {{/profile_background_color}}\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} a,\\u000a  body.user-style-{{screen_name}} ul.stream-tabs li,\\u000a  body.user-style-{{screen_name}} .component .promo strong,\\u000a  body.user-style-{{screen_name}} .message-thread-preview:hover .message-count,\\u000a  body.user-style-{{screen_name}} .list-membership-container li.create-a-list {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}};\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-screen-name,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-geo-text,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .user-profile-link,\\u000a  body.user-style-{{screen_name}} span.user-stat-link,\\u000a  body.user-style-{{screen_name}} a.title-link:hover,\\u000a  body.user-style-{{screen_name}} a.user-stats-count:hover span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a,\\u000a  body.user-style-{{screen_name}} .user-detailed-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .tweet-activity:hover a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link b,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-feedback,\\u000a  body.user-style-{{screen_name}} .promoted-tweet:hover .social-context a,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a:hover span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity .user,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-count,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence span.user,\\u000a  body.user-style-{{screen_name}} .JSBNG__onebox-user-screen-name:hover {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-screen-name {\\u000a    color: #333 !important;\\u000a  }\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-timestamp {\\u000a    color: #999 !important;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .hovered-stream-item,\\u000a  body.user-style-{{screen_name}} .stream-item:hover,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:active {\\u000a    {{#rgba_tweet_background_color}}\\u000a      background-color: {{rgba_tweet_background_color}};\\u000a    {{/rgba_tweet_background_color}}\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}};\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover {\\u000a    border-top-color: transparent;\\u000a    border-bottom-color: #EBEBEB;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:hover {\\u000a    {{#rgba_newtweets_background_color}}\\u000a      background-color: {{rgba_newtweets_background_color}};\\u000a    {{/rgba_newtweets_background_color}}\\u000a    {{#rgba_newtweets_border_color}}\\u000a      border-color: {{rgba_newtweets_border_color}};\\u000a    {{/rgba_newtweets_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-screen-name,\\u000a  body.user-style-{{screen_name}} .profile-screenname,\\u000a  body.user-style-{{screen_name}} .title-link,\\u000a  body.user-style-{{screen_name}} div.latest-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} div.truncated-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} a.user-stats-count span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .welcome-steps li .active a strong,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence span.user {\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-full-name,\\u000a  body.user-style-{{screen_name}} span.trend-location,\\u000a  body.user-style-{{screen_name}} .your-activity h3,\\u000a  body.user-style-{{screen_name}} .trends-inner h3,\\u000a  body.user-style-{{screen_name}} .dashboard .user-rec-inner h3,\\u000a  body.user-style-{{screen_name}} .latest-tweet,\\u000a  body.user-style-{{screen_name}} .truncated-tweet,\\u000a  body.user-style-{{screen_name}} .latest-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .truncated-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a s,\\u000a  body.user-style-{{screen_name}} .social-context div,\\u000a  body.user-style-{{screen_name}} .dashboard .dot,\\u000a  body.user-style-{{screen_name}} .component .promo,\\u000a  body.user-style-{{screen_name}} .component .promo a.definition,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .dismiss,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .ellip,\\u000a  body.user-style-{{screen_name}} .facets-media-not-displayed .not-displayed-text,\\u000a  body.user-style-{{screen_name}} .dashboard .copyright,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item a.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence {\\u000a    {{#rgba_text_color}}\\u000a      color: {{rgba_text_color}};\\u000a    {{/rgba_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #page-container,\\u000a  body.user-style-{{screen_name}} .user-sidebar-color,\\u000a  body.user-style-{{screen_name}} .expando-container .dashboard {\\u000a    {{#profile_sidebar_fill_color}}\\u000a      \\u000a      background: #{{profile_sidebar_fill_color}};\\u000a    {{/profile_sidebar_fill_color}}\\u000a    {{#rgba_sidebar_color}}\\u000a      \\u000a      background: {{rgba_sidebar_color}};\\u000a    {{/rgba_sidebar_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .activity:hover .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .hovered-stream-item .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .dashboard .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content  {\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}} !important;\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-atreply:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-hashtag:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-timeline-link:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-timeline-link,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-timeline-link {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} s,\\u000a  body.user-style-{{screen_name}} .pretty-link s {\\u000a    {{#profile_pretty_link_color}}\\u000a      color: #{{profile_pretty_link_color}};\\u000a    {{/profile_pretty_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard s,\\u000a  body.user-style-{{screen_name}} .dashboard .pretty-link s,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a s {\\u000a    {{#profile_pretty_link_sidebar_color}}\\u000a      color: #{{profile_pretty_link_sidebar_color}};\\u000a    {{/profile_pretty_link_sidebar_color}}\\u000a  }\\u000a\\u000a  {{\\u003Epill_css}}\\u000a\\u003C/style\\u003E\"\n        });\n    }\n;\n;\n    exports();\n});\nprovide(\"mixins/ActivityViewHelpers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.ActivityViewHelpers\", function() {\n            var a = 3, b = \"sources\", c = \"targets\", d = \"target_objects\", e = \"StreamTweet\", f = \"ActivityItemTweet\", g = \"StreamUser\", i = \"StreamList\", j = \"ActivityItemUser\", k = \"ActivityItemTruncatedTweet\", l = \"User\", m = \"List\", n = \"Status\", o = {\n                User: {\n                    Status: [\"user\",],\n                    List: [\"user\",],\n                    User: []\n                },\n                Status: {\n                    Status: [],\n                    User: [\"JSBNG__status\",],\n                    List: []\n                },\n                List: {\n                    Status: [],\n                    User: [\"user\",],\n                    List: []\n                }\n            }, p = {\n                User: ((twttr.isT1 ? \"ActivityUserLink\" : \"UserLink\")),\n                List: \"ListLink\"\n            }, q = {\n                your_activity: p,\n                profile_activity: p,\n                activity: p,\n                dashboard: {\n                    User: \"UserFullName\",\n                    List: \"ListLink\"\n                }\n            }, r = {\n                User: \"screen_name\",\n                List: \"list_title\"\n            };\n            ((twttr.isT1 && (f = \"StreamTweet\", j = \"UserAvatarLink24\", k = \"LatestTweet\")));\n            var s = {\n                your_activity: {\n                    favorite: {\n                        sources: {\n                            view: j,\n                            objectType: l,\n                            object: b,\n                            max: 15,\n                            useTruncated: !0\n                        },\n                        targets: {\n                            view: k,\n                            objectType: n,\n                            object: c,\n                            max: 1,\n                            useTruncated: !1\n                        }\n                    },\n                    mention: {\n                        view: e,\n                        objectType: n,\n                        object: d,\n                        max: 1\n                    },\n                    reply: {\n                        view: e,\n                        objectType: n,\n                        object: c,\n                        max: 1\n                    },\n                    retweet: {\n                        sources: {\n                            view: j,\n                            objectType: l,\n                            object: b,\n                            max: 15,\n                            useTruncated: !0\n                        },\n                        targets: {\n                            view: k,\n                            objectType: n,\n                            object: d,\n                            max: 1,\n                            useTruncated: !1\n                        }\n                    },\n                    follow: {\n                        view: j,\n                        objectType: l,\n                        object: b,\n                        max: 15\n                    },\n                    list_member_added: {\n                        view: j,\n                        objectType: l,\n                        object: c,\n                        max: 15\n                    },\n                    list_created: {\n                        view: i,\n                        objectType: m,\n                        object: c,\n                        max: 1\n                    }\n                },\n                profile_activity: {\n                    favorite: {\n                        view: f,\n                        objectType: n,\n                        object: c,\n                        max: 1\n                    },\n                    mention: {\n                        view: f,\n                        objectType: n,\n                        object: d,\n                        max: 1\n                    },\n                    reply: {\n                        view: f,\n                        objectType: n,\n                        object: c,\n                        max: 1\n                    },\n                    retweet: {\n                        view: f,\n                        objectType: n,\n                        object: d,\n                        max: 1\n                    },\n                    follow: {\n                        view: g,\n                        objectType: l,\n                        object: c,\n                        max: 12\n                    },\n                    list_member_added: {\n                        view: g,\n                        objectType: l,\n                        object: c,\n                        max: 12\n                    },\n                    list_created: {\n                        view: i,\n                        objectType: m,\n                        object: c,\n                        max: 1\n                    }\n                },\n                activity: {\n                    favorite: {\n                        primary: {\n                            view: f,\n                            objectType: n,\n                            object: c,\n                            max: 1\n                        },\n                        secondary: {\n                            view: \"UserAvatarLink24\",\n                            objectType: l,\n                            object: b,\n                            max: 15\n                        }\n                    },\n                    mention: {\n                        view: f,\n                        objectType: n,\n                        object: d,\n                        max: 1\n                    },\n                    reply: {\n                        view: f,\n                        objectType: n,\n                        object: c,\n                        max: 1\n                    },\n                    retweet: {\n                        primary: {\n                            view: f,\n                            objectType: n,\n                            object: d,\n                            max: 1\n                        },\n                        secondary: {\n                            view: \"UserAvatarLink24\",\n                            objectType: l,\n                            object: b,\n                            max: 15\n                        }\n                    },\n                    follow: {\n                        primary: {\n                            view: ((twttr.isT1 ? \"StreamUser\" : \"ActivityItemUser\")),\n                            objectType: l,\n                            object: c,\n                            max: ((twttr.isT1 ? 10 : 12))\n                        },\n                        secondary: {\n                            view: \"UserAvatarLink24\",\n                            objectType: l,\n                            object: b,\n                            max: 15\n                        }\n                    },\n                    list_member_added: {\n                        view: ((twttr.isT1 ? \"StreamUser\" : \"ActivityItemUser\")),\n                        objectType: l,\n                        object: c,\n                        max: 10\n                    },\n                    list_created: {\n                        view: i,\n                        objectType: m,\n                        object: c,\n                        max: 1\n                    }\n                },\n                dashboard: {\n                    favorite: {\n                        max: 0\n                    },\n                    mention: {\n                        max: 0\n                    },\n                    reply: {\n                        max: 0\n                    },\n                    retweet: {\n                        max: 0\n                    },\n                    follow: {\n                        max: 0\n                    },\n                    list_member_added: {\n                        max: 12\n                    },\n                    list_created: {\n                        max: 1\n                    }\n                }\n            }, t = {\n                sources: b,\n                targets: c,\n                target_objects: d\n            }, u = {\n                favorite: t,\n                mention: t,\n                reply: t,\n                retweet: t,\n                follow: t,\n                list_member_added: t,\n                list_created: t\n            }, v = [[[_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{{targets_screen_name_1}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}}, {{{targets_screen_name_1}}} and {{{targets_screen_name_2}}} to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}&#32;to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],], w = [[_(\"{{{sources_screen_name_0}}} created list {{{targets_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} created lists {{{targets_list_title_0}}} and {{{targets_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} created lists {{{targets_list_title_0}}}, {{{targets_list_title_1}}} and {{{targets_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} created lists {{{targets_list_title_0}}} and {{#link_targets_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{targets_count}} others.\\u003C/span\\u003E{{#link_targets_count}}\\u003C/a\\u003E{{/link_targets_count}}\"),],], x = ((((twttr.isT1 && twttr.currentUser)) && twttr.abdecider.chooseWithoutImpression(\"rename_favorite_australia_334\"))), y = ((((x === \"fav_to_like_australia\")) || ((((x === \"fav_to_like_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt))))))), z = ((((x === \"fav_to_star_australia\")) || ((((x === \"fav_to_star_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt)))))));\n            ((((((y || z)) || ((x === \"control\")))) && twttr.abdecider.choose(\"rename_favorite_australia_334\")));\n            var A = {\n                favorite: {\n                    your_activity: ((((!y && !z)) ? [[_(\"{{{sources_screen_name_0}}} favorited your Tweet\"),_(\"{{{sources_screen_name_0}}} favorited your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} favorited your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} favorited your Tweets\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} favorited your Tweet\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} favorited your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;favorited your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;favorited your Tweets\"),],] : ((y ? [[_(\"{{{sources_screen_name_0}}} liked your Tweet\"),_(\"{{{sources_screen_name_0}}} liked your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} liked your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} liked your Tweets\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} liked your Tweet\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} liked your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;liked your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;liked your Tweets\"),],] : [[_(\"{{{sources_screen_name_0}}} starred your Tweet\"),_(\"{{{sources_screen_name_0}}} starred your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} starred your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} starred your Tweets\"),],[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} starred your Tweet\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} starred your Tweets\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;starred your Tweet\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;starred your Tweets\"),],])))),\n                    profile_activity: ((((!y && !z)) ? [_(\"{{{sources_screen_name_0}}} favorited \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),] : ((y ? [_(\"{{{sources_screen_name_0}}} liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),] : [_(\"{{{sources_screen_name_0}}} liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),])))),\n                    activity: ((((!y && !z)) ? [_(\"{{{sources_screen_name_0}}} favorited \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} favorited \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} favorited \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;favorited \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),] : ((y ? [_(\"{{{sources_screen_name_0}}} liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;liked \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),] : [_(\"{{{sources_screen_name_0}}} starred \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} starred \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} starred \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;starred \\u003Cspan class='activity-target-screen-name'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E:\"),])))),\n                    dashboard: ((((!y && !z)) ? [[_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Efavorited\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Efavorited\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{full_targets_count}} Tweets\\u003C/span\\u003E\"),],_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} \\u003Cspan class='activity-action'\\u003Efavorited\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Efavorited\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),] : ((y ? [[_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Eliked\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Eliked\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{full_targets_count}} Tweets\\u003C/span\\u003E\"),],_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} \\u003Cspan class='activity-action'\\u003Eliked\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Eliked\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),] : [[_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Estarred\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Estarred\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{full_targets_count}} Tweets\\u003C/span\\u003E\"),],_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} \\u003Cspan class='activity-action'\\u003Estarred\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Estarred\\u003C/span\\u003E a \\u003Cspan class='dashboard-activity-item-entity'\\u003ETweet\\u003C/span\\u003E\"),]))))\n                },\n                mention: {\n                    your_activity: [_(\"{{{sources_screen_name_0}}} mentioned you\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} mentioned you\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} mentioned you\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;mentioned you\"),],\n                    profile_activity: null,\n                    activity: null\n                },\n                reply: {\n                    your_activity: [_(\"{{{sources_screen_name_0}}} replied to you\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} replied to you\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} replied to you\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;replied to you\"),],\n                    profile_activity: null,\n                    activity: null\n                },\n                retweet: {\n                    your_activity: [_(\"{{{sources_screen_name_0}}} retweeted you\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} retweeted you\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} retweeted you\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;retweeted you\"),],\n                    profile_activity: [_(\"{{{sources_screen_name_0}}} retweeted \\u003Cspan class='activity-target-screen-name'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E:\"),],\n                    activity: [_(\"{{{sources_screen_name_0}}} retweeted \\u003Cspan class='activity-target-screen-name'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} retweeted \\u003Cspan class='activity-target-screen-name'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} retweeted \\u003Cspan class='activity-target-screen-name'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E:\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;retweeted \\u003Cspan class='activity-target-screen-name'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E:\"),],\n                    dashboard: [[_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Eretweeted\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Eretweeted\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{full_target_objects_count}} people\\u003C/span\\u003E\"),],_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} \\u003Cspan class='activity-action'\\u003Eretweeted\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{target_objects_screen_name_0}}}\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Eretweeted\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{full_target_objects_count}}} people\\u003C/span\\u003E\"),]\n                },\n                follow: {\n                    your_activity: [_(\"{{{sources_screen_name_0}}} followed you\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} followed you\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} followed you\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;followed you\"),],\n                    profile_activity: [_(\"{{{sources_screen_name_0}}} followed:\"),],\n                    activity: [_(\"{{{sources_screen_name_0}}} followed:\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} followed:\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} followed:\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;followed:\"),],\n                    dashboard: [[_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} \\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{full_targets_count}} people\\u003C/span\\u003E\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} other\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} other\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{targets_count}} people\\u003C/span\\u003E\"),],[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{{targets_screen_name_0}}}\\u003C/span\\u003E\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;\\u003Cspan class='activity-action'\\u003Efollowed\\u003C/span\\u003E \\u003Cspan class='dashboard-activity-item-entity'\\u003E{{targets_count}} people\\u003C/span\\u003E\"),],]\n                },\n                list_member_added: {\n                    your_activity: [[[_(\"{{{sources_screen_name_0}}} added you to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} added you to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} added you to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} added you to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added you to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added you to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added you to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{{sources_screen_name_1}}} added you to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added you to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added you to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added you to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}}, {{{sources_screen_name_1}}} and {{{sources_screen_name_2}}} added you to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],[[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added you to list {{{target_objects_list_title_0}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added you to lists {{{target_objects_list_title_0}}} and {{{target_objects_list_title_1}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added you to lists {{{target_objects_list_title_0}}}, {{{target_objects_list_title_1}}} and {{{target_objects_list_title_2}}}\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/a\\u003E{{/link_sources_count}}&#32;added you to lists {{{target_objects_list_title_0}}} and {{#link_target_objects_count}}\\u003Ca class='activity-count' href='#'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{target_objects_count}} others.\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/a\\u003E{{/link_target_objects_count}}\"),],],],\n                    profile_activity: v,\n                    activity: v,\n                    dashboard: [[[_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to a list\"),_(\"{{{sources_screen_name_0}}} added {{{targets_screen_name_0}}} to {{#link_target_objects_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{full_target_objects_count}}\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/span\\u003E{{/link_target_objects_count}}&#32;lists\"),],[_(\"{{{sources_screen_name_0}}} added {{#link_targets_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{full_targets_count}}\\u003C/span\\u003E{{#link_targets_count}}\\u003C/span\\u003E{{/link_targets_count}}&#32;to a list\"),_(\"{{{sources_screen_name_0}}} added {{#link_targets_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{full_targets_count}}\\u003C/span\\u003E{{#link_targets_count}}\\u003C/span\\u003E{{/link_targets_count}}&#32;to {{#link_target_objects_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_target_objects_count}}\\u003Cspan class='count-wrap'\\u003E{{full_target_objects_count}}\\u003C/span\\u003E{{#link_target_objects_count}}\\u003C/span\\u003E{{/link_target_objects_count}}&#32;lists\"),],],[[_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to a list\"),_(\"{{{sources_screen_name_0}}} and {{#link_sources_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_sources_count}}\\u003Cspan class='count-wrap'\\u003E{{sources_count}} others\\u003C/span\\u003E{{#link_sources_count}}\\u003C/span\\u003E{{/link_sources_count}}&#32;added {{{targets_screen_name_0}}} to lists\"),],],]\n                },\n                list_created: {\n                    your_activity: null,\n                    profile_activity: w,\n                    activity: w,\n                    dashboard: [_(\"{{{sources_screen_name_0}}} made a list\"),_(\"{{{sources_screen_name_0}}} made {{#link_targets_count}}\\u003Cspan class='dashboard-activity-item-count'\\u003E{{/link_targets_count}}\\u003Cspan class='count-wrap'\\u003E{{full_targets_count}}\\u003C/span\\u003E{{#link_targets_count}}\\u003C/span\\u003E{{/link_targets_count}}&#32;lists\"),]\n                }\n            }, B = {\n                your_activity: {\n                    sourceClass: l,\n                    targetClass: null,\n                    targetObjectClass: null\n                },\n                profile_activity: {\n                    sourceClass: l,\n                    targetClass: l,\n                    targetObjectClass: null\n                },\n                activity: {\n                    sourceClass: l,\n                    targetClass: l,\n                    targetObjectClass: null\n                },\n                dashboard: {\n                    sourceClass: l,\n                    targetClass: l,\n                    targetObjectClass: null\n                }\n            }, C = {\n                favorite: {\n                    your_activity: {\n                        sourceClass: l,\n                        targetClass: null,\n                        targetObjectClass: null\n                    },\n                    profile_activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: null\n                    },\n                    activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: null\n                    },\n                    dashboard: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: null\n                    }\n                },\n                mention: B,\n                reply: B,\n                retweet: {\n                    your_activity: {\n                        sourceClass: l,\n                        targetClass: null,\n                        targetObjectClass: null\n                    },\n                    profile_activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: l\n                    },\n                    activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: l\n                    },\n                    dashboard: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: l\n                    }\n                },\n                follow: B,\n                list_member_added: {\n                    your_activity: {\n                        sourceClass: l,\n                        targetClass: null,\n                        targetObjectClass: m\n                    },\n                    profile_activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: m\n                    },\n                    activity: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: m\n                    },\n                    dashboard: {\n                        sourceClass: l,\n                        targetClass: l,\n                        targetObjectClass: m\n                    }\n                },\n                list_created: {\n                    your_activity: null,\n                    profile_activity: {\n                        sourceClass: l,\n                        targetClass: m,\n                        targetObjectClass: null\n                    },\n                    activity: {\n                        sourceClass: l,\n                        targetClass: m,\n                        targetObjectClass: null\n                    },\n                    dashboard: {\n                        sourceClass: l,\n                        targetClass: m,\n                        targetObjectClass: null\n                    }\n                }\n            }, D = {\n                favorite: \"activity-fav\",\n                mention: \"activity-reply\",\n                reply: \"activity-reply\",\n                retweet: \"activity-rt\",\n                follow: \"activity-follow\",\n                list_member_added: \"activity-list\",\n                list_created: \"activity-list\"\n            }, E;\n            ((twttr.isT1 ? E = {\n                favorite: ((((!y && !z)) ? [_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other favorite\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other favorite\\u003C/span\\u003E\"),_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other favorites\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other favorites\\u003C/span\\u003E\"),] : ((y ? [_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other like\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other like\\u003C/span\\u003E\"),_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other likes\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other likes\\u003C/span\\u003E\"),] : [_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other star\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other star\\u003C/span\\u003E\"),_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other stars\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other stars\\u003C/span\\u003E\"),])))),\n                mention: null,\n                reply: [_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other reply\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other reply\\u003C/span\\u003E\"),_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other replies\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other reply\\u003C/span\\u003E\"),],\n                retweet: [_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other retweet\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other retweet\\u003C/span\\u003E\"),_(\"\\u003Cspan class='show-text'\\u003E{{hidden_count}} other retweets\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other retweets\\u003C/span\\u003E\"),],\n                follow: null,\n                list_member_added: null,\n                list_created: null\n            } : E = {\n                favorite: _(\"\\u003Cspan class='show-text'\\u003EView other favorited Tweets by {{screen_name}}\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other favorited Tweets by {{screen_name}}\\u003C/span\\u003E\"),\n                mention: null,\n                reply: _(\"\\u003Cspan class='show-text'\\u003EView other replies by {{screen_name}}\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other replies by {{screen_name}}\\u003C/span\\u003E\"),\n                retweet: _(\"\\u003Cspan class='show-text'\\u003EView other retweets by {{screen_name}}\\u003C/span\\u003E\\u003Cspan class='hide-text'\\u003EHide other retweets by {{screen_name}}\\u003C/span\\u003E\"),\n                follow: null,\n                list_member_added: null,\n                list_created: null\n            })), this.statics({\n                objectClasses: C,\n                objectStrings: A,\n                supplements: s,\n                iconClasses: D,\n                supplementViewAllSentences: E,\n                lineItemObjects: u,\n                maxQualifiedEntities: a,\n                viewForObjectType: q,\n                substitutionKeyForObjectType: r,\n                translateToObjectType: o\n            });\n        }), a(twttr.mixins.ActivityViewHelpers);\n    });\n});\nprovide(\"multiGlobals/more_views\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.view(\"twttr.views.BaseAPIList\", function() {\n            var a = this;\n            twttr.views.Base.apply(this, arguments), this.items = [];\n            if (!this.obj) {\n                return;\n            }\n        ;\n        ;\n            this.obj.each(function(b) {\n                a.items.push(new a.ItemView(b));\n            });\n        }).methods({\n            ItemView: twttr.views.BaseAPI\n        }), twttr.view(\"twttr.views.UserImage24\").template(twttr.templates.user_image_24), twttr.view(\"twttr.views.UserAvatarLink24\").template(twttr.templates.user_avatar_link_24), twttr.view(\"twttr.views.LinkSimpleList\", function(a) {\n            this.links = a;\n        }), twttr.view(\"twttr.views.LinkList\", function(a, b) {\n            var a = ((a.array || a)), c = ((a.length - 1));\n            this.links = twttr.map(a, function(a, d) {\n                return twttr.merge({\n                    separator: ((((d == c)) ? !1 : b))\n                }, a);\n            });\n        }), twttr.view(\"twttr.views.SlideshowTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.SimpleTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.SimpleTweetLarge\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.SingleTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).methods({\n            linkified_text: function() {\n                var a = twttr.views.BaseTweet.prototype.linkified_text.apply(this, arguments), b = $(((((\"\\u003Cdiv\\u003E\" + a)) + \"\\u003C/div\\u003E\"))).JSBNG__find(\"a[data-twitter-media-url='true']\").attr(\"target\", \"\").end();\n                return b.html();\n            },\n            include_embed_link: function() {\n                return ((((twttr.decider.isAvailable(\"embed_code_dialog\") && twttr.app.isOnPage(\"permalink\"))) && !this.user[\"protected\"]));\n            },\n            is_permalink: function() {\n                return twttr.app.isOnPage(\"permalink\");\n            }\n        }), twttr.view(\"twttr.views.FollowingTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).methods({\n            show_follow_action: !0\n        }), twttr.view(\"twttr.views.DiscoveryStreamTweet\", function() {\n            twttr.views.StreamTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.StreamTweet).template(twttr.templates.stream_tweet_discovery).statics({\n            has: function(a, b) {\n                var c = ((b.hasOwnProperty(a) && !twttr.is.falsy(b[a])));\n                if (((c && twttr.is.array(b[a])))) {\n                    if (((b[a].length == 0))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    b[a][((b[a].length - 1))].is_last = !0;\n                }\n            ;\n            ;\n                return c;\n            }\n        }).methods({\n            show_follow_action: !0,\n            has_retweeters: function() {\n                return twttr.views.DiscoveryStreamTweet.has(\"retweeters\", this.network_activity);\n            },\n            has_retweet_count: function() {\n                return twttr.views.DiscoveryStreamTweet.has(\"retweet_count\", this);\n            }\n        }), twttr.view(\"twttr.views.ActivityItemTweet\", function() {\n            twttr.views.StreamTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.StreamTweet).methods({\n            should_callout_tweet_actions: function() {\n                return !0;\n            }\n        }), twttr.view(\"twttr.views.UnclickableTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).methods({\n            linkified_text: function() {\n                var a = twttr.views.BaseTweet.prototype.linkified_text.apply(this, arguments), b = $(((((\"\\u003Cdiv\\u003E\" + a)) + \"\\u003C/div\\u003E\")));\n                return b.JSBNG__find(\"a\").replaceWith(function() {\n                    return ((((\"\\u003Ca\\u003E\" + $(this).contents().text())) + \"\\u003C/a\\u003E\"));\n                }), b.html();\n            }\n        }), twttr.view(\"twttr.views.WelcomeLearnGameTweet\", function() {\n            twttr.views.UnclickableTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.UnclickableTweet), twttr.view(\"twttr.views.SemiClickableTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).template(twttr.templates.unclickable_tweet).methods({\n            linkified_text: function() {\n                var a = twttr.views.BaseTweet.prototype.linkified_text.apply(this, arguments), b = $(((((\"\\u003Cdiv\\u003E\" + a)) + \"\\u003C/div\\u003E\")));\n                return b.JSBNG__find(\"a.pretty-link\").each(function() {\n                    $(this).addClass(\"non-link\").removeAttr(\"href\");\n                }), b.html();\n            }\n        }), twttr.view(\"twttr.views.LatestTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).methods({\n            full_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp(), !0, !1, !0);\n            }\n        }), twttr.view(\"twttr.views.ActivityItemTruncatedTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.EmbeddedTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.DetailsPaneTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.InReplyTo\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.ProfilePane\", function() {\n            twttr.views.BaseStats.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseStats).methods({\n            impression_cookie: function() {\n                if (!this.promoted_content) {\n                    return;\n                }\n            ;\n            ;\n                var a = [];\n                return JSON.stringify([this.id,this.promoted_content.impression_id,this.promoted_content.disclosure_type,this.promoted_content.disclosure_text,a,]);\n            }\n        }), twttr.view(\"twttr.views.MessageThread\", function(a) {\n            twttr.views.Base.apply(this, arguments), this.items = [];\n            for (var b = 0; ((b < a.length)); b++) {\n                this.items.push(new twttr.views.Message(a[b]));\n            ;\n            };\n        ;\n        }).subclassOf(twttr.views.Base), twttr.view(\"twttr.views.ConversationThread\", function(a) {\n            twttr.views.Base.apply(this, arguments), this.items = [];\n            var b = null;\n            for (var c = 0; ((c < a.messages.length)); c++) {\n                var d = new twttr.views.Message(a.messages[c]);\n                ((((b && ((b.time_ago() !== d.time_ago())))) && (d.delimiter_text = d.time_ago()))), this.items.push(d), b = d;\n            };\n        ;\n        }).subclassOf(twttr.views.Base).methods({\n            screen_name: function() {\n                return this.threadId;\n            }\n        }), twttr.view(\"twttr.views.SmsFollow\").methods({\n            show_sms_prompt: function() {\n                return (($.inArray(twttr.pageLocale, [\"ja\",\"ko\",]) == -1));\n            },\n            sms_follow_text: function() {\n                var a = ((((\"\\u003Cstrong\\u003Efollow \" + this.screen_name)) + \"\\u003C/strong\\u003E\"));\n                switch (twttr.requestFullCity.substr(0, 2).toLowerCase()) {\n                  case \"us\":\n                    var b = \"40404\", c = _(\"the United States\");\n                    break;\n                  case \"ca\":\n                    var b = \"21212\", c = _(\"Canada\");\n                    break;\n                  default:\n                    return _(\"Text {{{command}}} to \\u003Ca href=\\\"#\\\" class=\\\"sms-codes-link\\\"\\u003Eyour carrier's shortcode\\u003C/a\\u003E\", {\n                        command: a\n                    });\n                };\n            ;\n                return _(\"Text {{{command}}} to {{{number}}} in {{{country}}}\", {\n                    command: a,\n                    number: ((((\"\\u003Cstrong\\u003E\" + b)) + \"\\u003C/strong\\u003E\")),\n                    country: ((((\"\\u003Ca href=\\\"#\\\" class=\\\"sms-codes-link\\\"\\u003E\" + c)) + \"\\u003C/a\\u003E\"))\n                });\n            }\n        }), twttr.view(\"twttr.views.PermalinkSignupCallOut\").subclassOf(twttr.views.SmsFollow), twttr.view(\"twttr.views.ProfileActions\").subclassOf(twttr.views.SmsFollow).methods({\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            can_view: function() {\n                return twttr.helpers.canViewUser(this.user);\n            },\n            show_device_notifications: function() {\n                return ((((!this.is_current_user() && this.following)) && ((((twttr.currentUser.lang != \"ja\")) || twttr.decider.isAvailable(\"email_device_settings\")))));\n            },\n            notifications_on_for_user: function() {\n                return ((twttr.currentUser.deviceSetup && this.notifications));\n            },\n            is_admin: function() {\n                return twttr.is.def(twttr.isAdmin);\n            }\n        }), twttr.view(\"twttr.views.MessageThreadPreview\").methods({\n            last_was_yours: function() {\n                return twttr.helpers.isCurrentUser(this.last_message().sender);\n            },\n            message_count: function() {\n                return this.messages.length;\n            },\n            last_message: function() {\n                return ((this._last_message ? this._last_message : this._last_message = new twttr.views.Message(this.messages[0])));\n            },\n            other_person: function() {\n                return new twttr.views.User(((this.last_was_yours() ? this.last_message().recipient : this.last_message().sender)));\n            },\n            has_new_message: function() {\n                return this.obj.hasNewMessages();\n            }\n        }), twttr.view(\"twttr.views.ConversationThreadUser\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.ConversationThreadPreview\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            message_count: function() {\n                return this.count;\n            },\n            last_message_date: function() {\n                return this.lastMessageDate;\n            },\n            timestamp: function() {\n                return twttr.helpers.timeAgo(this.lastMessageDate, !0, !0);\n            },\n            other_person: function() {\n                return new twttr.views.ConversationThreadUser(this.user);\n            }\n        }), twttr.view(\"twttr.views.Message\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            linkified_text: function() {\n                var a = b.util.linkify(this.text, {\n                    nofollow: !0\n                });\n                return a = b.util.linkifyEntities(a, this), a;\n            },\n            timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp(), !0, !0);\n            },\n            time_ago: function() {\n                return twttr.helpers.timeAgoRounded(this.actual_timestamp());\n            },\n            actual_timestamp: function() {\n                return twttr.helpers.parseDateString(this.created_at);\n            }\n        }), twttr.view(\"twttr.views.ProfileSignupCallOut\", function() {\n            twttr.views.BaseStats.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseStats), twttr.view(\"twttr.views.DashboardProfileStats\", function(a, b) {\n            twttr.views.BaseStats.apply(this, [a,]), this.profileStatsTitle = b;\n        }).subclassOf(twttr.views.BaseStats).methods({\n            profile_stats_title: function() {\n                return ((this.profileStatsTitle || _(\"About @{{screen_name}}\", {\n                    screen_name: this.obj.screenName\n                })));\n            }\n        }), twttr.view(\"twttr.views.UserStats\", function() {\n            twttr.views.BaseStats.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseStats), twttr.view(\"twttr.views.TrendItem\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            is_sponsored: function() {\n                return !!this.promoted_content;\n            },\n            is_event: function() {\n                return !!this.event_id;\n            },\n            event_class: function() {\n                return \"badge-top\";\n            },\n            event_title: function() {\n                return _(\"Trending event\");\n            },\n            promoted_badge_class: function() {\n                return ((\"badge-\" + ((this.promoted_content.disclosure_type || \"promoted\"))));\n            },\n            trend_search_path: function() {\n                return twttr.router.searchResultsPath({\n                    query: decodeURIComponent(this.query)\n                });\n            },\n            search_query_source: function() {\n                return twttr.search.searchQuerySource.TREND;\n            }\n        }), twttr.view(\"twttr.views.LocalTrendLocation\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.LocalTrendLocationNew\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.FollowList\").methods({\n            follow_list: function() {\n                return (new twttr.views.UserThumbList(this.users)).html();\n            }\n        }), twttr.view(\"twttr.views.LocalTrends\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            _sortPlaces: function(a) {\n                return a.sort(function(a, b) {\n                    return ((((a.JSBNG__name < b.JSBNG__name)) ? -1 : ((((a.JSBNG__name > b.JSBNG__name)) ? 1 : 0))));\n                });\n            },\n            country_locations: function() {\n                var a = [], c;\n                for (var d = 0; ((d < this.items.length)); d++) {\n                    var e = this.items[d];\n                    if (((e.placeType.code !== b.constants.placeTypes.city))) {\n                        if (((e.placeType.code == 19))) {\n                            c = e;\n                            continue;\n                        }\n                    ;\n                    ;\n                        a.push(e);\n                    }\n                ;\n                ;\n                };\n            ;\n                return a = this._sortPlaces(a), ((c && a.unshift(c))), a;\n            },\n            city_locations: function() {\n                var a = [];\n                for (var c = 0; ((c < this.items.length)); c++) {\n                    var d = this.items[c];\n                    ((((d.placeType.code === b.constants.placeTypes.city)) && a.push(d)));\n                };\n            ;\n                return a = this._sortPlaces(a), a;\n            }\n        }), twttr.view(\"twttr.views.LocalTrendsNew\", function(a, b) {\n            twttr.views.BaseAPIList.call(this, a), this.forceShowLocations = b;\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            _sortPlaces: function(a) {\n                return a.sort(function(a, b) {\n                    return ((((a.JSBNG__name < b.JSBNG__name)) ? -1 : ((((a.JSBNG__name > b.JSBNG__name)) ? 1 : 0))));\n                });\n            },\n            breadcrumbs: function() {\n                if (this.is_personalized()) {\n                    return null;\n                }\n            ;\n            ;\n                var a = twttr.trendLocations.withFilterAncestors().reverse();\n                if (twttr.decider.isAvailable(\"personalized_trends\")) {\n                    var b = twttr.trendLocations.current;\n                    ((((a[((a.length - 1))].woeid != b.woeid)) && a.push(b)));\n                }\n            ;\n            ;\n                return a[((a.length - 1))] = $.extend({\n                    is_last: !0\n                }, a[((a.length - 1))]), a;\n            },\n            is_personalized: function() {\n                return ((twttr.decider.isAvailable(\"personalized_trends\") && twttr.trendLocations.current.isPersonalized));\n            },\n            show_personalized: function() {\n                return ((this.is_personalized() && !this.forceShowLocations));\n            },\n            locations: function() {\n                var a = this._sortPlaces(twttr.trendLocations.currentChildren());\n                return ((twttr.trendLocations.current.isPersonalized && a.unshift(twttr.trendLocations.worldwide()))), a;\n            },\n            locationsFor: function(a) {\n                var b = this.locations(), c = Math.ceil(((b.length / 3)));\n                return b.slice(((a * c)), ((((a + 1)) * c)));\n            },\n            locations0: function() {\n                return this.locationsFor(0);\n            },\n            locations1: function() {\n                return this.locationsFor(1);\n            },\n            locations2: function() {\n                return this.locationsFor(2);\n            }\n        }), twttr.view(\"twttr.views.Dialog\", function(a) {\n            this.options = a;\n            var b = ((this.options.template || this.options));\n            twttr.views.Base.call(this, b);\n        }), twttr.view(\"twttr.views.TweetDialog\", function(a) {\n            this.options = a, this.options.fixed = !0, twttr.views.Dialog.call(this, a);\n        }).subclassOf(twttr.views.Dialog).template(twttr.templates.dialog).methods(twttr.EventProvider).methods({\n            afterRender: function(a) {\n                var b = {\n                    container_id: \"tweetbox\",\n                    condensed: !1,\n                    closeAfterSuccess: !1,\n                    template: {\n                        button_text: ((this.options.tweetButton || _(\"Tweet\"))),\n                        show_geo: this.options.template.show_geo,\n                        show_turkey: this.options.template.show_turkey\n                    },\n                    statusAction: ((this.options.statusAction || \"update\")),\n                    data: this.options.data,\n                    defaultContent: ((this.options.defaultContent || \"\")),\n                    height: 56,\n                    width: 452,\n                    origin: this.options.origin,\n                    enableDraft: this.options.enableDraft,\n                    enableAutoGrow: !0\n                };\n                this.tweetBox = new twttr.TweetBox(a.JSBNG__find(\".twttr-dialog-content\"), b), this.tweetBox.bind(\"ready\", twttr.bind(this, function() {\n                    this.trigger(\"ready\");\n                }));\n            }\n        }), twttr.view(\"twttr.views.Footer\", function() {\n            twttr.views.Base.apply(this, arguments);\n        }).methods({\n            year: function() {\n                return (new JSBNG__Date).getFullYear();\n            }\n        }), twttr.view(\"twttr.views.ReplyDialog\", function(a) {\n            this.options = a, this.options.statusAction = \"reply\", twttr.views.TweetDialog.call(this, this.options);\n        }).subclassOf(twttr.views.TweetDialog).mixin(twttr.mixins.i18nTweet).template(twttr.templates.dialog).methods({\n            afterRender: function(a) {\n                twttr.views.TweetDialog.prototype.afterRender.call(this, a);\n                var c = this;\n                twttr.API.Status.JSBNG__find(this.options.data.tweetId, twttr.bind(this, function(d) {\n                    var e = new twttr.views.ReplyDialogFooter({\n                        screen_name: d.user.screenName,\n                        text: b.util.linkifyEntities(b.util.linkify(d.text, {\n                            nofollow: !0\n                        }), d),\n                        profile_image_url: d.user.profileImageUrl\n                    });\n                    e.render(a.JSBNG__find(\".twttr-dialog-footer\"), \"append\"), a.JSBNG__find(\"div.tweet\").each(function() {\n                        c.updateRtlDisplay($(this));\n                    });\n                }));\n            }\n        }), twttr.view(\"twttr.views.KeyboardShortcuts\").methods({\n            current_user_screen_name: function() {\n                return twttr.currentUser.screenName;\n            }\n        }), twttr.view(\"twttr.views.UserThumbList\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.BaseUser\n        }), twttr.view(\"twttr.views.TweetActivityThumbList\", function() {\n            twttr.views.UserThumbList.apply(this, arguments), twttr.each(this.items.slice(this.constructor.max_items_to_show), function(a) {\n                a.is_hidden = !0;\n            });\n        }).template(twttr.templates.user_thumb_list).subclassOf(twttr.views.UserThumbList).statics({\n            max_items_to_show: 5\n        }), twttr.view(\"twttr.views.UserSmallListItem\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.UserThumbListItem\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.UserSmallList\", function(a) {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.UserSmallListItem\n        }), twttr.view(\"twttr.views.UserDetailedListItem\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.UserDetailedList\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.UserDetailedListItem\n        }), twttr.view(\"twttr.views.UserStaticListItem\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.UserStaticList\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.UserStaticListItem\n        }), twttr.view(\"twttr.views.UserItemAction\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.RecentlyViewed\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.BaseUser\n        }), twttr.view(\"twttr.views.ContactImportMatchesStats\", function() {\n            twttr.views.Base.apply(this, arguments);\n        }).subclassOf(twttr.views.Base).methods({\n            follow_all_text: function() {\n                return ((((this.count <= 1)) ? _(\"Follow all\") : _(\"Follow all {{count}}\", {\n                    count: ((this.count - this.following_count))\n                })));\n            }\n        }), twttr.view(\"twttr.views.DashboardContactImportMatchesStats\", function() {\n            twttr.views.ContactImportMatchesStats.apply(this, arguments);\n        }).subclassOf(twttr.views.ContactImportMatchesStats), twttr.view(\"twttr.views.MatchedContactUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.InviteContacts\", function() {\n            twttr.views.Base.apply(this, arguments);\n        }).subclassOf(twttr.views.Base).methods({\n            select_all_text: function() {\n                return ((((this.contacts.length == 1)) ? _(\"Select all\") : _(\"Select all {{count}}\", {\n                    count: this.contacts.length\n                })));\n            },\n            preview_link_url: twttr.router.invitationEmailPreviewPath,\n            truncate: function() {\n                return function(a, b) {\n                    var c = 28, d = b(a);\n                    return twttr.helpers.truncate(d, c);\n                };\n            }\n        }), twttr.view(\"twttr.views.FollowingPage\").methods({\n            following_header_string: function() {\n                var a = this.friends_count;\n                if (((a == 1))) {\n                    return ((this.is_current_user() ? _(\"You follow 1 person\") : _(\"{{user}} follows 1 person\", {\n                        user: this.JSBNG__name\n                    })));\n                }\n            ;\n            ;\n                var c = b.util.formatNumber(a, twttr.pageLocale);\n                return ((this.is_current_user() ? _(\"You follow {{num}} people\", {\n                    num: c\n                }) : _(\"{{user}} follows {{num}} people\", {\n                    user: this.JSBNG__name,\n                    num: c\n                })));\n            },\n            following_count_commaized: function() {\n                return b.util.formatNumber(this.friends_count, twttr.pageLocale);\n            }\n        }), twttr.view(\"twttr.views.FollowingSubtabs\", function() {\n            twttr.views.Base.apply(this, arguments), this[((\"active_subtab_\" + this.subtab))] = 1, this.screen_name = this.screenName;\n        }).subclassOf(twttr.views.Base), twttr.view(\"twttr.views.FollowersPage\").methods({\n            followers_header_string: function() {\n                var a = this.followers_count;\n                if (((a == 1))) {\n                    return ((this.is_current_user() ? _(\"You have 1 follower\") : _(\"{{user}} has 1 follower\", {\n                        user: this.JSBNG__name\n                    })));\n                }\n            ;\n            ;\n                var c = b.util.formatNumber(a, twttr.pageLocale);\n                return ((this.is_current_user() ? _(\"You have {{num}} followers\", {\n                    num: c\n                }) : _(\"{{user}} has {{num}} followers\", {\n                    user: this.JSBNG__name,\n                    num: c\n                })));\n            },\n            followers_count_commaized: function() {\n                return b.util.formatNumber(this.followers_count, twttr.pageLocale);\n            }\n        }), twttr.view(\"twttr.views.FollowersSubtabs\", function() {\n            twttr.views.Base.apply(this, arguments), this[((\"active_subtab_\" + this.subtab))] = 1, this.screen_name = this.screenName;\n        }).subclassOf(twttr.views.Base), twttr.view(\"twttr.views.WelcomeAmbassador\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.WelcomeLearnFlow\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser).methods({\n            JSBNG__name: function() {\n                return twttr.currentUser.JSBNG__name;\n            }\n        }), twttr.view(\"twttr.views.RecentTweets\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.SimpleTweet,\n            screen_name: function() {\n                return this.items[0].user.screen_name;\n            }\n        }), twttr.view(\"twttr.views.Replies\", function(a, b, c) {\n            twttr.views.BaseAPI.apply(this, arguments), this.descendants = ((b || [])), this.forks = ((c || []));\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            _viewFor: function(a) {\n                return new twttr.views.StreamTweet(a);\n            },\n            _viewsFor: function(a) {\n                var b = this;\n                return twttr.map(a, function(a) {\n                    return b._viewFor(a);\n                });\n            },\n            has_replies: function() {\n                return !0;\n            },\n            has_tweets: function() {\n                return ((((this.descendants.length > 0)) || ((this.forks.length > 0))));\n            },\n            descendant_tweet_views: function() {\n                return this._viewsFor(this.descendants);\n            },\n            fork_tweet_views: function() {\n                return this._viewsFor(this.forks);\n            },\n            JSBNG__on_permalink: function() {\n                return twttr.app.isOnPage(\"permalink\");\n            }\n        }), twttr.view(\"twttr.views.TweetActivity\").methods({\n            _list_for: function(a) {\n                return userList = new twttr.API.util.BaseCollection(a), (new twttr.views.TweetActivityThumbList(userList)).html();\n            },\n            _count_for: function(a, b) {\n                return (new twttr.views.TweetActivityCount({\n                    length: a,\n                    is_retweets: ((b === \"retweeters\")),\n                    is_favorites: ((b === \"favoriters\")),\n                    is_replies: ((b === \"repliers\"))\n                })).html();\n            },\n            _show_count: function(a) {\n                return ((a.length > twttr.views.TweetActivityThumbList.max_items_to_show));\n            },\n            show_retweets_count: function() {\n                return this._show_count(this.activities.retweeters);\n            },\n            show_replies_count: function() {\n                return this._show_count(this.activities.repliers);\n            },\n            show_favorites_count: function() {\n                return this._show_count(this.activities.favoriters);\n            },\n            favorites_list: function() {\n                return this._list_for(this.activities.favoriters);\n            },\n            retweets_list: function() {\n                return this._list_for(this.activities.retweeters);\n            },\n            replies_list: function() {\n                return this._list_for(this.activities.repliers);\n            },\n            retweets_count: function() {\n                return this._count_for(this.counts.retweeters_count, \"retweeters\");\n            },\n            favorites_count: function() {\n                return this._count_for(this.counts.favoriters_count, \"favoriters\");\n            },\n            replies_count: function() {\n                return this._count_for(this.counts.repliers_count, \"repliers\");\n            },\n            is_retweets_empty: function() {\n                return ((this.activities.retweeters.length === 0));\n            },\n            is_favorites_empty: function() {\n                return ((this.activities.favoriters.length === 0));\n            },\n            is_replies_empty: function() {\n                return ((this.activities.repliers.length === 0));\n            },\n            is_activity_empty: function() {\n                var a = ((this.is_favorites_empty() && this.is_retweets_empty())), b = ((!this.in_permalink_page && a)), c = ((((this.in_permalink_page && this.is_replies_empty())) && a));\n                return ((b || c));\n            }\n        }), twttr.view(\"twttr.views.ActivityOfMeStreamTitle\").methods({\n            should_see_activity_filters: function() {\n                return ((twttr.currentUser && ((twttr.currentUser.followersCount >= 2000))));\n            }\n        }), twttr.view(\"twttr.views.ActivityItemUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.ActivityItem\", function() {\n            twttr.views.BaseAPI.apply(this, arguments), this.is_your_activity = ((this.for_stream === \"your_activity\")), this.is_network_activity = ((this.for_stream === \"activity\"));\n        }).subclassOf(twttr.views.BaseAPI).template(twttr.templates.activity_item).mixin(twttr.mixins.ActivityViewHelpers).methods({\n            _getSupplement: function(a) {\n                var b = this.constructor.supplements[this.for_stream][this.JSBNG__event];\n                ((b.primary && (b = ((a ? b.secondary : b.primary)))));\n                if (((b.sources && b.targets))) {\n                    var c = ((((((this.is_retweet || this.is_favorite)) && ((this.sources.length === 1)))) && ((this.targets.length > 1))));\n                    b = ((c ? b.targets : b.sources));\n                }\n            ;\n            ;\n                return b;\n            },\n            _traverse: function(a, b, c) {\n                ((twttr.is.def(c) || (c = 0)));\n                if (((!b || ((c >= b.length))))) {\n                    return a;\n                }\n            ;\n            ;\n                var d = b[c];\n                if (((twttr.is.def(a[d]) && !twttr.is.nil(a[d])))) {\n                    return this._traverse(a[d], b, ((c + 1)));\n                }\n            ;\n            ;\n            },\n            _populateSubsWithObjects: function(a, b, c, d) {\n                if (!d) {\n                    return;\n                }\n            ;\n            ;\n                var e = this;\n                return twttr.inject(a, b, function(a, b, f) {\n                    var g = e.constructor.substitutionKeyForObjectType[d], i = twttr.API.Activity.classMap[e.JSBNG__event][c], j = e._traverse(f, e.constructor.translateToObjectType[d][i]);\n                    return a[((((((((c + \"_\")) + g)) + \"_\")) + b))] = (new twttr.views[e.constructor.viewForObjectType[e.for_stream][d]](j)).html(), a;\n                });\n            },\n            _populateSubsWithCounts: function(a, b, c) {\n                var d = ((c + \"_count\")), e = this[((c + \"_size\"))];\n                return b[((\"full_\" + d))] = e, b[d] = ((e - 1)), b;\n            },\n            _activity_supplement: function(a) {\n                var b = this, c = this._getSupplement(((a || !1))), d = 4, e = twttr.views[c.view], f = this[c.object], g = ((Math.min(c.max, f.length) - 1)), i = ((twttr.views.StreamUser === e));\n                return twttr.map(f, function(c, f) {\n                    var j;\n                    return ((((a && ((f == 0)))) ? \"\" : (c.embedded_by_activity = !0, c.is_your_activity = b.is_your_activity, c.is_network_activity = b.is_network_activity, c.for_activity = ((c.is_your_activity || c.is_network_activity)), ((((f > g)) && ((twttr.isT1 ? (c.hidden_by_activity = !0, c.hidden_stack_class_name = ((((f < d)) ? ((\"stack-item-\" + f)) : \"stack-item-hidden\"))) : c.hidden = !0)))), j = new e(c), ((i && ((b.is_your_activity ? (j.avatar_size_class = \"size24\", j.profile_image_url = j.mini_profile_image_url()) : (j.avatar_size_class = \"size73\", j.profile_image_url = j.bigger_profile_image_url()))))), ((twttr.isT1 ? Mustache.to_html(\"\\u003Cdiv class='supplement{{#is_hidden_supplement}} hidden-supplement {{hidden_stack_class_name}}{{/is_hidden_supplement}}{{^is_hidden_supplement}} visible-supplement{{/is_hidden_supplement}}'\\u003E{{{supplement}}}\\u003C/div\\u003E\", {\n                        supplement: j.html(),\n                        is_hidden_supplement: c.hidden_by_activity,\n                        hidden_stack_class_name: c.hidden_stack_class_name\n                    }) : j.html())))));\n                }).join(\"\");\n            },\n            icon_class: function() {\n                return this.constructor.iconClasses[this.JSBNG__event];\n            },\n            should_show_first_actor: function() {\n                return ((!this.is_your_activity || this.is_list_member_added));\n            },\n            first_actor: function() {\n                return new twttr.views.BaseUser(this.sources[0]);\n            },\n            view_all_supplements_sentence: function() {\n                var a = this.constructor.supplementViewAllSentences[this.JSBNG__event];\n                if (!a) {\n                    return \"\";\n                }\n            ;\n            ;\n                var b;\n                if (twttr.isT1) {\n                    var c = this.hidden_supplements_count();\n                    a = a[((Math.min(a.length, c) - 1))], b = {\n                        hidden_count: c\n                    };\n                }\n                 else b = this.sources[0];\n            ;\n            ;\n                return Mustache.to_html(a, b);\n            },\n            has_secondary_supplement: function() {\n                var a = ((this.sources.length > this.constructor.maxQualifiedEntities));\n                return ((((!this.is_your_activity && a)) && ((((this.is_follow || ((this.is_retweet && ((this.target_objects.length === 1)))))) || ((this.is_favorite && ((this.targets.length === 1))))))));\n            },\n            has_hidden_supplements: function() {\n                var a = this._getSupplement(), b = this[a.object];\n                return ((((b.length > a.max)) && ((a.objectType === \"Status\"))));\n            },\n            hidden_supplements_count: function() {\n                if (!this.has_hidden_supplements()) {\n                    return 0;\n                }\n            ;\n            ;\n                var a = this._getSupplement(), b = this[a.object];\n                return ((b.length - a.max));\n            },\n            supplement_count: function() {\n                var a = this._getSupplement(), b = this[a.object];\n                return b.length;\n            },\n            user_supplement_and_count_greater_than_two: function() {\n                return ((((this.is_follow || this.is_list_member_added)) && ((this.supplement_count() > 2))));\n            },\n            user_supplement_and_count_exactly_two: function() {\n                return ((((this.is_follow || this.is_list_member_added)) && ((this.supplement_count() === 2))));\n            },\n            should_show_truncated_tweet: function() {\n                return ((((this.is_your_activity && ((this.is_retweet || this.is_favorite)))) && this._getSupplement().useTruncated));\n            },\n            truncated_tweet: function() {\n                var a;\n                if (this.is_retweet) a = this.target_objects[0];\n                 else {\n                    if (!this.is_favorite) {\n                        throw new Error(\"You shouldn't be using truncated_tweet() if not a retweet or favorite!\");\n                    }\n                ;\n                ;\n                    a = this.targets[0];\n                }\n            ;\n            ;\n                return (new twttr.views.LatestTweet(a)).html();\n            },\n            activity_supplement: function() {\n                return this._activity_supplement();\n            },\n            activity_secondary_supplement: function() {\n                return this._activity_supplement(!0);\n            },\n            activity_line: function() {\n                var a = this, b = {\n                }, c = this.constructor.objectClasses[this.JSBNG__event][this.for_stream], d = this.constructor.objectStrings[this.JSBNG__event][this.for_stream];\n                ((((!d || !c)) && JSBNG__console.error(\"Should not have an activity item with this verb in this stream!\", this)));\n                var e = this.constructor.lineItemObjects;\n                b.position = this.min_position, this._populateSubsWithObjects(this[e[this.JSBNG__event].sources], b, \"sources\", c.sourceClass), this._populateSubsWithObjects(this[e[this.JSBNG__event].targets], b, \"targets\", c.targetClass), this._populateSubsWithObjects(this[e[this.JSBNG__event].target_objects], b, \"target_objects\", c.targetObjectClass), this._populateSubsWithCounts(this.sources, b, \"sources\"), this._populateSubsWithCounts(this.targets, b, \"targets\"), this._populateSubsWithCounts(this.target_objects, b, \"target_objects\");\n                var f = this._getSupplement();\n                if (((((this.is_your_activity && ((this.sources.length > f.max)))) || this.has_secondary_supplement()))) {\n                    b.link_sources_count = !0;\n                }\n            ;\n            ;\n                var g = d[((Math.min(this.sources.length, d.length) - 1))];\n                return ((twttr.is.array(g) && (g = g[((Math.min(this.targets.length, g.length) - 1))], ((twttr.is.array(g) && (g = g[((Math.min(this.target_objects.length, g.length) - 1))])))))), Mustache.to_html(g, b);\n            },\n            full_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp(), !0);\n            },\n            actual_timestamp: function() {\n                return twttr.helpers.parseDateString(this.created_at);\n            },\n            afterRender: function(a) {\n                ((twttr.isT1 || ((this.is_your_activity && JSBNG__setTimeout(function() {\n                    twttr.helpers.ellipsify(a.JSBNG__find(\".stream-item-activity-line .tweet-row\"));\n                }, 0)))));\n            }\n        }), twttr.view(\"twttr.views.DashboardActivityItem\", function() {\n            twttr.views.ActivityItem.apply(this, arguments);\n        }).subclassOf(twttr.views.ActivityItem), twttr.view(\"twttr.views.StreamUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.DashboardStreamUser\", function() {\n            this.constructor.uber.constructor.apply(this, arguments);\n        }).subclassOf(twttr.views.StreamUser), twttr.view(\"twttr.views.StreamFollowerRequest\", function() {\n            this.constructor.uber.constructor.apply(this, arguments);\n        }).subclassOf(twttr.views.StreamUser), twttr.view(\"twttr.views.ProfileUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.ProfileFollowCard\", function() {\n            twttr.views.BaseStats.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseStats), twttr.view(\"twttr.views.MiniProfileStats\", function() {\n            twttr.views.BaseStats.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseStats), twttr.view(\"twttr.views.List\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            is_public: function() {\n                return ((((this.mode === \"public\")) || ((this.mode === undefined))));\n            },\n            is_own_list: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            user_list_path: function() {\n                return twttr.router.userListPath({\n                    screen_name: this.user.screen_name,\n                    list_slug: this.slug\n                });\n            },\n            list_subscribers_path: function() {\n                return twttr.router.listSubscribersPath({\n                    screen_name: this.user.screen_name,\n                    list_slug: this.slug\n                });\n            },\n            list_members_path: function() {\n                return twttr.router.listMembersPath({\n                    screen_name: this.user.screen_name,\n                    list_slug: this.slug\n                });\n            },\n            full_name_sans_at: function() {\n                return this.full_name.replace(/^[@＠]/, \"\");\n            }\n        }), twttr.view(\"twttr.views.ListLink\", function() {\n            twttr.views.List.apply(this, arguments);\n        }).subclassOf(twttr.views.List), twttr.view(\"twttr.views.NewestListMembers\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.StreamList\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListStreamTitle\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListHeader\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListActions\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListStreamTabs\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListFollowCard\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.ListOfLists\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.List\n        }), twttr.view(\"twttr.views.ListDialog\").subclassOf(twttr.views.List), twttr.view(\"twttr.views.Retweeters\", function(a) {\n            twttr.views.Base.apply(this, arguments), this.count = a.count, this.retweeters = a.retweeters.map(function(a) {\n                return new twttr.views.BaseUser(a);\n            }).array;\n        }).methods({\n            retweeted_by_count: function() {\n                var a = ((this.tweet.retweetingStatus ? new twttr.views.BaseUser(this.tweet.retweetingStatus.user) : this.retweeters[0])), b = Mustache.to_html(\"\\u003Ca class=\\\"user-profile-link\\\" data-user-id=\\\"{{id}}\\\" href=\\\"{{path}}\\\" \\u003E{{screen_name}}\\u003C/a\\u003E\", {\n                    id: a.id,\n                    path: twttr.router.profilePath({\n                        screen_name: a.screen_name\n                    }),\n                    screen_name: a.screen_name\n                });\n                return ((((this.count === 1)) ? _(\"Retweeted by {{{user_link}}}\", {\n                    user_link: b\n                }) : ((((this.count === 2)) ? _(\"Retweeted by {{{user_link}}} and 1 other\", {\n                    user_link: b\n                }) : ((this.count ? _(\"Retweeted by {{{user_link}}} and {{count}} others\", {\n                    user_link: b,\n                    count: this.count\n                }) : _(\"Retweeted by {{{user_link}}} and others\", {\n                    user_link: b\n                })))))));\n            }\n        }), twttr.view(\"twttr.views.ProfilePage\").methods({\n            has_pending_requests: function() {\n                return ((twttr.helpers.isProfileUser() && twttr.currentUser[\"protected\"]));\n            },\n            is_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!twttr.profileUser.withheldScope)) && ((twttr.profileUser.withheldScope == \"user\"))));\n            },\n            is_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!twttr.profileUser.withheldScope)) && ((twttr.profileUser.withheldScope == \"user\")))) && !!twttr.profileUser.withheldCopyright));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(twttr.profileUser.id);\n            },\n            render_withheld: function() {\n                return ((this.is_withheld() && !this.is_current_user()));\n            }\n        }), twttr.view(\"twttr.views.StreamSuggestionCategory\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            user_sample: function() {\n                return ((((this.obj.sample && this.obj.sample.length)) ? new twttr.views.UserStaticList(this.obj.sample.slice(0, 2)) : !1));\n            },\n            category_name: function() {\n                return this.obj.JSBNG__name;\n            }\n        }), twttr.view(\"twttr.views.CardNewsOnebox\").subclassOf(twttr.views.BaseAPI).methods({\n            article_image: function() {\n                return this.obj.getImage(twttr.isSSL());\n            },\n            article_url: function() {\n                return this.obj.getExpandedUrl();\n            },\n            article_display_url: function() {\n                return this.obj.getDisplayUrl();\n            }\n        }), twttr.view(\"twttr.views.CardEventOnebox\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.CardAccountsOneboxItem\").subclassOf(twttr.views.BaseUser).methods({\n            is_onebox: !0\n        }), twttr.view(\"twttr.views.CardAccountsOnebox\", function(a, b) {\n            twttr.views.BaseAPIList.call(this, a), this.view_all_path = b;\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.CardAccountsOneboxItem\n        }), using(((twttr.isT1 ? \"multiGlobals/more_views_t1\" : \"multiGlobals/more_views_p1\")), function() {\n            twttr.views.makeDefaultViews(twttr.templates), a();\n        });\n    });\n});\nprovide(\"multiGlobals/more_views_t1\", function(a) {\n    using(\"util\", \"constants\", \"mixins/t1/discoveryStoryHelpers\").as(function(b) {\n        twttr.view(\"twttr.views.MiniProfileUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.MiniCurrentUser\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.Nav\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.AvatarRow\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.BaseUser\n        }), twttr.view(\"twttr.views.TypeaheadSearchItem\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            search_query_source: function() {\n                return ((twttr.is.def(this.id) ? twttr.search.searchQuerySource.SAVED_SEARCH : twttr.search.searchQuerySource.TYPEAHEAD));\n            }\n        }), twttr.view(\"twttr.views.TypeaheadAccountsShortcut\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            search_query_source: function() {\n                return twttr.search.searchQuerySource.TYPEAHEAD;\n            }\n        }), twttr.view(\"twttr.views.ProtectedAncestorTweet\").subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.CardNews\", function(a) {\n            twttr.views.BaseAPI.call(this, a.JSBNG__content.articles.get(0)), this.position = a.position, this.social_proof = a.attributes.social_proof, this.scribeComponent = \"card_news\";\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.discoverySearchHelper).methods({\n            article_display_url: function() {\n                return this.obj.getDisplayUrl();\n            },\n            article_image: function() {\n                return this.obj.getImage(twttr.isSSL());\n            },\n            article_url: function() {\n                return this.obj.getExpandedUrl();\n            }\n        }), twttr.view(\"twttr.views.CardTopic\", function(a) {\n            twttr.views.BaseAPI.call(this, a.JSBNG__content), this.position = a.position, this.scribeComponent = \"card_topic\";\n            if (((a.JSBNG__content.media && ((a.JSBNG__content.media.length > 0))))) {\n                var b = a.JSBNG__content.media[0];\n                this.has_image = ((((b.type === \"photo\")) && twttr.decider.isAvailable(\"t1d_topic_img\"))), this.has_video = ((((b.type === \"video\")) && twttr.decider.isAvailable(\"t1d_topic_vid\"))), this.has_media = ((this.has_image || this.has_video)), this.tweet = a.JSBNG__content.tweet, ((((this.tweet && this.tweet.user)) && (this.tweet.user.profile_image_url = twttr.assets.getPathFromAbsoluteURL(this.tweet.user.profile_image_url, {\n                    isVersioned: !1\n                })))), ((this.has_media && (this.mediaInstance = twttr.media.matchInstance(b.media_url), this.image_url = this.getImageUrl([\"large\",\"medium\",\"original\",]), this.has_media = !!this.image_url)));\n            }\n        ;\n        ;\n            this.media_type = ((this.has_image ? \"image\" : ((this.has_video ? \"video\" : null))));\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.discoverySearchHelper, twttr.mixins.discoveryMediaRenderHelper).methods({\n            getImageUrl: function(a) {\n                if (((!this.media || ((this.media.length === 0))))) {\n                    return null;\n                }\n            ;\n            ;\n                var b = this.media[0];\n                for (var c = 0; ((c < a.length)); c++) {\n                    var d = a[c];\n                    if (b.sizes[d]) {\n                        var e = b.sizes[d].url;\n                        if (e) {\n                            if (twttr.isSSL()) {\n                                var f = b.sizes[d].url_https;\n                                return ((f ? f : ((((this.mediaInstance && this.mediaInstance.constructor.ssl)) ? e.replace(/^http:/, \"https:\") : e))));\n                            }\n                        ;\n                        ;\n                            return e;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return null;\n            },\n            tweet_text: function() {\n                var a = this.text, b = this, c = ((this.entities && this.entities.urls));\n                ((c && twttr.each(c, function(b) {\n                    ((b.display_url && (a = a.replace(h(b.url), h(b.display_url)))));\n                })));\n                var d = ((this.entities && this.entities.media));\n                return ((d && twttr.each(d, function(c) {\n                    var d = b.text.substring(c.indices[0], c.indices[1]);\n                    ((c.display_url && (a = a.replace(h(d), h(c.display_url)))));\n                }))), a;\n            },\n            card_url: function() {\n                return ((this.tweet ? twttr.router.permalinkPath({\n                    screen_name: this.tweet.user.screen_name,\n                    id: this.tweet.id_str\n                }) : ((((twttr.router.searchFacetsSlideshowPath({\n                    query: this.obj.query,\n                    mode: ((this.has_image ? \"photos\" : \"videos\"))\n                }) + \"?url=\")) + encodeURIComponent(this.media[0].media_url)))));\n            },\n            attribution_url: function() {\n                return ((this.mediaInstance ? this.mediaInstance.domainUrl() : \"\"));\n            },\n            attribution_img: function() {\n                return ((this.mediaInstance ? this.mediaInstance.iconUrl() : \"\"));\n            },\n            attribution_name: function() {\n                return ((this.mediaInstance ? this.mediaInstance.attributionName() : \"\"));\n            },\n            has_attribution: function() {\n                return ((this.mediaInstance ? this.mediaInstance.hasAttributionInDiscovery() : !0));\n            }\n        }), twttr.view(\"twttr.views.StreamInterestCategory\").subclassOf(twttr.views.BaseAPI).methods({\n            user_sample: function() {\n                return ((((this.obj.sample && this.obj.sample.length)) ? new twttr.views.UserStaticList(this.obj.sample.slice(0, 7)) : !1));\n            },\n            interest_name: function() {\n                return this.obj.JSBNG__name;\n            }\n        }), twttr.view(\"twttr.views.DashboardStreamInterestCategory\").subclassOf(twttr.views.StreamInterestCategory).template(twttr.templates.stream_interest_category).methods({\n            user_sample: function() {\n                return ((((this.obj.sample && this.obj.sample.length)) ? new twttr.views.UserStaticList(this.obj.sample.slice(0, 3)) : !1));\n            }\n        }), twttr.view(\"twttr.views.WelcomeLearnProfile\").subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.StreamViewTogglerBase\", function() {\n            twttr.views.StreamViewToggler.apply(this, arguments);\n        }), twttr.view(\"twttr.views.MentionsStreamViewToggler\", function(a) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"All\"),\n                active1: !a,\n                route1: twttr.router.connectPath(),\n                title2: _(\"Mentions\"),\n                active2: a,\n                route2: twttr.router.mentionsPath()\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase), twttr.view(\"twttr.views.ProfileStreamViewToggler\", function(a, b) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"With Replies\"),\n                active1: a,\n                route1: twttr.router.profileWithRepliesPath({\n                    screen_name: b.screenName\n                }),\n                title2: _(\"Without\"),\n                active2: !a,\n                route2: twttr.router.profilePath({\n                    screen_name: b.screenName\n                })\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase).template(twttr.templates.stream_view_toggler), twttr.view(\"twttr.views.SearchStreamViewToggler\", function(a, b) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"Top\"),\n                active1: ((b == \"relevance\")),\n                route1: twttr.router.searchResultsPath({\n                    query: a\n                }),\n                tip1: \"Find the most relevant tweets\",\n                title2: _(\"All\"),\n                active2: ((b == \"tweets\")),\n                tip2: \"Find the most recent tweets\",\n                route2: twttr.router.searchRealtimePath({\n                    query: a\n                }),\n                title3: _(\"People you follow\"),\n                active3: ((b == \"timeline\")),\n                route3: twttr.router.searchTimelinePath({\n                    query: a\n                }),\n                tip3: \"Find tweets from people you follow\"\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase), twttr.view(\"twttr.views.ListsStreamViewToggler\", function(a) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"Subscribed to\"),\n                active1: !a,\n                route1: twttr.router.listsYouFollowPath(),\n                title2: _(\"Member of\"),\n                active2: a,\n                route2: twttr.router.listsFollowingYouPath()\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase), twttr.view(\"twttr.views.FollowersStreamViewToggler\", function(a, b) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"All\"),\n                active1: !b,\n                route1: twttr.router.userFollowersPath({\n                    screen_name: a\n                }),\n                title2: _(\"You know\"),\n                active2: b,\n                route2: twttr.router.followersYouFollowPath({\n                    screen_name: a\n                })\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase), twttr.view(\"twttr.views.ProfileListsStreamViewToggler\", function(a, b) {\n            twttr.views.StreamViewTogglerBase.call(this, {\n                title1: _(\"Subscribed to\"),\n                active1: a,\n                route1: twttr.router.subscriptionsPath(b),\n                title2: _(\"Member of\"),\n                active2: !a,\n                route2: twttr.router.membershipsPath(b)\n            });\n        }).subclassOf(twttr.views.StreamViewTogglerBase), twttr.view(\"twttr.views.StreamSavedSearch\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            saved_search_path: function() {\n                return twttr.router.searchResultsPath({\n                    query: decodeURIComponent(this.query)\n                });\n            },\n            search_query_source: function() {\n                return twttr.search.searchQuerySource.SAVED_SEARCH;\n            }\n        }), twttr.view(\"twttr.views.DirectMessageDialogConversationList\", function() {\n            var a = this;\n            twttr.views.Base.apply(a, arguments), a.items = [], twttr.each(a.threads, function(b) {\n                a.items.push(new twttr.views.DirectMessageDialogConversationListItem(b));\n            });\n        }).subclassOf(twttr.views.Base), twttr.view(\"twttr.views.DirectMessageDialogConversationListItem\", function() {\n            twttr.views.Base.apply(this, arguments), this.last_message = new twttr.views.Message(this.messages[0]), this.is_last_message_mine = twttr.helpers.isCurrentUser(this.last_message.sender);\n        }).methods({\n            is_unread: function() {\n                return this.obj.hasNewMessages();\n            },\n            last_message_text: function() {\n                var a = this.last_message, c = a.text;\n                return ((((a.entities && a.entities.urls)) && twttr.each(a.entities.urls, function(a) {\n                    ((a.display_url && (c = c.replace(new RegExp(b.util.escapeRegExpChars(h(a.url))), h(a.display_url)))));\n                }))), c;\n            },\n            last_message_timestamp: function() {\n                return this.last_message.timestamp();\n            },\n            last_message_actual_timestamp: function() {\n                return this.last_message.actual_timestamp();\n            },\n            is_replied: function() {\n                return ((this.is_last_message_mine && ((this.messages.length > 1))));\n            },\n            other_person: function() {\n                return this.last_message[((this.is_last_message_mine ? \"recipient\" : \"sender\"))];\n            }\n        }), twttr.view(\"twttr.views.DirectMessageDialogConversation\", function() {\n            var a = this;\n            twttr.views.Base.apply(a, arguments), a.items = [];\n            for (var b = ((a.messages.length - 1)); ((b >= 0)); b--) {\n                a.items.push(new twttr.views.DirectMessageDialogConversationItem(a.messages[b]));\n            ;\n            };\n        ;\n        }).subclassOf(twttr.views.Base), twttr.view(\"twttr.views.DirectMessageDialogConversationItem\", function() {\n            twttr.views.Message.apply(this, arguments);\n        }).subclassOf(twttr.views.Message).methods({\n            sent_or_received: function() {\n                return ((twttr.helpers.isCurrentUser(this.sender) ? \"sent\" : \"received\"));\n            }\n        }), twttr.view(\"twttr.views.TweetDetails\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.Ancestors\", function(a) {\n            twttr.views.BaseAPI.apply(this, arguments), this._ancestors = ((a || []));\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            _viewFor: function(a) {\n                return new twttr.views.SimpleTweet(a);\n            },\n            _viewsFor: function(a) {\n                var b = this;\n                return twttr.map(a, function(a) {\n                    return b._viewFor(a);\n                });\n            },\n            ancestors: function() {\n                return ((this._ancestors.length ? this._viewsFor(this._ancestors) : null));\n            }\n        }), twttr.view(\"twttr.views.TweetStats\", function(a) {\n            twttr.views.Base.apply(this, arguments);\n        }).subclassOf(twttr.views.Base).methods({\n            replies_count: function() {\n                return ((((this.repliers && this.repliers.length)) ? this.repliers_count : !1));\n            },\n            retweets_count: function() {\n                return ((((this.retweeters && this.retweeters.length)) ? this.retweeters_count : !1));\n            },\n            favorites_count: function() {\n                return ((((this.favoriters && this.favoriters.length)) ? this.favoriters_count : !1));\n            }\n        }), twttr.view(\"twttr.views.BigAvatarListItem\", function() {\n            twttr.views.BaseUser.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseUser), twttr.view(\"twttr.views.WebPersonalizationResults\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.BigAvatarListItem,\n            has_recs: function() {\n                return ((this.items && ((this.items.length > 0))));\n            }\n        }), twttr.view(\"twttr.views.GlobalNavSavedSearch\").subclassOf(twttr.views.BaseAPI).methods({\n            saved_search_path: function() {\n                return twttr.router.searchResultsPath({\n                    query: decodeURIComponent(this.query)\n                });\n            },\n            search_query_source: function() {\n                return twttr.search.searchQuerySource.SAVED_SEARCH;\n            }\n        }), twttr.view(\"twttr.views.GlobalNavSavedSearches\", function() {\n            twttr.views.BaseAPIList.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPIList).methods({\n            ItemView: twttr.views.GlobalNavSavedSearch\n        }), twttr.view(\"twttr.views.GeoMapSmall\").subclassOf(twttr.views.Base).methods({\n            place_map_url: function() {\n                return twttr.geo.getPlaceFullAddressAndMapLink(this).map_link;\n            }\n        }), twttr.view(\"twttr.views.PageProfile\").methods({\n            is_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!twttr.profileUser.withheldScope)) && ((twttr.profileUser.withheldScope == \"user\"))));\n            },\n            is_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!twttr.profileUser.withheldScope)) && ((twttr.profileUser.withheldScope == \"user\")))) && !!twttr.profileUser.withheldCopyright));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(twttr.profileUser.id);\n            },\n            render_withheld: function() {\n                return ((this.is_withheld() && !this.is_current_user()));\n            }\n        }), twttr.view(\"twttr.views.InlineReplyBox\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.SoccerMatchedEvent\").subclassOf(twttr.views.BaseAPI).methods({\n            _currentStatus: function() {\n                return this.obj.events.getMatchState().current_status;\n            },\n            _appendTeamPage: function(a) {\n                return ((a.user ? a.team_page = twttr.router.profilePath({\n                    screen_name: a.user.screen_name\n                }) : a.team_page = a.landing_page_url)), a;\n            },\n            getEvents: function() {\n                return this.obj.events;\n            },\n            home_team: function() {\n                return this._appendTeamPage(this.obj.events.getMatchedTeam(!0));\n            },\n            score: function() {\n                if (((this._currentStatus() === \"scheduled\"))) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this.obj.events.getMatchState().score;\n                return a.search_path = this.search_path(), a;\n            },\n            away_team: function() {\n                return this._appendTeamPage(this.obj.events.getMatchedTeam(!1));\n            },\n            match_state: function() {\n                var a = this.obj.events.getMatchState();\n                a.show_time_elapsed_time = !1;\n                if (((a.current_status === \"inprogress\"))) {\n                    a.show_time_elapsed_time = !0;\n                    var b = 0, c = 0, d = ((a.current_period_elapsed_time + 1));\n                    return ((a.overtime ? ((((d > 15)) ? (b = ((((a.current_period === 2)) ? 120 : 105)), c = ((d - 15))) : b = ((((((a.current_period === 2)) ? 105 : 90)) + d)))) : ((((d > 45)) ? (b = ((((a.current_period === 2)) ? 90 : 45)), c = ((d - 45))) : b = ((((((a.current_period === 2)) ? 45 : 0)) + d)))))), ((a.penalty_shootout ? (a.current_period_string = _(\"PK\"), a.current_period_elapsed_time_string = null) : (a.current_period_elapsed_time_string = Mustache.to_html(_(\"{{minutes}} min{{#extra_time}} (+{{extra_time}}){{/extra_time}}\", {\n                        minutes: b,\n                        extra_time: c\n                    })), ((a.overtime ? a.current_period_string = _(\"ET\") : ((((a.current_period === 1)) ? a.current_period_string = _(\"1st half\") : a.current_period_string = _(\"2nd half\")))))))), a;\n                }\n            ;\n            ;\n                return ((((a.current_status === \"halftime\")) ? (((a.overtime ? a.current_period_string = _(\"ET\") : ((a.penalty_shootout ? a.current_period_string = _(\"PK\") : a.current_period_string = _(\"Halftime\"))))), a) : null));\n            },\n            preview: function() {\n                return ((((this._currentStatus() === \"scheduled\")) ? {\n                    time: twttr.helpers.prettyTime(this.obj.events.getMatchedEventData().scheduled_start_time_utc, !0),\n                    url: this.obj.events.getMatchedEvent().preview_url,\n                    search_path: this.search_path()\n                } : null));\n            },\n            recap: function() {\n                var a = this.obj.events.getMatchState();\n                return ((((a.current_status === \"final\")) ? {\n                    url: this.obj.events.getMatchedEvent().recap_url\n                } : null));\n            },\n            hashtag: function() {\n                return this.obj.events.getMatchedEvent().event_data.match_hashtag;\n            },\n            search_path: function() {\n                return twttr.router.searchResultsPath({\n                    query: decodeURIComponent(this.obj.events.getMatchedEvent().event_data.match_hashtag)\n                });\n            },\n            show_follow: function() {\n                return !twttr.loggedIn;\n            }\n        }), twttr.view(\"twttr.views.CardSoccerOnebox\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.SoccerTicker\").subclassOf(twttr.views.BaseAPI).methods({\n            ticker_list: function() {\n                return this.obj.events.getOtherMatchState();\n            },\n            preview: function() {\n                return ((((this.obj.events.getOtherMatchState().length === 0)) ? this.obj.events.data().follow_news : null));\n            }\n        }), a();\n    });\n});\nprovide(\"$lib/easyXDM.js\", function(a) {\n    (function(a, b, c, d, e, f) {\n        function g(a, b) {\n            var c = typeof a[b];\n            return ((((((c == \"function\")) || ((((c == \"object\")) && !!a[b])))) || ((c == \"unknown\"))));\n        };\n    ;\n        function i(a, b) {\n            return ((((typeof a[b] == \"object\")) && !!a[b]));\n        };\n    ;\n        function j(a) {\n            return ((Object.prototype.toString.call(a) === \"[object Array]\"));\n        };\n    ;\n        function k(a) {\n            try {\n                var b = new ActiveXObject(a);\n                return b = null, !0;\n            } catch (c) {\n                return !1;\n            };\n        ;\n        };\n    ;\n        function l() {\n            l = E, Q = !0;\n            for (var a = 0; ((a < R.length)); a++) {\n                R[a]();\n            ;\n            };\n        ;\n            R.length = 0;\n        };\n    ;\n        function m(a, b) {\n            if (Q) {\n                a.call(b);\n                return;\n            }\n        ;\n        ;\n            R.push(function() {\n                a.call(b);\n            });\n        };\n    ;\n        function n() {\n            var a = parent;\n            if (((I !== \"\"))) {\n                for (var b = 0, c = I.split(\".\"); ((b < c.length)); b++) {\n                    a = a[c[b]];\n                ;\n                };\n            }\n        ;\n        ;\n            return a.easyXDM;\n        };\n    ;\n        function o(b) {\n            return a.easyXDM = K, I = b, ((I && (L = ((((\"easyXDM_\" + I.replace(\".\", \"_\"))) + \"_\"))))), J;\n        };\n    ;\n        function p(a) {\n            return a.match(F)[3];\n        };\n    ;\n        function q(a) {\n            var b = a.match(F), c = b[2], d = b[3], e = ((b[4] || \"\"));\n            if (((((((c == \"http:\")) && ((e == \":80\")))) || ((((c == \"https:\")) && ((e == \":443\"))))))) {\n                e = \"\";\n            }\n        ;\n        ;\n            return ((((((c + \"//\")) + d)) + e));\n        };\n    ;\n        function r(a) {\n            a = a.replace(H, \"$1/\");\n            if (!a.match(/^(http||https):\\/\\//)) {\n                var b = ((((a.substring(0, 1) === \"/\")) ? \"\" : c.pathname));\n                ((((b.substring(((b.length - 1))) !== \"/\")) && (b = b.substring(0, ((b.lastIndexOf(\"/\") + 1)))))), a = ((((((((c.protocol + \"//\")) + c.host)) + b)) + a));\n            }\n        ;\n        ;\n            while (G.test(a)) {\n                a = a.replace(G, \"\");\n            ;\n            };\n        ;\n            return a;\n        };\n    ;\n        function s(a, b) {\n            var c = \"\", d = a.indexOf(\"#\");\n            ((((d !== -1)) && (c = a.substring(d), a = a.substring(0, d))));\n            var e = [];\n            for (var g in b) {\n                ((b.hasOwnProperty(g) && e.push(((((g + \"=\")) + f(b[g]))))));\n            ;\n            };\n        ;\n            return ((((((a + ((N ? \"#\" : ((((a.indexOf(\"?\") == -1)) ? \"?\" : \"&\")))))) + e.join(\"&\"))) + c));\n        };\n    ;\n        function t(a) {\n            return ((typeof a == \"undefined\"));\n        };\n    ;\n        function u() {\n            var a = {\n            }, b = {\n                a: [1,2,3,]\n            }, c = \"{\\\"a\\\":[1,2,3]}\";\n            return ((((((((typeof JSON != \"undefined\")) && ((typeof JSON.stringify == \"function\")))) && ((JSON.stringify(b).replace(/\\s/g, \"\") === c)))) ? JSON : (((((Object.toJSON && ((Object.toJSON(b).replace(/\\s/g, \"\") === c)))) && (a.stringify = Object.toJSON))), ((((typeof String.prototype.evalJSON == \"function\")) && (b = c.evalJSON(), ((((((b.a && ((b.a.length === 3)))) && ((b.a[2] === 3)))) && (a.parse = function(a) {\n                return a.evalJSON();\n            })))))), ((((a.stringify && a.parse)) ? (u = function() {\n                return a;\n            }, a) : null)))));\n        };\n    ;\n        function v(a, b, c) {\n            var d;\n            for (var e in b) {\n                ((b.hasOwnProperty(e) && ((((e in a)) ? (d = b[e], ((((typeof d == \"object\")) ? v(a[e], d, c) : ((c || (a[e] = b[e])))))) : a[e] = b[e]))));\n            ;\n            };\n        ;\n            return a;\n        };\n    ;\n        function w() {\n            var c = b.createElement(\"div\");\n            c.JSBNG__name = ((L + \"TEST\")), v(c.style, {\n                position: \"absolute\",\n                left: \"-2000px\",\n                JSBNG__top: \"0px\"\n            }), b.body.appendChild(c), M = ((c.contentWindow !== a.JSBNG__frames[c.JSBNG__name])), b.body.removeChild(c);\n        };\n    ;\n        function x(a) {\n            ((t(M) && w()));\n            var c;\n            ((M ? c = b.createElement(((((\"\\u003Ciframe name='\" + a.props.JSBNG__name)) + \"' frameborder='0' allowtransparency='false' tabindex='-1', role='presentation' scrolling='no' /\\u003E\"))) : (c = b.createElement(\"div\"), c.JSBNG__name = a.props.JSBNG__name, c.setAttribute(\"frameborder\", \"0\"), c.setAttribute(\"allowtransparency\", \"false\"), c.setAttribute(\"tabindex\", \"-1\"), c.setAttribute(\"role\", \"presentation\"), c.setAttribute(\"scrolling\", \"no\")))), c.id = c.JSBNG__name = a.props.JSBNG__name, delete a.props.JSBNG__name, ((a.JSBNG__onLoad && O(c, \"load\", a.JSBNG__onLoad))), ((((typeof a.container == \"string\")) && (a.container = b.getElementById(a.container)))), ((a.container || (c.style.position = \"absolute\", c.style.JSBNG__top = \"-2000px\", a.container = b.body)));\n            var d = a.props.src;\n            return delete a.props.src, v(c, a.props), c.border = c.frameBorder = 0, a.container.appendChild(c), c.src = d, a.props.src = d, c;\n        };\n    ;\n        function y(a, b) {\n            ((((typeof a == \"string\")) && (a = [a,])));\n            var c, d = a.length;\n            while (d--) {\n                c = a[d], c = new RegExp(((((c.substr(0, 1) == \"^\")) ? c : ((((\"^\" + c.replace(/(\\*)/g, \".$1\").replace(/\\?/g, \".\"))) + \"$\")))));\n                if (c.test(b)) {\n                    return !0;\n                }\n            ;\n            ;\n            };\n        ;\n            return !1;\n        };\n    ;\n        function z(d) {\n            var e = d.protocol, f;\n            d.isHost = ((d.isHost || t(U.xdm_p))), N = ((d.hash || !1)), ((d.props || (d.props = {\n            })));\n            if (!d.isHost) {\n                d.channel = U.xdm_c, d.secret = U.xdm_s, d.remote = U.xdm_e, e = U.xdm_p;\n                if (((d.acl && !y(d.acl, d.remote)))) {\n                    throw new Error(((\"Access denied for \" + d.remote)));\n                }\n            ;\n            ;\n            }\n             else d.remote = r(d.remote), d.channel = ((d.channel || ((\"default\" + D++)))), d.secret = Math.JSBNG__random().toString(16).substring(2), ((t(e) && ((((q(c.href) == q(d.remote))) ? e = \"4\" : ((((g(a, \"JSBNG__postMessage\") || g(b, \"JSBNG__postMessage\"))) ? e = \"1\" : ((((g(a, \"ActiveXObject\") && k(\"ShockwaveFlash.ShockwaveFlash\"))) ? e = \"6\" : ((((((((JSBNG__navigator.product === \"Gecko\")) && ((\"JSBNG__frameElement\" in a)))) && ((JSBNG__navigator.userAgent.indexOf(\"WebKit\") == -1)))) ? e = \"5\" : ((d.remoteHelper ? (d.remoteHelper = r(d.remoteHelper), e = \"2\") : e = \"0\"))))))))))));\n        ;\n        ;\n            switch (e) {\n              case \"0\":\n                v(d, {\n                    interval: 100,\n                    delay: 2000,\n                    useResize: !0,\n                    useParent: !1,\n                    usePolling: !1\n                }, !0);\n                if (d.isHost) {\n                    if (!d.local) {\n                        var i = ((((c.protocol + \"//\")) + c.host)), j = b.body.getElementsByTagName(\"img\"), l, m = j.length;\n                        while (m--) {\n                            l = j[m];\n                            if (((l.src.substring(0, i.length) === i))) {\n                                d.local = l.src;\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        ((d.local || (d.local = a)));\n                    }\n                ;\n                ;\n                    var n = {\n                        xdm_c: d.channel,\n                        xdm_p: 0\n                    };\n                    ((((d.local === a)) ? (d.usePolling = !0, d.useParent = !0, d.local = ((((((((c.protocol + \"//\")) + c.host)) + c.pathname)) + c.search)), n.xdm_e = d.local, n.xdm_pa = 1) : n.xdm_e = r(d.local))), ((d.container && (d.useResize = !1, n.xdm_po = 1))), d.remote = s(d.remote, n);\n                }\n                 else v(d, {\n                    channel: U.xdm_c,\n                    remote: U.xdm_e,\n                    useParent: !t(U.xdm_pa),\n                    usePolling: !t(U.xdm_po),\n                    useResize: ((d.useParent ? !1 : d.useResize))\n                });\n            ;\n            ;\n                f = [new J.stack.HashTransport(d),new J.stack.ReliableBehavior({\n                }),new J.stack.QueueBehavior({\n                    encode: !0,\n                    maxLength: ((4000 - d.remote.length))\n                }),new J.stack.VerifyBehavior({\n                    initiate: d.isHost\n                }),];\n                break;\n              case \"1\":\n                f = [new J.stack.PostMessageTransport(d),];\n                break;\n              case \"2\":\n                f = [new J.stack.NameTransport(d),new J.stack.QueueBehavior,new J.stack.VerifyBehavior({\n                    initiate: d.isHost\n                }),];\n                break;\n              case \"3\":\n                f = [new J.stack.NixTransport(d),];\n                break;\n              case \"4\":\n                f = [new J.stack.SameOriginTransport(d),];\n                break;\n              case \"5\":\n                f = [new J.stack.FrameElementTransport(d),];\n                break;\n              case \"6\":\n                ((d.swf || (d.swf = \"../../tools/easyxdm.swf\"))), f = [new J.stack.FlashTransport(d),];\n            };\n        ;\n            return f.push(new J.stack.QueueBehavior({\n                lazy: d.lazy,\n                remove: !0\n            })), f;\n        };\n    ;\n        function A(a) {\n            var b, c = {\n                incoming: function(a, b) {\n                    this.up.incoming(a, b);\n                },\n                outgoing: function(a, b) {\n                    this.down.outgoing(a, b);\n                },\n                callback: function(a) {\n                    this.up.callback(a);\n                },\n                init: function() {\n                    this.down.init();\n                },\n                destroy: function() {\n                    this.down.destroy();\n                }\n            };\n            for (var d = 0, e = a.length; ((d < e)); d++) {\n                b = a[d], v(b, c, !0), ((((d !== 0)) && (b.down = a[((d - 1))]))), ((((d !== ((e - 1)))) && (b.up = a[((d + 1))])));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function B(a) {\n            a.up.down = a.down, a.down.up = a.up, a.up = a.down = null;\n        };\n    ;\n        var C = this, D = Math.floor(((Math.JSBNG__random() * 10000))), E = Function.prototype, F = /^((http.?:)\\/\\/([^:\\/\\s]+)(:\\d+)*)/, G = /[\\-\\w]+\\/\\.\\.\\//, H = /([^:])\\/\\//g, I = \"\", J = {\n        }, K = a.easyXDM, L = \"easyXDM_\", M, N = !1, O, P;\n        if (g(a, \"JSBNG__addEventListener\")) O = function(a, b, c) {\n            a.JSBNG__addEventListener(b, c, !1);\n        }, P = function(a, b, c) {\n            a.JSBNG__removeEventListener(b, c, !1);\n        };\n         else {\n            if (!g(a, \"JSBNG__attachEvent\")) {\n                throw new Error(\"Browser not supported\");\n            }\n        ;\n        ;\n            O = function(a, b, c) {\n                a.JSBNG__attachEvent(((\"JSBNG__on\" + b)), c);\n            }, P = function(a, b, c) {\n                a.JSBNG__detachEvent(((\"JSBNG__on\" + b)), c);\n            };\n        }\n    ;\n    ;\n        var Q = !1, R = [], S;\n        ((((\"readyState\" in b)) ? (S = b.readyState, Q = ((((S == \"complete\")) || ((~JSBNG__navigator.userAgent.indexOf(\"AppleWebKit/\") && ((((S == \"loaded\")) || ((S == \"interactive\"))))))))) : Q = !!b.body));\n        if (!Q) {\n            if (g(a, \"JSBNG__addEventListener\")) O(b, \"DOMContentLoaded\", l);\n             else {\n                O(b, \"readystatechange\", function() {\n                    ((((b.readyState == \"complete\")) && l()));\n                });\n                if (((b.documentElement.doScroll && ((a === JSBNG__top))))) {\n                    var T = function() {\n                        if (Q) {\n                            return;\n                        }\n                    ;\n                    ;\n                        try {\n                            b.documentElement.doScroll(\"left\");\n                        } catch (a) {\n                            d(T, 1);\n                            return;\n                        };\n                    ;\n                        l();\n                    };\n                    T();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            O(a, \"load\", l);\n        }\n    ;\n    ;\n        var U = function(a) {\n            a = a.substring(1).split(\"&\");\n            var b = {\n            }, c, d = a.length;\n            while (d--) {\n                c = a[d].split(\"=\"), b[c[0]] = e(c[1]);\n            ;\n            };\n        ;\n            return b;\n        }(((/xdm_e=/.test(c.search) ? c.search : c.hash)));\n        v(J, {\n            version: \"2.4.12.108\",\n            query: U,\n            stack: {\n            },\n            apply: v,\n            getJSONObject: u,\n            whenReady: m,\n            noConflict: o\n        }), J.DomHelper = {\n            JSBNG__on: O,\n            un: P,\n            requiresJSON: function(c) {\n                ((i(a, \"JSON\") || b.write(((((((\"\\u003Cscript type=\\\"text/javascript\\\" src=\\\"\" + c)) + \"\\\"\\u003E\\u003C\")) + \"/script\\u003E\")))));\n            }\n        }, function() {\n            var a = {\n            };\n            J.Fn = {\n                set: function(b, c) {\n                    a[b] = c;\n                },\n                get: function(b, c) {\n                    var d = a[b];\n                    return ((c && delete a[b])), d;\n                }\n            };\n        }(), J.Socket = function(a) {\n            var b = A(z(a).concat([{\n                incoming: function(b, c) {\n                    a.JSBNG__onMessage(b, c);\n                },\n                callback: function(b) {\n                    ((a.JSBNG__onReady && a.JSBNG__onReady(b)));\n                }\n            },])), c = q(a.remote);\n            this.origin = q(a.remote), this.destroy = function() {\n                b.destroy();\n            }, this.JSBNG__postMessage = function(a) {\n                b.outgoing(a, c);\n            }, b.init();\n        }, J.Rpc = function(a, b) {\n            if (b.local) {\n                for (var c in b.local) {\n                    if (b.local.hasOwnProperty(c)) {\n                        var d = b.local[c];\n                        ((((typeof d == \"function\")) && (b.local[c] = {\n                            method: d\n                        })));\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            var e = A(z(a).concat([new J.stack.RpcBehavior(this, b),{\n                callback: function(b) {\n                    ((a.JSBNG__onReady && a.JSBNG__onReady(b)));\n                }\n            },]));\n            this.origin = q(a.remote), this.destroy = function() {\n                e.destroy();\n            }, e.init();\n        }, J.stack.SameOriginTransport = function(a) {\n            var b, e, f, g;\n            return b = {\n                outgoing: function(a, b, c) {\n                    f(a), ((c && c()));\n                },\n                destroy: function() {\n                    ((e && (e.parentNode.removeChild(e), e = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    g = q(a.remote), ((a.isHost ? (v(a.props, {\n                        src: s(a.remote, {\n                            xdm_e: ((((((c.protocol + \"//\")) + c.host)) + c.pathname)),\n                            xdm_c: a.channel,\n                            xdm_p: 4\n                        }),\n                        JSBNG__name: ((((L + a.channel)) + \"_provider\"))\n                    }), e = x(a), J.Fn.set(a.channel, function(a) {\n                        return f = a, d(function() {\n                            b.up.callback(!0);\n                        }, 0), function(a) {\n                            b.up.incoming(a, g);\n                        };\n                    })) : (f = n().Fn.get(a.channel, !0)(function(a) {\n                        b.up.incoming(a, g);\n                    }), d(function() {\n                        b.up.callback(!0);\n                    }, 0))));\n                },\n                init: function() {\n                    m(b.JSBNG__onDOMReady, b);\n                }\n            };\n        }, J.stack.FlashTransport = function(a) {\n            function e(a) {\n                d(function() {\n                    g.up.incoming(a, k);\n                }, 0);\n            };\n        ;\n            function f(d) {\n                var e = a.swf, f = ((\"easyXDM_swf_\" + Math.floor(((Math.JSBNG__random() * 10000))))), g = ((((((o + \"easyXDM.Fn.get(\\\"flash_\")) + f)) + \"_init\\\")\"));\n                J.Fn.set(((((\"flash_\" + f)) + \"_init\")), function() {\n                    J.stack.FlashTransport.__swf = l = n.firstChild, d();\n                }), n = b.createElement(\"div\"), v(n.style, {\n                    height: \"1px\",\n                    width: \"1px\",\n                    postition: \"abosolute\",\n                    left: 0,\n                    JSBNG__top: 0\n                }), b.body.appendChild(n);\n                var i = ((((((((((\"proto=\" + c.protocol)) + \"&domain=\")) + p(c.href))) + \"&init=\")) + g));\n                n.innerHTML = ((((((((((((((((((((((((((((((((((((\"\\u003Cobject height='1' width='1' type='application/x-shockwave-flash' id='\" + f)) + \"' data='\")) + e)) + \"'\\u003E\")) + \"\\u003Cparam name='allowScriptAccess' value='always'\\u003E\\u003C/param\\u003E\")) + \"\\u003Cparam name='wmode' value='transparent'\\u003E\")) + \"\\u003Cparam name='movie' value='\")) + e)) + \"'\\u003E\\u003C/param\\u003E\")) + \"\\u003Cparam name='flashvars' value='\")) + i)) + \"'\\u003E\\u003C/param\\u003E\")) + \"\\u003Cembed type='application/x-shockwave-flash' FlashVars='\")) + i)) + \"' allowScriptAccess='always' wmode='transparent' src='\")) + e)) + \"' height='1' width='1'\\u003E\\u003C/embed\\u003E\")) + \"\\u003C/object\\u003E\"));\n            };\n        ;\n            var g, i, j, k, l, n, o = ((I ? ((I + \".\")) : \"\"));\n            return g = {\n                outgoing: function(b, c, d) {\n                    l.JSBNG__postMessage(a.channel, b), ((d && d()));\n                },\n                destroy: function() {\n                    try {\n                        l.destroyChannel(a.channel);\n                    } catch (b) {\n                    \n                    };\n                ;\n                    l = null, ((i && (i.parentNode.removeChild(i), i = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    k = q(a.remote), l = J.stack.FlashTransport.__swf;\n                    var b = function() {\n                        ((a.isHost ? J.Fn.set(((((\"flash_\" + a.channel)) + \"_onMessage\")), function(b) {\n                            ((((b == ((a.channel + \"-ready\")))) && (J.Fn.set(((((\"flash_\" + a.channel)) + \"_onMessage\")), e), d(function() {\n                                g.up.callback(!0);\n                            }, 0))));\n                        }) : J.Fn.set(((((\"flash_\" + a.channel)) + \"_onMessage\")), e))), l.createChannel(a.channel, a.remote, a.isHost, ((((((o + \"easyXDM.Fn.get(\\\"flash_\")) + a.channel)) + \"_onMessage\\\")\")), a.secret), ((a.isHost ? (v(a.props, {\n                            src: s(a.remote, {\n                                xdm_e: q(c.href),\n                                xdm_c: a.channel,\n                                xdm_s: a.secret,\n                                xdm_p: 6\n                            }),\n                            JSBNG__name: ((((L + a.channel)) + \"_provider\"))\n                        }), i = x(a)) : (l.JSBNG__postMessage(a.channel, ((a.channel + \"-ready\"))), d(function() {\n                            g.up.callback(!0);\n                        }, 0))));\n                    };\n                    ((l ? b() : f(b)));\n                },\n                init: function() {\n                    m(g.JSBNG__onDOMReady, g);\n                }\n            };\n        }, J.stack.PostMessageTransport = function(b) {\n            function e(a) {\n                if (a.origin) {\n                    return q(a.origin);\n                }\n            ;\n            ;\n                if (a.uri) {\n                    return q(a.uri);\n                }\n            ;\n            ;\n                if (a.domain) {\n                    return ((((c.protocol + \"//\")) + a.domain));\n                }\n            ;\n            ;\n                throw \"Unable to retrieve the origin of the event\";\n            };\n        ;\n            function f(a) {\n                var c = e(a);\n                ((((((c == k)) && ((a.data.substring(0, ((b.channel.length + 1))) == ((b.channel + \" \")))))) && g.up.incoming(a.data.substring(((b.channel.length + 1))), c)));\n            };\n        ;\n            var g, i, j, k;\n            return g = {\n                outgoing: function(a, c, d) {\n                    j.JSBNG__postMessage(((((b.channel + \" \")) + a)), ((c || k))), ((d && d()));\n                },\n                destroy: function() {\n                    P(a, \"message\", f), ((i && (j = null, i.parentNode.removeChild(i), i = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    k = q(b.remote), ((b.isHost ? (O(a, \"message\", function e(c) {\n                        ((((c.data == ((b.channel + \"-ready\")))) && (j = ((((\"JSBNG__postMessage\" in i.contentWindow)) ? i.contentWindow : i.contentWindow.JSBNG__document)), P(a, \"message\", e), O(a, \"message\", f), d(function() {\n                            g.up.callback(!0);\n                        }, 0))));\n                    }), v(b.props, {\n                        src: s(b.remote, {\n                            xdm_e: q(c.href),\n                            xdm_c: b.channel,\n                            xdm_p: 1\n                        }),\n                        JSBNG__name: ((((L + b.channel)) + \"_provider\"))\n                    }), i = x(b)) : (O(a, \"message\", f), j = ((((\"JSBNG__postMessage\" in a.parent)) ? a.parent : a.parent.JSBNG__document)), j.JSBNG__postMessage(((b.channel + \"-ready\")), k), d(function() {\n                        g.up.callback(!0);\n                    }, 0))));\n                },\n                init: function() {\n                    m(g.JSBNG__onDOMReady, g);\n                }\n            };\n        }, J.stack.FrameElementTransport = function(e) {\n            var f, g, i, j;\n            return f = {\n                outgoing: function(a, b, c) {\n                    i.call(this, a), ((c && c()));\n                },\n                destroy: function() {\n                    ((g && (g.parentNode.removeChild(g), g = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    j = q(e.remote), ((e.isHost ? (v(e.props, {\n                        src: s(e.remote, {\n                            xdm_e: q(c.href),\n                            xdm_c: e.channel,\n                            xdm_p: 5\n                        }),\n                        JSBNG__name: ((((L + e.channel)) + \"_provider\"))\n                    }), g = x(e), g.fn = function(a) {\n                        return delete g.fn, i = a, d(function() {\n                            f.up.callback(!0);\n                        }, 0), function(a) {\n                            f.up.incoming(a, j);\n                        };\n                    }) : (((((b.referrer && ((q(b.referrer) != U.xdm_e)))) && (a.JSBNG__top.JSBNG__location = U.xdm_e))), i = a.JSBNG__frameElement.fn(function(a) {\n                        f.up.incoming(a, j);\n                    }), f.up.callback(!0))));\n                },\n                init: function() {\n                    m(f.JSBNG__onDOMReady, f);\n                }\n            };\n        }, J.stack.NixTransport = function(e) {\n            var f, i, j, k, l;\n            return f = {\n                outgoing: function(a, b, c) {\n                    j(a), ((c && c()));\n                },\n                destroy: function() {\n                    l = null, ((i && (i.parentNode.removeChild(i), i = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    k = q(e.remote);\n                    if (e.isHost) {\n                        try {\n                            ((g(a, \"getNixProxy\") || a.execScript(\"Class NixProxy\\u000a    Private m_parent, m_child, m_Auth\\u000a\\u000a    Public Sub SetParent(obj, auth)\\u000a        If isEmpty(m_Auth) Then m_Auth = auth\\u000a        SET m_parent = obj\\u000a    End Sub\\u000a    Public Sub SetChild(obj)\\u000a        SET m_child = obj\\u000a        m_parent.ready()\\u000a    End Sub\\u000a\\u000a    Public Sub SendToParent(data, auth)\\u000a        If m_Auth = auth Then m_parent.send(CStr(data))\\u000a    End Sub\\u000a    Public Sub SendToChild(data, auth)\\u000a        If m_Auth = auth Then m_child.send(CStr(data))\\u000a    End Sub\\u000aEnd Class\\u000aFunction getNixProxy()\\u000a    Set GetNixProxy = New NixProxy\\u000aEnd Function\\u000a\", \"vbscript\"))), l = getNixProxy(), l.SetParent({\n                                send: function(a) {\n                                    f.up.incoming(a, k);\n                                },\n                                ready: function() {\n                                    d(function() {\n                                        f.up.callback(!0);\n                                    }, 0);\n                                }\n                            }, e.secret), j = function(a) {\n                                l.SendToChild(a, e.secret);\n                            };\n                        } catch (m) {\n                            throw new Error(((\"Could not set up VBScript NixProxy:\" + m.message)));\n                        };\n                    ;\n                        v(e.props, {\n                            src: s(e.remote, {\n                                xdm_e: q(c.href),\n                                xdm_c: e.channel,\n                                xdm_s: e.secret,\n                                xdm_p: 3\n                            }),\n                            JSBNG__name: ((((L + e.channel)) + \"_provider\"))\n                        }), i = x(e), i.contentWindow.JSBNG__opener = l;\n                    }\n                     else {\n                        ((((b.referrer && ((q(b.referrer) != U.xdm_e)))) && (a.JSBNG__top.JSBNG__location = U.xdm_e)));\n                        try {\n                            l = a.JSBNG__opener;\n                        } catch (n) {\n                            throw new Error(\"Cannot access window.JSBNG__opener\");\n                        };\n                    ;\n                        l.SetChild({\n                            send: function(a) {\n                                C.JSBNG__setTimeout(function() {\n                                    f.up.incoming(a, k);\n                                }, 0);\n                            }\n                        }), j = function(a) {\n                            l.SendToParent(a, e.secret);\n                        }, d(function() {\n                            f.up.callback(!0);\n                        }, 0);\n                    }\n                ;\n                ;\n                },\n                init: function() {\n                    m(f.JSBNG__onDOMReady, f);\n                }\n            };\n        }, J.stack.NameTransport = function(a) {\n            function b(b) {\n                var c = ((((a.remoteHelper + ((i ? \"#_3\" : \"#_2\")))) + a.channel));\n                j.contentWindow.sendMessage(b, c);\n            };\n        ;\n            function c() {\n                ((i ? ((((((++l === 2)) || !i)) && g.up.callback(!0))) : (b(\"ready\"), g.up.callback(!0))));\n            };\n        ;\n            function e(a) {\n                g.up.incoming(a, o);\n            };\n        ;\n            function f() {\n                ((n && d(function() {\n                    n(!0);\n                }, 0)));\n            };\n        ;\n            var g, i, j, k, l, n, o, p;\n            return g = {\n                outgoing: function(a, c, d) {\n                    n = d, b(a);\n                },\n                destroy: function() {\n                    j.parentNode.removeChild(j), j = null, ((i && (k.parentNode.removeChild(k), k = null)));\n                },\n                JSBNG__onDOMReady: function() {\n                    i = a.isHost, l = 0, o = q(a.remote), a.local = r(a.local), ((i ? (J.Fn.set(a.channel, function(b) {\n                        ((((i && ((b === \"ready\")))) && (J.Fn.set(a.channel, e), c())));\n                    }), p = s(a.remote, {\n                        xdm_e: a.local,\n                        xdm_c: a.channel,\n                        xdm_p: 2\n                    }), v(a.props, {\n                        src: ((((p + \"#\")) + a.channel)),\n                        JSBNG__name: ((((L + a.channel)) + \"_provider\"))\n                    }), k = x(a)) : (a.remoteHelper = a.remote, J.Fn.set(a.channel, e)))), j = x({\n                        props: {\n                            src: ((((a.local + \"#_4\")) + a.channel))\n                        },\n                        JSBNG__onLoad: function b() {\n                            var e = ((j || this));\n                            P(e, \"load\", b), J.Fn.set(((a.channel + \"_load\")), f), function g() {\n                                ((((typeof e.contentWindow.sendMessage == \"function\")) ? c() : d(g, 50)));\n                            }();\n                        }\n                    });\n                },\n                init: function() {\n                    m(g.JSBNG__onDOMReady, g);\n                }\n            };\n        }, J.stack.HashTransport = function(b) {\n            function c(a) {\n                if (!s) {\n                    return;\n                }\n            ;\n            ;\n                var c = ((((((((b.remote + \"#\")) + p++)) + \"_\")) + a));\n                ((((k || !t)) ? s.contentWindow : s)).JSBNG__location = c;\n            };\n        ;\n            function e(a) {\n                o = a, i.up.incoming(o.substring(((o.indexOf(\"_\") + 1))), u);\n            };\n        ;\n            function f() {\n                if (!r) {\n                    return;\n                }\n            ;\n            ;\n                var a = r.JSBNG__location.href, b = \"\", c = a.indexOf(\"#\");\n                ((((c != -1)) && (b = a.substring(c)))), ((((b && ((b != o)))) && e(b)));\n            };\n        ;\n            function g() {\n                l = JSBNG__setInterval(f, n);\n            };\n        ;\n            var i, j = this, k, l, n, o, p, r, s, t, u;\n            return i = {\n                outgoing: function(a, b) {\n                    c(a);\n                },\n                destroy: function() {\n                    a.JSBNG__clearInterval(l), ((((k || !t)) && s.parentNode.removeChild(s))), s = null;\n                },\n                JSBNG__onDOMReady: function() {\n                    k = b.isHost, n = b.interval, o = ((\"#\" + b.channel)), p = 0, t = b.useParent, u = q(b.remote);\n                    if (k) {\n                        b.props = {\n                            src: b.remote,\n                            JSBNG__name: ((((L + b.channel)) + \"_provider\"))\n                        };\n                        if (t) b.JSBNG__onLoad = function() {\n                            r = a, g(), i.up.callback(!0);\n                        };\n                         else {\n                            var c = 0, e = ((b.delay / 50));\n                            (function f() {\n                                if (((++c > e))) {\n                                    throw new Error(\"Unable to reference listenerwindow\");\n                                }\n                            ;\n                            ;\n                                try {\n                                    r = s.contentWindow.JSBNG__frames[((((L + b.channel)) + \"_consumer\"))];\n                                } catch (a) {\n                                \n                                };\n                            ;\n                                ((r ? (g(), i.up.callback(!0)) : d(f, 50)));\n                            })();\n                        }\n                    ;\n                    ;\n                        s = x(b);\n                    }\n                     else r = a, g(), ((t ? (s = parent, i.up.callback(!0)) : (v(b, {\n                        props: {\n                            src: ((((((b.remote + \"#\")) + b.channel)) + new JSBNG__Date)),\n                            JSBNG__name: ((((L + b.channel)) + \"_consumer\"))\n                        },\n                        JSBNG__onLoad: function() {\n                            i.up.callback(!0);\n                        }\n                    }), s = x(b))));\n                ;\n                ;\n                },\n                init: function() {\n                    m(i.JSBNG__onDOMReady, i);\n                }\n            };\n        }, J.stack.ReliableBehavior = function(a) {\n            var b, c, d = 0, e = 0, f = \"\";\n            return b = {\n                incoming: function(a, g) {\n                    var i = a.indexOf(\"_\"), j = a.substring(0, i).split(\",\");\n                    a = a.substring(((i + 1))), ((((j[0] == d)) && (f = \"\", ((c && c(!0)))))), ((((a.length > 0)) && (b.down.outgoing(((((((((j[1] + \",\")) + d)) + \"_\")) + f)), g), ((((e != j[1])) && (e = j[1], b.up.incoming(a, g)))))));\n                },\n                outgoing: function(a, g, i) {\n                    f = a, c = i, b.down.outgoing(((((((((e + \",\")) + ++d)) + \"_\")) + a)), g);\n                }\n            };\n        }, J.stack.QueueBehavior = function(a) {\n            function b() {\n                if (((a.remove && ((g.length === 0))))) {\n                    B(c);\n                    return;\n                }\n            ;\n            ;\n                if (((((i || ((g.length === 0)))) || k))) {\n                    return;\n                }\n            ;\n            ;\n                i = !0;\n                var e = g.shift();\n                c.down.outgoing(e.data, e.origin, function(a) {\n                    i = !1, ((e.callback && d(function() {\n                        e.callback(a);\n                    }, 0))), b();\n                });\n            };\n        ;\n            var c, g = [], i = !0, j = \"\", k, l = 0, m = !1, n = !1;\n            return c = {\n                init: function() {\n                    ((t(a) && (a = {\n                    }))), ((a.maxLength && (l = a.maxLength, n = !0))), ((a.lazy ? m = !0 : c.down.init()));\n                },\n                callback: function(a) {\n                    i = !1;\n                    var d = c.up;\n                    b(), d.callback(a);\n                },\n                incoming: function(b, d) {\n                    if (n) {\n                        var f = b.indexOf(\"_\"), g = parseInt(b.substring(0, f), 10);\n                        j += b.substring(((f + 1))), ((((g === 0)) && (((a.encode && (j = e(j)))), c.up.incoming(j, d), j = \"\")));\n                    }\n                     else c.up.incoming(b, d);\n                ;\n                ;\n                },\n                outgoing: function(d, e, i) {\n                    ((a.encode && (d = f(d))));\n                    var j = [], k;\n                    if (n) {\n                        while (((d.length !== 0))) {\n                            k = d.substring(0, l), d = d.substring(k.length), j.push(k);\n                        ;\n                        };\n                    ;\n                        while (k = j.shift()) {\n                            g.push({\n                                data: ((((j.length + \"_\")) + k)),\n                                origin: e,\n                                callback: ((((j.length === 0)) ? i : null))\n                            });\n                        ;\n                        };\n                    ;\n                    }\n                     else g.push({\n                        data: d,\n                        origin: e,\n                        callback: i\n                    });\n                ;\n                ;\n                    ((m ? c.down.init() : b()));\n                },\n                destroy: function() {\n                    k = !0, c.down.destroy();\n                }\n            };\n        }, J.stack.VerifyBehavior = function(a) {\n            function b() {\n                d = Math.JSBNG__random().toString(16).substring(2), c.down.outgoing(d);\n            };\n        ;\n            var c, d, e, f = !1;\n            return c = {\n                incoming: function(f, g) {\n                    var i = f.indexOf(\"_\");\n                    ((((i === -1)) ? ((((f === d)) ? c.up.callback(!0) : ((e || (e = f, ((a.initiate || b())), c.down.outgoing(f)))))) : ((((f.substring(0, i) === e)) && c.up.incoming(f.substring(((i + 1))), g)))));\n                },\n                outgoing: function(a, b, e) {\n                    c.down.outgoing(((((d + \"_\")) + a)), b, e);\n                },\n                callback: function(c) {\n                    ((a.initiate && b()));\n                }\n            };\n        }, J.stack.RpcBehavior = function(a, b) {\n            function c(a) {\n                a.jsonrpc = \"2.0\", f.down.outgoing(g.stringify(a));\n            };\n        ;\n            function d(a, b) {\n                var d = Array.prototype.slice;\n                return function() {\n                    var e = arguments.length, f, g = {\n                        method: b\n                    };\n                    ((((((e > 0)) && ((typeof arguments[((e - 1))] == \"function\")))) ? (((((((e > 1)) && ((typeof arguments[((e - 2))] == \"function\")))) ? (f = {\n                        success: arguments[((e - 2))],\n                        error: arguments[((e - 1))]\n                    }, g.params = d.call(arguments, 0, ((e - 2)))) : (f = {\n                        success: arguments[((e - 1))]\n                    }, g.params = d.call(arguments, 0, ((e - 1)))))), k[((\"\" + ++i))] = f, g.id = i) : g.params = d.call(arguments, 0))), ((((a.namedParams && ((g.params.length === 1)))) && (g.params = g.params[0]))), c(g);\n                };\n            };\n        ;\n            function e(a, b, d, e) {\n                if (!d) {\n                    ((b && c({\n                        id: b,\n                        error: {\n                            code: -32601,\n                            message: \"Procedure not found.\"\n                        }\n                    })));\n                    return;\n                }\n            ;\n            ;\n                var f, g;\n                ((b ? (f = function(a) {\n                    f = E, c({\n                        id: b,\n                        result: a\n                    });\n                }, g = function(a, d) {\n                    g = E;\n                    var e = {\n                        id: b,\n                        error: {\n                            code: -32099,\n                            message: a\n                        }\n                    };\n                    ((d && (e.error.data = d))), c(e);\n                }) : f = g = E)), ((j(e) || (e = [e,])));\n                try {\n                    var i = d.method.apply(d.scope, e.concat([f,g,]));\n                    ((t(i) || f(i)));\n                } catch (k) {\n                    g(k.message);\n                };\n            ;\n            };\n        ;\n            var f, g = ((b.serializer || u())), i = 0, k = {\n            };\n            return f = {\n                incoming: function(a, d) {\n                    var f = g.parse(a);\n                    if (f.method) ((b.handle ? b.handle(f, c) : e(f.method, f.id, b.local[f.method], f.params)));\n                     else {\n                        var i = k[f.id];\n                        ((f.error ? ((i.error && i.error(f.error))) : ((i.success && i.success(f.result))))), delete k[f.id];\n                    }\n                ;\n                ;\n                },\n                init: function() {\n                    if (b.remote) {\n                        for (var c in b.remote) {\n                            ((b.remote.hasOwnProperty(c) && (a[c] = d(b.remote[c], c))));\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    f.down.init();\n                },\n                destroy: function() {\n                    for (var c in b.remote) {\n                        ((((b.remote.hasOwnProperty(c) && a.hasOwnProperty(c))) && delete a[c]));\n                    ;\n                    };\n                ;\n                    f.down.destroy();\n                }\n            };\n        }, C.easyXDM = J;\n    })(window, JSBNG__document, JSBNG__location, window.JSBNG__setTimeout, decodeURIComponent, encodeURIComponent), a();\n});\nprovide(\"libwrap/easyxdm\", function(a) {\n    using(\"$lib/easyXDM.js\", function() {\n        a(easyXDM);\n    });\n});\nprovide(\"lib/lazyload\", function(a) {\n    a(function(a) {\n        function b(b, c) {\n            var d = a.createElement(b), e;\n            for (e in c) {\n                ((c.hasOwnProperty(e) && d.setAttribute(e, c[e])));\n            ;\n            };\n        ;\n            return d;\n        };\n    ;\n        function c(a) {\n            var b = k[a], c, d;\n            ((b && (c = b.callback, d = b.urls, d.shift(), l = 0, ((d.length || (((c && c.call(b.context, b.obj))), k[a] = null, ((m[a].length && e(a)))))))));\n        };\n    ;\n        function d() {\n            var b = JSBNG__navigator.userAgent;\n            i = {\n                async: ((a.createElement(\"script\").async === !0))\n            }, (((((((((i.webkit = /AppleWebKit\\//.test(b)) || (i.ie = /MSIE/.test(b)))) || (i.JSBNG__opera = /Opera/.test(b)))) || (i.gecko = /Gecko\\//.test(b)))) || (i.unknown = !0)));\n        };\n    ;\n        function e(e, l, n, o, p) {\n            var q = function() {\n                c(e);\n            }, r = ((e === \"css\")), s = [], t, u, v, w, x, y;\n            ((i || d()));\n            if (l) {\n                l = ((((typeof l == \"string\")) ? [l,] : l.concat()));\n                if (((((((r || i.async)) || i.gecko)) || i.JSBNG__opera))) {\n                    m[e].push({\n                        urls: l,\n                        callback: n,\n                        obj: o,\n                        context: p\n                    });\n                }\n                 else {\n                    for (t = 0, u = l.length; ((t < u)); ++t) {\n                        m[e].push({\n                            urls: [l[t],],\n                            callback: ((((t === ((u - 1)))) ? n : null)),\n                            obj: o,\n                            context: p\n                        });\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((k[e] || !(w = k[e] = m[e].shift())))) {\n                return;\n            }\n        ;\n        ;\n            ((j || (j = ((a.head || a.getElementsByTagName(\"head\")[0]))))), x = w.urls;\n            for (t = 0, u = x.length; ((t < u)); ++t) {\n                y = x[t], ((r ? v = ((i.gecko ? b(\"style\") : b(\"link\", {\n                    href: y,\n                    rel: \"stylesheet\"\n                }))) : (v = b(\"script\", {\n                    src: y\n                }), v.async = !1))), v.className = \"lazyload\", v.setAttribute(\"charset\", \"utf-8\"), ((((i.ie && !r)) ? v.JSBNG__onreadystatechange = function() {\n                    ((/loaded|complete/.test(v.readyState) && (v.JSBNG__onreadystatechange = null, q())));\n                } : ((((r && ((i.gecko || i.webkit)))) ? ((i.webkit ? (w.urls[t] = v.href, g()) : (v.innerHTML = ((((\"@import \\\"\" + y)) + \"\\\";\")), f(v)))) : v.JSBNG__onload = v.JSBNG__onerror = q)))), s.push(v);\n            ;\n            };\n        ;\n            for (t = 0, u = s.length; ((t < u)); ++t) {\n                j.appendChild(s[t]);\n            ;\n            };\n        ;\n        };\n    ;\n        function f(a) {\n            var b;\n            try {\n                b = !!a.sheet.cssRules;\n            } catch (d) {\n                l += 1, ((((l < 200)) ? JSBNG__setTimeout(function() {\n                    f(a);\n                }, 50) : ((b && c(\"css\")))));\n                return;\n            };\n        ;\n            c(\"css\");\n        };\n    ;\n        function g() {\n            var a = k.css, b;\n            if (a) {\n                b = n.length;\n                while (((--b >= 0))) {\n                    if (((n[b].href === a.urls[0]))) {\n                        c(\"css\");\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                l += 1, ((a && ((((l < 200)) ? JSBNG__setTimeout(g, 50) : c(\"css\")))));\n            }\n        ;\n        ;\n        };\n    ;\n        var i, j, k = {\n        }, l = 0, m = {\n            css: [],\n            js: []\n        }, n = a.styleSheets;\n        return {\n            css: function(a, b, c, d) {\n                e(\"css\", a, b, c, d);\n            },\n            js: function(a, b, c, d) {\n                e(\"js\", a, b, c, d);\n            }\n        };\n    }(window.JSBNG__document));\n});\nprovide(\"phoenix-more-css-wrapper\", function(a) {\n    var b = [];\n    if (!twttr.isTestEnv) {\n        if (twttr.isT1) {\n            var c = ((twttr.isRTL ? \".rtl\" : \"\"));\n            b.push(((twttr.hasHoversInCss ? ((((\"css!/t1/css/t1_more.bundle\" + c)) + \".css\")) : ((((\"css!/t1/css/t1_more_no_hovers.bundle\" + c)) + \".css\")))));\n        }\n         else b.push(\"css!/phoenix/css/phoenix_more.bundle.css\");\n    ;\n    }\n;\n;\n    using(b, function() {\n        a();\n    });\n});\nprovide(\"$lib/jquery.ui.core.js\", function(a) {\n    (function($, a) {\n        function b(a, b) {\n            var d = a.nodeName.toLowerCase();\n            if (((\"area\" === d))) {\n                var e = a.parentNode, f = e.JSBNG__name, g;\n                return ((((((!a.href || !f)) || ((e.nodeName.toLowerCase() !== \"map\")))) ? !1 : (g = $(((((\"img[usemap=#\" + f)) + \"]\")))[0], ((!!g && c(g))))));\n            }\n        ;\n        ;\n            return ((((/input|select|textarea|button|object/.test(d) ? !a.disabled : ((((\"a\" == d)) ? ((a.href || b)) : b)))) && c(a)));\n        };\n    ;\n        function c(a) {\n            return !$(a).parents().andSelf().filter(function() {\n                return (((($.curCSS(this, \"visibility\") === \"hidden\")) || $.expr.filters.hidden(this)));\n            }).length;\n        };\n    ;\n        $.ui = (($.ui || {\n        }));\n        if ($.ui.version) {\n            return;\n        }\n    ;\n    ;\n        $.extend($.ui, {\n            version: \"1.8.16\",\n            keyCode: {\n                ALT: 18,\n                BACKSPACE: 8,\n                CAPS_LOCK: 20,\n                COMMA: 188,\n                COMMAND: 91,\n                COMMAND_LEFT: 91,\n                COMMAND_RIGHT: 93,\n                CONTROL: 17,\n                DELETE: 46,\n                DOWN: 40,\n                END: 35,\n                ENTER: 13,\n                ESCAPE: 27,\n                HOME: 36,\n                INSERT: 45,\n                LEFT: 37,\n                MENU: 93,\n                NUMPAD_ADD: 107,\n                NUMPAD_DECIMAL: 110,\n                NUMPAD_DIVIDE: 111,\n                NUMPAD_ENTER: 108,\n                NUMPAD_MULTIPLY: 106,\n                NUMPAD_SUBTRACT: 109,\n                PAGE_DOWN: 34,\n                PAGE_UP: 33,\n                PERIOD: 190,\n                RIGHT: 39,\n                SHIFT: 16,\n                SPACE: 32,\n                TAB: 9,\n                UP: 38,\n                WINDOWS: 91\n            }\n        }), $.fn.extend({\n            propAttr: (($.fn.prop || $.fn.attr)),\n            _focus: $.fn.JSBNG__focus,\n            JSBNG__focus: function(a, b) {\n                return ((((typeof a == \"number\")) ? this.each(function() {\n                    var c = this;\n                    JSBNG__setTimeout(function() {\n                        $(c).JSBNG__focus(), ((b && b.call(c)));\n                    }, a);\n                }) : this._focus.apply(this, arguments)));\n            },\n            scrollParent: function() {\n                var a;\n                return (((((($.browser.msie && /(static|relative)/.test(this.css(\"position\")))) || /absolute/.test(this.css(\"position\")))) ? a = this.parents().filter(function() {\n                    return ((/(relative|absolute|fixed)/.test($.curCSS(this, \"position\", 1)) && /(auto|scroll)/.test((((($.curCSS(this, \"overflow\", 1) + $.curCSS(this, \"overflow-y\", 1))) + $.curCSS(this, \"overflow-x\", 1))))));\n                }).eq(0) : a = this.parents().filter(function() {\n                    return /(auto|scroll)/.test((((($.curCSS(this, \"overflow\", 1) + $.curCSS(this, \"overflow-y\", 1))) + $.curCSS(this, \"overflow-x\", 1))));\n                }).eq(0))), ((((/fixed/.test(this.css(\"position\")) || !a.length)) ? $(JSBNG__document) : a));\n            },\n            zIndex: function(b) {\n                if (((b !== a))) {\n                    return this.css(\"zIndex\", b);\n                }\n            ;\n            ;\n                if (this.length) {\n                    var c = $(this[0]), d, e;\n                    while (((c.length && ((c[0] !== JSBNG__document))))) {\n                        d = c.css(\"position\");\n                        if (((((((d === \"absolute\")) || ((d === \"relative\")))) || ((d === \"fixed\"))))) {\n                            e = parseInt(c.css(\"zIndex\"), 10);\n                            if (((!isNaN(e) && ((e !== 0))))) {\n                                return e;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        c = c.parent();\n                    };\n                ;\n                }\n            ;\n            ;\n                return 0;\n            },\n            disableSelection: function() {\n                return this.bind((((($.support.selectstart ? \"selectstart\" : \"mousedown\")) + \".ui-disableSelection\")), function(a) {\n                    a.preventDefault();\n                });\n            },\n            enableSelection: function() {\n                return this.unbind(\".ui-disableSelection\");\n            }\n        }), $.each([\"Width\",\"Height\",], function(b, c) {\n            function d(a, b, c, d) {\n                return $.each(e, function() {\n                    b -= ((parseFloat($.curCSS(a, ((\"padding\" + this)), !0)) || 0)), ((c && (b -= ((parseFloat($.curCSS(a, ((((\"border\" + this)) + \"Width\")), !0)) || 0))))), ((d && (b -= ((parseFloat($.curCSS(a, ((\"margin\" + this)), !0)) || 0)))));\n                }), b;\n            };\n        ;\n            var e = ((((c === \"Width\")) ? [\"Left\",\"Right\",] : [\"Top\",\"Bottom\",])), f = c.toLowerCase(), g = {\n                JSBNG__innerWidth: $.fn.JSBNG__innerWidth,\n                JSBNG__innerHeight: $.fn.JSBNG__innerHeight,\n                JSBNG__outerWidth: $.fn.JSBNG__outerWidth,\n                JSBNG__outerHeight: $.fn.JSBNG__outerHeight\n            };\n            $.fn[((\"JSBNG__inner\" + c))] = function(b) {\n                return ((((b === a)) ? g[((\"JSBNG__inner\" + c))].call(this) : this.each(function() {\n                    $(this).css(f, ((d(this, b) + \"px\")));\n                })));\n            }, $.fn[((\"JSBNG__outer\" + c))] = function(a, b) {\n                return ((((typeof a != \"number\")) ? g[((\"JSBNG__outer\" + c))].call(this, a) : this.each(function() {\n                    $(this).css(f, ((d(this, a, !0, b) + \"px\")));\n                })));\n            };\n        }), $.extend($.expr[\":\"], {\n            data: function(a, b, c) {\n                return !!$.data(a, c[3]);\n            },\n            focusable: function(a) {\n                return b(a, !isNaN($.attr(a, \"tabindex\")));\n            },\n            tabbable: function(a) {\n                var c = $.attr(a, \"tabindex\"), d = isNaN(c);\n                return ((((d || ((c >= 0)))) && b(a, !d)));\n            }\n        }), $(function() {\n            var a = JSBNG__document.body, b = a.appendChild(b = JSBNG__document.createElement(\"div\"));\n            $.extend(b.style, {\n                minHeight: \"100px\",\n                height: \"auto\",\n                padding: 0,\n                borderWidth: 0\n            }), $.support.minHeight = ((b.offsetHeight === 100)), $.support.selectstart = ((\"JSBNG__onselectstart\" in b)), a.removeChild(b).style.display = \"none\";\n        }), $.extend($.ui, {\n            plugin: {\n                add: function(a, b, c) {\n                    var d = $.ui[a].prototype;\n                    for (var e in c) {\n                        d.plugins[e] = ((d.plugins[e] || [])), d.plugins[e].push([b,c[e],]);\n                    ;\n                    };\n                ;\n                },\n                call: function(a, b, c) {\n                    var d = a.plugins[b];\n                    if (((!d || !a.element[0].parentNode))) {\n                        return;\n                    }\n                ;\n                ;\n                    for (var e = 0; ((e < d.length)); e++) {\n                        ((a.options[d[e][0]] && d[e][1].apply(a.element, c)));\n                    ;\n                    };\n                ;\n                }\n            },\n            contains: function(a, b) {\n                return ((JSBNG__document.compareDocumentPosition ? ((a.compareDocumentPosition(b) & 16)) : ((((a !== b)) && a.contains(b)))));\n            },\n            hasScroll: function(a, b) {\n                if ((($(a).css(\"overflow\") === \"hidden\"))) {\n                    return !1;\n                }\n            ;\n            ;\n                var c = ((((b && ((b === \"left\")))) ? \"scrollLeft\" : \"scrollTop\")), d = !1;\n                return ((((a[c] > 0)) ? !0 : (a[c] = 1, d = ((a[c] > 0)), a[c] = 0, d)));\n            },\n            isOverAxis: function(a, b, c) {\n                return ((((a > b)) && ((a < ((b + c))))));\n            },\n            isOver: function(a, b, c, d, e, f) {\n                return (($.ui.isOverAxis(a, c, e) && $.ui.isOverAxis(b, d, f)));\n            }\n        });\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.ui.widget.js\", function(a) {\n    (function($, a) {\n        if ($.cleanData) {\n            var b = $.cleanData;\n            $.cleanData = function(a) {\n                for (var c = 0, d; (((d = a[c]) != null)); c++) {\n                    try {\n                        $(d).triggerHandler(\"remove\");\n                    } catch (e) {\n                    \n                    };\n                ;\n                };\n            ;\n                b(a);\n            };\n        }\n         else {\n            var c = $.fn.remove;\n            $.fn.remove = function(a, b) {\n                return this.each(function() {\n                    return ((b || ((((!a || $.filter(a, [this,]).length)) && $(\"*\", this).add([this,]).each(function() {\n                        try {\n                            $(this).triggerHandler(\"remove\");\n                        } catch (a) {\n                        \n                        };\n                    ;\n                    }))))), c.call($(this), a, b);\n                });\n            };\n        }\n    ;\n    ;\n        $.widget = function(a, b, c) {\n            var d = a.split(\".\")[0], e;\n            a = a.split(\".\")[1], e = ((((d + \"-\")) + a)), ((c || (c = b, b = $.Widget))), $.expr[\":\"][e] = function(b) {\n                return !!$.data(b, a);\n            }, $[d] = (($[d] || {\n            })), $[d][a] = function(a, b) {\n                ((arguments.length && this._createWidget(a, b)));\n            };\n            var f = new b;\n            f.options = $.extend(!0, {\n            }, f.options), $[d][a].prototype = $.extend(!0, f, {\n                namespace: d,\n                widgetName: a,\n                widgetEventPrefix: (($[d][a].prototype.widgetEventPrefix || a)),\n                widgetBaseClass: e\n            }, c), $.widget.bridge(a, $[d][a]);\n        }, $.widget.bridge = function(b, c) {\n            $.fn[b] = function(d) {\n                var e = ((typeof d == \"string\")), f = Array.prototype.slice.call(arguments, 1), g = this;\n                return d = ((((!e && f.length)) ? $.extend.apply(null, [!0,d,].concat(f)) : d)), ((((e && ((d.charAt(0) === \"_\")))) ? g : (((e ? this.each(function() {\n                    var c = $.data(this, b), e = ((((c && $.isFunction(c[d]))) ? c[d].apply(c, f) : c));\n                    if (((((e !== c)) && ((e !== a))))) {\n                        return g = e, !1;\n                    }\n                ;\n                ;\n                }) : this.each(function() {\n                    var a = $.data(this, b);\n                    ((a ? a.option(((d || {\n                    })))._init() : $.data(this, b, new c(d, this))));\n                }))), g)));\n            };\n        }, $.Widget = function(a, b) {\n            ((arguments.length && this._createWidget(a, b)));\n        }, $.Widget.prototype = {\n            widgetName: \"widget\",\n            widgetEventPrefix: \"\",\n            options: {\n                disabled: !1\n            },\n            _createWidget: function(a, b) {\n                $.data(b, this.widgetName, this), this.element = $(b), this.options = $.extend(!0, {\n                }, this.options, this._getCreateOptions(), a);\n                var c = this;\n                this.element.bind(((\"remove.\" + this.widgetName)), function() {\n                    c.destroy();\n                }), this._create(), this._trigger(\"create\"), this._init();\n            },\n            _getCreateOptions: function() {\n                return (($.metadata && $.metadata.get(this.element[0])[this.widgetName]));\n            },\n            _create: function() {\n            \n            },\n            _init: function() {\n            \n            },\n            destroy: function() {\n                this.element.unbind(((\".\" + this.widgetName))).removeData(this.widgetName), this.widget().unbind(((\".\" + this.widgetName))).removeAttr(\"aria-disabled\").removeClass(((((this.widgetBaseClass + \"-disabled \")) + \"ui-state-disabled\")));\n            },\n            widget: function() {\n                return this.element;\n            },\n            option: function(b, c) {\n                var d = b;\n                if (((arguments.length === 0))) {\n                    return $.extend({\n                    }, this.options);\n                }\n            ;\n            ;\n                if (((typeof b == \"string\"))) {\n                    if (((c === a))) {\n                        return this.options[b];\n                    }\n                ;\n                ;\n                    d = {\n                    }, d[b] = c;\n                }\n            ;\n            ;\n                return this._setOptions(d), this;\n            },\n            _setOptions: function(a) {\n                var b = this;\n                return $.each(a, function(a, c) {\n                    b._setOption(a, c);\n                }), this;\n            },\n            _setOption: function(a, b) {\n                return this.options[a] = b, ((((a === \"disabled\")) && this.widget()[((b ? \"addClass\" : \"removeClass\"))](((((((this.widgetBaseClass + \"-disabled\")) + \" \")) + \"ui-state-disabled\"))).attr(\"aria-disabled\", b))), this;\n            },\n            enable: function() {\n                return this._setOption(\"disabled\", !1);\n            },\n            disable: function() {\n                return this._setOption(\"disabled\", !0);\n            },\n            _trigger: function(a, b, c) {\n                var d = this.options[a];\n                b = $.JSBNG__Event(b), b.type = ((((a === this.widgetEventPrefix)) ? a : ((this.widgetEventPrefix + a)))).toLowerCase(), c = ((c || {\n                }));\n                if (b.originalEvent) {\n                    for (var e = $.JSBNG__event.props.length, f; e; ) {\n                        f = $.JSBNG__event.props[--e], b[f] = b.originalEvent[f];\n                    ;\n                    };\n                }\n            ;\n            ;\n                return this.element.trigger(b, c), !(((($.isFunction(d) && ((d.call(this.element[0], b, c) === !1)))) || b.isDefaultPrevented()));\n            }\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.ui.mouse.js\", function(a) {\n    (function($, a) {\n        var b = !1;\n        $(JSBNG__document).mouseup(function(a) {\n            b = !1;\n        }), $.widget(\"ui.mouse\", {\n            options: {\n                cancel: \":input,option\",\n                distance: 1,\n                delay: 0\n            },\n            _mouseInit: function() {\n                var a = this;\n                this.element.bind(((\"mousedown.\" + this.widgetName)), function(b) {\n                    return a._mouseDown(b);\n                }).bind(((\"click.\" + this.widgetName)), function(b) {\n                    if (((!0 === $.data(b.target, ((a.widgetName + \".preventClickEvent\")))))) {\n                        return $.removeData(b.target, ((a.widgetName + \".preventClickEvent\"))), b.stopImmediatePropagation(), !1;\n                    }\n                ;\n                ;\n                }), this.started = !1;\n            },\n            _mouseDestroy: function() {\n                this.element.unbind(((\".\" + this.widgetName)));\n            },\n            _mouseDown: function(a) {\n                if (b) {\n                    return;\n                }\n            ;\n            ;\n                ((this._mouseStarted && this._mouseUp(a))), this._mouseDownEvent = a;\n                var c = this, d = ((a.which == 1)), e = ((((((typeof this.options.cancel == \"string\")) && a.target.nodeName)) ? $(a.target).closest(this.options.cancel).length : !1));\n                if (((((!d || e)) || !this._mouseCapture(a)))) {\n                    return !0;\n                }\n            ;\n            ;\n                this.mouseDelayMet = !this.options.delay, ((this.mouseDelayMet || (this._mouseDelayTimer = JSBNG__setTimeout(function() {\n                    c.mouseDelayMet = !0;\n                }, this.options.delay))));\n                if (((this._mouseDistanceMet(a) && this._mouseDelayMet(a)))) {\n                    this._mouseStarted = ((this._mouseStart(a) !== !1));\n                    if (!this._mouseStarted) {\n                        return a.preventDefault(), !0;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return ((((!0 === $.data(a.target, ((this.widgetName + \".preventClickEvent\"))))) && $.removeData(a.target, ((this.widgetName + \".preventClickEvent\"))))), this._mouseMoveDelegate = function(a) {\n                    return c._mouseMove(a);\n                }, this._mouseUpDelegate = function(a) {\n                    return c._mouseUp(a);\n                }, $(JSBNG__document).bind(((\"mousemove.\" + this.widgetName)), this._mouseMoveDelegate).bind(((\"mouseup.\" + this.widgetName)), this._mouseUpDelegate), a.preventDefault(), b = !0, !0;\n            },\n            _mouseMove: function(a) {\n                return ((((((!$.browser.msie || ((JSBNG__document.documentMode >= 9)))) || !!a.button)) ? ((this._mouseStarted ? (this._mouseDrag(a), a.preventDefault()) : (((((this._mouseDistanceMet(a) && this._mouseDelayMet(a))) && (this._mouseStarted = ((this._mouseStart(this._mouseDownEvent, a) !== !1)), ((this._mouseStarted ? this._mouseDrag(a) : this._mouseUp(a)))))), !this._mouseStarted))) : this._mouseUp(a)));\n            },\n            _mouseUp: function(a) {\n                return $(JSBNG__document).unbind(((\"mousemove.\" + this.widgetName)), this._mouseMoveDelegate).unbind(((\"mouseup.\" + this.widgetName)), this._mouseUpDelegate), ((this._mouseStarted && (this._mouseStarted = !1, ((((a.target == this._mouseDownEvent.target)) && $.data(a.target, ((this.widgetName + \".preventClickEvent\")), !0))), this._mouseStop(a)))), !1;\n            },\n            _mouseDistanceMet: function(a) {\n                return ((Math.max(Math.abs(((this._mouseDownEvent.pageX - a.pageX))), Math.abs(((this._mouseDownEvent.pageY - a.pageY)))) >= this.options.distance));\n            },\n            _mouseDelayMet: function(a) {\n                return this.mouseDelayMet;\n            },\n            _mouseStart: function(a) {\n            \n            },\n            _mouseDrag: function(a) {\n            \n            },\n            _mouseStop: function(a) {\n            \n            },\n            _mouseCapture: function(a) {\n                return !0;\n            }\n        });\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.ui.draggable.js\", function(a) {\n    (function($, a) {\n        $.widget(\"ui.draggable\", $.ui.mouse, {\n            widgetEventPrefix: \"drag\",\n            options: {\n                addClasses: !0,\n                appendTo: \"parent\",\n                axis: !1,\n                connectToSortable: !1,\n                containment: !1,\n                cursor: \"auto\",\n                cursorAt: !1,\n                grid: !1,\n                handle: !1,\n                helper: \"original\",\n                iframeFix: !1,\n                opacity: !1,\n                refreshPositions: !1,\n                revert: !1,\n                revertDuration: 500,\n                scope: \"default\",\n                JSBNG__scroll: !0,\n                scrollSensitivity: 20,\n                scrollSpeed: 20,\n                snap: !1,\n                snapMode: \"both\",\n                snapTolerance: 20,\n                stack: !1,\n                zIndex: !1\n            },\n            _create: function() {\n                ((((((this.options.helper == \"original\")) && !/^(?:r|a|f)/.test(this.element.css(\"position\")))) && (this.element[0].style.position = \"relative\"))), ((this.options.addClasses && this.element.addClass(\"ui-draggable\"))), ((this.options.disabled && this.element.addClass(\"ui-draggable-disabled\"))), this._mouseInit();\n            },\n            destroy: function() {\n                if (!this.element.data(\"draggable\")) {\n                    return;\n                }\n            ;\n            ;\n                return this.element.removeData(\"draggable\").unbind(\".draggable\").removeClass(\"ui-draggable ui-draggable-dragging ui-draggable-disabled\"), this._mouseDestroy(), this;\n            },\n            _mouseCapture: function(a) {\n                var b = this.options;\n                return ((((((this.helper || b.disabled)) || $(a.target).is(\".ui-resizable-handle\"))) ? !1 : (this.handle = this._getHandle(a), ((this.handle ? (((b.iframeFix && $(((((b.iframeFix === !0)) ? \"div\" : b.iframeFix))).each(function() {\n                    $(\"\\u003Cdiv class=\\\"ui-draggable-iframeFix\\\" style=\\\"background: #fff;\\\"\\u003E\\u003C/div\\u003E\").css({\n                        width: ((this.offsetWidth + \"px\")),\n                        height: ((this.offsetHeight + \"px\")),\n                        position: \"absolute\",\n                        opacity: \"0.001\",\n                        zIndex: 1000\n                    }).css($(this).offset()).appendTo(\"body\");\n                }))), !0) : !1)))));\n            },\n            _mouseStart: function(a) {\n                var b = this.options;\n                return this.helper = this._createHelper(a), this._cacheHelperProportions(), (($.ui.ddmanager && ($.ui.ddmanager.current = this))), this._cacheMargins(), this.cssPosition = this.helper.css(\"position\"), this.scrollParent = this.helper.scrollParent(), this.offset = this.positionAbs = this.element.offset(), this.offset = {\n                    JSBNG__top: ((this.offset.JSBNG__top - this.margins.JSBNG__top)),\n                    left: ((this.offset.left - this.margins.left))\n                }, $.extend(this.offset, {\n                    click: {\n                        left: ((a.pageX - this.offset.left)),\n                        JSBNG__top: ((a.pageY - this.offset.JSBNG__top))\n                    },\n                    parent: this._getParentOffset(),\n                    relative: this._getRelativeOffset()\n                }), this.originalPosition = this.position = this._generatePosition(a), this.originalPageX = a.pageX, this.originalPageY = a.pageY, ((b.cursorAt && this._adjustOffsetFromHelper(b.cursorAt))), ((b.containment && this._setContainment())), ((((this._trigger(\"start\", a) === !1)) ? (this._clear(), !1) : (this._cacheHelperProportions(), (((($.ui.ddmanager && !b.dropBehaviour)) && $.ui.ddmanager.prepareOffsets(this, a))), this.helper.addClass(\"ui-draggable-dragging\"), this._mouseDrag(a, !0), (($.ui.ddmanager && $.ui.ddmanager.dragStart(this, a))), !0)));\n            },\n            _mouseDrag: function(a, b) {\n                this.position = this._generatePosition(a), this.positionAbs = this._convertPositionTo(\"absolute\");\n                if (!b) {\n                    var c = this._uiHash();\n                    if (((this._trigger(\"drag\", a, c) === !1))) {\n                        return this._mouseUp({\n                        }), !1;\n                    }\n                ;\n                ;\n                    this.position = c.position;\n                }\n            ;\n            ;\n                if (((!this.options.axis || ((this.options.axis != \"y\"))))) {\n                    this.helper[0].style.left = ((this.position.left + \"px\"));\n                }\n            ;\n            ;\n                if (((!this.options.axis || ((this.options.axis != \"x\"))))) {\n                    this.helper[0].style.JSBNG__top = ((this.position.JSBNG__top + \"px\"));\n                }\n            ;\n            ;\n                return (($.ui.ddmanager && $.ui.ddmanager.drag(this, a))), !1;\n            },\n            _mouseStop: function(a) {\n                var b = !1;\n                (((($.ui.ddmanager && !this.options.dropBehaviour)) && (b = $.ui.ddmanager.drop(this, a)))), ((this.dropped && (b = this.dropped, this.dropped = !1)));\n                if (((((!this.element[0] || !this.element[0].parentNode)) && ((this.options.helper == \"original\"))))) {\n                    return !1;\n                }\n            ;\n            ;\n                if (((((((((((this.options.revert == \"invalid\")) && !b)) || ((((this.options.revert == \"valid\")) && b)))) || ((this.options.revert === !0)))) || (($.isFunction(this.options.revert) && this.options.revert.call(this.element, b)))))) {\n                    var c = this;\n                    $(this.helper).animate(this.originalPosition, parseInt(this.options.revertDuration, 10), function() {\n                        ((((c._trigger(\"JSBNG__stop\", a) !== !1)) && c._clear()));\n                    });\n                }\n                 else ((((this._trigger(\"JSBNG__stop\", a) !== !1)) && this._clear()));\n            ;\n            ;\n                return !1;\n            },\n            _mouseUp: function(a) {\n                return ((((this.options.iframeFix === !0)) && $(\"div.ui-draggable-iframeFix\").each(function() {\n                    this.parentNode.removeChild(this);\n                }))), (($.ui.ddmanager && $.ui.ddmanager.dragStop(this, a))), $.ui.mouse.prototype._mouseUp.call(this, a);\n            },\n            cancel: function() {\n                return ((this.helper.is(\".ui-draggable-dragging\") ? this._mouseUp({\n                }) : this._clear())), this;\n            },\n            _getHandle: function(a) {\n                var b = ((((!this.options.handle || !$(this.options.handle, this.element).length)) ? !0 : !1));\n                return $(this.options.handle, this.element).JSBNG__find(\"*\").andSelf().each(function() {\n                    ((((this == a.target)) && (b = !0)));\n                }), b;\n            },\n            _createHelper: function(a) {\n                var b = this.options, c = (($.isFunction(b.helper) ? $(b.helper.apply(this.element[0], [a,])) : ((((b.helper == \"clone\")) ? this.element.clone().removeAttr(\"id\") : this.element))));\n                return ((c.parents(\"body\").length || c.appendTo(((((b.appendTo == \"parent\")) ? this.element[0].parentNode : b.appendTo))))), ((((((c[0] != this.element[0])) && !/(fixed|absolute)/.test(c.css(\"position\")))) && c.css(\"position\", \"absolute\"))), c;\n            },\n            _adjustOffsetFromHelper: function(a) {\n                ((((typeof a == \"string\")) && (a = a.split(\" \")))), (($.isArray(a) && (a = {\n                    left: +a[0],\n                    JSBNG__top: ((+a[1] || 0))\n                }))), ((((\"left\" in a)) && (this.offset.click.left = ((a.left + this.margins.left))))), ((((\"right\" in a)) && (this.offset.click.left = ((((this.helperProportions.width - a.right)) + this.margins.left))))), ((((\"JSBNG__top\" in a)) && (this.offset.click.JSBNG__top = ((a.JSBNG__top + this.margins.JSBNG__top))))), ((((\"bottom\" in a)) && (this.offset.click.JSBNG__top = ((((this.helperProportions.height - a.bottom)) + this.margins.JSBNG__top)))));\n            },\n            _getParentOffset: function() {\n                this.offsetParent = this.helper.offsetParent();\n                var a = this.offsetParent.offset();\n                ((((((((this.cssPosition == \"absolute\")) && ((this.scrollParent[0] != JSBNG__document)))) && $.ui.contains(this.scrollParent[0], this.offsetParent[0]))) && (a.left += this.scrollParent.scrollLeft(), a.JSBNG__top += this.scrollParent.scrollTop())));\n                if (((((this.offsetParent[0] == JSBNG__document.body)) || ((((this.offsetParent[0].tagName && ((this.offsetParent[0].tagName.toLowerCase() == \"html\")))) && $.browser.msie))))) {\n                    a = {\n                        JSBNG__top: 0,\n                        left: 0\n                    };\n                }\n            ;\n            ;\n                return {\n                    JSBNG__top: ((a.JSBNG__top + ((parseInt(this.offsetParent.css(\"borderTopWidth\"), 10) || 0)))),\n                    left: ((a.left + ((parseInt(this.offsetParent.css(\"borderLeftWidth\"), 10) || 0))))\n                };\n            },\n            _getRelativeOffset: function() {\n                if (((this.cssPosition == \"relative\"))) {\n                    var a = this.element.position();\n                    return {\n                        JSBNG__top: ((((a.JSBNG__top - ((parseInt(this.helper.css(\"JSBNG__top\"), 10) || 0)))) + this.scrollParent.scrollTop())),\n                        left: ((((a.left - ((parseInt(this.helper.css(\"left\"), 10) || 0)))) + this.scrollParent.scrollLeft()))\n                    };\n                }\n            ;\n            ;\n                return {\n                    JSBNG__top: 0,\n                    left: 0\n                };\n            },\n            _cacheMargins: function() {\n                this.margins = {\n                    left: ((parseInt(this.element.css(\"marginLeft\"), 10) || 0)),\n                    JSBNG__top: ((parseInt(this.element.css(\"marginTop\"), 10) || 0)),\n                    right: ((parseInt(this.element.css(\"marginRight\"), 10) || 0)),\n                    bottom: ((parseInt(this.element.css(\"marginBottom\"), 10) || 0))\n                };\n            },\n            _cacheHelperProportions: function() {\n                this.helperProportions = {\n                    width: this.helper.JSBNG__outerWidth(),\n                    height: this.helper.JSBNG__outerHeight()\n                };\n            },\n            _setContainment: function() {\n                var a = this.options;\n                ((((a.containment == \"parent\")) && (a.containment = this.helper[0].parentNode)));\n                if (((((a.containment == \"JSBNG__document\")) || ((a.containment == \"window\"))))) {\n                    this.containment = [((((a.containment == \"JSBNG__document\")) ? 0 : (((($(window).scrollLeft() - this.offset.relative.left)) - this.offset.parent.left)))),((((a.containment == \"JSBNG__document\")) ? 0 : (((($(window).scrollTop() - this.offset.relative.JSBNG__top)) - this.offset.parent.JSBNG__top)))),((((((((((a.containment == \"JSBNG__document\")) ? 0 : $(window).scrollLeft())) + $(((((a.containment == \"JSBNG__document\")) ? JSBNG__document : window))).width())) - this.helperProportions.width)) - this.margins.left)),((((((((((a.containment == \"JSBNG__document\")) ? 0 : $(window).scrollTop())) + (($(((((a.containment == \"JSBNG__document\")) ? JSBNG__document : window))).height() || JSBNG__document.body.parentNode.scrollHeight)))) - this.helperProportions.height)) - this.margins.JSBNG__top)),];\n                }\n            ;\n            ;\n                if (((!/^(document|window|parent)$/.test(a.containment) && ((a.containment.constructor != Array))))) {\n                    var b = $(a.containment), c = b[0];\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = b.offset(), e = (($(c).css(\"overflow\") != \"hidden\"));\n                    this.containment = [((((parseInt($(c).css(\"borderLeftWidth\"), 10) || 0)) + ((parseInt($(c).css(\"paddingLeft\"), 10) || 0)))),((((parseInt($(c).css(\"borderTopWidth\"), 10) || 0)) + ((parseInt($(c).css(\"paddingTop\"), 10) || 0)))),((((((((((((e ? Math.max(c.scrollWidth, c.offsetWidth) : c.offsetWidth)) - ((parseInt($(c).css(\"borderLeftWidth\"), 10) || 0)))) - ((parseInt($(c).css(\"paddingRight\"), 10) || 0)))) - this.helperProportions.width)) - this.margins.left)) - this.margins.right)),((((((((((((e ? Math.max(c.scrollHeight, c.offsetHeight) : c.offsetHeight)) - ((parseInt($(c).css(\"borderTopWidth\"), 10) || 0)))) - ((parseInt($(c).css(\"paddingBottom\"), 10) || 0)))) - this.helperProportions.height)) - this.margins.JSBNG__top)) - this.margins.bottom)),], this.relative_container = b;\n                }\n                 else ((((a.containment.constructor == Array)) && (this.containment = a.containment)));\n            ;\n            ;\n            },\n            _convertPositionTo: function(a, b) {\n                ((b || (b = this.position)));\n                var c = ((((a == \"absolute\")) ? 1 : -1)), d = this.options, e = ((((((this.cssPosition != \"absolute\")) || ((((this.scrollParent[0] != JSBNG__document)) && !!$.ui.contains(this.scrollParent[0], this.offsetParent[0]))))) ? this.scrollParent : this.offsetParent)), f = /(html|body)/i.test(e[0].tagName);\n                return {\n                    JSBNG__top: ((((((b.JSBNG__top + ((this.offset.relative.JSBNG__top * c)))) + ((this.offset.parent.JSBNG__top * c)))) - (((((($.browser.safari && (($.browser.version < 526)))) && ((this.cssPosition == \"fixed\")))) ? 0 : ((((((this.cssPosition == \"fixed\")) ? -this.scrollParent.scrollTop() : ((f ? 0 : e.scrollTop())))) * c)))))),\n                    left: ((((((b.left + ((this.offset.relative.left * c)))) + ((this.offset.parent.left * c)))) - (((((($.browser.safari && (($.browser.version < 526)))) && ((this.cssPosition == \"fixed\")))) ? 0 : ((((((this.cssPosition == \"fixed\")) ? -this.scrollParent.scrollLeft() : ((f ? 0 : e.scrollLeft())))) * c))))))\n                };\n            },\n            _generatePosition: function(a) {\n                var b = this.options, c = ((((((this.cssPosition != \"absolute\")) || ((((this.scrollParent[0] != JSBNG__document)) && !!$.ui.contains(this.scrollParent[0], this.offsetParent[0]))))) ? this.scrollParent : this.offsetParent)), d = /(html|body)/i.test(c[0].tagName), e = a.pageX, f = a.pageY;\n                if (this.originalPosition) {\n                    var g;\n                    if (this.containment) {\n                        if (this.relative_container) {\n                            var i = this.relative_container.offset();\n                            g = [((this.containment[0] + i.left)),((this.containment[1] + i.JSBNG__top)),((this.containment[2] + i.left)),((this.containment[3] + i.JSBNG__top)),];\n                        }\n                         else g = this.containment;\n                    ;\n                    ;\n                        ((((((a.pageX - this.offset.click.left)) < g[0])) && (e = ((g[0] + this.offset.click.left))))), ((((((a.pageY - this.offset.click.JSBNG__top)) < g[1])) && (f = ((g[1] + this.offset.click.JSBNG__top))))), ((((((a.pageX - this.offset.click.left)) > g[2])) && (e = ((g[2] + this.offset.click.left))))), ((((((a.pageY - this.offset.click.JSBNG__top)) > g[3])) && (f = ((g[3] + this.offset.click.JSBNG__top)))));\n                    }\n                ;\n                ;\n                    if (b.grid) {\n                        var j = ((b.grid[1] ? ((this.originalPageY + ((Math.round(((((f - this.originalPageY)) / b.grid[1]))) * b.grid[1])))) : this.originalPageY));\n                        f = ((g ? ((((((((j - this.offset.click.JSBNG__top)) < g[1])) || ((((j - this.offset.click.JSBNG__top)) > g[3])))) ? ((((((j - this.offset.click.JSBNG__top)) < g[1])) ? ((j + b.grid[1])) : ((j - b.grid[1])))) : j)) : j));\n                        var k = ((b.grid[0] ? ((this.originalPageX + ((Math.round(((((e - this.originalPageX)) / b.grid[0]))) * b.grid[0])))) : this.originalPageX));\n                        e = ((g ? ((((((((k - this.offset.click.left)) < g[0])) || ((((k - this.offset.click.left)) > g[2])))) ? ((((((k - this.offset.click.left)) < g[0])) ? ((k + b.grid[0])) : ((k - b.grid[0])))) : k)) : k));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return {\n                    JSBNG__top: ((((((((f - this.offset.click.JSBNG__top)) - this.offset.relative.JSBNG__top)) - this.offset.parent.JSBNG__top)) + (((((($.browser.safari && (($.browser.version < 526)))) && ((this.cssPosition == \"fixed\")))) ? 0 : ((((this.cssPosition == \"fixed\")) ? -this.scrollParent.scrollTop() : ((d ? 0 : c.scrollTop())))))))),\n                    left: ((((((((e - this.offset.click.left)) - this.offset.relative.left)) - this.offset.parent.left)) + (((((($.browser.safari && (($.browser.version < 526)))) && ((this.cssPosition == \"fixed\")))) ? 0 : ((((this.cssPosition == \"fixed\")) ? -this.scrollParent.scrollLeft() : ((d ? 0 : c.scrollLeft()))))))))\n                };\n            },\n            _clear: function() {\n                this.helper.removeClass(\"ui-draggable-dragging\"), ((((((this.helper[0] != this.element[0])) && !this.cancelHelperRemoval)) && this.helper.remove())), this.helper = null, this.cancelHelperRemoval = !1;\n            },\n            _trigger: function(a, b, c) {\n                return c = ((c || this._uiHash())), $.ui.plugin.call(this, a, [b,c,]), ((((a == \"drag\")) && (this.positionAbs = this._convertPositionTo(\"absolute\")))), $.Widget.prototype._trigger.call(this, a, b, c);\n            },\n            plugins: {\n            },\n            _uiHash: function(a) {\n                return {\n                    helper: this.helper,\n                    position: this.position,\n                    originalPosition: this.originalPosition,\n                    offset: this.positionAbs\n                };\n            }\n        }), $.extend($.ui.draggable, {\n            version: \"1.8.16\"\n        }), $.ui.plugin.add(\"draggable\", \"connectToSortable\", {\n            start: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = c.options, e = $.extend({\n                }, b, {\n                    item: c.element\n                });\n                c.sortables = [], $(d.connectToSortable).each(function() {\n                    var b = $.data(this, \"sortable\");\n                    ((((b && !b.options.disabled)) && (c.sortables.push({\n                        instance: b,\n                        shouldRevert: b.options.revert\n                    }), b.refreshPositions(), b._trigger(\"activate\", a, e))));\n                });\n            },\n            JSBNG__stop: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = $.extend({\n                }, b, {\n                    item: c.element\n                });\n                $.each(c.sortables, function() {\n                    ((this.instance.isOver ? (this.instance.isOver = 0, c.cancelHelperRemoval = !0, this.instance.cancelHelperRemoval = !1, ((this.shouldRevert && (this.instance.options.revert = !0))), this.instance._mouseStop(a), this.instance.options.helper = this.instance.options._helper, ((((c.options.helper == \"original\")) && this.instance.currentItem.css({\n                        JSBNG__top: \"auto\",\n                        left: \"auto\"\n                    })))) : (this.instance.cancelHelperRemoval = !1, this.instance._trigger(\"deactivate\", a, d))));\n                });\n            },\n            drag: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = this, e = function(a) {\n                    var b = this.offset.click.JSBNG__top, c = this.offset.click.left, d = this.positionAbs.JSBNG__top, e = this.positionAbs.left, f = a.height, g = a.width, i = a.JSBNG__top, j = a.left;\n                    return $.ui.isOver(((d + b)), ((e + c)), i, j, f, g);\n                };\n                $.each(c.sortables, function(e) {\n                    this.instance.positionAbs = c.positionAbs, this.instance.helperProportions = c.helperProportions, this.instance.offset.click = c.offset.click, ((this.instance._intersectsWith(this.instance.containerCache) ? (((this.instance.isOver || (this.instance.isOver = 1, this.instance.currentItem = $(d).clone().removeAttr(\"id\").appendTo(this.instance.element).data(\"sortable-item\", !0), this.instance.options._helper = this.instance.options.helper, this.instance.options.helper = function() {\n                        return b.helper[0];\n                    }, a.target = this.instance.currentItem[0], this.instance._mouseCapture(a, !0), this.instance._mouseStart(a, !0, !0), this.instance.offset.click.JSBNG__top = c.offset.click.JSBNG__top, this.instance.offset.click.left = c.offset.click.left, this.instance.offset.parent.left -= ((c.offset.parent.left - this.instance.offset.parent.left)), this.instance.offset.parent.JSBNG__top -= ((c.offset.parent.JSBNG__top - this.instance.offset.parent.JSBNG__top)), c._trigger(\"toSortable\", a), c.dropped = this.instance.element, c.currentItem = c.element, this.instance.fromOutside = c))), ((this.instance.currentItem && this.instance._mouseDrag(a)))) : ((this.instance.isOver && (this.instance.isOver = 0, this.instance.cancelHelperRemoval = !0, this.instance.options.revert = !1, this.instance._trigger(\"out\", a, this.instance._uiHash(this.instance)), this.instance._mouseStop(a, !0), this.instance.options.helper = this.instance.options._helper, this.instance.currentItem.remove(), ((this.instance.placeholder && this.instance.placeholder.remove())), c._trigger(\"fromSortable\", a), c.dropped = !1)))));\n                });\n            }\n        }), $.ui.plugin.add(\"draggable\", \"cursor\", {\n            start: function(a, b) {\n                var c = $(\"body\"), d = $(this).data(\"draggable\").options;\n                ((c.css(\"cursor\") && (d._cursor = c.css(\"cursor\")))), c.css(\"cursor\", d.cursor);\n            },\n            JSBNG__stop: function(a, b) {\n                var c = $(this).data(\"draggable\").options;\n                ((c._cursor && $(\"body\").css(\"cursor\", c._cursor)));\n            }\n        }), $.ui.plugin.add(\"draggable\", \"opacity\", {\n            start: function(a, b) {\n                var c = $(b.helper), d = $(this).data(\"draggable\").options;\n                ((c.css(\"opacity\") && (d._opacity = c.css(\"opacity\")))), c.css(\"opacity\", d.opacity);\n            },\n            JSBNG__stop: function(a, b) {\n                var c = $(this).data(\"draggable\").options;\n                ((c._opacity && $(b.helper).css(\"opacity\", c._opacity)));\n            }\n        }), $.ui.plugin.add(\"draggable\", \"JSBNG__scroll\", {\n            start: function(a, b) {\n                var c = $(this).data(\"draggable\");\n                ((((((c.scrollParent[0] != JSBNG__document)) && ((c.scrollParent[0].tagName != \"HTML\")))) && (c.overflowOffset = c.scrollParent.offset())));\n            },\n            drag: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = c.options, e = !1;\n                if (((((c.scrollParent[0] != JSBNG__document)) && ((c.scrollParent[0].tagName != \"HTML\"))))) {\n                    if (((!d.axis || ((d.axis != \"x\"))))) {\n                        ((((((((c.overflowOffset.JSBNG__top + c.scrollParent[0].offsetHeight)) - a.pageY)) < d.scrollSensitivity)) ? c.scrollParent[0].scrollTop = e = ((c.scrollParent[0].scrollTop + d.scrollSpeed)) : ((((((a.pageY - c.overflowOffset.JSBNG__top)) < d.scrollSensitivity)) && (c.scrollParent[0].scrollTop = e = ((c.scrollParent[0].scrollTop - d.scrollSpeed)))))));\n                    }\n                ;\n                ;\n                    if (((!d.axis || ((d.axis != \"y\"))))) {\n                        ((((((((c.overflowOffset.left + c.scrollParent[0].offsetWidth)) - a.pageX)) < d.scrollSensitivity)) ? c.scrollParent[0].scrollLeft = e = ((c.scrollParent[0].scrollLeft + d.scrollSpeed)) : ((((((a.pageX - c.overflowOffset.left)) < d.scrollSensitivity)) && (c.scrollParent[0].scrollLeft = e = ((c.scrollParent[0].scrollLeft - d.scrollSpeed)))))));\n                    }\n                ;\n                ;\n                }\n                 else {\n                    if (((!d.axis || ((d.axis != \"x\"))))) {\n                        ((((((a.pageY - $(JSBNG__document).scrollTop())) < d.scrollSensitivity)) ? e = $(JSBNG__document).scrollTop((($(JSBNG__document).scrollTop() - d.scrollSpeed))) : (((((($(window).height() - ((a.pageY - $(JSBNG__document).scrollTop())))) < d.scrollSensitivity)) && (e = $(JSBNG__document).scrollTop((($(JSBNG__document).scrollTop() + d.scrollSpeed))))))));\n                    }\n                ;\n                ;\n                    if (((!d.axis || ((d.axis != \"y\"))))) {\n                        ((((((a.pageX - $(JSBNG__document).scrollLeft())) < d.scrollSensitivity)) ? e = $(JSBNG__document).scrollLeft((($(JSBNG__document).scrollLeft() - d.scrollSpeed))) : (((((($(window).width() - ((a.pageX - $(JSBNG__document).scrollLeft())))) < d.scrollSensitivity)) && (e = $(JSBNG__document).scrollLeft((($(JSBNG__document).scrollLeft() + d.scrollSpeed))))))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((((((((e !== !1)) && $.ui.ddmanager)) && !d.dropBehaviour)) && $.ui.ddmanager.prepareOffsets(c, a)));\n            }\n        }), $.ui.plugin.add(\"draggable\", \"snap\", {\n            start: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = c.options;\n                c.snapElements = [], $(((((d.snap.constructor != String)) ? ((d.snap.items || \":data(draggable)\")) : d.snap))).each(function() {\n                    var a = $(this), b = a.offset();\n                    ((((this != c.element[0])) && c.snapElements.push({\n                        item: this,\n                        width: a.JSBNG__outerWidth(),\n                        height: a.JSBNG__outerHeight(),\n                        JSBNG__top: b.JSBNG__top,\n                        left: b.left\n                    })));\n                });\n            },\n            drag: function(a, b) {\n                var c = $(this).data(\"draggable\"), d = c.options, e = d.snapTolerance, f = b.offset.left, g = ((f + c.helperProportions.width)), i = b.offset.JSBNG__top, j = ((i + c.helperProportions.height));\n                for (var k = ((c.snapElements.length - 1)); ((k >= 0)); k--) {\n                    var l = c.snapElements[k].left, m = ((l + c.snapElements[k].width)), n = c.snapElements[k].JSBNG__top, o = ((n + c.snapElements[k].height));\n                    if (!((((((((((((((((l - e)) < f)) && ((f < ((m + e)))))) && ((((n - e)) < i)))) && ((i < ((o + e)))))) || ((((((((((l - e)) < f)) && ((f < ((m + e)))))) && ((((n - e)) < j)))) && ((j < ((o + e)))))))) || ((((((((((l - e)) < g)) && ((g < ((m + e)))))) && ((((n - e)) < i)))) && ((i < ((o + e)))))))) || ((((((((((l - e)) < g)) && ((g < ((m + e)))))) && ((((n - e)) < j)))) && ((j < ((o + e))))))))) {\n                        ((((c.snapElements[k].snapping && c.options.snap.release)) && c.options.snap.release.call(c.element, a, $.extend(c._uiHash(), {\n                            snapItem: c.snapElements[k].item\n                        })))), c.snapElements[k].snapping = !1;\n                        continue;\n                    }\n                ;\n                ;\n                    if (((d.snapMode != \"JSBNG__inner\"))) {\n                        var p = ((Math.abs(((n - j))) <= e)), q = ((Math.abs(((o - i))) <= e)), r = ((Math.abs(((l - g))) <= e)), s = ((Math.abs(((m - f))) <= e));\n                        ((p && (b.position.JSBNG__top = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: ((n - c.helperProportions.height)),\n                            left: 0\n                        }).JSBNG__top - c.margins.JSBNG__top))))), ((q && (b.position.JSBNG__top = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: o,\n                            left: 0\n                        }).JSBNG__top - c.margins.JSBNG__top))))), ((r && (b.position.left = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: 0,\n                            left: ((l - c.helperProportions.width))\n                        }).left - c.margins.left))))), ((s && (b.position.left = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: 0,\n                            left: m\n                        }).left - c.margins.left)))));\n                    }\n                ;\n                ;\n                    var t = ((((((p || q)) || r)) || s));\n                    if (((d.snapMode != \"JSBNG__outer\"))) {\n                        var p = ((Math.abs(((n - i))) <= e)), q = ((Math.abs(((o - j))) <= e)), r = ((Math.abs(((l - f))) <= e)), s = ((Math.abs(((m - g))) <= e));\n                        ((p && (b.position.JSBNG__top = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: n,\n                            left: 0\n                        }).JSBNG__top - c.margins.JSBNG__top))))), ((q && (b.position.JSBNG__top = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: ((o - c.helperProportions.height)),\n                            left: 0\n                        }).JSBNG__top - c.margins.JSBNG__top))))), ((r && (b.position.left = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: 0,\n                            left: l\n                        }).left - c.margins.left))))), ((s && (b.position.left = ((c._convertPositionTo(\"relative\", {\n                            JSBNG__top: 0,\n                            left: ((m - c.helperProportions.width))\n                        }).left - c.margins.left)))));\n                    }\n                ;\n                ;\n                    ((((((!c.snapElements[k].snapping && ((((((((p || q)) || r)) || s)) || t)))) && c.options.snap.snap)) && c.options.snap.snap.call(c.element, a, $.extend(c._uiHash(), {\n                        snapItem: c.snapElements[k].item\n                    })))), c.snapElements[k].snapping = ((((((((p || q)) || r)) || s)) || t));\n                };\n            ;\n            }\n        }), $.ui.plugin.add(\"draggable\", \"stack\", {\n            start: function(a, b) {\n                var c = $(this).data(\"draggable\").options, d = $.makeArray($(c.stack)).sort(function(a, b) {\n                    return ((((parseInt($(a).css(\"zIndex\"), 10) || 0)) - ((parseInt($(b).css(\"zIndex\"), 10) || 0))));\n                });\n                if (!d.length) {\n                    return;\n                }\n            ;\n            ;\n                var e = ((parseInt(d[0].style.zIndex) || 0));\n                $(d).each(function(a) {\n                    this.style.zIndex = ((e + a));\n                }), this[0].style.zIndex = ((e + d.length));\n            }\n        }), $.ui.plugin.add(\"draggable\", \"zIndex\", {\n            start: function(a, b) {\n                var c = $(b.helper), d = $(this).data(\"draggable\").options;\n                ((c.css(\"zIndex\") && (d._zIndex = c.css(\"zIndex\")))), c.css(\"zIndex\", d.zIndex);\n            },\n            JSBNG__stop: function(a, b) {\n                var c = $(this).data(\"draggable\").options;\n                ((c._zIndex && $(b.helper).css(\"zIndex\", c._zIndex)));\n            }\n        });\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.ui.progressbar.js\", function(a) {\n    (function($, a) {\n        $.widget(\"ui.progressbar\", {\n            options: {\n                value: 0,\n                max: 100\n            },\n            min: 0,\n            _create: function() {\n                this.element.addClass(\"ui-progressbar ui-widget ui-widget-content ui-corner-all\").attr({\n                    role: \"progressbar\",\n                    \"aria-valuemin\": this.min,\n                    \"aria-valuemax\": this.options.max,\n                    \"aria-valuenow\": this._value()\n                }), this.valueDiv = $(\"\\u003Cdiv class='ui-progressbar-value ui-widget-header ui-corner-left'\\u003E\\u003C/div\\u003E\").appendTo(this.element), this.oldValue = this._value(), this._refreshValue();\n            },\n            destroy: function() {\n                this.element.removeClass(\"ui-progressbar ui-widget ui-widget-content ui-corner-all\").removeAttr(\"role\").removeAttr(\"aria-valuemin\").removeAttr(\"aria-valuemax\").removeAttr(\"aria-valuenow\"), this.valueDiv.remove(), $.Widget.prototype.destroy.apply(this, arguments);\n            },\n            value: function(b) {\n                return ((((b === a)) ? this._value() : (this._setOption(\"value\", b), this)));\n            },\n            _setOption: function(a, b) {\n                ((((a === \"value\")) && (this.options.value = b, this._refreshValue(), ((((this._value() === this.options.max)) && this._trigger(\"complete\")))))), $.Widget.prototype._setOption.apply(this, arguments);\n            },\n            _value: function() {\n                var a = this.options.value;\n                return ((((typeof a != \"number\")) && (a = 0))), Math.min(this.options.max, Math.max(this.min, a));\n            },\n            _percentage: function() {\n                return ((((100 * this._value())) / this.options.max));\n            },\n            _refreshValue: function() {\n                var a = this.value(), b = this._percentage();\n                ((((this.oldValue !== a)) && (this.oldValue = a, this._trigger(\"change\")))), this.valueDiv.toggle(((a > this.min))).toggleClass(\"ui-corner-right\", ((a === this.options.max))).width(((b.toFixed(0) + \"%\"))), this.element.attr(\"aria-valuenow\", a);\n            }\n        }), $.extend($.ui.progressbar, {\n            version: \"1.8.16\"\n        });\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.swfobject.js\", function(a) {\n    (function(a, h, b) {\n        function c(a, b) {\n            var d = ((((a[0] || 0)) - ((b[0] || 0))));\n            return ((((d > 0)) || ((((!d && ((a.length > 0)))) && c(a.slice(1), b.slice(1))))));\n        };\n    ;\n        function d(a) {\n            if (((typeof a != g))) {\n                return a;\n            }\n        ;\n        ;\n            var b = [], c = \"\";\n            for (var e in a) {\n                c = ((((typeof a[e] == g)) ? d(a[e]) : [e,((i ? encodeURI(a[e]) : a[e])),].join(\"=\"))), b.push(c);\n            ;\n            };\n        ;\n            return b.join(\"&\");\n        };\n    ;\n        function e(a) {\n            var b = [];\n            for (var c in a) {\n                ((a[c] && b.push([c,\"=\\\"\",a[c],\"\\\"\",].join(\"\"))));\n            ;\n            };\n        ;\n            return b.join(\" \");\n        };\n    ;\n        function f(a) {\n            var b = [];\n            for (var c in a) {\n                b.push([\"\\u003Cparam name=\\\"\",c,\"\\\" value=\\\"\",d(a[c]),\"\\\" /\\u003E\",].join(\"\"));\n            ;\n            };\n        ;\n            return b.join(\"\");\n        };\n    ;\n        var g = \"object\", i = !0;\n        try {\n            var j = ((b.description || function() {\n                return (new b(\"ShockwaveFlash.ShockwaveFlash\")).GetVariable(\"$version\");\n            }()));\n        } catch (k) {\n            j = \"Unavailable\";\n        };\n    ;\n        var l = ((j.match(/\\d+/g) || [0,]));\n        a[h] = {\n            available: ((l[0] > 0)),\n            activeX: ((b && !b.JSBNG__name)),\n            version: {\n                original: j,\n                array: l,\n                string: l.join(\".\"),\n                major: ((parseInt(l[0], 10) || 0)),\n                minor: ((parseInt(l[1], 10) || 0)),\n                release: ((parseInt(l[2], 10) || 0))\n            },\n            hasVersion: function(a) {\n                return a = ((/string|number/.test(typeof a) ? a.toString().split(\".\") : ((/object/.test(typeof a) ? [a.major,a.minor,] : ((a || [0,0,])))))), c(l, a);\n            },\n            encodeParams: !0,\n            expressInstall: \"expressInstall.swf\",\n            expressInstallIsActive: !1,\n            create: function(a) {\n                if (((((!a.swf || this.expressInstallIsActive)) || ((!this.available && !a.hasVersionFail))))) {\n                    return !1;\n                }\n            ;\n            ;\n                if (!this.hasVersion(((a.hasVersion || 1)))) {\n                    this.expressInstallIsActive = !0;\n                    if (((((typeof a.hasVersionFail == \"function\")) && !a.hasVersionFail.apply(a)))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    a = {\n                        swf: ((a.expressInstall || this.expressInstall)),\n                        height: 137,\n                        width: 214,\n                        flashvars: {\n                            MMredirectURL: JSBNG__location.href,\n                            MMplayerType: ((this.activeX ? \"ActiveX\" : \"PlugIn\")),\n                            MMdoctitle: ((JSBNG__document.title.slice(0, 47) + \" - Flash Player Installation\"))\n                        }\n                    };\n                }\n            ;\n            ;\n                attrs = {\n                    data: a.swf,\n                    type: \"application/x-shockwave-flash\",\n                    id: ((a.id || ((\"flash_\" + Math.floor(((Math.JSBNG__random() * 999999999))))))),\n                    width: ((a.width || 320)),\n                    height: ((a.height || 180)),\n                    style: ((a.style || \"\"))\n                }, i = ((((typeof a.useEncode != \"undefined\")) ? a.useEncode : this.encodeParams)), a.movie = a.swf, a.wmode = ((a.wmode || \"opaque\")), delete a.fallback, delete a.hasVersion, delete a.hasVersionFail, delete a.height, delete a.id, delete a.swf, delete a.useEncode, delete a.width;\n                var b = JSBNG__document.createElement(\"div\");\n                return b.innerHTML = [\"\\u003Cobject \",e(attrs),\"\\u003E\",f(a),\"\\u003C/object\\u003E\",].join(\"\"), b.firstChild;\n            }\n        }, a.fn[h] = function(b) {\n            var c = this.JSBNG__find(g).andSelf().filter(g);\n            return ((/string|object/.test(typeof b) && this.each(function() {\n                var c = a(this), d;\n                b = ((((typeof b == g)) ? b : {\n                    swf: b\n                })), b.fallback = this;\n                if (d = a[h].create(b)) {\n                    c.children().remove(), c.html(d);\n                }\n            ;\n            ;\n            }))), ((((typeof b == \"function\")) && c.each(function() {\n                var c = this;\n                c.jsInteractionTimeoutMs = ((c.jsInteractionTimeoutMs || 0)), ((((c.jsInteractionTimeoutMs < 660)) && ((((c.clientWidth || c.clientHeight)) ? b.call(c) : JSBNG__setTimeout(function() {\n                    a(c)[h](b);\n                }, ((c.jsInteractionTimeoutMs + 66)))))));\n            }))), c;\n        };\n    })(jQuery, \"flash\", ((JSBNG__navigator.plugins[\"Shockwave Flash\"] || window.ActiveXObject))), a();\n});\nprovide(\"$lib/jquery.hotkeys.js\", function(a) {\n    (function(a) {\n        function b(b) {\n            if (((((typeof b.data != \"string\")) && !a.isArray(b.data)))) {\n                return;\n            }\n        ;\n        ;\n            var c = b.handler, d = a.isArray(b.data), e = 0, f = b.data.length;\n            b.handler = function(g) {\n                var i = b.data, j;\n                ((d && (i = i[e]))), j = i.toLowerCase().split(\" \");\n                if (!((((this === g.target)) || ((!/textarea|select/i.test(g.target.nodeName) && ((g.target.type !== \"text\"))))))) {\n                    return;\n                }\n            ;\n            ;\n                var k = ((((g.type !== \"keypress\")) && a.hotkeys.specialKeys[g.which])), l = String.fromCharCode(g.which).toLowerCase(), m, n = \"\", o = {\n                };\n                ((((g.altKey && ((k !== \"alt\")))) && (n += \"alt+\"))), ((((g.ctrlKey && ((k !== \"ctrl\")))) && (n += \"ctrl+\"))), ((((((g.metaKey && !g.ctrlKey)) && ((k !== \"meta\")))) && (n += \"meta+\"))), ((((g.shiftKey && ((k !== \"shift\")))) && (n += \"shift+\"))), ((k ? o[((n + k))] = !0 : (o[((n + l))] = !0, o[((n + a.hotkeys.shiftNums[l]))] = !0, ((((n === \"shift+\")) && (o[a.hotkeys.shiftNums[l]] = !0))))));\n                for (var p = 0, q = j.length; ((p < q)); p++) {\n                    if (o[j[p]]) {\n                        return ((((!d || ((e === ((f - 1)))))) ? (e = 0, c.apply(this, arguments)) : (e += 1, !0)));\n                    }\n                ;\n                ;\n                };\n            ;\n                if (((d && ((e !== 0))))) {\n                    j = b.data[0].toLowerCase().split(\" \");\n                    for (var p = 0, q = j.length; ((p < q)); p++) {\n                        if (o[j[p]]) {\n                            return e = 1, !0;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    e = 0;\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        a.hotkeys = {\n            version: \"0.8\",\n            specialKeys: {\n                8: \"backspace\",\n                9: \"tab\",\n                13: \"return\",\n                16: \"shift\",\n                17: \"ctrl\",\n                18: \"alt\",\n                19: \"pause\",\n                20: \"capslock\",\n                27: \"esc\",\n                32: \"space\",\n                33: \"pageup\",\n                34: \"pagedown\",\n                35: \"end\",\n                36: \"JSBNG__home\",\n                37: \"left\",\n                38: \"up\",\n                39: \"right\",\n                40: \"down\",\n                45: \"insert\",\n                46: \"del\",\n                96: \"0\",\n                97: \"1\",\n                98: \"2\",\n                99: \"3\",\n                100: \"4\",\n                101: \"5\",\n                102: \"6\",\n                103: \"7\",\n                104: \"8\",\n                105: \"9\",\n                106: \"*\",\n                107: \"+\",\n                109: \"-\",\n                110: \".\",\n                111: \"/\",\n                112: \"f1\",\n                113: \"f2\",\n                114: \"f3\",\n                115: \"f4\",\n                116: \"f5\",\n                117: \"f6\",\n                118: \"f7\",\n                119: \"f8\",\n                120: \"f9\",\n                121: \"f10\",\n                122: \"f11\",\n                123: \"f12\",\n                144: \"numlock\",\n                145: \"JSBNG__scroll\",\n                191: \"/\",\n                224: \"meta\"\n            },\n            shiftNums: {\n                \"`\": \"~\",\n                1: \"!\",\n                2: \"@\",\n                3: \"#\",\n                4: \"$\",\n                5: \"%\",\n                6: \"^\",\n                7: \"&\",\n                8: \"*\",\n                9: \"(\",\n                0: \")\",\n                \"-\": \"_\",\n                \"=\": \"+\",\n                \";\": \": \",\n                \"'\": \"\\\"\",\n                \",\": \"\\u003C\",\n                \".\": \"\\u003E\",\n                \"/\": \"?\",\n                \"\\\\\": \"|\"\n            }\n        }, a.each([\"keydown\",\"keyup\",\"keypress\",], function() {\n            a.JSBNG__event.special[this] = {\n                add: b\n            };\n        });\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.autoellipsis.js\", function(a) {\n    (function($) {\n        function a(a, e) {\n            var f = a.data();\n            ((f || (f = {\n            })));\n            var g = f.wrapperElement;\n            ((g || (g = a.wrapInner(\"\\u003Cdiv/\\u003E\").JSBNG__find(\"\\u003Ediv\"))));\n            var i = g.data(), j = i.originalContent;\n            ((j ? g = i.originalContent.clone(!0).data({\n                originalContent: j\n            }).replaceAll(g) : g.data({\n                originalContent: g.clone(!0)\n            }))), a.data({\n                wrapperElement: g,\n                containerWidth: a.JSBNG__innerWidth(),\n                containerHeight: a.JSBNG__innerHeight()\n            });\n            var k = !1, l = g;\n            ((e.selector && (l = $(g.JSBNG__find(e.selector).get().reverse())))), l.each(function() {\n                var f = $(this), i = f.text(), j = !1;\n                if (((((g.JSBNG__innerHeight() - f.JSBNG__innerHeight())) > a.JSBNG__innerHeight()))) f.remove();\n                 else {\n                    d(f);\n                    if (f.contents().length) {\n                        ((k && (c(f).get(0).nodeValue += e.ellipsis, k = !1)));\n                        while (((g.JSBNG__innerHeight() > a.JSBNG__innerHeight()))) {\n                            j = b(f);\n                            if (!j) {\n                                k = !0, f.remove();\n                                break;\n                            }\n                        ;\n                        ;\n                            d(f);\n                            if (!f.contents().length) {\n                                k = !0, f.remove();\n                                break;\n                            }\n                        ;\n                        ;\n                            c(f).get(0).nodeValue += e.ellipsis;\n                        };\n                    ;\n                        ((((((((e.setTitle == \"JSBNG__onEllipsis\")) && j)) || ((e.setTitle == \"always\")))) ? f.attr(\"title\", i) : ((((e.setTitle != \"never\")) && f.removeAttr(\"title\")))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        };\n    ;\n        function b(a) {\n            var b = c(a);\n            if (b.length) {\n                var d = b.get(0).nodeValue, e = d.lastIndexOf(\" \");\n                return ((((e > -1)) ? (d = $.trim(d.substring(0, e)), b.get(0).nodeValue = d) : b.get(0).nodeValue = \"\")), !0;\n            }\n        ;\n        ;\n            return !1;\n        };\n    ;\n        function c(a) {\n            if (a.contents().length) {\n                var b = a.contents().last();\n                return ((b.filter(e).length ? b : c(b)));\n            }\n        ;\n        ;\n            return a.append(\"\"), a.contents().last();\n        };\n    ;\n        function d(a) {\n            if (a.contents().length) {\n                var b = a.contents().last();\n                if (b.filter(e).length) {\n                    var c = b.get(0).nodeValue;\n                    return c = $.trim(c), ((((c == \"\")) ? (b.remove(), !0) : !1));\n                }\n            ;\n            ;\n                while (d(b)) {\n                ;\n                };\n            ;\n                return ((b.contents().length ? !1 : (b.remove(), !0)));\n            }\n        ;\n        ;\n            return !1;\n        };\n    ;\n        function e() {\n            return ((this.nodeType === 3));\n        };\n    ;\n        function f(a, b) {\n            j[a] = b, ((k || (k = window.JSBNG__setInterval(function() {\n                i();\n            }, 200))));\n        };\n    ;\n        function g(a) {\n            ((j[a] && (delete j[a], ((j.length || ((k && (window.JSBNG__clearInterval(k), k = undefined))))))));\n        };\n    ;\n        function i() {\n            if (!l) {\n                l = !0;\n                for (var b in j) {\n                    $(b).each(function() {\n                        var c, d;\n                        c = $(this), d = c.data(), ((((((d.containerWidth != c.JSBNG__innerWidth())) || ((d.containerHeight != c.JSBNG__innerHeight())))) && a(c, j[b])));\n                    });\n                ;\n                };\n            ;\n                l = !1;\n            }\n        ;\n        ;\n        };\n    ;\n        var j = {\n        }, k, l = !1, m = {\n            ellipsis: \"...\",\n            setTitle: \"never\",\n            live: !1\n        };\n        $.fn.ellipsis = function(b, c) {\n            var d, e;\n            return d = $(this), ((((typeof b != \"string\")) && (c = b, b = undefined))), e = $.extend({\n            }, m, c), e.selector = b, d.each(function() {\n                var b = $(this);\n                a(b, e);\n            }), ((e.live ? f(d.selector, e) : g(d.selector))), this;\n        };\n    })(jQuery), a();\n});\nprovide(\"mixins/tweetFlagging\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.tweetFlagging\", function(a) {\n            a.methods({\n                flagLinkClicked: function(a, b) {\n                    var c = $(a.target), d = this, e = ((twttr.decider.isAvailable(\"flag_yourself_nsfw\") && twttr.helpers.isCurrentUser(b.user))), f = b.possiblySensitive, g = {\n                        isOurTweet: e,\n                        before: function() {\n                            if (e) {\n                                var a = c.attr(\"alternateText\");\n                                c.attr(\"alternateText\", c.html()), c.html(a);\n                            }\n                             else {\n                                var b = ((((((((\"&nbsp;\\u003Ca target=\\\"_blank\\\" href=\\\"\" + twttr.router.flagTurkeySupportPath())) + \"\\\"\\u003E\")) + _(\"(learn more)\"))) + \"\\u003C/a\\u003E\"));\n                                c.replaceWith(((((((\"\\u003Cspan\\u003E\" + _(\"Flagged\"))) + b)) + \"\\u003C/span\\u003E\")));\n                            }\n                        ;\n                        ;\n                        }\n                    };\n                    ((((f && !e)) ? twttr.dialogs.sensitiveFlagConfirmation(function() {\n                        b.flag(g);\n                    }).open() : (((e && (b.sync(\"possiblySensitive\", !b.possiblySensitive), g.possibly_sensitive = b.possiblySensitive))), b.flag(g))));\n                },\n                tweetFlaggable: function(a) {\n                    return ((((twttr.loggedIn && twttr.decider.isAvailable(\"media_flagging\"))) && ((!a || ((a.possiblySensitiveEditable !== !1))))));\n                }\n            });\n        }), a(twttr.mixins.tweetFlagging);\n    });\n});\nprovide(\"promptbird\", function(a) {\n    using(\"util\", \"components/Promptbird\").as(function(b) {\n        twttr.promptbird = ((twttr.promptbird || {\n        })), twttr.promptbird.renderComponentFromPrompt = function(a) {\n            var c = b.util.camelize(((\"Prompt_\" + a.JSBNG__prompt.template_name)));\n            if (!twttr.components[c]) {\n                var d = new Error(((((\"Promptbird component \\\"\" + c)) + \"\\\" is undefined\")));\n                ((twttr.isLocalhost && JSBNG__console.log(d, ((d.stack || \"error.stack is unavailable :(\")))));\n                return;\n            }\n        ;\n        ;\n            var e = new twttr.components[c](a);\n            return e.bind(\"destroyed\", twttr.promptbird.destroyCallback), e;\n        }, twttr.promptbird.destroyCallback = function() {\n            delete twttr.promptbird.cache;\n        }, twttr.promptbird.getPrompt = function() {\n            var a = (new b.util.Location(JSBNG__location.href)).search;\n            if (((!twttr.decider.isAvailable(\"promptbird_phoenix\") && !/force_prompt_id/.test(a)))) {\n                return;\n            }\n        ;\n        ;\n            if (!twttr.promptbird.cache) {\n                return;\n            }\n        ;\n        ;\n            if (!twttr.promptbird.cache.JSBNG__prompt.template_name) {\n                return;\n            }\n        ;\n        ;\n            return twttr.promptbird.cache;\n        }, twttr.promptbird.getPromptByFormat = function(a) {\n            var b = twttr.promptbird.getPrompt();\n            if (!b) {\n                return;\n            }\n        ;\n        ;\n            for (var c = 0; ((c < a.length)); c++) {\n                if (((b.JSBNG__prompt.format === a[c]))) {\n                    return b;\n                }\n            ;\n            ;\n            };\n        ;\n        }, a(twttr.promptbird);\n    });\n});\nprovide(\"MessageManager\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.MessageThread\", function(a, b) {\n            this.threadId = a, this.messages = b;\n        }).methods({\n            hasNewMessages: function() {\n                return ((((twttr.app.caches.dmThreads.get(this.threadId) !== this.messages[0].id)) && !twttr.helpers.isCurrentUser(this.messages[0].sender)));\n            }\n        }), twttr.klass(\"twttr.MessageManager\", function() {\n            var a = this;\n            if (!twttr.loggedIn) {\n                return;\n            }\n        ;\n        ;\n            ((twttr.isT1 || this.setupContinuousPoll())), ((((twttr.isT1 && twttr.decider.isAvailable(\"t1_dm_poll\"))) && ($(JSBNG__document).JSBNG__on(\"active\", function() {\n                a.poll(twttr.MessageManager.activePollInterval);\n            }), $(JSBNG__document).JSBNG__on(\"inactive\", function() {\n                a.poll(twttr.MessageManager.inactivePollInterval);\n            }))));\n        }).statics({\n            activePollInterval: 90000,\n            inactivePollInterval: 300000\n        }).methods(twttr.EventProvider).methods({\n            setupContinuousPoll: function() {\n                var a = this;\n                ((this._pollingState ? ((((this._pollingState == \"running\")) && this._fetchMessages())) : (this._pollingState = \"starting\", this._fetchMessages(function() {\n                    a._sort(), a.bind(\"messagesArrived\", function(b, c) {\n                        if (twttr.isT1) {\n                            for (var d = ((c.length() - 1)); ((d >= 0)); d--) {\n                                a.addMessage(c.get(d));\n                            ;\n                            };\n                        }\n                         else {\n                            c.each(function(b) {\n                                a.addMessage(b);\n                            });\n                        }\n                    ;\n                    ;\n                    }), ((((!twttr.isT1 || twttr.decider.isAvailable(\"t1_dm_poll\"))) ? a.poll(twttr.MessageManager.activePollInterval) : a.stopContinuousPoll())), a._intializeThreadState(), a.trigger(\"firstMessagesReceived\"), a.trigger(\"pendingThreads\");\n                }))));\n            },\n            isContinuouslyPolling: function() {\n                return ((!!this._pollingState && ((this._pollingState !== \"starting\"))));\n            },\n            stopContinuousPoll: function() {\n                ((this.isContinuouslyPolling() && (JSBNG__clearInterval(this._pollId), delete this._pollId, this._pollingState = null)));\n            },\n            poll: function(a) {\n                var b = this;\n                b.stopContinuousPoll(), b.currentPollInterval = a, b._pollId = JSBNG__setInterval(function() {\n                    b._fetchMessages();\n                }, a), b._pollingState = \"running\";\n            },\n            reset: function() {\n                this.threads = [], this.sentMessages = null, this.receivedMessage = null, twttr.app.caches.dmThreads.clear();\n            },\n            getAllThreads: function(a) {\n                var b = this;\n                ((this.threads ? a(this.threads) : this.JSBNG__one(\"firstMessagesReceived\", function() {\n                    a(b.threads);\n                })));\n            },\n            getThread: function(a, b) {\n                var c = this;\n                if (this.threads) {\n                    for (var d = 0; ((d < this.threads.length)); d++) {\n                        if (((this.threads[d].threadId === a))) {\n                            return b(this.threads[d]);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    return b();\n                }\n            ;\n            ;\n                this.getAllThreads(function(d) {\n                    c.getThread(a, b);\n                });\n            },\n            addMessage: function(a, b) {\n                var c = this;\n                this.getThread(a.threadId, function(d) {\n                    if (d) {\n                        if (twttr.helpers.isCurrentUser(a.sender)) {\n                            for (var e = 0, f = d.messages, g = f.length; ((e < g)); e++) {\n                                var i = f[e].id;\n                                if (((i < a.id))) {\n                                    break;\n                                }\n                            ;\n                            ;\n                                if (((i === a.id))) {\n                                    return;\n                                }\n                            ;\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        d.messages.unshift(a);\n                        for (var e = 0, j = c.threads.length; ((e < j)); e++) {\n                            if (((c.threads[e].threadId === d.threadId))) {\n                                c.threads.splice(e, 1);\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                     else d = new twttr.MessageThread(a.threadId, [a,]);\n                ;\n                ;\n                    ((c.threads || (c.threads = []))), c.threads.unshift(d), ((b && c._markMessageAsRead(a))), c.trigger(\"updatedThread\", [d,\"new\",{\n                        message: a\n                    },]), c.trigger(((\"newMessage.\" + a.threadId)), [a,]), c.trigger(\"pendingThreads\");\n                });\n            },\n            deleteMessage: function(a, b) {\n                var c = this;\n                this.getThread(b, function(d) {\n                    if (d) {\n                        for (var e = 0, f = d.messages, g = f.length; ((e < g)); e++) {\n                            if (((f[e].id === a))) {\n                                var i = f.splice(e, 1)[0];\n                                i.destroy({\n                                    error: function() {\n                                        c.addMessage(i);\n                                    },\n                                    success: function(a) {\n                                        var b = {\n                                        };\n                                        b[((a.id + \"\"))] = {\n                                            item_type: twttr.constants.clientEvent.itemType.message,\n                                            target_id: a.id\n                                        }, trackClient({\n                                            component: \"stream\",\n                                            action: \"delete\"\n                                        }, {\n                                            item_ids: [a.id,],\n                                            item_details: b\n                                        });\n                                    }\n                                });\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        if (((d.messages.length === 0))) {\n                            for (var j = 0; ((j < c.threads.length)); j++) {\n                                if (((c.threads[j].threadId === b))) {\n                                    c.threads.splice(j, 1);\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            c.trigger(\"deletedThread\", [b,]);\n                        }\n                         else c.trigger(\"updatedThread\", [d,\"delete\",{\n                            messageId: a\n                        },]);\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    c.trigger(((\"deletedMessage.\" + b)), [a,]), c.trigger(\"pendingThreads\");\n                });\n            },\n            hasPendingThreads: function() {\n                var a = 0, b = this.threads;\n                if (b) {\n                    for (var c = 0, d = b.length; ((c < d)); c++) {\n                        ((b[c].hasNewMessages() && a++));\n                    ;\n                    };\n                }\n            ;\n            ;\n                return a;\n            },\n            markThreadAsRead: function(a) {\n                var b = this;\n                this.getThread(a, function(c) {\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    b._markMessageAsRead(c.messages[0]), b.trigger(\"readThread\", [a,]), b.trigger(\"pendingThreads\");\n                });\n            },\n            _markMessageAsRead: function(a) {\n                twttr.app.caches.dmThreads.set(a.threadId, a.id);\n            },\n            _intializeThreadState: function() {\n                if (!twttr.app.caches.dmThreads.get(\"##initialized\")) {\n                    twttr.app.caches.dmThreads.set(\"##initialized\", !0);\n                    var a = this.threads;\n                    for (var b = 0, c = a.length; ((b < c)); b++) {\n                        twttr.app.caches.dmThreads.set(a[b].threadId, a[b].messages[0].id);\n                    ;\n                    };\n                ;\n                    return !0;\n                }\n            ;\n            ;\n                return !1;\n            },\n            _fetchMessages: function(a) {\n                function b() {\n                    d++;\n                    if (((((d === 2)) || !e))) {\n                        c.isFetching = !1, ((a && a()));\n                    }\n                ;\n                ;\n                };\n            ;\n                var c = this, d = 0;\n                if (this.isFetching) {\n                    return;\n                }\n            ;\n            ;\n                this.isFetching = !0;\n                var e = ((!twttr.isT1 || ((this._pollingState === \"starting\")))), f, g = {\n                    count: 50,\n                    success: function(a) {\n                        ((((a.length() > 0)) && (((c.receivedMessages ? c.receivedMessages.concat(a) : c.receivedMessages = a)), c.trigger(\"messagesArrived\", [a,]), c._receivedSinceID = a.first().id))), f = a, b();\n                    },\n                    cancel: function() {\n                    \n                    },\n                    error: function(a, b) {\n                        ((((a.JSBNG__status === 502)) && b.retry()));\n                    }\n                };\n                ((c._receivedSinceID && (g.since_id = c._receivedSinceID))), ((twttr.currentUser && twttr.currentUser.receivedMessages(g)));\n                var i = {\n                    count: 50,\n                    success: function(a) {\n                        ((((a.length() > 0)) && (((c.sentMessages ? c.sentMessages.concat(a) : c.sentMessages = a)), c.trigger(\"messagesArrived\", [a,]), c._sentSinceID = a.first().id))), b();\n                    },\n                    cancel: function() {\n                    \n                    },\n                    error: function(a, b) {\n                        ((((a.JSBNG__status === 502)) && b.retry()));\n                    }\n                };\n                ((c._sentSinceID && (i.since_id = c._sentSinceID))), ((((twttr.currentUser && e)) && twttr.currentUser.sentMessages(i)));\n            },\n            _sort: function() {\n                this.allMessages = [], ((this.sentMessages && (this.allMessages = this.allMessages.concat(this.sentMessages.array)))), ((this.receivedMessages && (this.allMessages = this.allMessages.concat(this.receivedMessages.array)))), this.allMessages.sort(function(a, b) {\n                    return twttr.natcompare(b.id, a.id);\n                });\n                var a = {\n                }, b = [];\n                for (var c = 0; ((c < this.allMessages.length)); c++) {\n                    var d = this.allMessages[c], e = d.threadId;\n                    ((a[e] || (a[e] = [], b.push(e)))), a[e].push(d);\n                };\n            ;\n                this.threads = [];\n                for (var c = 0; ((c < b.length)); c++) {\n                    this.threads.push(new twttr.MessageThread(b[c], a[b[c]]));\n                ;\n                };\n            ;\n            }\n        }), a(twttr.MessageManager);\n    });\n});\nprovide(\"ConversationManager\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.ConversationThread\", function(a) {\n            this.threadId = a.user.screenName, this.user = a.user, this.count = a.count, this.lastMessageDate = a.lastMessageDate, this.lastMessageId = a.lastMessageId, this.messages = [];\n        }).methods(twttr.EventProvider).methods({\n            sort: function() {\n                this.messages.sort(function(a, b) {\n                    return ((b.id - a.id));\n                });\n            },\n            addMessage: function(a) {\n                if ((($.inArray(a, this.messages) > -1))) {\n                    return;\n                }\n            ;\n            ;\n                this.messages.push(a), this.sort(), ((((a.id > this.lastMessageId)) && (this.lastMessageDate = a.createdAt, this.lastMessageId = a.id, this.count++))), this.trigger(\"newMessage\", [a,]);\n            },\n            deleteMessage: function(a, b) {\n                var c = !1;\n                this.messages = $.grep(this.messages, function(b, d) {\n                    return ((((b.id === a)) && (b.destroy(), c = !0))), ((b.id !== a));\n                });\n                if (!c) {\n                    return;\n                }\n            ;\n            ;\n                if (((this.messages.length > 0))) {\n                    var d = this.messages[((this.messages.length - 1))];\n                    ((((d.id > this.lastMessageId)) && (this.lastMessageDate = d.createdAt, this.lastMessageId = d.id)));\n                }\n            ;\n            ;\n                this.count--, this.trigger(\"deletedMessage\", [a,]), b();\n            },\n            getMessages: function(a) {\n                var b = this, c = {\n                    user_id: this.user.id,\n                    since_id: ((this.since_id || 0)),\n                    count: 100,\n                    success: function(c) {\n                        c.each(function(a) {\n                            b.addMessage(a);\n                        }), a(b);\n                    }\n                };\n                twttr.currentUser.conversationWith(c);\n            }\n        }), twttr.klass(\"twttr.ConversationManager\", function() {\n            this.threads = {\n            }, this.since_id = 0;\n        }).methods(twttr.EventProvider).methods({\n            _fetchMessages: $.noop,\n            _sort: $.noop,\n            setupContinuousPoll: function() {\n                if (this._pollId) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                this._pollId = JSBNG__setInterval(function() {\n                    a.getAllThreads($.noop);\n                }, b.constants.directMessagePollInterval);\n            },\n            isContinuouslyPolling: function() {\n                return twttr.is.def(this._pollId);\n            },\n            stopContinuousPoll: function() {\n                ((this.isContinuouslyPolling() && (JSBNG__clearInterval(this._pollId), delete this._pollId)));\n            },\n            getThread: function(a, b) {\n                var c = this.threads[a];\n                return ((c ? c.getMessages(b) : b()));\n            },\n            getAllThreads: function(a) {\n                function b(b) {\n                    var d;\n                    for (var e = ((b.array.length - 1)); ((e >= 0)); e--) {\n                        var f = b.array[e];\n                        ((c.threads[f.user.screenName] ? (d = c.threads[f.user.screenName], d.getMessages($.noop)) : (d = new twttr.ConversationThread(f), c.threads[d.threadId] = d))), c.since_id = d.lastMessageId, c.trigger(\"updatedThread\", [d,\"new\",]);\n                    };\n                ;\n                    a();\n                };\n            ;\n                var c = this;\n                twttr.currentUser.conversations({\n                    success: b,\n                    since_id: this.since_id,\n                    count: 100\n                });\n            },\n            addMessage: function(a) {\n                var b = this.threads[a.threadId];\n                ((b ? (b.addMessage(a), this.trigger(\"updatedThread\", [b,\"new\",])) : (b = new twttr.ConversationThread({\n                    threadId: a.threadId,\n                    user: a.user,\n                    count: 1,\n                    lastMessageDate: a.createdAt,\n                    lastMessageId: a.id\n                }), this.threads[b.threadId] = b)));\n            },\n            deleteMessage: function(a, b) {\n                var c = this, d = this.threads[b];\n                ((d && d.deleteMessage(a, function() {\n                    c.trigger(\"updatedThread\", [d,\"\",]), ((((d.count === 0)) && (c.trigger(\"deletedThread\", [b,]), delete c.threads[b])));\n                })));\n            }\n        }), a(twttr.ConversationManager);\n    });\n});\nprovide(\"externalOauthPopup\", function(a) {\n    using().as(function(b) {\n        a(function(a) {\n            var b, c = a.url, d = ((((c.indexOf(\"?\") == -1)) ? \"?\" : \"&\"));\n            c += ((((d + \"callback_hash=\")) + encodeURIComponent(a.callbackUrl)));\n            var e = $(window), f = ((((window.JSBNG__screenY || window.JSBNG__screenTop)) || 0)), g = ((((window.JSBNG__screenX || window.JSBNG__screenLeft)) || 0)), i = ((((((e.height() - 500)) / 2)) + f)), j = ((((((e.width() - 500)) / 2)) + g)), a = [((\"width=\" + ((a.width ? a.width : 500)))),((\"height=\" + ((a.height ? a.height : 500)))),((\"top=\" + i)),((\"left=\" + j)),\"toolbar=no\",\"location=yes\",];\n            window.open(c, \"twitter_oauth\", a.join(\",\")).JSBNG__focus();\n        });\n    });\n});\nprovide(\"mixins/photoBox\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.photoBox\", function(a) {\n            a.methods({\n                _initPhotobox: function() {\n                    var a = this;\n                    if (((((!twttr.decider.isAvailable(\"turkey\") || ((this.options.statusAction === \"directMessage\")))) || ((this.options.template.show_turkey === !1))))) {\n                        return;\n                    }\n                ;\n                ;\n                    this.tweetBoxId = twttr.turkey.getTweetBoxId(), this.options.template.tweet_box_id = this.tweetBoxId, (new twttr.views.PhotoControl(this.options.template)).render(this.$find(\"div.tweet-button-container\"), \"prepend\");\n                    var b = this._getTextLength;\n                    this._getTextLength = function() {\n                        var a = b.apply(this, arguments);\n                        return ((((this.turkey && this.turkey.hasItems())) && (a += ((this.turkey.count() * ((twttr.constants.tcoLength + 1))))))), a;\n                    };\n                    var c = this.makeRequest;\n                    this.makeRequest = function(a, b, d) {\n                        ((((this.turkey && this.turkey.hasItems())) ? (this._sendingStatus = !0, this.turkey.tweet(b, d)) : c.apply(this, [a,b,d,])));\n                    };\n                    var d = this.resetTweetContent;\n                    this.resetTweetContent = function() {\n                        d.apply(this, arguments), ((this.turkey && this.turkey.reset()));\n                    };\n                    var e = function() {\n                        a.createFunc(), a._registerPhotoboxEvents();\n                        if (((a.options.origin && ((((a.options.origin == \"main_tweet_box\")) || ((a.options.origin == \"new-tweet-titlebar-button\"))))))) {\n                            var b = {\n                                context: ((((a.options.origin == \"main_tweet_box\")) ? \"timeline\" : \"popup\")),\n                                event_info: twttr.turkey.tweetboxMode()\n                            };\n                            trackClient({\n                                component: \"tweetbox\",\n                                action: \"impression\"\n                            }, b);\n                        }\n                    ;\n                    ;\n                    };\n                    this.bind(\"open\", e), ((((((!this.options.condensed || ((!this.options.condensedContent && this.options.defaultContent)))) || this._getDraftTweet())) && e()));\n                },\n                _registerPhotoboxEvents: function() {\n                    var a = this;\n                    this.turkey.bind(\"photoChanged\", function() {\n                        a.editor.trigger(\"didChangeContent\", [a.editor.JSBNG__content(),]);\n                    });\n                    var b = function() {\n                        ((a.turkey && a.turkey.destroy()));\n                    };\n                    this.bind(\"close\", b), this.bind(\"destroy\", b), this.bind(\"titleChanged\", function(b, c, d) {\n                        if (((d == \"dm\"))) {\n                            ((a.turkey && a.turkey.disable())), a.$find(\".turkey-control\").hide();\n                        }\n                         else {\n                            if (((((((d == \"reply\")) || ((d == \"mention\")))) || ((d == \"update\"))))) {\n                                ((a.turkey && a.turkey.enable())), a.$find(\".turkey-control\").show();\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    });\n                },\n                createFunc: function() {\n                    ((this.turkey && this.turkey.remove())), this.turkey = new twttr.turkey.PhotoThumbnails(this.editor, this.$find(\".turkey-selected-files\"), this.$find(\".turkey-add-action\"), this.tweetBoxId);\n                }\n            });\n        }), a();\n    });\n});\nprovide(\"mixins/profileStreamMixin\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.profileStreamMixin\", function() {\n            this.methods({\n                beforeShowNewItems: function() {\n                    this.keepPromotedTweetsAtTop = !0, this.constructor.uber.beforeShowNewItems.apply(this, arguments), this.promotedTweetWasExpanded = this.promotedTweetIsExpanded(), this.collapsePromotedTweet(), this.movePromotedTweetToTop();\n                },\n                JSBNG__onShowNewItems: function(a) {\n                    this.constructor.uber.JSBNG__onShowNewItems.apply(this, arguments), this.trigger(\"JSBNG__onShowNewItems\"), ((this.promotedTweetWasExpanded && this.expandPromotedTweet())), this.logPromotedImpressions(this.items.slice(0, this.newItemsCount));\n                },\n                JSBNG__onShowOldItems: function(a) {\n                    this.constructor.uber.JSBNG__onShowOldItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(((this.items.length - this.oldItemsCount))));\n                },\n                afterFirstSwitchingTo: function() {\n                    this.constructor.uber.afterFirstSwitchingTo.apply(this, arguments), $(JSBNG__document).trigger(\"profileVisit\", twttr.profileUser);\n                },\n                _getPromotedStreamTweet: function() {\n                    return this.$find(\"div.stream-items .promoted-tweet\");\n                },\n                _collapseExpandPromotedTweet: function(a) {\n                    var b = this._getPromotedStreamTweet();\n                    ((((b.length && ((twttr.app.currentPageName() === \"profile\")))) && twttr.app.currentPage().send(\"showHide\", [b,{\n                        autoExpanded: !0,\n                        forceClose: !a,\n                        noAnimation: !0,\n                        containerClass: \".expanding-stream-item\"\n                    },])));\n                },\n                collapsePromotedTweet: function() {\n                    this._collapseExpandPromotedTweet(!1);\n                },\n                expandPromotedTweet: function() {\n                    this._collapseExpandPromotedTweet(!0);\n                },\n                domNodeSelector: function() {\n                    return ((this.streamManagerDomNodeSelector ? ((this.streamManagerDomNodeSelector + \" .profile-stream\")) : null));\n                },\n                _getStreamErrorComponent: function(a) {\n                    return this._getUserStreamErrorComponent(a);\n                },\n                _getEmptyStreamHtml: function() {\n                    return ((this.stream_user_is_current_user() ? _(\"You haven't tweeted yet.\") : _(\"@{{screen_name}} hasn't tweeted yet.\", {\n                        screen_name: this.screenName\n                    })));\n                },\n                _updateSinceId: function(a) {\n                    var b = ((((a.length == 1)) && a[0].isPromoted())), c = ((((((a.length > 1)) && a[0].isPromoted())) && ((twttr.natcompare(a[0].id, a[1].id) > 0))));\n                    ((((b || c)) ? this._sinceId = a[0].id : this.constructor.uber._updateSinceId.apply(this, arguments)));\n                },\n                wokeUp: function() {\n                    signal(\"\\u003EstreamWokeUp\");\n                }\n            }), ((twttr.isT1 && this.methods({\n                _setTitle: function(a) {\n                    a(_(\"Tweets\"));\n                },\n                _setViewToggler: function(a) {\n                    ((twttr.streams.Profile.shouldDisplay() && a(new twttr.views.ProfileStreamViewToggler(!0, this.params))));\n                }\n            })));\n        });\n        a(c);\n    });\n});\nprovide(\"streams/Mentions\", function(a) {\n    using().as(function(b) {\n        twttr.tweetStream(\"twttr.streams.Mentions\").statics({\n            isLoadingRelationships: !1\n        }).setTitle(function(a) {\n            ((twttr.isT1 ? a(_(\"Mentions\")) : a(_(\"Tweets mentioning {{username}}\", {\n                username: ((\"@\" + twttr.currentUser.screenName))\n            }))));\n        }).update(function(a, b, c) {\n            var d = this;\n            if (((twttr.secrets && twttr.secrets.hideMentions))) {\n                var e = a.success;\n                a.success = function(b) {\n                    e.apply(a, arguments);\n                    if (d.constructor.isLoadingRelationships) {\n                        return;\n                    }\n                ;\n                ;\n                    d.constructor.isLoadingRelationships = !0, JSBNG__setTimeout(function() {\n                        var a = {\n                            user_a: twttr.currentUser.id,\n                            user_ids: b.map(function(a) {\n                                return a.user.id;\n                            }).join(\",\")\n                        };\n                        $.ajax({\n                            url: \"/account/batch_followed_by\",\n                            data: a,\n                            dataType: \"jsonp\",\n                            type: \"get\",\n                            success: function(a) {\n                                var b = [];\n                                for (var c in a.relationships) {\n                                    ((a.relationships[c] || b.push(((((\".stream-tweet[data-user-id=\" + c)) + \"]\")))));\n                                ;\n                                };\n                            ;\n                                ((((b.length > 0)) && $(b.join(\",\")).hide())), d.constructor.isLoadingRelationships = !1;\n                            }\n                        });\n                    }, 10);\n                };\n            }\n        ;\n        ;\n            twttr.currentUser.mentions(a);\n        }).methods({\n            _getEmptyStreamHtml: function() {\n                return _(\"Tweets that mention you, or are in reply to you, appear here.\");\n            }\n        }).deciderKey(\"tweet_stream_mentions\").pollingDeciderKey(\"tweet_stream_mentions_polling\"), a();\n    });\n});\nprovide(\"streams/Favorites\", function(a) {\n    using().as(function(b) {\n        twttr.tweetStream(\"twttr.streams.Favorites\", function() {\n            twttr.streams.TweetStream.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: function() {\n                    return ((twttr.profileUser && twttr.profileUser.id));\n                }\n            }), this._registerEvents();\n        }).setTitle(function(a) {\n            ((twttr.isT1 ? a(_(\"Favorites\")) : ((((!this.screenName || this.stream_user_is_current_user())) ? a(_(\"Your Favorites\")) : a(_(\"{{username}}'s Favorites\", {\n                username: this.screenName\n            }))))));\n        }).update(function(a, b, c) {\n            ((this.screenName ? twttr.API.User.JSBNG__find(this.screenName).favorites(a) : twttr.currentUser.favorites(a)));\n        }).methods({\n            _getEmptyStreamHtml: function() {\n                return ((((!this.screenName || this.stream_user_is_current_user())) ? _(\"Your favorite tweets get saved here. To favorite a tweet, hover over it and click: \\u003Cspan class='favorite-icon'\\u003E\\u003C/span\\u003E \\u003Cstrong\\u003EFavorite\\u003C/strong\\u003E\") : _(\"\\u003Cb\\u003E@{{screen_name}}\\u003C/b\\u003E hasn't favorited any Tweets yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function() {\n                if (twttr.loggedIn) {\n                    var a = function(a, b) {\n                        return ((twttr.helpers.isProfileUser() ? b : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.Status, \"favorite\", a), this._registerRemoveFromStreamEvent(twttr.API.Status, \"unfavorite\", a);\n                }\n            ;\n            ;\n            }\n        }).deciderKey(\"tweet_stream_favorites\").pollingDeciderKey(\"tweet_stream_favorites_polling\"), a();\n    });\n});\nprovide(\"streams/User\", function(a) {\n    using().as(function(b) {\n        var c = twttr.tweetStream(\"twttr.streams.User\", function(a) {\n            var b = this;\n            twttr.streams.TweetStream.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: function() {\n                    return ((twttr.profileUser && twttr.profileUser.id));\n                }\n            }), this.JSBNG__one(\"JSBNG__onShowNewItems\", function() {\n                b.expandPromotedTweet();\n            }), ((twttr.helpers.isCurrentUser(a.screenName) && twttr.API.Status.bind(\"unretweet\", function(a, c) {\n                b.$node.JSBNG__find(((((\"[data-item-id=\" + c.id)) + \"][data-item-type=tweet]\"))).remove();\n            })));\n        }).mixin(twttr.mixins.profileStreamMixin).statics({\n            _supportsPromotedContent: twttr.isT1\n        }).update(function(a, b, d) {\n            a.cacheOptions = {\n                shouldCacheAssociated: !1\n            }, a.pc = !!c._supportsPromotedContent, a.include_rts = !this.params.noRetweets, ((this.params.canViewUser ? twttr.API.User.JSBNG__find(this.params.screenName).timeline(a) : d(this, twttr.streams.PROTECTED)));\n        }).deciderKey(\"tweet_stream_user\").pollingDeciderKey(\"tweet_stream_user_polling\");\n        a(c);\n    });\n});\nprovide(\"streams/Profile\", function(a) {\n    using().as(function(b) {\n        var c = twttr.tweetStream(\"twttr.streams.Profile\", function(a) {\n            var b = this;\n            twttr.streams.TweetStream.apply(this, arguments), this.JSBNG__one(\"JSBNG__onShowNewItems\", function() {\n                b.expandPromotedTweet();\n            });\n        }).mixin(twttr.mixins.profileStreamMixin).statics({\n            _supportsPromotedContent: !0,\n            shouldDisplay: function() {\n                return ((((twttr.profileUser.verified && twttr.loggedIn)) && ((twttr.abdecider.choose(\"replies_stripped_on_verified_profiles_222\") == \"stripped_replies_on_verified\"))));\n            }\n        }).update(function(a, b, d) {\n            a.cacheOptions = {\n                shouldCacheAssociated: !1\n            }, a.pc = !!c._supportsPromotedContent, a.include_rts = !this.params.noRetweets, ((this.params.canViewUser ? twttr.API.User.JSBNG__find(this.params.screenName).profileTimeline(a) : d(this, twttr.streams.PROTECTED)));\n        }).methods({\n            _setViewToggler: function(a) {\n                a(new twttr.views.ProfileStreamViewToggler(!1, this.params));\n            }\n        }).statics({\n            _supportsPromotedContent: !0\n        }).deciderKey(\"tweet_stream_profile\").pollingDeciderKey(\"tweet_stream_profile_polling\");\n        a(c);\n    });\n});\nprovide(\"streams/FollowingTweets\", function(a) {\n    using().as(function(b) {\n        twttr.tweetStream(\"twttr.streams.FollowingTweets\", function() {\n            twttr.streams.TweetStream.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: function() {\n                    return ((twttr.profileUser && twttr.profileUser.id));\n                }\n            }), this.registerUserActionEvents();\n        }).mixin(twttr.mixins.userActionable).update(function(a, b, c) {\n            a.cacheOptions = {\n                shouldCacheAssociated: !1\n            }, ((this.params.canViewUser ? twttr.API.User.JSBNG__find(this.params.screenName).followingTweets(a) : c(this, twttr.streams.PROTECTED)));\n        }).methods({\n            itemViewClass: \"FollowingTweet\",\n            JSBNG__onUserActionFollowSync: function(a) {\n                this._findTweetsAndUpdateFollowState(a, !0);\n            },\n            JSBNG__onUserActionUnfollowSync: function(a) {\n                this._findTweetsAndUpdateFollowState(a, !1);\n            },\n            JSBNG__onShowNewItems: function(a) {\n                this._addFollowButtonsToNewTweets(a), this.constructor.uber.JSBNG__onShowNewItems.apply(this, arguments), this.trigger(\"showedNewItems\");\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this._addFollowButtonsToNewTweets(a), this.constructor.uber.JSBNG__onShowOldItems.apply(this, arguments), this.trigger(\"showedOldItems\");\n            },\n            selectedItemsByUserId: function(a) {\n                var b = ((((\".stream-item:has(.stream-item-content[data-user-id=\" + a)) + \"])\"));\n                return this.$streamItems().JSBNG__find(b);\n            },\n            _reRenderTweetsByUserId: function(a) {\n                var b = this;\n                this.selectedItemsByUserId(a).each(function(a, c) {\n                    var d = $(c), e = d.JSBNG__find(\".stream-tweet\").attr(\"data-tweet-id\");\n                    twttr.API.Status.JSBNG__find(e, function(a) {\n                        d.replaceWith(b._renderItemHtml(a));\n                    });\n                });\n            },\n            _getStreamErrorComponent: function(a) {\n                return this._getUserStreamErrorComponent(a);\n            },\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"The people you follow haven't tweeted anything recently.\") : _(\"The people that @{{screen_name}} follows haven't tweeted recently.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _setTitle: function() {\n                $(\"#following-page-context\").html(_(\"Here&rsquo;s what they&rsquo;re tweeting right now.\"));\n            },\n            _findUserIds: function(a) {\n                var b = [];\n                return a.JSBNG__find(\".stream-item-content\").each(function(a, c) {\n                    b.push(parseInt($(c).attr(\"data-user-id\"), 10));\n                }), b.slice(0, twttr.constants.users.maxLookupSize);\n            },\n            _addFollowButtonsToNewTweets: function(a) {\n                if (((!twttr.loggedIn || ((a.length === 0))))) {\n                    return !1;\n                }\n            ;\n            ;\n                var b = this, c = this._findUserIds(a);\n                twttr.API.User.findAll(c, {\n                    reload: !0,\n                    success: function(a) {\n                        a.each(function(a) {\n                            ((((!a.following || ((twttr.loggedIn && ((a.id !== twttr.currentUser.id)))))) && b._findTweetsAndUpdateFollowState(a.id, ((a.following ? null : !1)))));\n                        });\n                    }\n                });\n            },\n            _findTweetsAndUpdateFollowState: function(a, b) {\n                var c;\n                ((twttr.is.nil(b) ? c = \"\" : ((b ? c = Mustache.to_html(\"\\u003Cspan class=\\\"follow-text-quiet\\\"\\u003E&middot; {{action}}\\u003C/span\\u003E\", {\n                    action: _(\"Following\")\n                }) : c = Mustache.to_html(\"\\u003Cspan class=\\\"follow-text-quiet\\\"\\u003E&middot;\\u003C/span\\u003E \\u003Ca href=\\\"#\\\" class=\\\"js-action-follow tweet-follow-action follow-action\\\" data-user-id=\\\"{{id}}\\\"\\u003E{{action}}\\u003C/a\\u003E\", {\n                    id: a,\n                    action: _(\"Follow\")\n                })))));\n                var d = this.selectedItemsByUserId(a);\n                d.each(function(a, b) {\n                    $(b).JSBNG__find(\".tweet-user-follow\").html(c);\n                });\n            }\n        }).deciderKey(\"tweet_stream_following\").pollingDeciderKey(\"tweet_stream_following_polling\"), a();\n    });\n});\nprovide(\"streams/List\", function(a) {\n    using(\"components/AddPeople\", \"components/NoListMembers\", \"streams/TweetStream\", function(b, c, d) {\n        twttr.tweetStream(\"twttr.streams.List\", function() {\n            d.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: function() {\n                    return ((twttr.profileUser && twttr.profileUser.id));\n                },\n                message: this.params.listSlug\n            });\n        }).setTitle(function(a) {\n            ((twttr.isT1 ? a((new twttr.views.ListStreamTitle({\n                full_name: _(\"Tweets\")\n            })).html()) : (twttr.merge(this.params, {\n                full_name: _(\"@{{screenName}}/{{listSlug}}\", this.params),\n                slug: this.params.listSlug,\n                user: {\n                    screen_name: this.params.screenName\n                }\n            }), a((new twttr.views.ListStreamTitle(this.params)).html()))));\n        }).update(function(a, b, c) {\n            this._getList(function(b) {\n                b.statuses(a);\n            });\n        }).methods({\n            _getEmptyStreamComponent: function() {\n                return ((twttr.helpers.isCurrentUser(this.screenName) ? new b : new c));\n            },\n            _getList: function(a) {\n                var b = this;\n                this._fetchingCallbacks = ((this._fetchingCallbacks || [])), this._fetchingCallbacks.push(a);\n                if (this._fetching) {\n                    return;\n                }\n            ;\n            ;\n                this._fetching = !0, twttr.API.User.JSBNG__find(this.screenName, {\n                    success: function(a) {\n                        a.lists.JSBNG__find(b.params.listSlug, function(a) {\n                            if (!a) {\n                                b.trigger(\"notFound\");\n                                return;\n                            }\n                        ;\n                        ;\n                            b.memberCount = a.memberCount;\n                            var c;\n                            while (c = b._fetchingCallbacks.pop()) {\n                                c(a);\n                            ;\n                            };\n                        ;\n                            b._list = a, b._fetching = !1;\n                        });\n                    },\n                    error: function() {\n                        b.trigger(\"notFound\");\n                    }\n                });\n            }\n        }).deciderKey(\"tweet_stream_list\").pollingDeciderKey(\"tweet_stream_list_polling\"), a(twttr.streams.List);\n    });\n});\nprovide(\"streams/Search\", function(a) {\n    using().as(function(b, c) {\n        var d = twttr.tweetStream(\"twttr.streams.Search\", function(a) {\n            return ((twttr.is.def(a.pretty_query) || (a.pretty_query = a.query))), twttr.streams.TweetStream.apply(this, arguments), this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                query: a.query\n            }))), this;\n        }).setTitle(function(a) {\n            var b = this;\n            if (this.params.hideTitle) {\n                return;\n            }\n        ;\n        ;\n            var c = twttr.merge({\n                top_mode: ((this.params.mode == \"relevance\")),\n                all_mode: ((this.params.mode == \"tweets\")),\n                timeline_mode: ((this.params.mode == \"timeline\")),\n                with_links_mode: ((this.params.mode == \"links\"))\n            }, this.params);\n            a((new twttr.views.SearchStreamTitle(c)).html());\n            var d = $(\".js-stream-title .stream-tab-dropdown\"), e = new twttr.control.Dropdown(d, {\n                items: [{\n                    label: _(\"Top\"),\n                    handlers: this._getSearchHandlers(\"relevance\")\n                },{\n                    label: _(\"All\"),\n                    handlers: this._getSearchHandlers(\"tweets\")\n                },{\n                    label: _(\"With links\"),\n                    handlers: this._getSearchHandlers(\"links\")\n                },],\n                direction: \"left\"\n            });\n            e.render(d, \"append\");\n        }).update(function(a, b, c) {\n            var d = this;\n            ((((((!twttr.is.def(a.since_id) && ((this.items.length > 0)))) && !twttr.is.def(a.max_id))) && (a.since_id = \"1\")));\n            if (!a.since_id) {\n                var e = a.success;\n                a.success = function(a, b) {\n                    d.logSearchImpressions(a), d._next_page = b.response.next_page;\n                    var c = e.apply({\n                    }, arguments);\n                    return ((((!d._next_page && !b.response.served_by_blender)) && d.reachedTheEnd())), c;\n                };\n            }\n        ;\n        ;\n            ((a.max_id && (a.page = d._next_page))), ((this.params.debug && (a.debug = this.params.debug)));\n            var f = twttr.util.params().promoted_location;\n            ((f && (a.promoted_location = f))), ((this.params.experimentId && (a.experimentId = this.params.experimentId))), ((((this.params.mode === \"links\")) ? a.filter = \"links\" : ((((this.params.mode === \"relevance\")) ? a.mode = \"relevance\" : ((((this.params.mode === \"timeline\")) && (a.mode = \"timeline\"))))))), this.search(this.params.query, a);\n        }).methods({\n            _shouldCache: !1,\n            search: function(a, b) {\n                var c = this;\n                if (this.inProgress) {\n                    return;\n                }\n            ;\n            ;\n                var d = function(a, b) {\n                    return a = ((a || $.noop)), function() {\n                        return c.inProgress = b, a.apply(this, arguments);\n                    };\n                };\n                b.before = d(b.before, !0), b.success = d(b.success, !1), b.error = d(b.error, !1), b.cancel = d(b.cancel, !1), b.query_source = twttr.search.getLastQuerySource(), twttr.API.Status.search(a, b);\n            },\n            _getSearchHandlers: function(a) {\n                var b = this;\n                return {\n                    click: function() {\n                        b.params.mode = a, twttr.app.currentPage().send(\"getStreamManager\", function(a) {\n                            a.switchTo(twttr.streams.Search, b.params);\n                        });\n                    }\n                };\n            },\n            scribeData: function() {\n                return twttr.merge(twttr.streams.Stream.prototype.scribeData.apply(this), {\n                    query: this.params.query,\n                    type: this.params.mode\n                });\n            },\n            logSearchImpressions: function(a) {\n                var b = [], c = [], d = [], e = [];\n                a.each(function(a) {\n                    ((a.isPromoted() ? (d.push(a.id), e.push(a.impressionId)) : ((((a.resultCategory === \"popular\")) ? c.push(a.id) : b.push(a.id)))));\n                }), scribble(\"integrated_search_impression\", {\n                    mode: this.params.mode,\n                    query: this.params.query,\n                    pretty_query: this.params.pretty_query,\n                    top_tweets: c,\n                    promoted_tweets: d,\n                    impression_ids: e,\n                    tweet_count: a.length()\n                });\n            },\n            _getEmptyStreamHtml: function() {\n                if (((this.params.mode === \"links\"))) {\n                    return _(\"No Tweet results with links for \\u003Cstrong\\u003E{{pretty_query}}\\u003C/strong\\u003E.\", this.params);\n                }\n            ;\n            ;\n                if (((this.params.mode === \"relevance\"))) {\n                    var a = {\n                        path: twttr.router.searchRealtimePath({\n                            query: this.params.query\n                        }),\n                        pretty_query: this.params.pretty_query\n                    };\n                    return twttr.router.routeTo(twttr.router.searchRealtimePath({\n                        query: this.params.query\n                    }));\n                }\n            ;\n            ;\n                return _(\"No Tweet results for \\u003Cstrong\\u003E{{pretty_query}}\\u003C/strong\\u003E.\", this.params);\n            },\n            _getStreamEndHtml: function() {\n                if (((this.params.mode === \"links\"))) {\n                    return _(\"Older Tweet results with links for \\u003Cstrong\\u003E{{pretty_query}}\\u003C/strong\\u003E are unavailable.\", this.params);\n                }\n            ;\n            ;\n                if (((this.params.mode === \"relevance\"))) {\n                    var a = {\n                        path: twttr.router.searchRealtimePath({\n                            query: this.params.query\n                        }),\n                        pretty_query: this.params.pretty_query\n                    };\n                    return _(\"You&rsquo;ve reached the end of the Top Tweets for \\u003Cstrong\\u003E{{pretty_query}}\\u003C/strong\\u003E. \\u003Cdiv\\u003E\\u003Ca href=\\\"{{path}}\\\"\\u003EView all Tweets\\u003C/a\\u003E.\\u003C/div\\u003E\", a);\n                }\n            ;\n            ;\n                return _(\"Older Tweet results for \\u003Cstrong\\u003E{{pretty_query}}\\u003C/strong\\u003E are unavailable.\", this.params);\n            },\n            beforeShowNewItems: function() {\n                this.constructor.uber.beforeShowNewItems.apply(this, arguments), this.movePromotedTweetToTop();\n            },\n            JSBNG__onShowNewItems: function(a) {\n                this.constructor.uber.JSBNG__onShowNewItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(0, this.newItemsCount));\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this.constructor.uber.JSBNG__onShowOldItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(((this.items.length - this.oldItemsCount))));\n            }\n        }).deciderKey(\"tweet_stream_search\").pollingDeciderKey(\"tweet_stream_search_polling\");\n        ((twttr.isT1 && d.methods({\n            _setHeader: function(a, b) {\n                a((new twttr.views.TweetSearchStreamHeader(b)).$html());\n            },\n            _setTitle: function(a) {\n                a(_(\"Tweets\"));\n            },\n            _setViewToggler: function(a) {\n                a(new twttr.views.SearchStreamViewToggler(this.params.query, this.params.mode));\n            }\n        }))), a(d);\n    });\n});\nprovide(\"streams/UserStream\", function(a) {\n    using().as(function(b) {\n        twttr.stream(\"twttr.streams.UserStream\", function(a, b, c) {\n            var d = this;\n            twttr.streams.Stream.apply(this, arguments), this.scribbler = ((this.params.scribbler || twttr.Scribbler.clientEvent)), ((this.isCursorPagination() ? this.cursor = -1 : this.page = 0)), this.registerUserActionEvents();\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.userActionable).methods({\n            itemViewClass: \"StreamUser\",\n            streamItemType: \"user\",\n            IDS_PER_REQUEST: 5000,\n            update: function(a) {\n            \n            },\n            _fetchItems: function(a) {\n                var b = this;\n                if (((!twttr.decider.isAvailable(\"people_streams\") || ((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))))) {\n                    a(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var c = {\n                    success: function(c, d) {\n                        var e = b.isCursorPagination();\n                        b.push(c.array);\n                        var f = ((((d && d.fetchedFullPage)) || ((c.length() === b.PAGE_SIZE))));\n                        ((e ? b.cursor = d.response.next_cursor : ((f ? b.page = ((b.page + 1)) : b.page = -1)))), ((((((e && !b.cursor)) || ((!e && ((b.page === -1)))))) && b.reachedTheEnd())), c.each(function(a) {\n                            ((a.promotedContent && twttr.API.util.PromotedContent.logImpression(a.promotedContent.impression_id)));\n                        }), a(b, twttr.streams.SUCCESS);\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR))), b._scribeResults(\"error\", [], {\n                            status_code: c.JSBNG__status\n                        });\n                    },\n                    timeout: function(a) {\n                        a.retry();\n                    },\n                    cancel: function() {\n                        a(b, twttr.streams.TIMEOUT), b._scribeResults(\"error\", [], {\n                            status_code: 502\n                        });\n                    }\n                };\n                c = twttr.merge(c, ((this.isCursorPagination() ? {\n                    cursor: this.cursor\n                } : {\n                    page: ((this.page + 1))\n                }))), this.update(c);\n            },\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            PAGE_SIZE: 20,\n            isCursorPagination: function() {\n                return !0;\n            },\n            _getStreamErrorComponent: function(a) {\n                return ((((a === twttr.streams.PROTECTED)) ? new twttr.components.ProtectedUser({\n                    screen_name: this.params.screenName\n                }) : twttr.streams.Stream.prototype._getStreamErrorComponent.apply(this, arguments)));\n            },\n            _scribeResults: function(a, b, c) {\n                twttr.streams.Stream.prototype._scribeResults.apply(this, arguments);\n                var b = ((b || []));\n                c = ((c || {\n                }));\n                if (((((a == \"error\")) || ((((a == \"initial\")) && !b.length))))) {\n                    this.scribbler.scribe({\n                        component: \"stream\",\n                        action: ((((a == \"error\")) ? \"error\" : \"no_results\"))\n                    }, twttr.merge(c, {\n                        item_count: 0,\n                        event_value: 0,\n                        cursor_or_page: this._cursorOrPage(),\n                        referring_event: a\n                    }));\n                }\n                 else {\n                    if (b.length) {\n                        var d = this, e = [], f;\n                        twttr.each(b, function(a, b) {\n                            e.push(a.id);\n                            if (((((d.constructor._namespace.indexOf(\"UserRecommendations\") != -1)) || ((d.constructor._namespace.indexOf(\"PeopleSearch\") != -1))))) {\n                                var c;\n                                ((((a.promotedContent && a.promotedContent.impression_id)) && (c = {\n                                    item_type: twttr.constants.clientEvent.itemType.promotedUser,\n                                    item_token: a.promotedContent.impression_id\n                                }))), ((c && (f = ((f || {\n                                })), c.item_position = b, f[((a.id + \"\"))] = c)));\n                            }\n                        ;\n                        ;\n                        }), ((f && (c.item_details = f))), this.scribbler.scribe({\n                            component: \"stream\",\n                            action: \"results\"\n                        }, twttr.merge(c, {\n                            item_ids: e,\n                            item_count: e.length,\n                            event_value: e.length,\n                            cursor_or_page: this._cursorOrPage(),\n                            referring_event: a\n                        }));\n                    }\n                ;\n                }\n            ;\n            ;\n            },\n            sortUsersByIds: function(a, b) {\n                var c = [], d = {\n                };\n                return twttr.each(a, function(a) {\n                    d[a.id] = a;\n                }), twttr.each(b, function(a) {\n                    ((d[a] && c.push(d[a])));\n                }), c;\n            },\n            fetchUsersById: function(a, b) {\n                var c = this, d, e, f;\n                twttr.API.User.JSBNG__find(this.screenName, function(d) {\n                    if (!twttr.helpers.canViewUser(d)) {\n                        c._showError(twttr.streams.PROTECTED), c.doneLoadingMore();\n                        return;\n                    }\n                ;\n                ;\n                    e = ((c.page * c.PAGE_SIZE)), f = ((c.fetchedIds && ((e < c.IDS_PER_REQUEST)))), ((f ? c.hydrateUsers(a) : (c.page = 0, d[b]({\n                        cursor: c.idsCursor,\n                        success: function(b, d) {\n                            ((d.response.next_cursor && (c.idsCursor = d.response.next_cursor))), c.fetchedIds = b, c.hydrateUsers(a);\n                        }\n                    }))));\n                });\n            },\n            hydrateUsers: function(a) {\n                var b = this, c = this.fetchedIds, d = a.success;\n                a.success = function(a) {\n                    var c = b.sortUsersByIds(a.array, e);\n                    a.array = c, d.call(this, a, {\n                        fetchedFullPage: ((e.length == b.PAGE_SIZE))\n                    });\n                };\n                var e = c.slice(((this.page * this.PAGE_SIZE)), ((((this.page + 1)) * this.PAGE_SIZE)));\n                ((twttr.decider.isAvailable(\"people_stream_fresh\") ? ((e.length ? twttr.API.User.findAll(e, {\n                    success: a.success,\n                    reload: !0\n                }) : a.success(new twttr.anywhere.api.util.BaseCollection([])))) : twttr.API.User.findAll(e, a.success)));\n            }\n        }), a(twttr.streams.UserStream);\n    });\n});\nprovide(\"streams/Friends\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.Friends\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments);\n            var c = this;\n            this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                profile_id: ((twttr.profileUser && twttr.profileUser.id)),\n                context: \"profile\"\n            }))), this._registerEvents();\n        }).subclassOf(twttr.streams.UserStream).methods({\n            PAGE_SIZE: 100,\n            update: function(a) {\n                this.fetchUsersById(a, \"friendIds\");\n            },\n            isCursorPagination: function() {\n                return !1;\n            },\n            _countString: function(a) {\n                return ((((a === 1)) ? _(\"You follow 1 person\") : _(\"You follow {{friendsCount}} people\", {\n                    friendsCount: b.util.formatNumber(a, twttr.pageLocale)\n                })));\n            },\n            _setTitle: function(a) {\n                $(\"#following-page-context\").html(_(\"Here&rsquo;s more about them.\"));\n                if (this.params.subtab) {\n                    var b = new twttr.views.FollowingSubtabs(this.params);\n                    a(b.html());\n                }\n            ;\n            ;\n            },\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You aren't following anyone yet.\") : _(\"@{{screen_name}} isn't following anyone yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function() {\n                if (twttr.loggedIn) {\n                    var a = function(a, b) {\n                        return ((twttr.helpers.isProfileUser() ? b : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.User, \"follow\", a), this._registerRemoveFromStreamEvent(twttr.API.User, \"unfollow\", a);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"people_stream_friends\"\n        });\n        ((twttr.isT1 && c.methods({\n            _setTitle: function(a) {\n                a(_(\"Following\"));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"streams/FollowerRequests\", function(a) {\n    using(\"_\", \"mixins/protectedUserActionable\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.FollowerRequests\", function(a, b) {\n            var c = this;\n            this.constructor.uber.constructor.apply(this, arguments), this.cursor = 0, this.oldItemsCount = -1, this.pending_users = [], this.getFollowerRequestCount = function(a) {\n                var b = this;\n                ((((b.oldItemsCount == -1)) ? twttr.currentUser.friends.pending(function(c, d) {\n                    b.oldItemsCount = c.length, b.pending_users = c, a(b.oldItemsCount);\n                }) : (b.oldItemsCount = b.pending_users.length, a(b.oldItemsCount))));\n            }, this.registerProtectedUserActions();\n        }).subclassOf(twttr.streams.UserStream).mixin(b.mixins.protectedUserActionable).methods({\n            itemViewClass: \"StreamFollowerRequest\",\n            streamItemType: \"user\",\n            update: function(a) {\n            \n            },\n            _fetchItems: function(a) {\n                var b = this;\n                b.getFollowerRequestCount(function(c) {\n                    var d = {\n                        success: function(d, e) {\n                            b.push(d.array), b.cursor = ((b.cursor + b.constructor.PAGE_SIZE)), ((((b.cursor >= c)) && b.reachedTheEnd())), a(b, twttr.streams.SUCCESS);\n                        },\n                        error: function(c) {\n                            ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                        },\n                        timeout: function(a) {\n                            a.retry();\n                        },\n                        cancel: function() {\n                            a(b, twttr.streams.TIMEOUT);\n                        }\n                    };\n                    sliced_list = b.pending_users.slice(b.cursor, ((b.cursor + b.constructor.PAGE_SIZE))), twttr.API.User.findAll(sliced_list, d);\n                });\n            },\n            _setTitle: function(a) {\n                a(_(\"Your pending follower requests\"));\n            }\n        }).statics({\n            PAGE_SIZE: 20,\n            _deciderKey: \"people_stream_follower_requests\"\n        }), a(twttr.streams.FollowerRequests);\n    });\n});\nprovide(\"streams/Followers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.Followers\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments), this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                profile_id: ((twttr.profileUser && twttr.profileUser.id)),\n                context: \"profile\"\n            }))), this._registerEvents(a);\n        }).subclassOf(twttr.streams.UserStream).methods({\n            PAGE_SIZE: 100,\n            update: function(a) {\n                this.fetchUsersById(a, \"followerIds\");\n            },\n            isCursorPagination: function() {\n                return !1;\n            },\n            _setTitle: function(a) {\n                if (this.params.subtab) {\n                    var b = new twttr.views.FollowersSubtabs(this.params);\n                    a(b.html());\n                }\n            ;\n            ;\n            },\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You don't have any followers yet.\") : _(\"@{{screen_name}} doesn't have any followers yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c) {\n                        return ((((!twttr.helpers.isProfileUser() && ((c.screenName === a.screenName)))) ? twttr.currentUser : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.User, \"follow\", b), this._registerRemoveFromStreamEvent(twttr.API.User, \"unfollow\", b);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"people_stream_followers\"\n        });\n        ((twttr.isT1 && c.methods({\n            _setTitle: function(a) {\n                a(_(\"Followers\"));\n            },\n            _setViewToggler: function(a, b) {\n                ((((twttr.loggedIn && !twttr.helpers.isProfileUser())) && a(new twttr.views.FollowersStreamViewToggler(b.screenName, !1))));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"streams/SocialContextStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.SocialContextStream\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments), this.params = a;\n            var c = ((((a.socialContextType == \"followsInCommonWith\")) ? \"following_social_context\" : \"followers_social_context\"));\n            this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                profile_id: ((twttr.profileUser && twttr.profileUser.id)),\n                context: \"profile\",\n                event_info: c\n            })));\n        }).subclassOf(twttr.streams.UserStream).methods({\n            update: function(a) {\n                var b = this;\n                twttr.API.User.JSBNG__find(this.screenName, function(c) {\n                    if (!twttr.helpers.canViewUser(c)) {\n                        b._showError(twttr.streams.PROTECTED), b.doneLoadingMore();\n                        return;\n                    }\n                ;\n                ;\n                    twttr.currentUser[b.params.socialContextType](twttr.profileUser.id, a);\n                });\n            },\n            _getEmptyStreamHtml: function() {\n                var a = {\n                    user: twttr.profileUser.screenName\n                };\n                return ((((this.params.socialContextType == \"followsInCommonWith\")) ? _(\"You and @{{user}} don't follow anyone in common.\", a) : _(\"You don't follow anyone who follows @{{user}}.\", a)));\n            }\n        }).statics({\n            _deciderKey: \"social_context\"\n        });\n        ((twttr.isT1 ? c.methods({\n            _setTitle: function(a) {\n                a(_(\"Followers\"));\n            },\n            _setViewToggler: function(a, b) {\n                ((((twttr.loggedIn && !twttr.helpers.isProfileUser())) && a(new twttr.views.FollowersStreamViewToggler(b.screenName, !0))));\n            }\n        }) : c.methods({\n            _setTitle: function(a) {\n                if (((this.params.socialContextType == \"followsInCommonWith\"))) {\n                    var b = new twttr.views.FollowingSubtabs(this.params);\n                }\n                 else {\n                    var b = new twttr.views.FollowersSubtabs(this.params);\n                }\n            ;\n            ;\n                a(b.html());\n            }\n        }))), a(twttr.streams.SocialContextStream);\n    });\n});\nprovide(\"streams/SuggestionCategoriesStream\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"mixins/SuggestionCategoriesStreamT1\" : \"\")), \"mixins/discoveryHelper\").as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.SuggestionCategoriesStream\", function(a, b) {\n            a.pathRoot = ((a.pathRoot || \"whoToFollow\")), twttr.streams.Stream.apply(this, arguments), this.$node.addClass(\"suggestion-categories\");\n            var c = this;\n            this.$node.delegate(\"div[data-item-type=suggestion_category]\", \"click\", function(a) {\n                var b = $(this).attr(\"data-item-id\"), d = {\n                };\n                return d[b] = {\n                    item_position: $(\"div.js-stream-manager-container div.js-stream-item\").index($(a.target).closest(\".js-stream-item\"))\n                }, ((b && (trackClient({\n                    component: \"suggestion_category\",\n                    action: \"click\"\n                }, {\n                    step: \"interests\",\n                    query: b,\n                    item_details: d\n                }), c.routePageTo(c.params.pathRoot, \"InterestsCategory\", {\n                    category: b\n                })))), !1;\n            });\n        }).subclassOf(twttr.streams.Stream).statics({\n            cacheCategories: function(a) {\n                this.CATEGORIES = a, this.CATEGORY_MAP = this.buildCategoryMap(a);\n            },\n            buildCategoryMap: function(a) {\n                return a.reduce({\n                }, function(a, b) {\n                    return a[b.slug] = b, a;\n                });\n            },\n            filterTopTweetsCategories: function(a) {\n                var b = this.buildCategoryMap(a);\n                return a.filter(function(a) {\n                    if (a.slug.match(/^(.+)[_-]top-tweets$/i)) {\n                        var c = b[RegExp.$1];\n                        return ((c && (c.topTweetsCategory = a))), !1;\n                    }\n                ;\n                ;\n                    return !0;\n                });\n            }\n        }).methods({\n            itemViewClass: \"StreamSuggestionCategory\",\n            streamItemType: \"suggestion_category\",\n            sampleSize: \"\",\n            streamItemId: function(a) {\n                return a.slug;\n            },\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            addTipsies: function() {\n            \n            },\n            _fetchItems: function(a) {\n                var b = this;\n                if (!twttr.decider.isAvailable(\"suggestion_categories_streams\")) {\n                    a(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var c = {\n                    sample_size: this.sampleSize,\n                    samples: !0,\n                    success: function(c) {\n                        c = b.constructor.filterTopTweetsCategories(c), b.constructor.cacheCategories(c);\n                        var d = c.map(function(a) {\n                            var c, d;\n                            return ((((((a.topTweetsCategory && a.topTweetsCategory.sample)) && (d = a.topTweetsCategory.sample.shift()))) && (c = d.id))), a.clone({\n                                category_link: b.pagePathFor(b.params.pathRoot, \"InterestsCategory\", {\n                                    category: a.slug\n                                }),\n                                category_top_tweets_user_id: c,\n                                category_top_tweets_is_current_user: ((!!twttr.currentUser && ((twttr.currentUser.id == c)))),\n                                following_category_top_tweets: ((a.topTweetsCategory ? a.topTweetsCategory.followingTopTweets : null))\n                            });\n                        });\n                        b.push(d.array), a(b, twttr.streams.SUCCESS), b.addTipsies(), b.reachedTheEnd();\n                        var e = c.map(function(a, b) {\n                            return a.JSBNG__name;\n                        });\n                        b.scribbler.scribe({\n                            component: \"stream\",\n                            action: \"results\"\n                        }, {\n                            item_names: e,\n                            item_count: e.length()\n                        });\n                    },\n                    error: function() {\n                        a(b, twttr.streams.ERROR);\n                    }\n                };\n                ((b.defaultOpts && (c = twttr.merge(b.defaultOpts, c)))), ((b.params.lang && (c.lang = b.params.lang))), ((b.params.country && (c.country = b.params.country))), ((b.params.city && (c.city = b.params.city))), c.top_tweets = !0, twttr.API.SuggestionCategory.getAll(c);\n            },\n            _setTitle: function(a) {\n                ((((this.params.title !== undefined)) ? a(this.params.title) : a(_(\"Select the topics you are interested in. Find a few people you want to hear from, then follow them.\"))));\n            },\n            _getHeaderComponent: function() {\n                return ((this.params.noHeaderFooter ? null : new twttr.components.SuggestionCategoriesList(this.constructor.CATEGORIES, this.params.pathRoot)));\n            },\n            _getStreamEndComponent: function() {\n                return this._getHeaderComponent();\n            }\n        }).mixin(twttr.mixins.discoveryHelper);\n        ((c && d.mixin(c))), a(d);\n    });\n});\nprovide(\"streams/PeopleSearch\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.streams.PeopleSearch\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments), ((((!a.scribbler && a.query)) && (this.scribbler = twttr.Scribbler.clientEvent.spawnWithTerms({\n            }, {\n                query: a.query\n            })))), this.ignoreScribeItemPosition = !1;\n        }).subclassOf(twttr.streams.UserStream).methods({\n            scribeData: function() {\n                return twttr.merge(twttr.streams.Stream.prototype.scribeData.apply(this), {\n                    JSBNG__name: \"Search\",\n                    query: this.params.query,\n                    type: \"people\"\n                });\n            },\n            update: function(a) {\n                a.display_location = \"search-view-all-stream\", a.pc = !0, twttr.API.User.search(this.params.query, a);\n            },\n            isCursorPagination: function() {\n                return !1;\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"No people results for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E.\", {\n                    query: this.params.query\n                });\n            },\n            getStreamEndHtml: function() {\n                return _(\"No more people results for \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E.\", {\n                    query: this.params.query\n                });\n            },\n            _setHeader: function(a, b) {\n                ((this.header ? a(this.header.$node) : a((new twttr.views.StreamHeader(b)).$html())));\n            },\n            _setTitle: function(a) {\n                ((twttr.isT1 ? a(_(\"People\")) : a(_(\"Results for: \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\", {\n                    query: this.params.query\n                }))));\n            }\n        }).statics({\n            _deciderKey: \"people_stream_people_search\"\n        }), a(twttr.streams.PeopleSearch);\n    });\n});\nprovide(\"streams/t1/HeadlessPeopleSearch\", function(a) {\n    using(\"_\").as(function(a, _) {\n        twttr.klass(\"twttr.streams.HeadlessPeopleSearch\", function(a, b) {\n            twttr.streams.PeopleSearch.apply(this, arguments);\n            var c = new twttr.streams[a.headerStreamClass](a, b);\n            this._setHeader = c._setHeader, this._setTitle = c._setTitle, this._setHeaderButton = c._setHeaderButton, this._updateHeaderFromStream = c._updateHeaderFromStream;\n        }).subclassOf(twttr.streams.PeopleSearch).methods({\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.BackLink(b.backLinkOptions));\n            }\n        });\n    }), a(twttr.streams.HeadlessPeopleSearch);\n});\nprovide(\"streams/DashboardPeopleSearch\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.DashboardPeopleSearch\", function(a, b) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", twttr.streams.PeopleSearch.apply(this, arguments);\n        }).subclassOf(twttr.streams.PeopleSearch).methods({\n            scribeData: function() {\n                return twttr.merge(twttr.streams.Stream.prototype.scribeData.apply(this), {\n                    JSBNG__name: \"Search\",\n                    query: this.params.query,\n                    type: \"people\"\n                });\n            },\n            update: function(a) {\n                a.display_location = \"search-view-all-stream\", a.pc = !1, twttr.API.User.search(this.params.query, a);\n            },\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), a();\n    });\n});\nprovide(\"streams/DashboardTopPeopleSearch\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.DashboardTopPeopleSearch\", function(a, b) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", twttr.streams.UserStream.apply(this, arguments);\n        }).subclassOf(twttr.streams.UserStream).methods({\n            update: function(a) {\n                var b = {\n                    is_t1: twttr.isT1,\n                    statuses: !1,\n                    stories: !0,\n                    related_queries: !1,\n                    spelling_corrections: !1,\n                    query_source: twttr.search.searchQuerySource.TYPED_QUERY\n                };\n                twttr.merge(b, a);\n                var c = this, d = ((b.success || $.noop));\n                b.success = function(a, b) {\n                    var e = new twttr.anywhere.api.util.BaseCollection;\n                    a.stories.each(function(a) {\n                        ((((a.type == \"user\")) && (e = e.concat(a.JSBNG__content.users))));\n                    }), d(e, b), c.trigger(\"results\", [e,]);\n                }, twttr.API.Search.search(this.params.query, b);\n            },\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            _getStreamEndComponent: function() {\n                return new twttr.components.TopPeopleStreamEnd(this.params.query);\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), twttr.klass(\"twttr.components.TopPeopleStreamEnd\").subclassOf(twttr.components.Base).initializer(function(a) {\n            (new twttr.views.TopPeopleStreamEnd({\n                query: a\n            })).render(this.$node, \"append\");\n        }), a();\n    });\n});\nprovide(\"streams/ListFollowers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.ListFollowers\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments), this._registerEvents(a);\n        }).subclassOf(twttr.streams.UserStream).methods({\n            update: function(a) {\n                var b = this;\n                twttr.API.User.JSBNG__find(this.screenName).lists(function(c) {\n                    c.JSBNG__find(function(a) {\n                        return ((a.slug === b.params.listSlug));\n                    }).followers(a);\n                });\n            },\n            _setTitle: function(a) {\n                ((twttr.isT1 ? a(_(\"List subscribers\")) : a(_(\"People following this list\"))));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c) {\n                        return ((((c.slug === a.listSlug)) ? twttr.currentUser : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.List, \"follow\", b), this._registerRemoveFromStreamEvent(twttr.API.List, \"unfollow\", b);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"people_stream_list_followers\"\n        }), a(twttr.streams.ListFollowers);\n    });\n});\nprovide(\"streams/ListMembers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.ListMembers\", function(a, b) {\n            twttr.streams.UserStream.apply(this, arguments), this._registerEvents(a);\n        }).subclassOf(twttr.streams.UserStream).methods({\n            update: function(a) {\n                var b = this;\n                twttr.API.User.JSBNG__find(this.screenName).lists(function(c) {\n                    c.JSBNG__find(function(a) {\n                        return ((a.slug === b.params.listSlug));\n                    }).members(a);\n                });\n            },\n            _setTitle: function(a) {\n                ((twttr.isT1 ? a(_(\"List members\")) : a(_(\"People this list follows\"))));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c, d) {\n                        return ((((c.slug === a.listSlug)) ? d : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.widget.ListMembershipDialog, \"addListMember\", b), this._registerRemoveFromStreamEvent(twttr.widget.ListMembershipDialog, \"removeListMember\", b);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"people_stream_list_members\"\n        }), a(twttr.streams.ListMembers);\n    });\n});\nprovide(\"streams/Discover\", function(a) {\n    using(\"_\", \"util\", \"mixins/t1/cardActionable\", \"helpers\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.streams.Discover\", function(a, b) {\n            var c = this;\n            twttr.streams.Stream.apply(c, arguments), this.scribbler = twttr.Scribbler.clientEvent, c.registerCardActions(), this.registerTweetActionEvents(), this.initComponentEvents(), c.$find(\".js-user-tipsy\").tipsy({\n                gravity: \"s\"\n            }), twttr.API.CurrentUser.bind(\"changedLocation.discovery\", function() {\n                ((jQuery.contains(JSBNG__document.body, c.$node[0]) ? c._fetchItems($.noop) : c._lastUpdate = null));\n            });\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.cardActionable, twttr.mixins.componentEvents, twttr.mixins.tweetActionable).statics({\n            discoveryRefreshRate: 300000\n        }).methods({\n            streamItemType: \"story\",\n            _expandable: !0,\n            itemViewClass: function(a) {\n                return twttr.views[((\"Card\" + b.util.capitalize(a.type)))];\n            },\n            streamItemId: function(a) {\n                return a.getId();\n            },\n            addTipsies: function() {\n                this.$find(\".js-user-tipsy\").tipsy({\n                    gravity: \"s\"\n                });\n            },\n            afterFirstSwitchingTo: function(a) {\n                this._fetchItems(a);\n            },\n            afterSwitchingToAgain: function(a) {\n                ((((!this._lastUpdate || ((((this._lastUpdate + twttr.streams.Discover.discoveryRefreshRate)) <= this.now())))) ? this._fetchItems(a) : ((a && a()))));\n            },\n            now: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            reset: function() {\n                this.$streamItems().empty(), this.items = [], this.itemIds = null, this.$find(\".js-discovery-error\").remove();\n            },\n            _setTitle: function(a) {\n                a(_(\"Stories\"));\n            },\n            _fetchItems: function(a) {\n                var b = this;\n                ((!this.items.length && this.showLoadingSpinner()));\n                var c = function() {\n                    b.reset(), b._lastUpdate = null, b.hideLoadingSpinner(), (new twttr.views.DiscoveryStreamError).$html().appendTo(b.dom()), a(b, twttr.streams.ERROR);\n                }, d = function(d) {\n                    if (d.stories.isEmpty()) {\n                        c();\n                        return;\n                    }\n                ;\n                ;\n                    b.reset(), b.hideLoadingSpinner(), b._lastUpdate = b.now(), $.each(d.stories.array, function(a, b) {\n                        b.position = ((a + 1));\n                    }), b.push(d.stories.array), b.newItemsCount = d.stories.length(), b.render(), b.ellipsify(), b.addTipsies(), ((a && a(b, twttr.streams.SUCCESS))), b.reachedTheEnd();\n                };\n                twttr.API.Discovery.discovery({\n                    success: d,\n                    error: c,\n                    include_entities: !0,\n                    tweet_count: 0\n                });\n            },\n            ellipsify: function() {\n                b.helpers.ellipsify(this.$find(\"h3.js-story-title,p.js-metadata\")), b.helpers.ellipsify(this.$find(\"p.js-news-snippet, h4.js-news-headline\"), !1, !0, null, {\n                    ellipsis: \"&ellip;\"\n                });\n            },\n            _scribeResults: function(a, c, d) {\n                this._scribeEmptyResults(a, c, d);\n                if (c.length) {\n                    var e = [], f = {\n                    };\n                    twttr.each(c, function(a, c) {\n                        var d, g = ((((a.JSBNG__content && a.JSBNG__content.articles)) && a.JSBNG__content.articles.array[0]));\n                        ((g ? d = g.query : ((a.JSBNG__content && (d = a.JSBNG__content.query))))), ((d && (e.push(d), f[d] = {\n                            item_type: b.constants.clientEvent.itemType.story,\n                            item_position: c,\n                            item_description: a.type\n                        })));\n                    }), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"results\"\n                    }, {\n                        item_names: e,\n                        item_count: e.length,\n                        event_value: e.length,\n                        item_details: f,\n                        referring_event: a\n                    });\n                }\n            ;\n            ;\n            }\n        }).click({\n            \".story-social-new-tweet\": function(a, b) {\n                a.stopPropagation(), a.preventDefault();\n                var c = b.data(\"url\");\n                (new twttr.widget.TweetDialog({\n                    draggable: !0,\n                    template: {\n                        title: _(\"Tweet this link\")\n                    },\n                    defaultContent: c,\n                    origin: \"discovery-story-tweet-button\"\n                })).open().JSBNG__focus();\n            }\n        }), a(twttr.streams.Discover);\n    });\n});\nprovide(\"streams/SavedSearches\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.streams.SavedSearches\", function(a, b) {\n            twttr.streams.Stream.apply(this, arguments), this.oldItemsCount = -1, this.scribbler = twttr.Scribbler.clientEvent;\n        }).subclassOf(twttr.streams.Stream).methods({\n            itemViewClass: \"StreamSavedSearch\",\n            streamItemType: \"saved_search\",\n            streamItemId: function(a) {\n                return a.id;\n            }\n        }).methods({\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            _setTitle: function(a) {\n                a(\"Saved searches\");\n            },\n            _fetchItems: function(a) {\n                var b = this;\n                twttr.currentUser.savedSearches(function(c) {\n                    b.items = c.array, ((((b.oldItemsCount == -1)) && (b.oldItemsCount = b.items.length))), a(b, twttr.streams.SUCCESS), b.reachedTheEnd();\n                });\n            },\n            _scribeResults: function(a, b, c) {\n                this._scribeEmptyResults(a, b, c);\n                if (b.length) {\n                    var d = twttr.map(b, function(a) {\n                        return a.query;\n                    });\n                    this.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"results\"\n                    }, {\n                        item_names: d,\n                        item_count: d.length,\n                        event_value: d.length,\n                        referring_event: a\n                    });\n                }\n            ;\n            ;\n            }\n        }), a(twttr.streams.SavedSearches);\n    });\n});\nprovide(\"mixins/SinceMaxPagination\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.SinceMaxPagination\", function() {\n            this.statics({\n                deciderKey: function(a) {\n                    return this._deciderKey = a, this;\n                }\n            }), this.methods({\n                _fetchItems: function(a) {\n                    this.fetcher(!0, a);\n                },\n                fetcher: function(a, b, c) {\n                    var d = this;\n                    ((twttr.is.fn(a) && (c = b, b = a, a = !1)));\n                    if (((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))) {\n                        b(this, twttr.streams.DECIDER);\n                        return;\n                    }\n                ;\n                ;\n                    var e = ((a ? this._optionsForOld(b) : this._optionsForNew(b)));\n                    c = ((c || {\n                    })), e = twttr.merge(c, e), ((this.excludeEntities || (e.include_entities = 1))), this.update(e, this.params, b);\n                },\n                fetchUntilScreenIsFull: function() {\n                    var a = this;\n                    ((((((!this.noMoreOldItems && this._isInDOM())) && this._shorterThanWindow())) && this.getMoreOldItems(function(b, c) {\n                        ((((c !== twttr.streams.SUCCESS)) ? a._showError(c) : a.fetchUntilScreenIsFull()));\n                    })));\n                },\n                _isInDOM: function() {\n                    return jQuery.contains(JSBNG__document.body, this.$node[0]);\n                },\n                _shorterThanWindow: function() {\n                    return ((this.$node.height() < $(window).height()));\n                },\n                _optionsForNew: function(a) {\n                    var b = this, c = {\n                        success: function(c) {\n                            ((((c instanceof twttr.API.util.BaseCollection)) && (c = c.array))), ((c.length && (b._updateIds(c), b.unshift(c)))), ((a && a(b, twttr.streams.SUCCESS)));\n                        },\n                        error: function(c) {\n                            ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                        }\n                    };\n                    return ((this.items.length && (c.since_id = this._sinceId))), c;\n                },\n                _optionsForOld: function(a) {\n                    var b = this, c = {\n                        success: function(d) {\n                            ((c.max_id && (d = d.slice(1)))), ((((d instanceof twttr.API.util.BaseCollection)) && (d = d.array))), ((d.length ? (b._updateIds(d), b.push(d)) : b.reachedTheEnd())), ((a && a(b, twttr.streams.SUCCESS)));\n                        },\n                        error: function(c) {\n                            ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                        },\n                        timeout: function(a) {\n                            a.retry();\n                        },\n                        cancel: function() {\n                            a(b, twttr.streams.TIMEOUT);\n                        }\n                    };\n                    return ((this.items.length ? (c.max_id = this._maxId, c.count = ((this.PAGE_SIZE + 1))) : c.count = this.PAGE_SIZE)), c;\n                },\n                _updateIds: function(a) {\n                    ((twttr.is.array(a) || (a = Array.prototype.slice.call(arguments))));\n                    var b = a[0], c = a[((a.length - 1))], d, e;\n                    ((this._idForItem ? (d = this._idForItem(b, \"first\"), e = this._idForItem(c, \"last\")) : (d = b.id, e = c.id)));\n                    if (((!this._sinceId || ((twttr.natcompare(d, this._sinceId) > 0))))) {\n                        this._sinceId = d;\n                    }\n                ;\n                ;\n                    if (((!this._maxId || ((twttr.natcompare(e, this._maxId) < 0))))) {\n                        this._maxId = e;\n                    }\n                ;\n                ;\n                }\n            });\n        }), a(twttr.mixins.SinceMaxPagination);\n    });\n});\nprovide(\"mixins/PollingStream\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.PollingStream\", function() {\n            var a = {\n                ACTIVE: 30000,\n                INACTIVE: 90000\n            }, b = !0, c = a.ACTIVE;\n            $(window).JSBNG__focus(function() {\n                c = a.ACTIVE, b = !0;\n            }), $(window).JSBNG__blur(function() {\n                c = a.INACTIVE, b = !1;\n            }), this.statics({\n                pollingDeciderKey: function(a) {\n                    return this._pollingDeciderKey = a, this;\n                }\n            }), this.methods({\n                _getInterval: function() {\n                    return ((this.timeouts ? ((b ? this.timeouts.ACTIVE : this.timeouts.INACTIVE)) : c));\n                },\n                _pollFetch: function() {\n                    var a = {\n                        headers: {\n                            \"X-Twitter-Polling\": !0\n                        }\n                    };\n                    this.fetcher(twttr.bind(this, function(a) {\n                        var b = a.newItemsCount;\n                        ((((b > 0)) && (this.showNewItems(b, !0), this.trigger(\"newItems\", [a,b,]))));\n                    }), a);\n                },\n                startPeriodicFetcher: function() {\n                    if (((this.periodicUpdater || ((this.constructor._pollingDeciderKey && !twttr.decider.isAvailable(this.constructor._pollingDeciderKey)))))) {\n                        return;\n                    }\n                ;\n                ;\n                    this.periodicUpdater = JSBNG__setTimeout(twttr.bind(this, this.fetchNewItemsThenPoll), this._getInterval());\n                },\n                stopPeriodicFetcher: function() {\n                    ((this.periodicUpdater && (JSBNG__clearTimeout(this.periodicUpdater), this.periodicUpdater = null)));\n                },\n                fetchNewItemsThenPoll: function() {\n                    var a = !0;\n                    ((this._pollShouldFetch && (a = this._pollShouldFetch()))), ((a && this._pollFetch())), this.restartFetcher();\n                },\n                restartFetcher: function() {\n                    this.stopPeriodicFetcher(), this.startPeriodicFetcher();\n                }\n            });\n        }), a(twttr.mixins.PollingStream);\n    });\n});\nprovide(\"mixins/activityStreamEvents\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.activityStreamEvents\", function() {\n            var a;\n            ((twttr.isT1 ? a = \"div.stream-item-activity-me div.activity-supplement img.avatar,     div.stream-item-activity-network div.follow-more-than-two img.avatar,     div.stream-item-activity-network.stream-item-list_member_added img.avatar,     div.stream-item-activity-network div.activity-secondary-supplement img.user-profile-link\" : a = \".stream-item-activity-me .sub-stream-item img.user-content-image,     .stream-item-activity-network .follow-more-than-two img.user-content-image,     .stream-item-activity-network.stream-item-list_member_added img.user-content-image,     .stream-item-activity-network .activity-secondary-supplement .user-profile-link\")), $(a).tipsy({\n                live: !0,\n                gravity: \"s\"\n            });\n        }), a(twttr.mixins.activityStreamEvents);\n    });\n});\nprovide(\"mixins/inviteFriends\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.inviteFriends\", function() {\n            this.methods({\n                sendInvitesByEmailSuccess: function(a) {\n                    var b = ((a.invited && a.invited.length));\n                    ((b ? (this.scribbler.scribe({\n                        section: \"dashboard\",\n                        component: \"invite_friends\",\n                        action: \"invited\"\n                    }, {\n                        event_value: b,\n                        item_count: b\n                    }), twttr.showMessage(((((b > 1)) ? _(\"OK, we will send invites to your {{count}} friends!\", {\n                        count: b\n                    }) : _(\"OK, we will send an invite to {{email}}!\", {\n                        email: a.invited[0]\n                    })))), this.$textarea.val(\"\")) : twttr.showError(_(\"Something is wrong, nobody was invited :-(\")))), this.$textarea.removeAttr(\"disabled\").JSBNG__blur();\n                },\n                sendInvitesByEmailError: function(a) {\n                    var b = twttr.helpers.extractEmailAddresses(this.$textarea.val()), c = ((((b.length === 1)) ? b[0].split(\",\") : b.length)), d = ((twttr.API.util.RemoteRequest.apiErrorCodeFromResponse(a) || a.JSBNG__status));\n                    this.scribbler.scribe({\n                        component: \"invite_friends\",\n                        action: \"error\"\n                    }, {\n                        status_code: d,\n                        item_count: c\n                    });\n                    switch (d) {\n                      case 47:\n                        twttr.showError(_(\"We couldn't send invitations to any of those addresses.\"));\n                        break;\n                      case 37:\n                        twttr.showError(_(\"There was an error emailing your friends. Please try again later.\"));\n                        break;\n                      default:\n                        twttr.showMessage(_(\"OK, we will send invites to your friends!\"));\n                    };\n                ;\n                    this.$textarea.removeAttr(\"disabled\").JSBNG__focus();\n                },\n                formSubmitCallback: function() {\n                    if (this.$textarea.attr(\"disabled\")) {\n                        return;\n                    }\n                ;\n                ;\n                    var a = twttr.helpers.extractEmailAddresses(this.$textarea.val());\n                    if (a.length) {\n                        this.$textarea.attr(\"disabled\", \"disabled\").val(a.join(\", \"));\n                        var b = this;\n                        twttr.API.AddressBook.sendInvitesByEmail(a, {\n                            source: \"invite_friends\",\n                            success: twttr.bind(this, this.sendInvitesByEmailSuccess),\n                            error: twttr.bind(this, this.sendInvitesByEmailError)\n                        });\n                    }\n                     else twttr.showError(_(\"Please check the address you entered.\"));\n                ;\n                ;\n                },\n                addFormEvents: function(a) {\n                    this.scribbler = ((a || new twttr.Scribbler)), this.$textarea = ((this.$textarea || this.$find(\"textarea\"))), this.$textarea.bind(\"keyup\", function(a) {\n                        var c = $(this);\n                        ((((((a.which == b.constants.keyCodes.enter)) || ((c.val().indexOf(\",\") > 0)))) && c.addClass(\"expanded\")));\n                    }), twttr.helpers.addFormEvents(this.$find(\"form\"), twttr.bind(this, this.formSubmitCallback));\n                }\n            });\n        }), a(twttr.mixins.inviteFriends);\n    });\n});\nprovide(\"mixins/newStreamItemsBar\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.newStreamItemsBar\", function() {\n            this.methods({\n                showNewStreamItemsBar: function(a) {\n                    var b = this.$find(\".js-new-tweets-bar\"), c;\n                    ((this.newStreamItemsBarPhrase ? c = this.newStreamItemsBarPhrase(a) : c = ((((a == 1)) ? _(\"1 new item\") : _(\"{{count}} new items\", {\n                        count: a\n                    }))))), ((((b.length > 0)) ? b.html(c) : (b = $((new twttr.views.NewTweetsBar({\n                        tweets_count_phrase: c,\n                        is_tweet: !1\n                    })).html()), b.hide().prependTo(this.dom()).slideDown())));\n                }\n            });\n        }), a(twttr.mixins.newStreamItemsBar);\n    });\n});\nprovide(\"mixins/typeaheadScribing\", function(a) {\n    using().as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.typeaheadScribing\", function() {\n            return this.methods({\n                startStatsTimer: function() {\n                    ((this._statsTimerStart || (this._statsTimerStart = +(new JSBNG__Date)))), this._lastTimerEvent = \"start\";\n                },\n                pauseStatsTimer: function() {\n                    ((((((this._statsTimerStart !== 0)) && ((this._lastTimerEvent == \"start\")))) && (this._statsCumulativeTime += ((+(new JSBNG__Date) - this._statsTimerStart)), this._statsTimerStart = 0))), this._lastTimerEvent = \"pause\";\n                },\n                resetStatsTimer: function() {\n                    this._statsCumulativeTime = 0, this._statsTimerStart = 0, this._lastTimerEvent = \"pause\";\n                },\n                addLocalLatency: function(a, b) {\n                    this._localLatencies.push(b);\n                },\n                addRemoteLatency: function(a, b) {\n                    this._remoteLatencies.push(b);\n                },\n                medianAndStdDev: function(a) {\n                    var b = twttr.reduce(a, 0, function(a, b, c) {\n                        return ((a + c));\n                    }), c = a.length, d = ((b / c)), e = twttr.reduce(a, 0, function(a, b, c) {\n                        return ((a + ((((c - d)) * ((c - d))))));\n                    }), f = Math.sqrt(((e / c)));\n                    return {\n                        median: d,\n                        stdDev: f\n                    };\n                },\n                scribe: function(a, b) {\n                    ((twttr.is.def(this._scribbler) || (this._scribbler = twttr.Scribbler.global.spawn({\n                        context: \"typeahead\"\n                    }), this._scribbler.component = {\n                    }))), this._scribbler.scribe(a, b);\n                },\n                browserInfo: function() {\n                    var a = \"unknown\";\n                    return (($.browser.webkit ? a = \"webkit\" : (($.browser.msie ? a = \"msie\" : (($.browser.mozilla ? a = \"mozilla\" : (($.browser.JSBNG__opera && (a = \"JSBNG__opera\"))))))))), {\n                        browser: a,\n                        version: $.browser.version\n                    };\n                },\n                scribeLocalStorageLatency: function(a, b, c) {\n                    var d = this.browserInfo();\n                    this.scribe(\"typeahead_localstorage_latency\", {\n                        type: b,\n                        latency: c,\n                        browser: d.browser,\n                        version: d.version\n                    });\n                },\n                scribeSelect: function(a, b, c) {\n                    var d = this._statsCumulativeTime, e = ((((a.type === \"click\")) ? \"click\" : \"enter\")), f = ((c.length > 0)), g = ((c.data(\"remote\") === !0)), i = \"unknown\";\n                    ((c.data(\"query\") ? i = \"saved search\" : ((c.JSBNG__find(\"a\").data(\"search-query\") ? i = \"query suggestion\" : ((c.data(\"user-id\") && (i = \"users\")))))));\n                    var j = ((((this.$node.JSBNG__find(\".js-selectable\").index(c) + 1)) || 0)), k = this.medianAndStdDev(this._localLatencies), l = this.medianAndStdDev(this._remoteLatencies), m = ((((((twttr && twttr.users)) && twttr.users.typeahead)) ? twttr.users.typeahead.length : 0)), n;\n                    try {\n                        n = JSON.stringify(JSBNG__localStorage).length;\n                    } catch (o) {\n                        n = 0;\n                    };\n                ;\n                    this.scribe(\"typeahead_select\", {\n                        time_to_completion: d,\n                        keystrokes_to_completion: this._keystrokes,\n                        item_count: f.toString(),\n                        item_details: i,\n                        index: j,\n                        query: b,\n                        was_remote: g.toString(),\n                        local_latency_median: k.median,\n                        local_latency_std_dev: k.stdDev,\n                        remote_latency_median: l.median,\n                        remote_latency_std_dev: l.stdDev,\n                        click_or_enter: e,\n                        local_storage_size: n,\n                        users_in_local_storage: m,\n                        people_from_api: ((twttr.caches.User.get(\"typeahead_people_from_api\") || 0)),\n                        people_followed: twttr.caches.User.get(\"typeahead_people_followed\"),\n                        profile_visits: twttr.caches.User.get(\"typeahead_profile_visits\"),\n                        people_blocked: twttr.caches.User.get(\"typeahead_people_blocked\"),\n                        people_unblocked: twttr.caches.User.get(\"typeahead_people_unblocked\")\n                    }), this.resetStatsTimer(), this._keystrokes = 0;\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/discoveryHelper\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.discoveryHelper\", function(a) {\n            return a.methods({\n                pagePathFor: function(a, b, c) {\n                    return twttr.router[((((a + ((b || \"\")))) + \"Path\"))](c);\n                },\n                routePageTo: function(a, b, c) {\n                    twttr.router.routeTo(this.pagePathFor(a, b, c));\n                },\n                localizeQuery: function(a, b) {\n                    return ((b.lang && (a.lang = b.lang))), ((b.country && (a.country = b.country))), ((b.city && (a.city = b.city))), a.top_tweets = !0, a;\n                }\n            }), a;\n        }), a(twttr.mixins.discoveryHelper);\n    });\n});\nprovide(\"mixins/usesRelatedResults\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.usesRelatedResults\", function(a) {\n            return a.methods({\n                _conversationRoleFor: function(a) {\n                    return a.annotations.ConversationRole;\n                },\n                tweetsForConversationRole: function(a, b) {\n                    var c = this, d = twttr.filter(a.results.array, function(a) {\n                        return ((c._conversationRoleFor(a) === b));\n                    });\n                    return twttr.map(d, function(a) {\n                        return a.value;\n                    });\n                },\n                _groupNamed: function(a, b) {\n                    return twttr.filter(a.array, function(a) {\n                        return ((a.groupName === b));\n                    })[0];\n                },\n                conversationGroupFor: function(a) {\n                    return this._groupNamed(a, \"TweetsWithConversation\");\n                },\n                withRelatedResults: function(a, b, c) {\n                    var d = this;\n                    twttr.API.Status.related(a.id, {\n                        include_entities: 1,\n                        success: function(b) {\n                            d._logResultGroups(b, a), c.success(b);\n                        },\n                        error: ((c.error || function() {\n                        \n                        }))\n                    });\n                },\n                _logResultGroups: function(a, b) {\n                    var c = this, d = (((((((((new JSBNG__Date).getTime() + \"-\")) + ((twttr.currentUser ? twttr.currentUser.id : \"guest\")))) + \"-\")) + b.id)), e = [], f = {\n                        related_impression_id: d,\n                        groups: e\n                    }, g;\n                    $.each(a.array, function(a, b) {\n                        var f = [], i = [];\n                        e.push(c._scribeDataFor(b, a)), ((g || (g = c._abDataFor(b)))), b.sync(\"relatedImpressionId\", d);\n                    }), scribble(\"show-related-tweets\", f), ((g && scribble(\"show-related-tweets\", g, \"www_ab_testing\")));\n                },\n                _scribeDataFor: function(a, b) {\n                    var c = {\n                        pos: b,\n                        groupName: a.groupName,\n                        resultType: a.resultType,\n                        annotations: this._annotationsFor(a),\n                        tweets: this._tweetsFor(a)\n                    };\n                    return a.sync(\"relatedGroupName\", a.groupName), c;\n                },\n                _abDataFor: function(a) {\n                    var b;\n                    for (var c in a.annotations) {\n                        ((((c == \"abData\")) && ((b || (b = a.annotations[c])))));\n                    ;\n                    };\n                ;\n                    if (b) {\n                        for (var d in b) {\n                            a.sync(((\"ab_data_\" + d)), b[d]);\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return b;\n                },\n                _annotationsFor: function(a) {\n                    var b = [], c = \"\";\n                    for (var d in a.annotations) {\n                        if (((d != \"abData\"))) {\n                            var e = {\n                                type: d,\n                                value: a.annotations[d]\n                            };\n                            b.push(e), c += ((a.annotations[d] + \" \"));\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    return ((((c.length > 0)) && (c = c.substring(0, ((c.length - 1)))))), a.sync(\"relatedAnnotations\", c), b;\n                },\n                _tweetsFor: function(a) {\n                    var b = [];\n                    return $.each(a.results.array, function(c, d) {\n                        ((((a.resultType == \"Tweet\")) && b.push(d.value.id)));\n                    }), b;\n                }\n            }), a;\n        }), a(twttr.mixins.usesRelatedResults);\n    });\n});\nprovide(\"mixins/profileHelper\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.profileHelper\", function(a) {\n            return a.methods({\n                getUserInfo: function(a, b, c, d) {\n                    c = ((c || {\n                    })), this._screenName = ((a ? a.toLowerCase() : a));\n                    var e;\n                    ((((((c.batch === !0)) && twttr.decider.isAvailable(\"profile_combined_api\"))) ? e = twttr.API.User.findForProfile : e = twttr.API.User.JSBNG__find)), e.call(twttr.API.User, this._screenName, {\n                        success: twttr.bind(this, function(a) {\n                            this.profileUser = twttr.profileUser = a, ((b && b()));\n                        }),\n                        error: twttr.bind(this, function(a) {\n                            signal(\"\\u003EwokeUp\"), ((((a.JSBNG__status == 403)) ? ((twttr.isT1 ? twttr.app.switchToPage(\"403\").send(\"suspendedUser\") : twttr.Router.performRedirect(twttr.router.suspendedPath()))) : this.trigger(\"notFound\"))), ((d && d()));\n                        })\n                    });\n                },\n                _isSocialContextAvailable: function() {\n                    return ((((twttr.decider.isAvailable(\"social_context\") && twttr.loggedIn)) && ((twttr.currentUser.id != twttr.profileUser.id))));\n                },\n                _defaultedScreenName: function(a) {\n                    return ((((!a && twttr.loggedIn)) ? twttr.currentUser.screenName : a));\n                },\n                _addPromotedData: function() {\n                    ((((twttr.promotedAccountStore.hasAccount() && ((twttr.promotedAccountStore.getAccount().id == this.profileUser.id)))) && (this.profileUser = twttr.API.util.PromotedStore.getPromotedUserInstance(this.profileUser, twttr.promotedAccountStore.getAccount().impressionId), twttr.promotedAccountStore.clear())));\n                },\n                noAutoRender: !0\n            }).addViewData(function() {\n                return {\n                    profile_user: new twttr.views.ProfileUser(twttr.profileUser)\n                };\n            }), a;\n        }), a(twttr.mixins.profileHelper);\n    });\n});\nprovide(\"mixins/commonDashboardClickHandlers\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.commonDashboardClickHandlers\", function(a) {\n            return a.click({\n                \".title-link\": function(b, c) {\n                    var d = {\n                        input: \"click\",\n                        component: \"dashboard\",\n                        subcomponent: a._name,\n                        target: \"dashboard_title\",\n                        item: c.JSBNG__find(\".dashboard-component-title\").html()\n                    };\n                    scribble(\"dashboard_click\", d);\n                },\n                \".user-profile-link\": function(b, c) {\n                    var d = ((c.is(\"img\") || c.JSBNG__find(\"img\")[0])), e = ((c.attr(\"data-user-id\") || c.closest(\"a\").attr(\"data-user-id\"))), f = {\n                        input: \"click\",\n                        component: \"dashboard\",\n                        subcomponent: a._name,\n                        target: \"user_profile_link\",\n                        target_type: ((d ? \"image\" : \"link\")),\n                        profile_id: e\n                    };\n                    scribble(\"dashboard_click\", f);\n                }\n            }), a;\n        }), a(twttr.mixins.commonDashboardClickHandlers);\n    });\n});\nprovide(\"mixins/t1/cardActionable\", function(a) {\n    using(\"constants\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.cardActionable\", function() {\n            this.methods({\n                registerCardActions: function() {\n                    var a = this;\n                    a.$node.delegate(\".js-action-card-search\", \"click\", function(b) {\n                        var c = a._getCardQuery(this);\n                        a._scribeCardAction(\"search\", ((\"card_\" + a._getElementCardType(this))), {\n                            query: a._getCardQuery(this),\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    }), a.$node.delegate(\".js-action-card-news\", \"click\", function(b) {\n                        var c = a._getCardQuery(this);\n                        a._scribeCardAction(\"open_link\", \"card_news\", {\n                            url: $(this).attr(\"href\"),\n                            query: c,\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        }), b.stopPropagation();\n                    }), a.$node.delegate(\".js-action-card-expandtweets\", \"simpleExpandoContract\", function(b) {\n                        var c = a._getCardQuery(this);\n                        a._scribeCardAction(\"deselect\", \"card_news\", {\n                            query: c,\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    }), a.$node.delegate(\".js-action-card-expandtweets\", \"simpleExpandoExpand\", function(b) {\n                        var c = a._getCardQuery(this);\n                        a._scribeCardAction(\"select\", \"card_news\", {\n                            query: c,\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    }), a.$node.delegate(\".js-action-card-tweetlink\", \"click\", function(b) {\n                        var c = a._getCardQuery(this), d = a._getStreamItemId(this);\n                        a._scribeCardAction(\"compose_tweet\", \"card_news\", {\n                            url: d,\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    }), a.$node.delegate(\".js-action-card-permalink\", \"click\", function(b) {\n                        var c = a._getCardTweetId(this);\n                        a._scribeCardAction(\"permalink\", \"card_tweet\", {\n                            item_count: 1,\n                            item_ids: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    }), a.$node.delegate(\".js-action-profile\", \"click\", function(b) {\n                        var c = a._getCardTweetId(this);\n                        a._scribeCardAction(\"profile_click\", \"card_tweet\", {\n                            item_count: 1,\n                            item_ids: [c,],\n                            item_details: a._getCardItemDetails(this, c, a._getElementUserId(this))\n                        });\n                    }), a.$node.delegate(\".js-action-card-media\", \"click\", function(b) {\n                        var c = a._getCardQuery(this);\n                        a._scribeCardAction(\"click\", ((a._getCardMediaType(this) + \"_card_topic\")), {\n                            query: c,\n                            item_names: [c,],\n                            item_details: a._getCardItemDetails(this, c)\n                        });\n                    });\n                },\n                _scribeCardAction: function(a, b, c) {\n                    trackClient({\n                        action: a,\n                        component: b\n                    }, c);\n                },\n                _getCardAttribute: function(a, b) {\n                    var c = $(a).closest(\".js-story-item\");\n                    return c.attr(b);\n                },\n                _getElementUserId: function(a) {\n                    var b = $(a).closest(\".js-actionable-tweet\");\n                    return b.attr(\"data-user-id\");\n                },\n                _getCardTweetId: function(a) {\n                    return this._getCardAttribute(a, \"data-tweet-id\");\n                },\n                _getCardQuery: function(a) {\n                    return this._getCardAttribute(a, \"data-query\");\n                },\n                _getStreamItemId: function(a) {\n                    var b = $(a).closest(\".js-stream-item\");\n                    return b.attr(\"data-item-id\");\n                },\n                _getElementCardType: function(a) {\n                    return this._getCardAttribute(a, \"data-story-type\");\n                },\n                _getCardMediaType: function(a) {\n                    return this._getCardAttribute(a, \"data-card-media-type\");\n                },\n                _getCardItemPosition: function(a, b) {\n                    var c = $(a).closest(\"div.js-stream-items\"), d;\n                    return ((c.length && c.JSBNG__find(\"[data-query]\").each(function(a) {\n                        var c = $(this), e = c.attr(\"data-query\");\n                        if (((((b + \"\")) == e))) {\n                            return d = a, !1;\n                        }\n                    ;\n                    ;\n                    }))), d;\n                },\n                _getCardItemDetails: function(a, c, d) {\n                    var e = {\n                    }, f = {\n                        item_type: b.constants.clientEvent.itemType.story,\n                        item_description: this._getElementCardType(a),\n                        item_position: this._getCardItemPosition(a, c)\n                    };\n                    return ((d && (f.target_id = d))), e[((\"\" + c))] = f, e;\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/t1/discoveryStoryHelpers\", function(a) {\n    using(\"_\", \"constants\", \"util\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.discoverySearchHelper\", function(a) {\n            this.methods({\n                formatted_tweet_count_text: function() {\n                    return _(\"{{count}} Tweets\", {\n                        count: b.util.formatNumber(this.tweet_count, twttr.pageLocale)\n                    });\n                },\n                story_name: function() {\n                    return ((this.JSBNG__name || this.query));\n                },\n                is_hashtag: function() {\n                    return ((this.story_name().substring(0, 1) === \"#\"));\n                },\n                search_path: function() {\n                    return twttr.router.searchResultsPath({\n                        query: decodeURIComponent(this.query)\n                    });\n                },\n                search_query_source: function() {\n                    return twttr.search.searchQuerySource.TREND;\n                }\n            });\n        }), d = twttr.klass.mixin(\"twttr.mixins.discoveryMediaRenderHelper\", function(a) {\n            this.methods({\n                escaped_query: function() {\n                    return escape(((this.id || this.query)));\n                },\n                afterHtml: function() {\n                    if (!this.has_media) {\n                        return;\n                    }\n                ;\n                ;\n                    var a = this;\n                    JSBNG__setTimeout(function() {\n                        var b = (new JSBNG__Date).getTime(), c = a.escaped_query(), d = $(((((\"div.js-story-item[data-query='\" + c)) + \"']\")));\n                        d.JSBNG__find(\"div.js-story-load-status\").show();\n                        var e = d.JSBNG__find(\"img.js-story-media\").error(function(b) {\n                            ((twttr.decider.isAvailable(\"t1d_scribe_errors\") && a._scribe(\"error\", {\n                                id: c,\n                                url: a.image_url\n                            }))), d.removeClass(\"js-loading loading\"), d.addClass(\"js-nomedia nomedia\");\n                        }).load(function() {\n                            ((twttr.decider.isAvailable(\"t1d_scribe_times\") && a._scribe(\"complete\", {\n                                id: c,\n                                time: (((new JSBNG__Date).getTime() - b)),\n                                url: a.image_url\n                            }))), d.removeClass(\"js-loading loading\");\n                        });\n                        e.attr(\"src\", a.image_url);\n                    }, 0);\n                },\n                _scribe: function(a, b) {\n                    trackClient({\n                        action: a,\n                        component: this.scribeComponent\n                    }, b);\n                }\n            });\n        });\n        a(c, d);\n    });\n});\nprovide(\"mixins/UserSimilaritiesStreamT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.UserSimilaritiesStreamT1\", function() {\n            this.methods({\n                _setTitle: function(a) {\n                    ((twttr.helpers.isCurrentUser(twttr.profileUser.screenName) ? a(_(\"Similar to you\")) : a(_(\"Similar to {{full_name}}\", {\n                        full_name: twttr.profileUser.JSBNG__name\n                    }))));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/SuggestionCategoriesStreamT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.SuggestionCategoriesStreamT1\", function() {\n            this.methods({\n                itemViewClass: \"StreamInterestCategory\",\n                sampleSize: \"large\",\n                addTipsies: function() {\n                    this.$find(\".js-user-tipsy\").tipsy({\n                        gravity: \"s\"\n                    });\n                },\n                _setHeader: function(a, b) {\n                    b.header_help = _(\"Select topics you&rsquo;re interested in. Follow people you want to hear from.\"), b.placeholder = _(\"Search for a topic, full name, or @username\");\n                    var c = new twttr.components.t1.PeopleSearchStreamHeader(twttr.router.whoToFollowInterestsSearchPath, b);\n                    a(c.$node);\n                },\n                _setTitle: function(a) {\n                    a(_(\"Browse categories\"));\n                },\n                _getStreamEndComponent: function() {\n                    return new twttr.components.StreamEnd(this._getStreamEndHtml(), this._getStreamEndShowBird());\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/SuggestionCategoryMembersStreamT1\", function(a) {\n    using(\"helpers\", \"mixins/hasGovernmentSearchHeader\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.SuggestionCategoryMembersStreamT1\", function() {\n            this.mixin(b.mixins.hasGovernmentSearchHeader), this.methods({\n                _setTitle: function(a) {\n                    a(this.category.JSBNG__name);\n                },\n                _setViewToggler: function(a) {\n                    var b = {\n                        route: twttr.router.whoToFollowInterestsPath(),\n                        JSBNG__name: _(\"View all categories\")\n                    };\n                    a(new twttr.views.BackLink(b));\n                },\n                _getStreamEndComponent: function() {\n                    return new twttr.components.StreamEnd(this._getStreamEndHtml(), this._getStreamEndShowBird());\n                },\n                _showGovernmentSearchHeader: function() {\n                    return ((((twttr.abdecider.choose(\"government_sul_your_reps_195\") !== \"show_in_government_sul\")) ? !1 : ((this.category.slug === ((twttr.isLocalhost ? \"celebrities\" : \"government\"))))));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/UserRecommendationsT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.UserRecommendationsT1\", function() {\n            this.methods({\n                getRecPosition: function(a) {\n                    var b;\n                    return this.$find(\".js-account-summary\").each(function(c, d) {\n                        if (((a.attr(\"data-user-id\") == $(d).attr(\"data-user-id\")))) {\n                            return b = c, !1;\n                        }\n                    ;\n                    ;\n                    }), b;\n                },\n                LIST_ITEM_SELECTOR: \".js-recommended-followers \\u003E .js-actionable-user\",\n                _generateUserList: function(a) {\n                    return $(((((\"\\u003Cdiv class=\\\"js-recommended-followers flex-module-inner\\\" data-section-id=\\\"wtf\\\"\\u003E\" + (new twttr.views.UserSmallList(a)).html())) + \"\\u003C/div\\u003E\")));\n                },\n                _removeRefreshLink: function() {\n                    this.$find(\"a.js-refresh-suggestions\").parent(\"span\").remove();\n                },\n                _getModuleViewName: function() {\n                    return ((this.screenName ? \"DashboardUserSimilarities\" : \"DashboardUserRecommendations\"));\n                },\n                _shouldHaveSpacer: function() {\n                    return !1;\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/hasGovernmentSearchHeader\", function(a) {\n    using(\"helpers\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.hasGovernmentSearchHeader\", function() {\n            this.methods({\n                _setHeader: function(a) {\n                    var c = this;\n                    if (this._showGovernmentSearchHeader()) {\n                        var d = (new twttr.views.GovernmentAccountSearch({\n                            zip_code: ((((this.params && this.params.zipCode)) || \"\"))\n                        })).$html();\n                        b.helpers.addFormEvents(d.JSBNG__find(\".js-government-account-search\"), function(a, b) {\n                            c.trigger(\"governmentSearch\", [b.zip,]);\n                        }), a(d);\n                    }\n                     else a();\n                ;\n                ;\n                },\n                _showGovernmentSearchHeader: function() {\n                    return !0;\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/prefollowingStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.prefollowingStream\", function(a) {\n            return a.methods({\n                deferredFollows: {\n                },\n                preFollows: {\n                },\n                userActionPrefollow: function(a) {\n                    var b = twttr.helpers.getUserId(a);\n                    this.preFollows[b] = !0, this.userActionFollow(a);\n                },\n                userActionFollow: function(a) {\n                    var b = this, c = twttr.helpers.getUserId(a);\n                    ((this.deferFollows ? (this.deferredFollows[c] = !0, twttr.API.User.trigger(\"prefollow_before\"), twttr.API.User.JSBNG__find(c, function(c) {\n                        b.updateButtonFollow(a, c[\"protected\"]), twttr.API.User.trigger(((c[\"protected\"] ? \"prefollow_request_success\" : \"prefollow_success\")), c);\n                    })) : this.constructor.uber.userActionFollow.apply(this, arguments)));\n                },\n                userActionUnfollow: function(a) {\n                    var b = twttr.helpers.getUserId(a);\n                    ((((this.deferFollows && this.deferredFollows[b])) ? (delete this.deferredFollows[b], twttr.API.User.trigger(\"unprefollow_before\"), twttr.API.User.JSBNG__find(b, function(a) {\n                        twttr.API.User.trigger(\"unprefollow_success\", a);\n                    }), ((this.preFollows[b] && (delete this.preFollows[b], this.scribbler.scribe({\n                        action: \"unprefollow\"\n                    }, {\n                        item_ids: [((\"\" + b)),],\n                        item_count: 1\n                    }))))) : this.constructor.uber.userActionUnfollow.apply(this, arguments)));\n                },\n                commitPrefollows: function(a) {\n                    var b = this, c = [], d = [], e = 0;\n                    for (var f in this.deferredFollows) {\n                        c.push(f);\n                    ;\n                    };\n                ;\n                    for (var f in this.preFollows) {\n                        d.push(f);\n                    ;\n                    };\n                ;\n                    if (((c.length == 0))) {\n                        a();\n                        return;\n                    }\n                ;\n                ;\n                    this.scribbler.scribe({\n                        action: \"prefollow\"\n                    }, {\n                        item_ids: d,\n                        item_count: d.length\n                    }), twttr.currentUser.friends.followAll(c, {\n                        stringifiedIds: !0,\n                        success: function(_, c) {\n                            for (var d = 0; ((d < c.response.length)); ++d) {\n                                var e = c.response[d];\n                                b.scribbler.scribe({\n                                    action: \"follow\"\n                                }, {\n                                    item_ids: [((\"\" + e.id)),],\n                                    item_count: 1\n                                });\n                            };\n                        ;\n                            a();\n                        },\n                        error: function() {\n                            twttr.currentUser.friendsCount += c.length, a();\n                        }\n                    }), this.deferFollows = !1, this.deferredFollows = {\n                    }, this.preFollows = {\n                    };\n                }\n            }), a;\n        }), a(twttr.mixins.prefollowingStream);\n    });\n});\nprovide(\"streams/StarterList\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.streams.StarterList\", function(a, b) {\n            twttr.streams.ListMembers.apply(this, arguments);\n        }).subclassOf(twttr.streams.ListMembers).mixin(twttr.mixins.discoveryHelper).methods({\n            update: function(a) {\n                this.params.list.members(a);\n            },\n            _setTitle: function(a) {\n                a(_(\"{{name}} suggests you also follow these accounts:\", this.params.list.user.attributes));\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"Sorry, {{name}} doesn't recommend anybody in particular.\\u003Cbr /\\u003EFind users by \\u003Ca href='{{url}}'\\u003EInterests\\u003C/a\\u003E.\", {\n                    url: this.pagePathFor(this.params.pathRoot, \"Interests\"),\n                    JSBNG__name: this.params.list.user.JSBNG__name\n                });\n            }\n        }), a(twttr.streams.StarterList);\n    });\n});\nprovide(\"streams/StarterFriends\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.StarterFriends\", function() {\n            twttr.streams.UserStream.apply(this, arguments);\n        }).subclassOf(twttr.streams.UserStream).methods({\n            update: function(a) {\n                var b = this;\n                twttr.API.User.JSBNG__find(this.screenName, function(c) {\n                    if (!twttr.helpers.canViewUser(c)) {\n                        b._showError(twttr.streams.PROTECTED), b.doneLoadingMore();\n                        return;\n                    }\n                ;\n                ;\n                    c.friends(a);\n                });\n            },\n            _setTitle: function(a) {\n                a(_(\"@{{screen_name}} follows these accounts:\", {\n                    screen_name: this.screenName\n                }));\n            }\n        }).statics({\n            _deciderKey: \"people_stream_friends\"\n        }), a(twttr.streams.StarterFriends);\n    });\n});\nprovide(\"streams/UserRecommendationsStream\", function(a) {\n    using(\"_\", \"streams/UserStream\", \"mixins/userRecommendationsHelper\", \"mixins/userActionable\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.streams.UserRecommendationsStream\", function(a, c, d) {\n            b.streams.UserStream.call(this, a, c), ((c && (this._processLoadedUsers(c), ((a.cursor && (this.cursor = a.cursor)))))), this.whotofollowComponentName = \"whotofollow_stream\", this.registerUserRecommendationsActions();\n        }).subclassOf(b.streams.UserStream).mixin(b.mixins.userRecommendationsHelper, b.mixins.userActionable).methods({\n            afterFirstSwitchingTo: function(a) {\n                ((((this.items && this.items.length)) ? (a(this, twttr.streams.SUCCESS), this.render()) : this.getMoreOldItems(a)));\n            },\n            _processLoadedUsers: function(a, b) {\n                ((a && this.doneLoadingMore()));\n                var c = \"whotofollow_view_all_recommended_users\", d = ((this.params.inWelcomeFlow ? \"welcome_flow\" : \"find_users\")), e = {\n                    tracking_context: d\n                };\n                return ((b && (e.error_status = b.JSBNG__status))), this.trackImpressions(a, c, e), a;\n            },\n            loadRecommendedUsers: function(a) {\n                a.personalized = ((((a.personalized || this.params.personalized)) || !1)), a.force_bq = a.personalized, a.algorithm = ((((a.algorithm || this.params.algorithm)) || \"\")), a.connections = !0;\n                if (this.params.inWelcomeFlow) {\n                    var b = twttr.abdecider.choose(\"wtf_welcome_persistent_100\"), c = ((b && b.match(/bucket(\\d+)/))), d = ((c ? c[1] : 0));\n                    a.high_timeout = !0, a.display_location = \"welcome-flow-recommendations\", a.bucket_id = d;\n                }\n            ;\n            ;\n                ((twttr.decider.isAvailable(\"wtf_visited_users\") && (a.related_users = twttr.recentlyViewedUsers.stack.concat(twttr.loggedOutViewedUsers.stack)))), ((((a.cursor === undefined)) && (a.cursor = -1)));\n                var e = this, f = a.success;\n                a.success = function(a, b) {\n                    e.hadBqResults = b.response.had_bq_results;\n                    var c = e.recsToUsers(a);\n                    f(c, b);\n                }, ((twttr.loggedIn ? twttr.currentUser.recommendedUsers2(a) : twttr.API.User.recommendedUsers2(a)));\n            },\n            update: function(a) {\n                var b = this, c = a.success, d = a.error, e = function() {\n                    var a = {\n                        success: function(a, d) {\n                            a = b._processLoadedUsers(a), c(a, d);\n                        }\n                    };\n                    ((b.params.lang && (a.lang = b.params.lang))), ((b.params.country && (a.country = b.params.country))), ((b.params.city && (a.city = b.params.city))), a.bypass_cache = !0, twttr.API.SuggestionCategory.randomSample(a), b.sulFallback = !0, ((b._streamManager && b._streamManager.setTitle(b)));\n                };\n                a.success = function(a, d) {\n                    a = b._processLoadedUsers(a);\n                    if (!a.length()) {\n                        if (((((twttr.decider.isAvailable(\"whotofollow_random_sample\") && ((b.params.useSulFallback !== !1)))) && ((!b.params.inWelcomeFlow || b.params.useSulFallback))))) {\n                            e();\n                            return;\n                        }\n                    ;\n                    ;\n                        b.trigger(\"noMoreRecommendations\");\n                    }\n                ;\n                ;\n                    b.sulFallback = !1, c(a, d), ((b._streamManager && b._streamManager.setTitle(b)));\n                }, a.error = function(a) {\n                    b._processLoadedUsers(null, a), ((d && d(a)));\n                }, ((((((((a.cursor == -1)) && twttr.decider.isAvailable(\"promoted_accounts_in_whotofollow_viewall\"))) && !b.params.inWelcomeFlow)) && (a.pc = !b.params.noPromotedContent, a.display_location = \"wtf-view-all-stream\"))), ((((this.params.sulWithNoFollows && ((twttr.currentUser.friendsCount == 0)))) ? e() : this.loadRecommendedUsers(a)));\n            },\n            setStreamManager: function(a) {\n                this._streamManager = a;\n            },\n            _setTitle: function(a) {\n                if (((this.params.invisibleWhenEmpty && ((!this.items || ((this.items.length == 0))))))) {\n                    a(\"\");\n                    return;\n                }\n            ;\n            ;\n                if (twttr.is.def(this.params.title)) {\n                    a(this.params.title);\n                    return;\n                }\n            ;\n            ;\n                if (twttr.isT1) {\n                    a(_(\"Who to follow\"));\n                    return;\n                }\n            ;\n            ;\n                ((this.params.inWelcomeFlow ? a(_(\"Follow these people to get started:\")) : ((this.params.inHomePage ? (this.$find(\".stream-title\").css(\"border-bottom\", \"1px solid #EBEBEB\"), a(_(\"\\u003Cdiv class=\\\"wtf-timeline-title\\\"\\u003E\\u003Cdiv class=\\\"wtf-timeline-text\\\"\\u003EIt looks like you aren&#39;t following anyone yet.\\u003Cbr /\\u003E\\u003Cb\\u003EGo ahead and follow some people!\\u003C/b\\u003E\\u003C/div\\u003E\\u003Cbutton class=\\\"done-right button selected\\\" type=\\\"button\\\"\\u003EDone following\\u003C/button\\u003E\\u003C/div\\u003E\"))) : ((this.sulFallback ? a(_(\"We&#39;re building a list of personalized suggestions for you. In the meantime, here are some other \\u003Ca href=\\\"{{url}}\\\"\\u003Einteresting accounts\\u003C/a\\u003E to follow.\", {\n                    url: twttr.router.whoToFollowInterestsPath()\n                })) : a(_(\"Twitter accounts suggested for you based on who you follow and more.\"))))))));\n            },\n            _getEmptyStreamHtml: function() {\n                return ((((this.params.invisibleWhenEmpty && ((!this.items || ((this.items.length == 0)))))) ? \"\" : ((this.params.personalizedOnly ? _(\"We&#39;re sorry, Twitter does not have any personalized suggestions to show you at this time. You can browse our regular \\u003Ca href='{{url}}'\\u003EWho to Follow\\u003C/a\\u003E list.\", {\n                    url: twttr.router.whoToFollowPath()\n                }) : _(\"Sorry, we&#39;ve temporarily run out of recommendations for you. We're out there looking for more right now. Please check back soon!\")))));\n            },\n            _getStreamEndHtml: function() {\n                return ((this.params.inHomePage ? _(\"\\u003Cbutton class=\\\"done-right button selected\\\" type=\\\"button\\\"\\u003EDone following\\u003C/button\\u003E\\u003C/div\\u003E\") : _(\"\\u003Ca href='#' class='back-to-top'\\u003EBack to top &uarr;\\u003C/a\\u003E\")));\n            },\n            _getStreamEndShowBird: function() {\n                return ((this.params.inHomePage ? !1 : !0));\n            },\n            _trackNewImpressions: function() {\n            \n            }\n        });\n        ((twttr.isT1 && c.methods({\n            _setHeader: function(a, b) {\n                b.header_help = _(\"Twitter accounts suggested for you based on who you follow and more.\");\n                var c = new twttr.components.t1.PeopleSearchStreamHeader(twttr.router.whoToFollowSuggestionsSearchPath, b);\n                a(c.$node);\n            }\n        }))), a(twttr.streams.UserRecommendationsStream);\n    });\n});\nprovide(\"streams/UserRecommendationsDashboardStream\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.UserRecommendationsDashboardStream\", function(a, b) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", this.deferFollows = !!a.deferFollows, twttr.streams.UserRecommendationsStream.call(this, a, b);\n        }).subclassOf(twttr.streams.UserRecommendationsStream).mixin(twttr.mixins.prefollowingStream).methods({\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), a(twttr.streams.UserRecommendationsDashboardStream);\n    });\n});\nprovide(\"streams/UserSimilaritiesStream\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"mixins/UserSimilaritiesStreamT1\" : \"\"))).as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.UserSimilaritiesStream\", function(a, b) {\n            twttr.streams.UserStream.call(this, a, b), this.registerUserRecommendationsActions(), this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                profile_id: ((twttr.profileUser && twttr.profileUser.id)),\n                context: \"profile\"\n            })));\n        }).subclassOf(twttr.streams.UserStream).mixin(twttr.mixins.userRecommendationsHelper).methods({\n            update: function(a) {\n                var b = this, c = a.success, d = a.error, e = \"whotofollow_view_all_similar_users\", f = \"similar_to\";\n                a.success = function(a, d) {\n                    var g = b.recsToUsers(a);\n                    b.trackImpressions(g, e, {\n                        tracking_context: f\n                    }), c(g, d);\n                }, a.error = function(a) {\n                    b.trackImpressions(null, e, {\n                        tracking_context: f,\n                        error_status: a.JSBNG__status\n                    }), ((d && d(a)));\n                }, a.connections = !1, a.pc = !0, a.display_location = \"st-view-all-stream\", twttr.profileUser.similarUsers(a);\n            },\n            setStreamManager: function(a) {\n                this._streamManager = a;\n            },\n            _setTitle: function(a) {\n                a(_(\"Accounts similar to @{{screen_name}}:\", {\n                    screen_name: this.params.screenName\n                }));\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"Sorry, we've temporarily run out of users similar to @{{screen_name}}. We're out there looking for more right now. Please check back soon!\", {\n                    screen_name: this.params.screenName\n                });\n            },\n            _trackNewImpressions: function() {\n            \n            }\n        });\n        ((c && d.mixin(c))), a(twttr.streams.UserSimilaritiesStream);\n    });\n});\nprovide(\"streams/ContactImportMatches\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.streams.ContactImportMatches\", function(a, b, c) {\n            a.pathRoot = ((a.pathRoot || \"whoToFollow\")), twttr.streams.UserStream.apply(this, arguments), this.$node.addClass(\"contact-import-matches\"), ((a.noBigImages || (this.$node.addClass(\"contact-import-images\"), this.itemViewClass = \"MatchedContactUser\"))), this._loadedMatches = !1, this._loadingCount = 0, this._loadingComponent = new twttr.views.ContactImportLoading, this._followingCount = 0, this._showFollowing = !1, this.$headerNode = this.getHeaderContainer();\n            var d = this;\n            this.$headerNode.delegate(\".js-toggle-following\", \"click\", function(a) {\n                return d._toggleFollowing(), !1;\n            });\n        }).subclassOf(twttr.streams.UserStream).mixin(twttr.mixins.discoveryHelper).methods({\n            streamViewClass: \"ContactImportMatches\",\n            afterSwitchingToAgain: function(a) {\n                this.afterFirstSwitchingTo(a);\n            },\n            afterFirstSwitchingTo: function(a) {\n                twttr.API.User.bind(\"follow.ContactImportMatches\", twttr.bind(this, this._incrementFollowingCount)), twttr.API.User.bind(\"follow_request.ContactImportMatches\", twttr.bind(this, this._incrementFollowingCount)), twttr.API.User.bind(\"unfollow.ContactImportMatches\", twttr.bind(this, this._decrementFollowingCount)), ((this._loadedMatches || this.getMoreOldItems(a)));\n            },\n            beforeSwitchingAway: function() {\n                ((this._timeout && (window.JSBNG__clearTimeout(this._timeout), this._timeout = null))), twttr.API.User.unbind(\".ContactImportMatches\");\n            },\n            update: function(a) {\n                this._loadingError = !1;\n                var b = this, c = a.success, d = a.error;\n                a.success = function(a, d) {\n                    var e = !b._loadedMatches;\n                    b._loadedMatches = ((\"users\" in d.response));\n                    if (b.params.forceInviteInline) {\n                        return b._inviteOthersInline(), !1;\n                    }\n                ;\n                ;\n                    if (b._loadedMatches) {\n                        delete b._loadingComponent;\n                        if (d.response.count) {\n                            b.showInviteesPopup = ((!!d.response.others_count && ((b.params.pathRoot == \"welcome\"))));\n                            var f = twttr.merge(d.response, {\n                                retry_service_path: b.pagePathFor(b.params.pathRoot, \"Import\")\n                            });\n                            ((((d.response.following_count == d.response.count)) && (f.following_count = 0, b._showFollowing = !0))), ((e && b.scribbler.scribe({\n                                component: \"stream\",\n                                action: \"matches\"\n                            }))), b._followingCount = d.response.following_count, b._othersCount = d.response.others_count, b._matchesHeaderComponent = new twttr.components.ContactImportMatchesStats(b, f);\n                        }\n                         else ((e && b.scribbler.scribe({\n                            component: \"stream\",\n                            action: \"no_matches\"\n                        }))), ((d.response.others_count ? b._inviteOthersInline() : window.JSBNG__setTimeout(function() {\n                            b.routePageTo(b.params.pathRoot, \"Import\"), twttr.showMessage(_(\"There was no one in your address book\"));\n                        }, 0)));\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    c(a, d), ((((((((b._loadedMatches && b._followingCount)) && ((b.$node.parents(\".dashboard\").length == 0)))) && ((Math.abs(((((twttr.$doc.scrollTop() + twttr.windowHeight)) - twttr.$doc.height()))) < 500)))) && b.getMoreOldItems())), ((b._loadedMatches || ((((b._loadingCount++ < b.constructor._retryCount)) ? b._scheduleRetry() : (b.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"timeout\"\n                    }), b._loadingCount = 0, b._showError(twttr.streams.TIMEOUT))))));\n                }, a.error = function(a, c) {\n                    if (((a.error == \"denied\"))) {\n                        b.routePageTo(b.params.pathRoot, \"Import\"), twttr.showMessage(_(\"Authorization to access your contacts was denied\"));\n                        return;\n                    }\n                ;\n                ;\n                    ((a.error && (b._loadingError = !0))), b.trigger(\"error\"), d(a, c);\n                }, twttr.API.AddressBook.contactsMatches(a);\n            },\n            _scribeResults: function(a, b, c) {\n                if (((((a == \"initial\")) && !this._loadedMatches))) {\n                    return;\n                }\n            ;\n            ;\n                c = ((c || {\n                })), c.message = ((\"\" + this._othersCount)), twttr.streams.UserStream.prototype._scribeResults.apply(this, [a,b,c,]);\n            },\n            _toggleFollowing: function() {\n                this._showFollowing = !this._showFollowing;\n                for (var a = 0; ((a < this.items.length)); ++a) {\n                    var b = this.items[a];\n                    if (((b.following || b.followRequestSent))) {\n                        var c = this.$node.JSBNG__find(this.itemSelector(b.id));\n                        ((this._showFollowing ? c.fadeIn() : c.fadeOut()));\n                    }\n                ;\n                ;\n                };\n            ;\n                this._updateFollowingToggle();\n            },\n            _incrementFollowingCount: function(a, b) {\n                this._updateFollowing(b, !0);\n            },\n            _decrementFollowingCount: function(a, b) {\n                this._updateFollowing(b, !1);\n            },\n            _updateFollowing: function(a, b) {\n                for (var c = 0; ((c < this.items.length)); ++c) {\n                    var d = this.items[c];\n                    if (((d.id == a.id))) {\n                        this.items[c] = a;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                this._followingCount = Math.max(0, ((this._followingCount + ((b ? 1 : -1))))), ((this._showFollowing && this._updateFollowingToggle()));\n            },\n            _updateFollowingToggle: function() {\n                var a = {\n                    following_count: this._followingCount\n                }, b;\n                ((this._showFollowing ? b = _(\"Hide {{following_count}} following\", a) : b = _(\"Show {{following_count}} following\", a))), this.$headerNode.JSBNG__find(\".js-toggle-following\").text(b);\n            },\n            _followAll: function(a) {\n                var b = this;\n                if (a.hasClass(\"disabled\")) {\n                    return;\n                }\n            ;\n            ;\n                a.addClass(\"disabled\");\n                var c = {\n                    success: function(c, d) {\n                        a.removeClass(\"disabled\");\n                        var e = \"\";\n                        switch (c.followed_ids.length) {\n                          case 0:\n                            e = _(\"Requests were sent to everybody.\");\n                            break;\n                          case 1:\n                            e = _(\"Congratulations! You are now following 1 more user.\");\n                            break;\n                          default:\n                            e = _(\"Congratulations! You are now following {{count}} more users.\", {\n                                count: c.followed_ids.length\n                            });\n                        };\n                    ;\n                        twttr.showMessage(e), twttr.API.User.startBulkFollowing();\n                        var f = 0;\n                        twttr.API.User.findAllCached(c.followed_ids).each(function(a) {\n                            a.data(\"following\", !0), a.following = !0;\n                            var b = {\n                                requestParameters: [{\n                                    user_id: a.id\n                                },]\n                            };\n                            twttr.API.User.trigger(\"follow_before\", b), twttr.API.User.trigger(\"follow_success\", a), f++;\n                        }), twttr.API.User.findAllCached(c.requested_ids).each(function(a) {\n                            a.data(\"follow_request_sent\", !0), a.followRequestSent = !0;\n                            var b = {\n                                requestParameters: [{\n                                    user_id: a.id\n                                },]\n                            };\n                            twttr.API.User.trigger(\"follow_request_before\", b), twttr.API.User.trigger(\"follow_request_success\", a), f++;\n                        }), twttr.API.User.stopBulkFollowing(), b.scribbler.scribe({\n                            component: \"stream_header\",\n                            action: \"follow\"\n                        }, {\n                            item_count: c.followed_ids.length,\n                            item_ids: c.followed_ids,\n                            event_value: c.followed_ids.length,\n                            event_info: \"follow_all\",\n                            context: \"import\"\n                        }), b.scribbler.scribe({\n                            component: \"stream_header\",\n                            action: \"follow_all\"\n                        }, {\n                            item_count: c.followed_ids.length,\n                            event_value: c.followed_ids.length,\n                            context: \"import\"\n                        }), b._followingCount += ((((c.followed_ids.length + c.requested_ids.length)) - f)), ((this._showFollowing && this._updateFollowingToggle()));\n                    },\n                    error: function(b) {\n                        a.removeClass(\"disabled\"), twttr.showError(_(\"There was an error following your contacts.\"));\n                    }\n                };\n                twttr.API.AddressBook.followAllContacts(c);\n            },\n            _saveAsList: function() {\n                var a = this;\n                (new twttr.widget.ListDialog({\n                    template: {\n                        JSBNG__content: (new twttr.views.ListDialog({\n                            JSBNG__name: _(\"Friends\"),\n                            mode: \"private\"\n                        })).html()\n                    },\n                    JSBNG__onSuccess: function(b) {\n                        options = {\n                            success: function(b, c) {\n                                twttr.API.User.findAllCached(b).each(function(b) {\n                                    ((a.isDuplicate(b) && a.rerenderItem(b.id, b)));\n                                }), a.scribbler.scribe({\n                                    component: \"stream_header\",\n                                    action: \"save_list\"\n                                }, {\n                                    event_value: b.length,\n                                    item_count: b.length\n                                });\n                            },\n                            error: function() {\n                                twttr.showError(_(\"There was an error adding your contacts to the list.\"));\n                            }\n                        }, twttr.API.AddressBook.addContactsToList(b.id, options);\n                    }\n                })).open();\n            },\n            inviteOthers: function(a) {\n                ((a || this.scribbler.scribe({\n                    component: \"invite_contacts_link\",\n                    action: \"click\"\n                }))), this.showInviteesPopup = !1;\n                var b = this, c = {\n                    success: function(c, d) {\n                        b.scribbler.scribe({\n                            component: \"invite_contacts_dialog\",\n                            action: \"open\"\n                        }), b.inviteDialog = (new twttr.widget.InviteContactsDialog(d.response, {\n                            css: {\n                            },\n                            JSBNG__onSuccess: function() {\n                                this.close();\n                            },\n                            scribbler: b.scribbler,\n                            routeToHome: a\n                        })).open();\n                    }\n                };\n                twttr.API.AddressBook.contactsOthers(c);\n            },\n            _inviteOthersInline: function() {\n                this.showInviteesPopup = !1, this._suppressStreamEnd = !0;\n                var a = this, b = {\n                    success: function(b, c) {\n                        a.doneLoadingMore();\n                        var d = new twttr.components.InviteContacts(c.response, {\n                            scribbler: a.scribbler\n                        });\n                        a.scribbler.scribe({\n                            component: \"invite_contacts\",\n                            action: \"impression\"\n                        }), a.$node.JSBNG__find(\"div.stream-items\").append(d.$node), a._renderInviteHeader(b.length), a.reachedTheEnd();\n                    },\n                    error: function(b) {\n                        a.doneLoadingMore(), a._loadingError = !0, a._showError(twttr.streams.ERROR);\n                    }\n                };\n                twttr.API.AddressBook.contactsOthers(b), window.JSBNG__setTimeout(function() {\n                    a._loadingComponent = new twttr.views.ContactImportLoading, a.showLoadingSpinner();\n                }, 0);\n            },\n            _scheduleRetry: function() {\n                var a = this;\n                this._timeout = window.JSBNG__setTimeout(function() {\n                    a._timeout = null, a._loadingComponent = new twttr.views.ContactImportLoading, a.getMoreOldItems();\n                }, 5000), this.showLoadingSpinner();\n            },\n            _renderItemHtml: function(a) {\n                var b = twttr.streams.UserStream.prototype._renderItemHtml.call(this, a);\n                return ((((((!this._showFollowing && ((a.following || a.followRequestSent)))) && !this.selectedItem(a.id).length)) && (b = b.replace(/^<div /, \"\\u003Cdiv style='display:none' \")))), b;\n            },\n            _getStreamLoadingComponent: function() {\n                return ((this._loadingComponent || twttr.streams.UserStream.prototype._getStreamLoadingComponent.call(this)));\n            },\n            _getStreamErrorComponent: function(a) {\n                var b = ((this._loadingError ? _(\"There was an error loading your contacts.\") : _(\"Loading seems to be taking a while.\"))), c = new twttr.components.ContactImportErrorEnd(b), d = this;\n                return c.bind(\"tryImportAgain\", function(a) {\n                    d.routePageTo(d.params.pathRoot, \"Import\");\n                }), c;\n            },\n            _getHeaderComponent: function() {\n                return this._matchesHeaderComponent;\n            }\n        }).statics({\n            _deciderKey: \"contact_import_stream\",\n            _retryCount: 13\n        });\n        ((twttr.isT1 ? c.methods({\n            _setHeader: function(a, b) {\n                if (this.header) a(this.header.$node);\n                 else {\n                    var c = new twttr.views.ContactImportMatchesHeader(b);\n                    a(c.html());\n                }\n            ;\n            ;\n            },\n            _updateHeaderFromStream: function(a) {\n                ((this._matchesHeaderComponent && (this.header = this._matchesHeaderComponent, a.html(this._matchesHeaderComponent.$node))));\n            },\n            _renderInviteHeader: function(a) {\n                this.$headerNode.JSBNG__find(\".js-contact-import-header-placeholder\").html((new twttr.views.InviteContactsHeader({\n                    count: a\n                })).html());\n            },\n            getHeaderContainer: function() {\n                return ((this.streamManager ? this.streamManager.$headerContainer() : null));\n            },\n            _setTitle: function(a) {\n                a(_(\"Find friends\"));\n            },\n            _setViewToggler: function(a) {\n                a(new twttr.views.BackLink({\n                    route: twttr.router.whoToFollowImportPath(),\n                    JSBNG__name: _(\"Try another service\")\n                }));\n            }\n        }) : c.methods({\n            getHeaderContainer: function() {\n                return this.$node;\n            },\n            _setTitle: function(a) {\n                a(\"\");\n            },\n            _renderInviteHeader: function(a) {\n                (new twttr.views.InviteContactsHeader({\n                    count: a\n                })).render(this.$find(\".invite-contacts-component\"), \"prepend\"), twttr.helpers.handlePopupLinks(this.$node);\n            }\n        }))), a(twttr.streams.ContactImportMatches);\n    });\n});\nprovide(\"streams/DashboardContactImportMatches\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.DashboardContactImportMatches\", function(a, b) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", a.noBigImages = !0, twttr.streams.ContactImportMatches.apply(this, arguments);\n        }).subclassOf(twttr.streams.ContactImportMatches).methods({\n            _setHeader: function(a, b) {\n                ((this.header ? a(this.header.$node) : a(\"\")));\n            },\n            _updateHeaderFromStream: function(a) {\n                twttr.streams.ContactImportMatches.prototype._updateHeaderFromStream.apply(this, arguments), $(window).trigger(\"resize\");\n            },\n            itemViewClass: \"DashboardStreamUser\",\n            customHeaderView: \"DashboardContactImportMatchesStats\"\n        }), a();\n    });\n});\nprovide(\"streams/ContactImportServices\", function(a) {\n    using(\"externalOauthPopup\", ((twttr.isT1 ? \"mixins/ContactImportServicesT1\" : \"\"))).as(function(b, c, d) {\n        twttr.klass(\"twttr.streams.ContactImportServices\", function(a, c) {\n            a.pathRoot = ((a.pathRoot || \"whoToFollow\")), twttr.streams.Stream.apply(this, arguments);\n            var d = this;\n            this.$node.addClass(\"contact-import-services\"), this.$node.delegate(\".js-wipe-addressbook\", \"click\", function(a) {\n                (new twttr.widget.Prompt({\n                    modal: !0,\n                    draggable: !0,\n                    template: {\n                        container_id: \"wipe-addressbook\",\n                        title: _(\"Are you sure you want to remove your contacts? Who To Follow suggestions may become less relevant.\")\n                    },\n                    callback: function(a) {\n                        ((a && $.ajax({\n                            type: \"POST\",\n                            dataType: \"json\",\n                            url: \"/users/wipe_addressbook.json\",\n                            headers: {\n                                \"X-PHX\": !0\n                            },\n                            data: {\n                                authenticity_token: twttr.API.getConfig().postAuthenticityToken\n                            },\n                            success: function() {\n                                twttr.showMessage(_(\"Your contacts have been removed.\"));\n                            },\n                            error: function() {\n                                twttr.showMessage(_(\"Oops, we couldn't remove your contacts at this time.\"));\n                            }\n                        })));\n                    }\n                })).open();\n            }), this.$node.delegate(\"div.service-button, .js-service-row\", \"click\", function(c) {\n                var e = $(this), f = e.JSBNG__find(\".js-service-name\").attr(\"data-service-id\"), g = {\n                    query: f\n                };\n                ((e.hasClass(\"selected\") && (g.event_info = \"selected\"))), d.scribbler.scribe({\n                    component: \"stream\",\n                    action: \"launch_service\"\n                }, g), ((((e.attr(\"data-popup\") === \"true\")) ? b.externalOauthPopup({\n                    url: e.attr(\"data-url\"),\n                    width: e.attr(\"data-width\"),\n                    height: e.attr(\"data-height\"),\n                    callbackUrl: d.pagePathFor(a.pathRoot, \"ImportMatches\")\n                }) : window.open(e.attr(\"data-url\"), \"_blank\").JSBNG__focus())), ((d._matchesStreamKey ? d._streamManager.clearKeyFromCache(d._matchesStreamKey) : d._streamManager.clearFromCache(twttr.streams.ContactImportMatches, {\n                    pathRoot: a.pathRoot\n                }))), c.preventDefault();\n            });\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.discoveryHelper).methods({\n            setStreamManager: function(a) {\n                this._streamManager = a;\n            },\n            setMatchesStreamKey: function(a) {\n                this._matchesStreamKey = a;\n            },\n            update: function(a) {\n                ((this.params.lang && (a.lang = this.params.lang))), ((this.params.country && (a.country = this.params.country))), ((this.params.context && (a.context = this.params.context))), twttr.API.AddressBook.contactsServices(a);\n            },\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            _fetchItems: function(a) {\n                var b = this;\n                if (((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))) {\n                    a(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var c = {\n                    success: function(c, d) {\n                        b.push(c), b.reachedTheEnd();\n                        var e, f = twttr.map(c, function(a, b) {\n                            return ((a.matched_email && (e = a.matched_email))), a.id;\n                        }), g = {\n                            item_names: f,\n                            item_count: f.length\n                        };\n                        ((e && (g.message = e))), b.scribbler.scribe({\n                            component: \"stream\",\n                            action: \"results\"\n                        }, g), a(b, twttr.streams.SUCCESS);\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                    }\n                };\n                this.update(c);\n            },\n            _renderItemsHtml: function(a) {\n                var b = null;\n                for (var c = 0; ((c < a.length)); ++c) {\n                    ((a[c].matched_email && (b = a[c])));\n                    var d = a[c].name_template;\n                    ((((d && twttr.views[d])) && (a[c].html_name = (new twttr.views[d]).html())));\n                };\n            ;\n                return ((((this.params.JSBNG__onlyMatched && b)) && (a = [b,]))), (new twttr.views.ContactImportServicesVertical({\n                    services: a,\n                    matched_service: b,\n                    matched_service_name: ((b || {\n                    })).JSBNG__name,\n                    in_welcome_flow: this.params.inWelcomeFlow\n                })).html();\n            },\n            _setTitle: function(a) {\n                ((((twttr.abdecider.choose(\"timeline_copy_317\") === \"stream\")) ? a(_(\"Search the services you use to discover which of your friends are already using Twitter. Follow any of the friends you find to add their Tweets to your stream.\")) : a(_(\"Search the services you use to discover which of your friends are already using Twitter. Follow any of the friends you find to add their Tweets to your timeline.\"))));\n            },\n            _getStreamEndComponent: function() {\n                return null;\n            }\n        }).statics({\n            _deciderKey: \"contact_import_stream\"\n        }), ((d && twttr.streams.ContactImportServices.mixin(twttr.mixins.ContactImportServicesT1))), a(twttr.streams.ContactImportServices);\n    });\n});\nprovide(\"mixins/ContactImportServicesT1\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.ContactImportServicesT1\", function() {\n            this.methods({\n                _setHeader: function(a, b) {\n                    b.header_help = _(\"Search your contacts for friends already on Twitter, or invite them via email.\");\n                    var c = new twttr.components.t1.PeopleSearchStreamHeader(twttr.router.whoToFollowImportSearchPath, b);\n                    a(c.$node);\n                },\n                _setTitle: function(a) {\n                    a(_(\"Find friends\"));\n                },\n                _getStreamEndComponent: function() {\n                    return new twttr.components.StreamEndInviteFriends(this._getStreamEndHtml(), this._getStreamEndShowBird());\n                }\n            });\n        }), a(twttr.streams.ContactImportServicesT1);\n    });\n});\nprovide(\"streams/DashboardContactImportServices\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.DashboardContactImportServices\", function(a, b) {\n            a = ((a || {\n            })), twttr.streams.ContactImportServices.call(this, a, b);\n        }).subclassOf(twttr.streams.ContactImportServices).methods({\n            _setHeader: function(a, b) {\n                a(\"\");\n            }\n        }), a();\n    });\n});\nprovide(\"streams/TweetGameDashboardStream\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.TweetGameDashboardStream\", function(a, b) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", this.deferFollows = !!a.deferFollows, twttr.streams.UserStream.call(this, a, b);\n        }).subclassOf(twttr.streams.UserStream).mixin(twttr.mixins.prefollowingStream).methods({\n            update: function(a) {\n                a.success(new twttr.anywhere.api.util.BaseCollection, {\n                    response: {\n                    }\n                });\n            },\n            afterFirstSwitchingTo: function(a) {\n                ((((this.items && this.items.length)) && (a(this, twttr.streams.SUCCESS), this.render())));\n            },\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), a(twttr.streams.TweetGameDashboardStream);\n    });\n});\nprovide(\"StoredUserStack\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.StoredUserStack\", function(a, b) {\n            this.storageKey = a, ((b || (b = twttr.caches.User)));\n            var c = b.get(this.storageKey);\n            this.cache = ((c ? c.index : {\n            })), this.stack = ((c ? c.stack : [])), this.timestamps = ((((c && c.timestamps)) ? c.timestamps : {\n            }));\n        }).methods(twttr.EventProvider).statics({\n            MAX_SIZE: 10\n        }).methods({\n            push: function(a) {\n                if (!twttr.helpers.isCurrentUser(a)) {\n                    var b = ((a.id || a.toString()));\n                    ((twttr.is.def(this.cache[b]) && (this.stack = twttr.filter(this.stack, function(a) {\n                        return ((a != b));\n                    })))), this.cache[b] = this.stack.push(b), this.timestamps[b] = (new JSBNG__Date).getTime();\n                    if (((this.size() > twttr.StoredUserStack.MAX_SIZE))) {\n                        var c = this.stack.shift();\n                        delete this.timestamps[c], delete this.cache[c];\n                    }\n                ;\n                ;\n                    this.trigger(\"push\", b);\n                }\n            ;\n            ;\n                return this.save();\n            },\n            save: function() {\n                return twttr.caches.User.set(this.storageKey, {\n                    index: this.cache,\n                    stack: this.stack,\n                    timestamps: this.timestamps\n                }), this.size();\n            },\n            clear: function() {\n                this.cache = {\n                }, this.stack = [], this.timestamps = {\n                }, this.save();\n            },\n            size: function() {\n                return this.stack.length;\n            },\n            getLatestUserId: function() {\n                var a = this.size();\n                return ((a ? this.stack[((a - 1))] : null));\n            },\n            getLastPushTime: function(a) {\n                return this.timestamps[a];\n            },\n            findAll: function(a) {\n                twttr.API.User.findAll(this.stack.reverse(), a);\n            }\n        }), twttr.app.waitForSignal(\"init\", function() {\n            twttr.recentlyViewedUsers = new twttr.StoredUserStack(\"recentlyViewedUsers\"), twttr.loggedOutViewedUsers = new twttr.StoredUserStack(\"recentlyViewedUsers\", new twttr.cache.local.User($.cookie(\"guest_id\")));\n        }), a(twttr.StoredUserStack);\n    });\n});\nprovide(\"PasswordStrength\", function(a) {\n    using().as(function(b) {\n        twttr.PasswordStrength = function() {\n            function a(a) {\n                return ((typeof a == \"function\"));\n            };\n        ;\n            function b(a, b) {\n                var c = \"\";\n                for (var d = 0; ((d < b.length)); d++) {\n                    var e = !0;\n                    for (var f = 0; ((((f < a)) && ((((((f + d)) + a)) < b.length)))); f++) {\n                        e = ((e && ((b.charAt(((f + d))) == b.charAt(((((f + d)) + a)))))));\n                    ;\n                    };\n                ;\n                    ((((f < a)) && (e = !1))), ((e ? (d += ((a - 1)), e = !1) : c += b.charAt(d)));\n                };\n            ;\n                return c;\n            };\n        ;\n            return {\n                check: function(c, d) {\n                    var e = 0, d = ((d || {\n                    }));\n                    if (((c.length < ((d.minlength || 6))))) {\n                        return {\n                            score: 0,\n                            msgClass: \"tooshort\"\n                        };\n                    }\n                ;\n                ;\n                    var f = c.toLowerCase();\n                    if (((d.username && ((f == ((a(d.username) ? d.username() : d.username)).toLowerCase()))))) {\n                        return {\n                            score: 0,\n                            msgClass: \"obvious\"\n                        };\n                    }\n                ;\n                ;\n                    if ((($.inArray(f, ((twttr.BANNED_PASSWORDS || []))) != -1))) {\n                        return {\n                            score: 0,\n                            msgClass: \"banned\"\n                        };\n                    }\n                ;\n                ;\n                    if (c.match(/^\\s*$/)) {\n                        return {\n                            score: 0,\n                            msgClass: \"whitespace\"\n                        };\n                    }\n                ;\n                ;\n                    if (d.requireStrong) {\n                        var g = \"# ` ~ ! @ $ % ^ & * ( ) - _ = + [ ] { }  | ; : ' \\\" , . \\u003C \\u003E / ?\".split(\" \");\n                        g = $.map(g, function(a) {\n                            return ((\"\\\\\" + a));\n                        }).join(\"\");\n                        var i = [\"\\\\d\",\"[a-z]\",\"[A-Z]\",((((\"[\" + g)) + \"]\")),], j = $.map(i, function(a) {\n                            return ((((\"(?=.*\" + a)) + \")\"));\n                        }).join(\"\");\n                        if (!c.match(new RegExp(((((\"(\" + j)) + \"){10,}\"))))) {\n                            return {\n                                score: 0,\n                                msgClass: \"tooweak\"\n                            };\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    e += ((c.length * 4)), e += ((((b(1, c).length - c.length)) * 1)), e += ((((b(2, c).length - c.length)) * 1)), e += ((((b(3, c).length - c.length)) * 1)), e += ((((b(4, c).length - c.length)) * 1)), ((c.match(/(.*[0-9].*[0-9].*[0-9])/) && (e += 5))), ((c.match(/(.*[!@#$%^&*?_~].*[!@#$%^&*?_~])/) && (e += 5))), ((c.match(/([a-z].*[A-Z])|([A-Z].*[a-z])/) && (e += 10))), ((((c.match(/([a-zA-Z])/) && c.match(/([0-9])/))) && (e += 15))), ((((c.match(/([!@#$%^&*?_~])/) && c.match(/([0-9])/))) && (e += 15))), ((((c.match(/([!@#$%^&*?_~])/) && c.match(/([a-zA-Z])/))) && (e += 15)));\n                    if (((c.match(/^\\w+$/) || c.match(/^\\d+$/)))) {\n                        e -= 10;\n                    }\n                ;\n                ;\n                    return ((((e < 0)) && (e = 0))), ((((e > 100)) && (e = 100))), ((((e < 34)) ? {\n                        score: e,\n                        msgClass: \"weak\"\n                    } : ((((e < 50)) ? {\n                        score: e,\n                        msgClass: \"good\"\n                    } : ((((e < 75)) ? {\n                        score: e,\n                        msgClass: \"strong\"\n                    } : {\n                        score: e,\n                        msgClass: \"verystrong\"\n                    }))))));\n                }\n            };\n        }(), a(twttr.PasswordStrength);\n    });\n});\nprovide(\"mixins/urlShortener\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.urlShortener\", function(a) {\n            a.mixin(twttr.mixins.caretHelper).statics({\n                matchers: {\n                    tco: /^https?:\\/\\/t.co\\/\\w+$/\n                }\n            }).methods({\n                _registerUrlShortenerEvents: function() {\n                    ((this._explainLinkShortening && this.editor.bind(\"didChangeContent\", twttr.bind(this, this._showCounterTipsy)))), this.$counterText = $(\"\\u003Cspan class=\\\"tweetbox-counter-tipsy\\\"\\u003E\\u003C/span\\u003E\"), this.$counter.before(this.$counterText), this.$counterText.css(\"opacity\", 0), this.$links = [], this._a = !1, this._isTipShowing = !1, this._oldLinkLen = 0;\n                    var a = this._getTextLength;\n                    this._getTextLength = function(c) {\n                        var d = a.apply(this, arguments), e = twttr.txt.extractUrls(c);\n                        return d -= e.join(\"\").length, twttr.each(e, function(a) {\n                            d += b.constants.tcoLength, ((a.match(/https:/) && (d += 1)));\n                        }), d;\n                    };\n                },\n                _getLinkCounterText: function(a) {\n                    var b = _(\"Links will appear shortened\"), c = _(\"Link will appear shortened\");\n                    return ((((a > 1)) ? b : c));\n                },\n                _showCounterTipsy: function() {\n                    var a = this, b, c, d = 15;\n                    a._linkLen = a._extractUrls().length, ((((a._linkLen && ((a._linkLen !== a._oldLinkLen)))) ? (a.$counterText.html(a._getLinkCounterText(a._linkLen)), c = a.$container.JSBNG__find(\"div.tweet-button-container\"), b = c.width(), c.children().each(function() {\n                        b -= $(this).JSBNG__outerWidth(!0);\n                    }), twttr.helpers.ellipsify(a.$container.JSBNG__find(\".geo-text\").width(function(a, c) {\n                        return ((((((b < 0)) || !c)) ? ((((c + b)) - d)) : c));\n                    }), !0), a.$counterText.animate({\n                        opacity: 1\n                    }, 100), a._isTipShowing = !0) : ((((a._isTipShowing && !a._linkLen)) && (a.$counterText.animate({\n                        opacity: 0\n                    }, 100, function() {\n                        a.$counterText.html(\"\"), twttr.helpers.ellipsify(a.$container.JSBNG__find(\".geo-text\").width(\"\"), !0);\n                    }), a._isTipShowing = !1))))), a._oldLinkLen = a._linkLen;\n                },\n                _showCounterFade: function() {\n                    if (twttr.txt.extractUrls(this.getCurrentWord(this.getCaret())).length) {\n                        this.$counter.css({\n                            color: \"green\"\n                        });\n                        if (!this._a) {\n                            var a = this.$counter.clone(), b = this.$counter.position();\n                            a.css({\n                                left: b.left,\n                                JSBNG__top: b.JSBNG__top\n                            }), a.addClass(\"tweet-counter-proxy\"), this.$counter.after(a);\n                            function c() {\n                                a.remove();\n                            };\n                        ;\n                            a.animate({\n                                fontSize: \"40px\",\n                                opacity: 0,\n                                marginTop: -20,\n                                marginLeft: -Math.round(((a.width() / 2)))\n                            }, 200, c), this._a = !0;\n                        }\n                    ;\n                    ;\n                    }\n                     else this.$counter.css({\n                        color: \"\"\n                    }), ((this._a && (this._a = !1)));\n                ;\n                ;\n                },\n                _tweetReady: function() {\n                    this.lock(), this.callTalon(this._extractUrls(), twttr.bind(this, function(a) {\n                        this.setTweetContent(this.replaceWithTalonUrls(a)), this.unlock(), this.tweet();\n                    }));\n                },\n                _extractUrls: function() {\n                    return this.filterInvalidLinks(twttr.txt.extractUrls(this.editor.JSBNG__content()));\n                },\n                replaceWithTalonUrls: function(a) {\n                    var b = this.editor.JSBNG__content();\n                    return twttr.each(a, function(a) {\n                        b = this.replaceContent(b, a);\n                    }, this), b;\n                },\n                callTalon: function(a, b) {\n                    ((a.length ? twttr.API.Urls.shortenMultiple(a, b) : b([])));\n                },\n                replaceContent: function(a, b) {\n                    return a.replace(b.expanded_url, b.url);\n                },\n                filterInvalidLinks: function(b) {\n                    return twttr.filter(b, function(b) {\n                        return !b.match(a.matchers.tco);\n                    });\n                },\n                _mousemove: function(a) {\n                    var b = a.pageX, c = a.pageY;\n                    twttr.each(this.$links, function(a) {\n                        var d = $(a), e = d.offset(), f = d.attr(\"data-mouse-entered\");\n                        if (((((((((b >= e.left)) && ((b <= ((e.left + d.width())))))) && ((c >= e.JSBNG__top)))) && ((c <= ((e.JSBNG__top + d.height()))))))) {\n                            if (((!f || ((f === \"false\"))))) {\n                                d.attr(\"data-mouse-entered\", \"true\"), d.trigger(\"mouseenter\");\n                            }\n                        ;\n                        ;\n                            return !1;\n                        }\n                    ;\n                    ;\n                        ((((f === \"true\")) && (d.attr(\"data-mouse-entered\", \"false\"), d.trigger(\"mouseleave\"))));\n                    });\n                },\n                _matchUrls: function() {\n                    JSBNG__setTimeout(twttr.bind(this, function() {\n                        this.$links = this.$find(\"a.twitter-timeline-link\"), this.$links.tipsy({\n                            html: !0,\n                            gravity: \"n\",\n                            offset: 3,\n                            class: \"tweetbox-tipsy\",\n                            title: function() {\n                                return ((((\"\\u003Cspan class=\\\"tweetbox-tipsy-text\\\"\\u003E\" + _(\"Link will be displayed as {{url}}\", {\n                                    url: twttr.helpers.displayUrl(this.href)\n                                }))) + \"\\u003C/span\\u003E\"));\n                            }\n                        });\n                    }), 0);\n                }\n            });\n        }), a(twttr.mixins.urlShortener);\n    });\n});\nprovide(\"mixins/caretHelper\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.caretHelper\", function() {\n            return this.statics({\n                spaceBoundary: /\\s|$/,\n                wordEnd: /\\S+$/\n            }).methods({\n                init: function() {\n                    this.$input.bind(\"JSBNG__blur\", twttr.bind(this, function(a) {\n                        JSBNG__setTimeout(twttr.bind(this, function() {\n                            this.hide();\n                        }), 1000);\n                    })).bind(\"mouseup\", twttr.bind(this, function(a) {\n                        JSBNG__setTimeout(twttr.bind(this, function() {\n                            this.getCaret();\n                        }), 0);\n                    })).bind(\"JSBNG__focus\", twttr.bind(this, function(a) {\n                        this.getCaret();\n                    }));\n                },\n                getCurrentText: function() {\n                    return this.$input.val();\n                },\n                setCaretPosition: function(a) {\n                    var b = this.$input[0];\n                    if (b.setSelectionRange) {\n                        b.JSBNG__focus(), b.setSelectionRange(a, a);\n                    }\n                     else {\n                        if (b.createTextRange) {\n                            var c = b.createTextRange();\n                            c.collapse(!0), c.moveEnd(\"character\", a), c.moveStart(\"character\", a), c.select();\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    this.lastCaret = a;\n                },\n                getCaret: function() {\n                    var a = this.$input[0], b = 0;\n                    if (JSBNG__document.selection) {\n                        try {\n                            a.JSBNG__focus();\n                        } catch (c) {\n                        \n                        };\n                    ;\n                        var d = JSBNG__document.selection.createRange();\n                        if (((d == null))) {\n                            return this.lastCaret = 0, 0;\n                        }\n                    ;\n                    ;\n                        var e = a.createTextRange(), f = e.duplicate();\n                        e.moveToBookmark(d.getBookmark()), f.setEndPoint(\"EndToStart\", e), b = f.text.length;\n                    }\n                     else if (((a.selectionStart || ((a.selectionStart == \"0\"))))) {\n                        b = a.selectionStart;\n                    }\n                    \n                ;\n                ;\n                    return this.lastCaret = b, b;\n                },\n                insertOrReplaceSelection: function(a, b) {\n                    var c = this.$input[0], d = this.getCaret(), e = ((d + a.length));\n                    if (JSBNG__document.selection) {\n                        c.JSBNG__focus();\n                        var f = JSBNG__document.selection.createRange();\n                        f.text = a;\n                        if (b) {\n                            var g = c.createTextRange();\n                            g.collapse(!0), g.moveEnd(\"character\", e), g.moveStart(\"character\", d), g.select();\n                        }\n                         else this.setCaretPosition(e);\n                    ;\n                    ;\n                    }\n                     else if (((c.selectionStart || ((c.selectionStart == \"0\"))))) {\n                        var i = c.selectionStart, j = c.selectionEnd, k = c.scrollTop;\n                        c.value = ((((c.value.substring(0, i) + a)) + c.value.substring(j, c.value.length))), c.JSBNG__focus(), c.selectionStart = ((b ? d : e)), c.selectionEnd = e, c.scrollTop = k;\n                    }\n                     else c.value += a, this.setCaretPosition(e), c.JSBNG__focus();\n                    \n                ;\n                ;\n                    this.lastCaret = e, this.$input.change();\n                },\n                getCurrentWord: function(a) {\n                    var b = this.getCurrentText(), c = b.slice(0, a), d = b.slice(a, b.length), e = b.charAt(((a - 1)));\n                    if (((!e || ((e === \" \"))))) {\n                        return \"\";\n                    }\n                ;\n                ;\n                    this.leftBoundary = c.search(this.constructor.wordEnd);\n                    var f = c.slice(this.leftBoundary, c.length), g = d.slice(0, d.search(this.constructor.spaceBoundary)), i = f.concat(g);\n                    return this.rightBoundary = ((this.leftBoundary + i.length)), i;\n                },\n                replaceCurrentWord: function(a) {\n                    var b = this.getCurrentText().split(\"\");\n                    this.oldValueArray = b;\n                    var c = b.slice(0, this.leftBoundary), d = b.slice(this.rightBoundary, b.length);\n                    if (((((d.length < 1)) || !d[0].match(/\\s/)))) {\n                        a += \" \";\n                    }\n                ;\n                ;\n                    var e = ((((c.join(\"\") + a)).length + 1));\n                    return {\n                        value: ((((c.join(\"\") + a)) + d.join(\"\"))),\n                        cursor: e\n                    };\n                }\n            }), this;\n        }), a(twttr.mixins.caretHelper);\n    });\n});\nprovide(\"geo\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.provide(\"twttr.geo\", {\n            LOG_VERSION: 3,\n            UI_VERSION: 2,\n            LOCATION_CACHE_INTERVAL: 30000,\n            BROWSER_GEO_BANNER_APPEAR_DELAY: 500,\n            BROWSER_GEO_BANNER_DISAPPEAR_INTERVAL: 100,\n            PLACE_SEARCH_AUTOCOMPLETE_DELAY: 250,\n            MAX_NEARBY_PLACES: 12,\n            MAX_NEARBY_NEIGHBORHOODS: 5,\n            MAX_PLACE_SEARCH_RESULTS: 50,\n            MAX_PLACE_AUTOCOMPLETE_RESULTS: 8,\n            PLACE_SEARCH_RESULTS_PER_PAGE: 5,\n            PLACE_CREATION_DEFAULT_ZOOM_LEVEL: 15,\n            SIMILAR_PLACES_MAX_ZOOM_LEVEL: 17,\n            ACCEPTABLE_LOCATION_ACCURACY: 1000,\n            ACCEPTABLE_LOCATION_TIMEOUT: 5000,\n            LOCATION_TIMEOUT: 15000,\n            LOCATION_MAXIMUM_AGE: 60000,\n            MAX_SIMILAR_PLACES: 5,\n            TARGET_POI_NAME_LENGTH: 40,\n            TARGET_PLACE_NAME_LENGTH: 50,\n            POI_MARKER_SIZE: {\n                width: 43,\n                height: 32\n            },\n            POI_MARKER_HOTSPOT: {\n                x: 14,\n                y: 33\n            },\n            POI_MAP_DEAD_ZONE: {\n                left: 4,\n                JSBNG__top: 24,\n                right: 6,\n                bottom: 0\n            },\n            geoEnabled: null,\n            currentLocation: {\n            },\n            mapsTimeout: 10000,\n            mapsListeners: [],\n            Exceptions: {\n                GeoSupportException: function() {\n                    this.msg = _(\"This browser does not support GeoLocation\");\n                }\n            },\n            mapsInitialized: function() {\n                while (twttr.geo.mapsListeners.length) {\n                    var a = twttr.geo.mapsListeners.shift();\n                    a();\n                };\n            ;\n            },\n            loadMaps: function(a) {\n                if (twttr.geo.mapsAvailable()) a();\n                 else {\n                    twttr.geo.mapsListeners.push(a);\n                    if (((twttr.geo.mapsListeners.length == 1))) {\n                        var b = ((((window.JSBNG__location.protocol === \"https:\")) ? \"https://maps-api-ssl.google.com\" : \"http://maps.google.com\"));\n                        b += \"/maps/api/js?v=3.4&sensor=false&callback=twttr.geo.mapsInitialized\", ((window.JSBNG__location.hostname.match(/^(.+\\.)?twitter\\.com$/) && (b += \"&client=free-twitter\")));\n                        var c = JSBNG__document.createElement(\"script\");\n                        c.type = \"text/javascript\", c.src = b, JSBNG__document.body.appendChild(c), JSBNG__setTimeout(twttr.geo.mapsInitialized, twttr.geo.mapsTimeout);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            mapsAvailable: function() {\n                return ((((typeof google != \"undefined\")) && ((google.maps !== undefined))));\n            },\n            getBestContainer: function(a) {\n                if (!a) {\n                    return {\n                        JSBNG__name: \"\",\n                        full_name: \"\",\n                        contained_within: [],\n                        place_type: \"city\",\n                        bounding_box: {\n                            type: \"Polygon\",\n                            coordinates: [[[-122.51368188,37.70813196,],[-122.35845384,37.70813196,],[-122.35845384,37.83245301,],[-122.51368188,37.83245301,],],]\n                        }\n                    };\n                }\n            ;\n            ;\n                var b = {\n                    JSBNG__name: ((a.part_of_name || \"\")),\n                    full_name: ((a.part_of_name || \"\")),\n                    contained_within: [],\n                    place_type: \"city\"\n                };\n                return ((a.contained_within && twttr.every(a.contained_within, function(a) {\n                    return b = a, ((a.place_type != \"city\"));\n                }))), b;\n            },\n            getPlaceFullAddressAndMapLink: function(a) {\n                var b = [twttr.geo.getPlaceAttribute(a, \"street_address\"),((((a.contained_within && ((a.contained_within.length > 0)))) ? a.contained_within[0].full_name : null)),];\n                b = twttr.filter(b, function(a) {\n                    return a;\n                }).join(\", \");\n                var c = ((((a.place_type == \"poi\")) ? b : ((((a.JSBNG__name + \", \")) + b))));\n                return {\n                    full_address: b,\n                    map_link: ((\"http://maps.google.com/maps?\" + $.param({\n                        q: c\n                    })))\n                };\n            },\n            placesFromApi: function(a) {\n                var b = [];\n                return a.each(function(a) {\n                    b.push(a.data());\n                }), b;\n            },\n            getPlaceAttribute: function(a, b) {\n                return ((((a.attributes && a.attributes[b])) || \"\"));\n            },\n            getPlaceDetails: function(a) {\n                var b = twttr.geo.getPlaceAttribute(a, \"street_address\");\n                if (b) {\n                    return b;\n                }\n            ;\n            ;\n                switch (a.place_type) {\n                  case \"city\":\n                    return _(\"a city\");\n                  case \"neighborhood\":\n                    return _(\"a neighborhood\");\n                  case \"country\":\n                    return _(\"a country\");\n                  case \"admin\":\n                    return _(\"a state or province\");\n                  default:\n                    return twttr.geo.getBestContainer(a).JSBNG__name;\n                };\n            ;\n            },\n            getFullPlace: function(a) {\n                return $.extend({\n                }, a, {\n                    address: twttr.geo.getPlaceAttribute(a, \"street_address\"),\n                    container: twttr.geo.getBestContainer(a).full_name,\n                    phone: twttr.geo.getPlaceAttribute(a, \"phone\"),\n                    place_id: a.id,\n                    place_name: a.full_name\n                }, twttr.geo.getPlaceFullAddressAndMapLink(a));\n            }\n        }), a(twttr.geo);\n    });\n});\nprovide(\"components/Autocomplete\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.provide(\"twttr.users\", {\n            autocompleted: []\n        }), twttr.klass(\"twttr.components.Autocomplete\", function(a) {\n            var c = {\n                limit: 5,\n                textarea: !1,\n                preselect: !0\n            };\n            this.options = twttr.merge({\n            }, c, a), this.$input = $(this.options.input), this.$container = $(\"\\u003Cul class=\\\"autocomplete-container\\\"\\u003E\\u003C/ul\\u003E\").insertAfter(this.options.input), this._isCompletionsOpen = !1, ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"phoenix_autocomplete\") || b.util.params().autocomplete)))) && this.registerEvents())), this.init();\n        }).mixin(twttr.mixins.caretHelper).statics({\n            cache: {\n            },\n            regCache: new twttr.cache.Simple,\n            hashtagCache: {\n            },\n            _isCompletionsOpen: !1,\n            nextCursor: -1,\n            cursorCount: 0,\n            requestedUsers: !1,\n            getAutocompletedUsers: function(a) {\n                !!twttr.currentUser;\n                var c = this;\n                if (((twttr.loggedIn && ((twttr.decider.isAvailable(\"phoenix_autocomplete\") || b.util.params().autocomplete))))) {\n                    function d(a) {\n                        return twttr.map(a, function(a, b) {\n                            return [a.id,a.screenName,a.JSBNG__name,a.profileImageUrl,];\n                        });\n                    };\n                ;\n                    if (!this.requestedUsers) {\n                        this.requestedUsers = !0;\n                        var e = twttr.caches.User.get(\"autocomplete_friends\");\n                        ((e ? (twttr.users.autocompleted = e, ((a && a()))) : function() {\n                            function b(e) {\n                                ((((((++c.cursorCount <= 5)) && twttr.currentUser)) ? twttr.currentUser.friends({\n                                    count: 100,\n                                    cursor: e,\n                                    success: twttr.bind(c, function(c, e) {\n                                        twttr.components.Autocomplete.invalidateCache();\n                                        if (c.isEmpty()) {\n                                            ((a && a()));\n                                            return;\n                                        }\n                                    ;\n                                    ;\n                                        c = d(c.toArray()), twttr.users.autocompleted.push.apply(twttr.users.autocompleted, c), twttr.components.Autocomplete.resetStorageCache(), ((e.response.next_cursor ? b(e.response.next_cursor) : ((a && a()))));\n                                    })\n                                }) : ((a && a()))));\n                            };\n                        ;\n                            ((twttr.currentUser && twttr.components.Autocomplete.addToList([twttr.currentUser.id,twttr.currentUser.screenName,twttr.currentUser.JSBNG__name,twttr.currentUser.profileImageUrl,]))), b(twttr.components.Autocomplete.nextCursor);\n                        }()));\n                    }\n                     else ((a && a()));\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        }).methods(twttr.EventProvider).statics({\n            username: /^[@＠]([a-zA-Z0-9_]{1,20})$/,\n            hashtag: /^[#＃]([a-zA-Z0-9_]+)/,\n            transformAvatar: /(.+)(?:_normal)\\.(\\w+)$/,\n            _matchesContiguously: function(a, b) {\n                var c = twttr.components.Autocomplete, d = c._matchesContiguouslyCaches.matchers = ((c._matchesContiguouslyCaches.matchers || {\n                })), e = c._matchesContiguouslyCaches.results = ((c._matchesContiguouslyCaches.results || {\n                }));\n                return ((((e[a] && ((e[a][b] !== undefined)))) ? e[a][b] : (d[a] = ((d[a] || new RegExp(((\"^\" + a)), \"i\"))), e[a] = ((e[a] || {\n                })), e[a][b] = d[a].test(b.replace(/\\W/, \"\")), e[a][b])));\n            },\n            _matchesConsecutively: function(a, b) {\n                var c = twttr.components.Autocomplete, d = c._matchesConsecutivelyCaches.matchers = ((c._matchesConsecutivelyCaches.matchers || {\n                })), e = c._matchesConsecutivelyCaches.results = ((c._matchesConsecutivelyCaches.results || {\n                }));\n                return ((((e[a] && ((e[a][b] !== undefined)))) ? e[a][b] : (d[a] = ((d[a] || new RegExp(a.split(\"\").join(\".*\"), \"i\"))), e[a] = ((e[a] || {\n                })), e[a][b] = d[a].test(b), e[a][b])));\n            },\n            levenSorter: function(a, c) {\n                var d = twttr.components.Autocomplete._currentPrefix, e = b.util.leven(a, d), f = b.util.leven(c, d);\n                return ((((e < f)) ? -1 : ((((e > f)) ? 1 : 0))));\n            },\n            sorter: function(a, c) {\n                var d = twttr.components.Autocomplete._matchesContiguously, e = twttr.components.Autocomplete._matchesConsecutively, f = twttr.components.Autocomplete._currentPrefix;\n                if (((d(f, a[1]) && !d(f, c[1])))) {\n                    return -1;\n                }\n            ;\n            ;\n                if (((!d(f, a[1]) && d(f, c[1])))) {\n                    return 1;\n                }\n            ;\n            ;\n                if (((d(f, a[2]) && !d(f, c[2])))) {\n                    return -1;\n                }\n            ;\n            ;\n                if (((!d(f, a[2]) && d(f, c[2])))) {\n                    return 1;\n                }\n            ;\n            ;\n                if (((e(f, a[1]) && !e(f, c[1])))) {\n                    return -1;\n                }\n            ;\n            ;\n                if (((!e(f, a[1]) && e(f, c[1])))) {\n                    return 1;\n                }\n            ;\n            ;\n                if (((e(f, a[2]) && !e(f, c[2])))) {\n                    return -1;\n                }\n            ;\n            ;\n                if (((!e(f, a[2]) && e(f, c[2])))) {\n                    return 1;\n                }\n            ;\n            ;\n                var g = b.util.leven(a[1], f), i = b.util.leven(c[1], f);\n                if (((g < i))) {\n                    return -1;\n                }\n            ;\n            ;\n                if (((g > i))) {\n                    return 1;\n                }\n            ;\n            ;\n                var j = b.util.leven(a[2], f), k = b.util.leven(c[2], f);\n                return ((((j < k)) ? -1 : ((((j > k)) ? 1 : 0))));\n            },\n            _htmlEscapeAndStrongifyMatches: function(a, b) {\n                return h(a.replace(b, \"\\u003Cstrong\\u003E$1\\u003C/strong\\u003E\")).replace(/&lt;(\\/?strong)&gt;/g, \"\\u003C$1\\u003E\");\n            }\n        }).statics({\n            _matchesContiguouslyCaches: {\n                results: {\n                },\n                matchers: {\n                }\n            },\n            _matchesConsecutivelyCaches: {\n                results: {\n                },\n                matchers: {\n                }\n            }\n        }).statics({\n            invalidateCache: function(a) {\n                if (!a) {\n                    this.cache = {\n                    }, twttr.components.Autocomplete._matchesConsecutivelyCaches.results = {\n                    }, twttr.components.Autocomplete._matchesConsecutivelyCaches.matchers = {\n                    }, twttr.components.Autocomplete._matchesContiguouslyCaches.results = {\n                    }, twttr.components.Autocomplete._matchesContiguouslyCaches.matchers = {\n                    };\n                    return;\n                }\n            ;\n            ;\n                var b = \"\";\n                a = a.split(\"\");\n                for (var c = ((a.length - 1)); ((c >= 0)); c--) {\n                    b += a.shift(), delete this.cache[b], delete twttr.components.Autocomplete._matchesConsecutivelyCaches.results[b], delete twttr.components.Autocomplete._matchesConsecutivelyCaches.matchers[b], delete twttr.components.Autocomplete._matchesContiguouslyCaches.results[b], delete twttr.components.Autocomplete._matchesContiguouslyCaches.matchers[b];\n                ;\n                };\n            ;\n            },\n            resetStorageCache: function() {\n                var a = [], b = 0;\n                twttr.users.autocompleted.sort(function(a, b) {\n                    return ((((a[0] < b[0])) ? -1 : ((((a[0] > b[0])) ? 1 : 0))));\n                });\n                for (var c = 0, d = twttr.users.autocompleted.length; ((c < d)); c++) {\n                    if (((twttr.users.autocompleted[((c + 1))] && ((twttr.users.autocompleted[c][0] == twttr.users.autocompleted[((c + 1))][0]))))) {\n                        continue;\n                    }\n                ;\n                ;\n                    a[b++] = twttr.users.autocompleted[c];\n                };\n            ;\n                twttr.users.autocompleted = a, twttr.caches.User.set(\"autocomplete_friends\", twttr.users.autocompleted, 259200000);\n            },\n            addToList: function(a) {\n                var b = !1;\n                for (var c = 0, d = twttr.users.autocompleted.length; ((c < d)); ++c) {\n                    if (((twttr.users.autocompleted[c][1] === a[1]))) {\n                        b = !0;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                ((b || twttr.users.autocompleted.push(a))), twttr.components.Autocomplete.invalidateCache(a[1]), this.resetStorageCache();\n            }\n        }).methods({\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.Dialog.bind(\"close\", twttr.bind(this, function() {\n                    this.hide();\n                }));\n                var b = ((\"keypress\" + (((($.browser.webkit || $.browser.msie)) ? \" keydown\" : \"\"))));\n                this.$input.bind(\"keyup click\", twttr.bind(this, this.keyup)), this.$input.bind(\"change\", twttr.bind(this, this.change)), this.$input.bind(b, twttr.bind(this, this.keypress)), this.$container.delegate(\"li.selectable\", \"mouseenter\", function(b) {\n                    a.$container.JSBNG__find(\"li.selected\").removeClass(\"selected\"), $(this).addClass(\"selected\");\n                }).delegate(\"li.selectable\", \"click\", twttr.bind(this, function(a) {\n                    a.preventDefault();\n                    if ($(a.target).hasClass(\"twttr-follow-notice\")) {\n                        return;\n                    }\n                ;\n                ;\n                    $(a.target).addClass(\"selected\").siblings(\".selected\").removeClass(\"selected\"), this.select(), this.JSBNG__focus();\n                })), this.$input.bind(\"keydown\", function(b) {\n                    if (b.ctrlKey) {\n                        return;\n                    }\n                ;\n                ;\n                    if (((!a._isCompletionsOpen && ((b.which == twttr.constants.keyCodes.escape))))) {\n                        return;\n                    }\n                ;\n                ;\n                    b.stopPropagation();\n                }), this.position();\n            },\n            JSBNG__focus: function() {\n                this.$input.JSBNG__focus();\n            },\n            set: function(a) {\n                if (this.options.textarea) {\n                    var b = this.replaceCurrentWord(a);\n                    this.$input.val(b.value), this.setCaretPosition(b.cursor);\n                }\n                 else this.$input.val(a);\n            ;\n            ;\n                this.$input.change();\n            },\n            hide: function() {\n                JSBNG__setTimeout(twttr.bind(this, function() {\n                    this.$container.css(\"visibility\", \"hidden\"), ((this._isCompletionsOpen && this.trigger(\"hide\"))), this._isCompletionsOpen = !1, this.constructor._isCompletionsOpen = !1;\n                }), 0);\n            },\n            show: function() {\n                this.$container.css(\"visibility\", \"visible\"), this.constructor._isCompletionsOpen = !0, this._isCompletionsOpen = !0;\n            },\n            keypress: function(a) {\n                if (a.ctrlKey) {\n                    return;\n                }\n            ;\n            ;\n                switch (a.keyCode) {\n                  case b.constants.keyCodes.tab:\n                \n                  case b.constants.keyCodes.enter:\n                \n                  case b.constants.keyCodes.escape:\n                    if (!this._isCompletionsOpen) {\n                        return;\n                    }\n                ;\n                ;\n                    a.preventDefault();\n                    break;\n                  case b.constants.keyCodes.upArrow:\n                    ((((this._isCompletionsOpen && !a.shiftKey)) && (this.previous(), a.preventDefault())));\n                    break;\n                  case b.constants.keyCodes.downArrow:\n                    ((((this._isCompletionsOpen && !a.shiftKey)) && (this.next(), a.preventDefault())));\n                };\n            ;\n                a.stopPropagation(), JSBNG__setTimeout(twttr.bind(this, this.change), 0);\n            },\n            keyup: function(a) {\n                if (a.ctrlKey) {\n                    return;\n                }\n            ;\n            ;\n                a.stopPropagation();\n                if (((((a && ((((a.keyCode === b.constants.keyCodes.tab)) || ((a.keyCode === b.constants.keyCodes.shift)))))) && !this._isCompletionsOpen))) {\n                    return;\n                }\n            ;\n            ;\n                var c = \"\", d = !1;\n                if (this.options.textarea) {\n                    var e = this.getCaret();\n                    c = this.getCurrentWord(e).replace(twttr.constants.regexps.dirMark, \"\"), ((c.match(this.constructor.username) ? (c = RegExp.$1, this.autocompleteType = \"username\", d = !0) : ((c.match(this.constructor.hashtag) && (c = RegExp.$1, this.autocompleteType = \"hashtag\", d = !0)))));\n                }\n                 else this.autocompleteType = \"username\", c = this.$input.val(), d = !0;\n            ;\n            ;\n                if (((c.length && d))) {\n                    switch (a.keyCode) {\n                      case b.constants.keyCodes.escape:\n                        this.hide(), a.stopPropagation();\n                        break;\n                      case b.constants.keyCodes.upArrow:\n                    \n                      case b.constants.keyCodes.downArrow:\n                        break;\n                      case b.constants.keyCodes.tab:\n                    \n                      case b.constants.keyCodes.enter:\n                        ((((!a.shiftKey && this._isCompletionsOpen)) && this.select()));\n                        break;\n                      default:\n                        ((((this.autocompleteType == \"hashtag\")) ? this.lookUpHashtag(c) : this.lookUpUser(c)));\n                    };\n                }\n                 else {\n                    this.hide();\n                }\n            ;\n            ;\n            },\n            select: function() {\n                var a = this.$container.JSBNG__find(\"li.selected\"), b = a.JSBNG__find(\"b\").text(), c = a.JSBNG__find(\"img\").attr(\"src\");\n                this.set(b), this.hide();\n                if (((this.autocompleteType === \"username\"))) {\n                    var d = a.attr(\"data-user-screenname\"), e = a.attr(\"data-user-id\");\n                    this.trigger(\"select\", [this.autocompleteType,b,c,d,e,]);\n                }\n                 else this.trigger(\"select\", [this.autocompleteType,b,c,]);\n            ;\n            ;\n            },\n            change: function() {\n                var a = this.getCurrentText(), b = ((this.lastText || \"\"));\n                if (((a === b))) {\n                    return;\n                }\n            ;\n            ;\n                var c = 0, d = a.length, e = b.length, f = Math.min(d, this.getCaret());\n                for (var g = 0; ((g < f)); g++) {\n                    if (((b.charAt(g) !== a.charAt(g)))) {\n                        break;\n                    }\n                ;\n                ;\n                    c += 1;\n                };\n            ;\n                var i = 0;\n                for (var g = 1; ((g <= ((d - c)))); g++) {\n                    if (((b.charAt(((e - g))) !== a.charAt(((d - g)))))) {\n                        break;\n                    }\n                ;\n                ;\n                    i += 1;\n                };\n            ;\n                var j = ((c + i));\n                this.lastText = a, this.trigger(\"substitution\", [c,((e - j)),((d - j)),a,]);\n            },\n            sanitize: function(a) {\n                return this.constructor._currentPrefix = a.replace(/ /g, \"\"), this.constructor._currentPrefix;\n            },\n            appendNotice: function(a) {\n                return ((((twttr.currentUser && ((twttr.currentUser.friendsCount > 500)))) && (a += ((((\"\\u003Cli class=\\\"twttr-follow-notice\\\"\\u003E\" + _(\"\\u003Cem\\u003EShowing most recent 500 you're following\\u003C/em\\u003E\"))) + \"\\u003C/li\\u003E\"))))), a;\n            },\n            lookUpHashtag: function(a) {\n                var b = this;\n                a = this.sanitize(a);\n                var c = this.constructor.hashtagCache[a];\n                if (c) {\n                    this.$container.html(c), this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\"), this.show();\n                    return;\n                }\n            ;\n            ;\n                var d = function(a) {\n                    if (a.match(b.regexPrefix)) {\n                        return a;\n                    }\n                ;\n                ;\n                }, e = twttr.merge({\n                }, this.getFilteredResults(a, ((twttr.suggestedHashtags || [])), d, this.constructor.levenSorter), !0), f = this.getItemTemplate(e, function(a, c) {\n                    return ((((\"\\u003Cli class=\\\"hashtag-completion selectable\\\"\\u003E\\u003Cb\\u003E#\" + b.constructor._htmlEscapeAndStrongifyMatches(a, c))) + \"\\u003C/b\\u003E\\u003C/li\\u003E\"));\n                }).slice(0, this.options.limit);\n                if (((f.length > 0))) {\n                    var g = f.join(\"\");\n                    this.constructor.hashtagCache[a] = g, this.$container.html(g), this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\"), this.show();\n                }\n                 else this.hide();\n            ;\n            ;\n            },\n            lookUpUser: function(a) {\n                var b = this;\n                a = this.sanitize(a);\n                var c = this.constructor.cache[a];\n                if (c) {\n                    this.$container.html(c), ((this.options.preselect && this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\"))), this.show();\n                    return;\n                }\n            ;\n            ;\n                var d = function(a) {\n                    if (a[1].match(b.regexPrefix)) {\n                        return a;\n                    }\n                ;\n                ;\n                    if (a[2].replace(/ /g, \"\").match(b.regexPrefix)) {\n                        return a;\n                    }\n                ;\n                ;\n                }, e = twttr.merge({\n                }, this.getFilteredResults(a, twttr.users.autocompleted, d, this.constructor.sorter), !0), f = this.getItemTemplate(e, function(a, c) {\n                    var d = a[3].replace(b.constructor.transformAvatar, \"$1_mini.$2\");\n                    return ((((((((((((((((((((\"\\u003Cli data-user-id=\\\"\" + h(a[0]))) + \"\\\" data-user-screenname=\\\"\")) + h(a[1]))) + \"\\\" class=\\\"selectable\\\"\\u003E\\u003Cimg src=\\\"\")) + h(d))) + \"\\\"/\\u003E \\u003Cspan\\u003E\\u003Cb\\u003E@\")) + b.constructor._htmlEscapeAndStrongifyMatches(a[1], c))) + \"\\u003C/b\\u003E \\u003Cem\\u003E\")) + b.constructor._htmlEscapeAndStrongifyMatches(a[2], c))) + \"\\u003C/em\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\"));\n                }).slice(0, this.options.limit);\n                ((this.options.defaultResults && twttr.each(this.options.defaultResults, function(b) {\n                    ((((!b.show || b.show(a, e))) && f.splice(f.length, 0, b.format(a))));\n                })));\n                if (((f.length > 0))) {\n                    var g = f.join(\"\");\n                    g = this.appendNotice(g), this.constructor.cache[a] = g, this.$container.html(g), ((this.options.preselect && this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\"))), this.show();\n                }\n                 else this.hide();\n            ;\n            ;\n            },\n            position: function() {\n                JSBNG__setTimeout(twttr.bind(this, function() {\n                    if (this.$input.offsetParent().length) {\n                        var a = this.$input.position(), b = Math.round(((((a.JSBNG__top + this.$input.JSBNG__innerHeight())) + 1))), c = Math.round(a.left);\n                        this.$container.css({\n                            JSBNG__top: b,\n                            left: c\n                        });\n                    }\n                ;\n                ;\n                }), 0), this.$container.css({\n                    width: this.$input.JSBNG__innerWidth()\n                });\n            },\n            getItemTemplate: function(a, b) {\n                var c = new RegExp(((((\"(\" + this.constructor._currentPrefix.split(\"\").join(\"|\"))) + \")\")), \"gi\");\n                return twttr.map(a, twttr.bind(this, function(a, d) {\n                    return b(a, c);\n                }), null, \"array\");\n            },\n            getFilteredResults: function(a, b, c, d) {\n                var e = this, f, g = this.constructor.regCache.get(a);\n                if (g) this.regexPrefix = g;\n                 else {\n                    var i = a.split(\"\"), j = ((\"^\" + i.join(\"\\\\w*\")));\n                    this.regexPrefix = new RegExp(j, \"i\"), this.constructor.regCache.set(a, this.regexPrefix);\n                }\n            ;\n            ;\n                var k = twttr.filter(b, c);\n                return ((d ? k.sort(d) : k));\n            },\n            next: function() {\n                var a = this.$container.JSBNG__find(\"li.selected\");\n                if (!a.length) {\n                    this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\");\n                    return;\n                }\n            ;\n            ;\n                a = a.removeClass(\"selected\").nextAll(\"li.selectable:first\"), ((a.length ? a.addClass(\"selected\") : this.$container.JSBNG__find(\"li.selectable:first\").addClass(\"selected\")));\n            },\n            previous: function() {\n                var a = this.$container.JSBNG__find(\"li.selected\");\n                if (!a.length) {\n                    this.$container.JSBNG__find(\"li.selectable:last\").addClass(\"selected\");\n                    return;\n                }\n            ;\n            ;\n                a = a.removeClass(\"selected\").prevAll(\"li.selectable:first\"), ((a.length ? a.addClass(\"selected\") : this.$container.JSBNG__find(\"li.selectable:last\").addClass(\"selected\")));\n            }\n        }), a(twttr.components.Autocomplete);\n    });\n});\nprovide(\"components/Typeahead\", function(a) {\n    using(\"constants\", \"mixins/typeaheadScribing\").as(function(b, c, d) {\n        var e = twttr.klass.component(\"twttr.components.Typeahead\", function(a) {\n            var b = this, c = {\n                pauseInterval: 300,\n                closeDelay: 500,\n                select: $.noop\n            };\n            this.options = twttr.merge({\n            }, c, a), this.datasources = this.options.datasources, this._select = this.options.select, this.val = this._val = \"\", this.typingPauseDetectionTimeoutId = null, this.$input = $(this.options.input), this.$inputHint = $(this.options.inputHint), this.$node = $((new twttr.views.Typeahead).html()).insertAfter(this.$inputHint), this._isCompletionsOpen = this._wasCompletionsOpen = !1, this._keystrokes = 0, this._localLatencies = [], this._remoteLatencies = [], this._lastTimerEvent = \"none\", this._statsTimerStart = 0, this._statsCumulativeTime = 0, this._resultsDirty = !1, this._lastHint = \"\", this._placeholder = this.$input.attr(\"placeholder\"), this.resizeTimer = null, this.heightLimit = {\n                1: 0,\n                2: 1,\n                3: 2,\n                4: 3,\n                5: 5,\n                6: 6\n            };\n            var d = twttr.abdecider.choose(\"typeahead_271\", !0);\n            this.inBucket = ((((d !== \"control\")) && ((((d === \"typeahead\")) || twttr.decider.isAvailable(\"swift_typeahead\"))))), this.registerTypeaheadEvents();\n            if (((twttr.loggedIn && ((twttr.decider.isAvailable(\"typeahead\") || this.inBucket))))) {\n                var e = this.$find(\".js-typeahead-results\");\n                twttr.each(this.datasources, function(a) {\n                    a.bind(\"show\", function(a, c) {\n                        ((((((c === b._val)) && b.$input.hasClass(\"JSBNG__focus\"))) && b.show()));\n                    }), a.bind(\"scribeLocalStorageLatency\", twttr.bind(b, b.scribeLocalStorageLatency)), a.bind(\"localLatency\", twttr.bind(b, b.addLocalLatency)), a.bind(\"remoteLatency\", twttr.bind(b, b.addRemoteLatency)), a.bind(\"resultsDirty\", twttr.bind(b, b.resultsDirty)), a.bind(\"hint\", twttr.bind(b, b.hint)), a.init(), e.append(a.$node);\n                }), this.bind(\"hint\", twttr.bind(this, this.hint)), this.resizeHeight(), this.executeQueryIfAlreadyFocused();\n            }\n        ;\n        ;\n        }).deciderKey(\"typeahead\").mixin(d).methods({\n            registerTypeaheadEvents: function() {\n                var a = this, b = ((\"keypress\" + (((($.browser.webkit || $.browser.msie)) ? \" keydown\" : \"\"))));\n                this.$input.bind(\"keyup click\", twttr.bind(this, this.keyup)), this.$input.bind(b, twttr.bind(this, this.keypress)), this.$node.delegate(\".js-selectable\", \"mouseenter\", function(b) {\n                    a.$find(\".selected\").removeClass(\"selected\"), $(this).addClass(\"selected\");\n                    var c = $(this).data(\"hint\");\n                    c = ((c ? c : \"\")), a.trigger(\"hint\", [c,a.$input.val(),]);\n                }).delegate(\".js-selectable\", \"click\", twttr.bind(this, function(a) {\n                    this.select(a);\n                })), this.$input.bind(\"keydown\", function(b) {\n                    ((((b.keyCode === 27)) && (a.$input.removeClass(\"JSBNG__focus\"), a.$inputHint.removeClass(\"JSBNG__focus\"), a.hide(), a.$input.trigger(\"JSBNG__blur\")))), JSBNG__clearTimeout(a.typingPauseDetectionTimeoutId);\n                }), this.$input.bind(\"JSBNG__focus\", twttr.bind(this, this.JSBNG__focus)), this.$input.bind(\"JSBNG__blur\", twttr.bind(this, this.JSBNG__blur)), this.$node.bind({\n                    mouseenter: function() {\n                        a.mouseOverDropDown = !0;\n                    },\n                    mouseleave: function() {\n                        a.mouseOverDropDown = !1;\n                    }\n                }), twttr.widget.Dialog.bind(\"close\", twttr.bind(this, function() {\n                    this.hide();\n                })), $(window).resize(function() {\n                    JSBNG__clearTimeout(a.resizeTimer), a.resizeTimer = JSBNG__setTimeout(twttr.bind(a, a.resizeHeight), 100);\n                }), $(JSBNG__document).click(function(b) {\n                    ((a.$node.parent().JSBNG__find($(b.target)) || a.hide()));\n                }), $(JSBNG__document).bind(\"searchPlaceholderUpdate\", function(b, c) {\n                    a._placeholder = c;\n                });\n            },\n            hint: function(a, b, c) {\n                if (((twttr.decider.isAvailable(\"typeahead_hinting\") || this.inBucket))) {\n                    var d = this.$input.val();\n                    ((((((((d.toLowerCase() === c.toLowerCase())) && this.inputIsFocused())) && ((this.$input[0].scrollWidth <= this.$input.width())))) ? this.$inputHint.val(((d + b.slice(d.length)))) : this.$inputHint.val(\"\"))), ((((((c === \"\")) && ((b !== \"\")))) && this.$input.attr(\"placeholder\", \"\"))), this.$inputHint.css(\"direction\", this.$input.css(\"direction\"));\n                }\n            ;\n            ;\n            },\n            resultsDirty: function() {\n                this._resultsDirty = !0;\n                if (this.$input.hasClass(\"JSBNG__focus\")) {\n                    var a = this.$input.val();\n                    this.queryLocalData(a), this.queryRemoteData(a);\n                }\n            ;\n            ;\n            },\n            executeQueryIfAlreadyFocused: function() {\n                ((this.inputIsFocused() && (this.$input.addClass(\"JSBNG__focus\"), this.$inputHint.addClass(\"JSBNG__focus\"), this.JSBNG__focus())));\n            },\n            JSBNG__focus: function(a) {\n                var b = this.$input.val();\n                ((((((((b === this._val)) && this._wasCompletionsOpen)) && !this._resultsDirty)) ? (this.show(), ((((((this._lastHint !== \"\")) && ((twttr.decider.isAvailable(\"typeahead_hinting\") || this.inBucket)))) && (this.$inputHint.val(this._lastHint), this.$input.attr(\"placeholder\", \"\"))))) : JSBNG__setTimeout(twttr.bind(this, function() {\n                    this.queryLocalData(b), this.typingPauseDetectionTimeoutId = JSBNG__setTimeout(twttr.bind(this, function() {\n                        this.queryRemoteData(b);\n                    }), this.options.pauseInterval);\n                }), 0))), this.startStatsTimer();\n            },\n            JSBNG__blur: function(a) {\n                this._lastHint = this.$inputHint.val();\n                if (((twttr.decider.isAvailable(\"typeahead_hinting\") || this.inBucket))) {\n                    this.$inputHint.val(\"\"), this.$input.attr(\"placeholder\", this._placeholder);\n                }\n            ;\n            ;\n                ((((!this.mouseOverDropDown && !twttr.search.mouseOverMagnifying)) && JSBNG__setTimeout(twttr.bind(this, function() {\n                    this.hide();\n                }), this.options.closeDelay))), this.pauseStatsTimer();\n            },\n            inputIsFocused: function() {\n                return ((this.$input.is(\":focus\") || ((this.$input[0] == JSBNG__document.activeElement))));\n            },\n            resizeHeight: function() {\n                var a = $(window).height(), b = Math.ceil(((a / 100))), c = ((((b in this.heightLimit)) ? this.heightLimit[b] : ((((b < 2)) ? 1 : 6))));\n                twttr.each(this.datasources, function(a) {\n                    a.trigger(\"newLimit\", c);\n                });\n            },\n            autocompleteHint: function(a) {\n                if (((((this._isCompletionsOpen && !a.shiftKey)) && this.isCursorAtEnd()))) {\n                    var c = ((this.$input.css(\"direction\") === \"rtl\"));\n                    if (((((c && ((a.keyCode === b.constants.keyCodes.rightArrow)))) || ((!c && ((a.keyCode === b.constants.keyCodes.leftArrow))))))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this.$node.JSBNG__find(\".js-selectable.selected[data-hint]:visible\").first();\n                    if (((((d.length === 0)) && ((this.$node.JSBNG__find(\".js-selectable.selected\").length === 1))))) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((d.length === 0)) && (d = this.$node.JSBNG__find(\".js-selectable[data-hint]:visible\").first()))), this.$input.val(d.data(\"hint\")), a.preventDefault();\n                }\n            ;\n            ;\n            },\n            isCursorAtEnd: function() {\n                var a;\n                return ((JSBNG__document.selection ? (this.$input.JSBNG__focus(), a = JSBNG__document.selection.createRange(), a.moveStart(\"character\", -this.$input[0].value.length), ((((this.$input.val().length - a.text.length)) === 0))) : ((((typeof this.$input[0].selectionStart == \"number\")) ? ((((this.$input.val().length - this.$input[0].selectionStart)) === 0)) : !0))));\n            },\n            hide: function() {\n                JSBNG__setTimeout(twttr.bind(this, function() {\n                    ((this._isCompletionsOpen && (this.$node.hide(), this._wasCompletionsOpen = this._isCompletionsOpen, ((this._isCompletionsOpen && this.trigger(\"hide\"))), this._isCompletionsOpen = !1)));\n                }), 0);\n            },\n            show: function() {\n                ((((this.$find(\".js-selectable\").length > 0)) && (this.$node.show(), this._isCompletionsOpen = !0)));\n            },\n            keypress: function(a) {\n                a.stopPropagation();\n                switch (a.keyCode) {\n                  case b.constants.keyCodes.enter:\n                    if (((((((this.inputIsFocused() && !a.shiftKey)) && ((a.type === \"keypress\")))) || ((((((this.inputIsFocused() && !a.shiftKey)) && ((a.type === \"keydown\")))) && ((a.metaKey || a.ctrlKey))))))) {\n                        a.preventDefault(), this.select(a);\n                    }\n                ;\n                ;\n                    break;\n                  case b.constants.keyCodes.escape:\n                    ((this._isCompletionsOpen && a.preventDefault()));\n                    break;\n                  case b.constants.keyCodes.rightArrow:\n                    if (((a.charCode === 39))) {\n                        break;\n                    }\n                ;\n                ;\n                  case b.constants.keyCodes.leftArrow:\n                \n                  case b.constants.keyCodes.tab:\n                    this.autocompleteHint(a);\n                    break;\n                  case b.constants.keyCodes.upArrow:\n                    ((((this._isCompletionsOpen && !a.shiftKey)) && (this.previous(), a.preventDefault())));\n                    break;\n                  case b.constants.keyCodes.downArrow:\n                    ((((this._isCompletionsOpen && !a.shiftKey)) && (this.next(), a.preventDefault())));\n                };\n            ;\n            },\n            keyup: function(a) {\n                ((((a.type !== \"click\")) && (a.stopPropagation(), ((((a.keyCode !== b.constants.keyCodes.enter)) && this._keystrokes++)))));\n                if (((((a && ((((a.keyCode === b.constants.keyCodes.tab)) || ((a.keyCode === b.constants.keyCodes.shift)))))) && !this._isCompletionsOpen))) {\n                    return;\n                }\n            ;\n            ;\n                val = this.$input.val();\n                var c = this;\n                if (((((val !== this._val)) || this._resultsDirty))) {\n                    this.hide(), JSBNG__setTimeout(twttr.bind(this, function() {\n                        this.queryLocalData(val), this.typingPauseDetectionTimeoutId = JSBNG__setTimeout(function() {\n                            c.queryRemoteData(val);\n                        }, this.options.pauseInterval);\n                    }), 0), this._resultsDirty = !1;\n                }\n            ;\n            ;\n            },\n            queryLocalData: function(a) {\n                ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"typeahead_local_queries\") || this.inBucket)))) && (this._val = a, twttr.each(this.datasources, function(b) {\n                    b.localQueryAndRenderResults(a);\n                }))));\n            },\n            queryRemoteData: function(a) {\n                var b = this;\n                ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"typeahead_remote_queries\") || this.inBucket)))) && twttr.each(b.datasources, function(b) {\n                    b.remoteQueryAndRenderResults(a);\n                })));\n            },\n            select: function(a) {\n                var b = this.$find(\".selected\"), c = this.$input.val();\n                if (((((c === \"\")) && ((b.length === 0))))) {\n                    return;\n                }\n            ;\n            ;\n                var d = ((a.metaKey || a.ctrlKey));\n                this.$input.val(\"\"), this.$inputHint.val(\"\"), this.hide(), this.$input.JSBNG__blur(), trackClient({\n                    section: \"top_nav\",\n                    component: \"searchbox\",\n                    action: \"search\"\n                }, {\n                    query: c\n                }), this.scribeSelect(a, c, b, d), this._select(a, c, b, d);\n            },\n            next: function() {\n                var a = this.$find(\".selected\").removeClass(\"selected\"), b = this.$find(\".js-selectable:visible\"), c = b.index(a), d = ((((c === b.length)) ? 0 : ((c + 1))));\n                ((((d !== b.length)) && $(b[d]).addClass(\"selected\")));\n                var e = ((d === b.length)), f = $(b[d]), g = $(b[0]);\n                this.hintForNextOrPreviousItem(e, f, g);\n            },\n            previous: function() {\n                var a = this.$find(\".selected\").removeClass(\"selected\"), b = this.$find(\".js-selectable:visible\"), c = b.index(a), d = ((((c === -1)) ? ((b.length - 1)) : ((c - 1))));\n                ((((d !== -1)) && $(b[d]).addClass(\"selected\")));\n                var e = ((d === -1)), f = $(b[d]), g = $(b[0]);\n                this.hintForNextOrPreviousItem(e, f, g);\n            },\n            hintForNextOrPreviousItem: function(a, b, c) {\n                var d = this.$input.val(), e = b.data(\"hint\"), f = \"\";\n                ((e ? f = e : ((a && (f = c.data(\"hint\")))))), this.trigger(\"hint\", [f,d,]);\n            }\n        });\n        a(e);\n    });\n});\nprovide(\"components/TypeaheadDatasource\", function(a) {\n    using().as(function(b, _) {\n        var c = twttr.klass.component(\"twttr.components.TypeaheadDatasource\").methods({\n            init: $.noop,\n            localQueryAndRenderResults: $.noop,\n            remoteQueryAndRenderResults: $.noop,\n            inBucket: function() {\n                var a = twttr.abdecider.choose(\"typeahead_271\", !0);\n                return ((((a !== \"control\")) && ((((a === \"typeahead\")) || twttr.decider.isAvailable(\"swift_typeahead\")))));\n            },\n            tokenizeName: function(a) {\n                return $.trim(a.replace(/[@#]/, \"\")).toLowerCase().split(/[\\s-_]+/);\n            },\n            tokenizeScreenName: function(a) {\n                return $.trim(a).toLowerCase().split(/_/);\n            },\n            tokenizeText: function(a) {\n                return $.trim(a).toLowerCase().split(/[\\s-_]+/);\n            },\n            queryTopicAndAccountRemoteApi: function(a, b, c) {\n                twttr.API.User.typeaheadGlobal(a, {\n                    count: b,\n                    success: function(b) {\n                        $(JSBNG__document).trigger(\"accountResults\", [a,c,b.users,]), $(JSBNG__document).trigger(\"topicResults\", [a,c,b.topics,]);\n                    }\n                });\n            },\n            updateStorageCache: function() {\n                var a = 259200000;\n                twttr.caches.User.set(\"typeahead_friends\", twttr.users.typeahead, a), twttr.caches.User.set(\"typeahead_people_from_api\", ((((twttr.users.typeahead.length - 1)) || 0)));\n            },\n            reset: function() {\n                twttr.caches.User.reset();\n            },\n            get: function(a) {\n                twttr.caches.User.get(a);\n            },\n            set: function(a, b, c) {\n                var d = 259200000;\n                c = ((c || d)), twttr.caches.User.set(a, b, c);\n            },\n            update: function(a, b) {\n                twttr.caches.User.update(a, b);\n            },\n            \"delete\": function(a) {\n                twttr.caches.User.set(a, null, -1);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/TypeaheadSearchQueryDatasource\", function(a) {\n    using(\"components/TypeaheadDatasource\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.TypeaheadSearchQueryDatasource\", function(a) {\n            var b = {\n                limit: 6\n            };\n            this.options = twttr.merge({\n            }, b, a), this.$node = (new twttr.views.TypeaheadSavedSearches).render(), this.$results = this.$find(\"ul\"), this.savedSearches = [], this._version = 10, this._lastQuery = \"\";\n        }).subclassOf(b.components.TypeaheadDatasource).deciderKey(\"typeahead_saved_searches\").methods({\n            init: function() {\n                var a = this;\n                this.$node.hide(), ((((this._version !== twttr.caches.User.get(\"saved_searches_version\"))) && (twttr.caches.User.set(\"saved_searches\", null, -1), twttr.caches.User.set(\"saved_searches_version\", this._version)))), this.cacheSavedSearches(), twttr.API.SavedSearch.bind(\"create\", function(b, c) {\n                    ((((b.type === \"create\")) && (((($.inArray(c), a.savedSearches) && a.savedSearches.push(c))), twttr.caches.User.update(\"saved_searches\", a.savedSearches), ((((a.savedSearches.length === 1)) && $(\".global-nav .js-search-form\").addClass(\"has-saved-searches\"))), a.updateOrDirtyResults())));\n                }), twttr.API.SavedSearch.bind(\"delete\", function(b, c) {\n                    ((((b.type === \"delete\")) && (a.savedSearches = a.savedSearches.filter(function(a) {\n                        return ((a.query != c.query));\n                    }), twttr.caches.User.update(\"saved_searches\", a.savedSearches), ((((a.savedSearches.length === 0)) && $(\".global-nav .js-search-form\").removeClass(\"has-saved-searches\"))), a.updateOrDirtyResults())));\n                }), this.bindLimitBasedOnWindowHeight(), this.bindRemoteApiListener();\n            },\n            bindRemoteApiListener: function() {\n                var a = this;\n                ((((twttr.decider.isAvailable(\"typeahead_searches\") || this.inBucket())) && $(JSBNG__document).bind(\"topicResults\", function(b, c, d, e) {\n                    var c = a._lastQuery, f = \"\", g = [];\n                    if (((c === \"\"))) g = a.savedSearches;\n                     else {\n                        ((e.length && twttr.each(e, function(b) {\n                            var c = b.topic, d = b.rounded_score;\n                            ((a.isSavedSearch(c) || g.push(a.mapQuerySuggestionsToApiSearchItem(c, d))));\n                        })));\n                        if (((twttr.decider.isAvailable(\"typeahead_new_style_saved_searches\") || a.inBucket()))) {\n                            g = g.concat(twttr.filter(a.savedSearches, twttr.bind(a, a.matcher(c))));\n                        }\n                    ;\n                    ;\n                        g = g.slice(0, Math.min(4, a.options.limit));\n                    }\n                ;\n                ;\n                    f = ((((g.length > 0)) ? g[0].JSBNG__name : \"\")), a.trigger(\"hint\", [f,c,]), a.render(g, c);\n                    var i = ((new JSBNG__Date - d));\n                    a.trigger(\"remoteLatency\", i);\n                })));\n            },\n            bindLimitBasedOnWindowHeight: function() {\n                this.bind(\"newLimit\", twttr.bind(this, function(a, b) {\n                    this.options.limit = b;\n                }));\n            },\n            updateOrDirtyResults: function() {\n                ((this.$node.is(\":visible\") ? this.localQueryAndRenderResults(this._lastQuery) : this.trigger(\"resultsDirty\")));\n            },\n            cacheSavedSearches: function() {\n                var a = this;\n                savedSearches = twttr.caches.User.get(\"saved_searches\"), ((savedSearches ? a.savedSearches = savedSearches : twttr.currentUser.savedSearches(function(b) {\n                    a.savedSearches = b.array, $(\".global-nav .js-search-form\").addClass(\"has-saved-searches\");\n                    var c = 3600000;\n                    twttr.caches.User.set(\"saved_searches\", a.savedSearches, c), a.trigger(\"resultsDirty\");\n                })));\n            },\n            mapQuerySuggestionsToApiSearchItem: function(a, b) {\n                return {\n                    debug_info: ((twttr.decider.isAvailable(\"typeahead_debug_info\") ? ((((\" title=\\\"score = \" + b)) + \"\\\"\")) : \"\")),\n                    search_results_path: twttr.router.searchResultsPath({\n                        query: a\n                    }),\n                    query: a,\n                    JSBNG__name: a,\n                    search_query_source: \"typeahead_click\"\n                };\n            },\n            localQueryAndRenderResults: function(a) {\n                if (((twttr.decider.isAvailable(\"typeahead_saved_searches\") || this.inBucket()))) {\n                    var b = new JSBNG__Date;\n                    this._lastQuery = a;\n                    var c = twttr.filter(this.savedSearches, twttr.bind(this, this.matcher(a)));\n                    this.render(c, a);\n                    var d = ((c[0] ? c[0].JSBNG__name : \"\"));\n                    this.trigger(\"hint\", [d,a,]);\n                    var e = ((new JSBNG__Date - b));\n                    this.trigger(\"localLatency\", e);\n                }\n            ;\n            ;\n            },\n            remoteQueryAndRenderResults: $.noop,\n            matcher: function(a) {\n                return function(b) {\n                    if (((b.JSBNG__name.toLowerCase().indexOf(a.toLowerCase()) === 0))) {\n                        return b;\n                    }\n                ;\n                ;\n                };\n            },\n            ranker: function(a) {\n                return function(b, c) {\n                    return ((((((a.length / c.length)) + c.matched_count)) - ((((a.length / b.length)) + b.matched_count))));\n                };\n            },\n            renderSearch: function(a) {\n                return (new twttr.views.TypeaheadSearchItem(a)).html();\n            },\n            render: function(a, b) {\n                this.$results.attr(\"data-search-query\", b.toLowerCase());\n                var c = twttr.map(a, this.renderSearch);\n                if (((c.length > 0))) {\n                    var d = c.join(\"\");\n                    this.$results.html(d), this.$node.show(), this.$node.addClass(\"has-results\"), this.trigger(\"show\", b);\n                }\n                 else this.$results.empty(), this.$node.hide(), this.$node.removeClass(\"has-results\");\n            ;\n            ;\n            },\n            isSavedSearch: function(a) {\n                for (var b = 0, c = this.savedSearches.length; ((b < c)); b++) {\n                    if (((this.savedSearches[b].JSBNG__name.toLowerCase() === a))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/TypeaheadAccountsDatasource\", function(a) {\n    using(\"components/TypeaheadDatasource\").as(function(b, _) {\n        twttr.provide(\"twttr.users\", {\n            typeahead: {\n                adjacencyList: {\n                },\n                userHash: {\n                },\n                length: 0\n            }\n        });\n        var c = twttr.klass.component(\"twttr.components.TypeaheadAccountsDatasource\", function(a) {\n            var b = {\n                limit: 6\n            };\n            this.options = twttr.merge({\n            }, b, a), this.$node = (new twttr.views.TypeaheadAccounts).render(), this.$results = this.$find(\"ul\"), this.weights = {\n                PROFILE_VISIT_BOOST: 10,\n                UNCACHED_PROFILE_VISIT: 75,\n                FOLLOW: 100,\n                UNBLOCK: 50,\n                SELF: 250\n            }, this.IE8_ACCOUNT_LIMIT = 1000, this.ACCOUNT_LIMIT = 2500, this.addUsersQueue = [], this.blocks = {\n            }, this.userIdsCurrentlyRendered = {\n            }, this._version = 66, this.isFullySupportedBrowser = !(($.browser.msie && ((parseInt($.browser.version, 10) < 8))));\n        }).subclassOf(b.components.TypeaheadDatasource).deciderKey(\"typeahead_people\").methods({\n            init: function() {\n                this.$node.hide(), ((((this.isFullySupportedBrowser && ((((twttr.decider.isAvailable(\"typeahead_people\") && twttr.decider.isAvailable(\"typeahead_people_local_queries\"))) || this.inBucket())))) && (this.clearCacheIfNewVersion(), this.bindRemoteApiListener(), this.bindProfileVisitHandler(), this.bindFollowEventHandler(), this.bindBlockEventHandler(), this.bindUnblockEventHandler(), this.bindLimitBasedOnWindowHeight(), this.getTypeaheadUsers(), this.userIdsCurrentlyRendered = {\n                })));\n            },\n            clearCacheIfNewVersion: function() {\n                ((((this._version !== twttr.caches.User.get(\"typeahead_people_version\"))) && (twttr.caches.User.set(\"typeahead_friends\", null, -1), twttr.caches.User.set(\"blocks\", null, -1), twttr.caches.User.set(\"typeahead_people_version\", this._version), twttr.caches.User.set(\"typeahead_people_from_api\", 0), twttr.caches.User.set(\"typeahead_people_followed\", 0), twttr.caches.User.set(\"typeahead_profile_visits\", 0), twttr.caches.User.set(\"typeahead_people_blocked\", 0), twttr.caches.User.set(\"typeahead_people_unblocked\", 0))));\n            },\n            mapJavaScriptUser: function(a, b) {\n                return {\n                    id: a.id,\n                    screen_name: a.screenName,\n                    JSBNG__name: a.JSBNG__name,\n                    profile_image_url: a.profileImageUrl,\n                    profile_image_url_https: a.profileImageUrlHttps,\n                    verified: a.verified,\n                    tokens: ((a.tokens || this.tokenizeJavascriptUserObject(a))),\n                    weight: ((((b || a.weight)) || 0))\n                };\n            },\n            mapApiUser: function(a, b) {\n                return {\n                    id: a.id,\n                    screen_name: a.screen_name,\n                    JSBNG__name: a.JSBNG__name,\n                    profile_image_url: a.profile_image_url,\n                    profile_image_url_https: a.profile_image_url_https,\n                    verified: a.verified,\n                    tokens: a.tokens,\n                    weight: ((((b || parseFloat(a.rounded_graph_weight))) || 0))\n                };\n            },\n            bindRemoteApiListener: function() {\n                $(JSBNG__document).bind(\"accountResults\", twttr.bind(this, function(a, b, c, d) {\n                    if (((this.$results.attr(\"data-query\") === b.toLowerCase()))) {\n                        d = twttr.filter(d, twttr.bind(this, this.filterBlockedUsers)), d = twttr.filter(d, twttr.bind(this, this.filterAlreadyDisplayedUsers)), this.renderRemoteUsers(d, b);\n                        var e = ((new JSBNG__Date - c));\n                        this.trigger(\"remoteLatency\", e);\n                    }\n                ;\n                ;\n                }));\n            },\n            bindProfileVisitHandler: function() {\n                var a = this;\n                $(JSBNG__document).bind(\"profileVisit\", function(b, c) {\n                    if (!c.screenName) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = a.removeFromList(a.mapJavaScriptUser(c));\n                    ((d ? (d.tokens = a.tokenizeJavascriptUserObject(d), a.addToList(a.mapApiUser(d, ((d.weight + a.weights.PROFILE_VISIT_BOOST))))) : (c.tokens = a.tokenizeJavascriptUserObject(c), a.addToList(a.mapJavaScriptUser(c, a.weights.UNCACHED_PROFILE_VISIT)))));\n                    var e = ((a.get(\"typeahead_profile_visits\") || 0));\n                    a.set(\"typeahead_profile_visits\", ((e + 1)));\n                });\n            },\n            bindFollowEventHandler: function() {\n                var a = this;\n                twttr.API.User.bind(\"follow\", function(b, c) {\n                    a.addToList(a.mapJavaScriptUser(c, a.weights.FOLLOW)), a.set(\"typeahead_people_followed\", ((a.get(\"typeahead_people_followed\") + 1))), a.trigger(\"resultsDirty\");\n                });\n            },\n            bindBlockEventHandler: function() {\n                var a = this;\n                twttr.API.User.bind(\"block\", function(b, c) {\n                    a.blocks[c.id] = c, a.update(\"blocks\", a.blocks), a.removeFromList(a.mapJavaScriptUser(c)), a.set(\"typeahead_people_blocked\", ((a.get(\"typeahead_people_blocked\") + 1))), a.trigger(\"resultsDirty\");\n                });\n            },\n            bindUnblockEventHandler: function() {\n                var a = this;\n                twttr.API.User.bind(\"unblock\", function(b, c) {\n                    delete a.blocks[c.id], a.update(\"blocks\", a.blocks), a.addToList(a.mapJavaScriptUser(c, a.weights.UNBLOCK)), a.set(\"typeahead_people_unblocked\", ((a.get(\"typeahead_people_unblocked\") + 1))), a.trigger(\"resultsDirty\");\n                });\n            },\n            bindLimitBasedOnWindowHeight: function() {\n                this.bind(\"newLimit\", twttr.bind(this, function(a, b) {\n                    this.options.limit = b;\n                }));\n            },\n            localQueryAndRenderResults: function(a) {\n                this.userIdsCurrentlyRendered = {\n                }, this.$results.attr(\"data-query\", a.toLowerCase());\n                if (((this.isFullySupportedBrowser && ((((twttr.decider.isAvailable(\"typeahead_people\") && twttr.decider.isAvailable(\"typeahead_people_local_queries\"))) || this.inBucket()))))) {\n                    var b = new JSBNG__Date, c;\n                    ((((a.length && twttr.users.typeahead)) ? (processedQuery = this.processQuery(a), c = this.getPossiblyMatchingAccounts(processedQuery), c = twttr.filter(c, twttr.bind(this, this.matcher(processedQuery, twttr.users.typeahead.length))), c = twttr.filter(c, twttr.bind(this, this.filterBlockedUsers)), c = c.sort(this.ranker), c = c.slice(0, this.options.limit)) : c = [])), this.renderLocalUsers(c, a);\n                    var d = ((new JSBNG__Date - b));\n                    this.trigger(\"localLatency\", d);\n                }\n            ;\n            ;\n            },\n            remoteQueryAndRenderResults: function(a) {\n                var b = this;\n                if (((this.isFullySupportedBrowser && ((((twttr.decider.isAvailable(\"typeahead_people\") && twttr.decider.isAvailable(\"typeahead_people_remote_queries\"))) || this.inBucket()))))) {\n                    var c = new JSBNG__Date, d;\n                    ((a.length && this.queryTopicAndAccountRemoteApi(a, ((this.options.limit + 2)), c)));\n                }\n            ;\n            ;\n            },\n            processQuery: function(a) {\n                var b = this.tokenizeText(a);\n                return {\n                    raw: a,\n                    length: a.length,\n                    terms: twttr.map(this.tokenizeText(a), function(a) {\n                        return {\n                            val: a\n                        };\n                    })\n                };\n            },\n            getUserObjectsFromIds: function(a) {\n                var b = [], c = twttr.users.typeahead.userHash;\n                for (var d = 0, e = a.length; ((d < e)); d++) {\n                    (((($.inArray(c[a[d]], b) === -1)) && b.push(c[a[d]])));\n                ;\n                };\n            ;\n                return b;\n            },\n            getPossiblyMatchingAccounts: function(a) {\n                var b = {\n                }, c = {\n                };\n                for (var d = 0, e = a.terms.length; ((d < e)); d++) {\n                    var f = a.terms[d], g = f.val[0], i = twttr.users.typeahead.adjacencyList[g];\n                    ((((((f && i)) && !b[g])) && (b[g] = !0, twttr.map(i, function(a) {\n                        c[a] = !0;\n                    }))));\n                };\n            ;\n                var j = [];\n                return $.each(c, function(a) {\n                    j.push(a);\n                }), this.getUserObjectsFromIds(j);\n            },\n            matcher: function(a, b) {\n                return function(b) {\n                    var c = b.tokens, d = [];\n                    for (var e = 0, f = c.length; ((e < f)); e++) {\n                        for (var g = 0, i = a.terms.length; ((g < i)); g++) {\n                            ((((c[e].token.indexOf(a.terms[g].val) === 0)) && d.push(g)));\n                        ;\n                        };\n                    ;\n                    };\n                ;\n                    b.matchedCount = $.unique(d).length;\n                    if (((b.matchedCount === a.terms.length))) {\n                        return b;\n                    }\n                ;\n                ;\n                };\n            },\n            ranker: function(a, b) {\n                return ((b.weight - a.weight));\n            },\n            renderLocalUsers: function(a, b) {\n                var c = twttr.map(a, twttr.bind(this, this.renderAccount));\n                ((((b && a.length)) && c.push((new twttr.views.TypeaheadAccountsShortcut({\n                    query: b\n                })).html()))), this.$results.html(c.join(\"\")), ((((c.length > 0)) ? (this.$node.show(), this.$node.addClass(\"has-results\"), this.trigger(\"show\", b)) : (this.$node.hide(), this.$node.removeClass(\"has-results\"))));\n            },\n            renderRemoteUsers: function(a, b) {\n                var c = this.$results.JSBNG__find(\"li a[data-shortcut=\\\"true\\\"]\").length, d = ((this.$results.JSBNG__find(\"li\").length - c));\n                a = a.slice(0, Math.max(0, ((this.options.limit - d))));\n                var e = twttr.map(a, twttr.bind(this, this.renderAccount));\n                ((((((b && ((c === 0)))) && a.length)) ? (e.push((new twttr.views.TypeaheadAccountsShortcut({\n                    query: b\n                })).html()), this.$results.html(e.join(\"\"))) : $(e.join(\"\")).insertBefore(this.$results.JSBNG__find(\".js-shortcut\")))), ((((e.length > 0)) && (this.$node.show(), this.$node.addClass(\"has-results\"), this.trigger(\"show\", b))));\n            },\n            tokenizeJavascriptUserObject: function(a) {\n                var b = this.tokenizeScreenName(a.screenName).concat([((\"@\" + a.screenName)),], this.tokenizeName(a.JSBNG__name));\n                return twttr.map(b, function(a) {\n                    return {\n                        token: a\n                    };\n                });\n            },\n            mapApiUsers: function(a) {\n                var b = this;\n                return twttr.map(a, function(a, c) {\n                    return b.mapApiUser(a);\n                });\n            },\n            addCurrentUser: function() {\n                if (twttr.currentUser) {\n                    var a = twttr.currentUser;\n                    a.tokens = this.tokenizeJavascriptUserObject(a), this.addToList(this.mapJavaScriptUser(twttr.currentUser, this.weights.SELF));\n                }\n            ;\n            ;\n            },\n            getTypeaheadUsers: function() {\n                if (((twttr.decider.isAvailable(\"typeahead_local_queries\") || this.inBucket()))) {\n                    if (!this.requestedUsers) {\n                        var a = this;\n                        this.requestedUsers = !0;\n                        var b = twttr.caches.User.get(\"typeahead_people_from_api\"), c = +(new JSBNG__Date);\n                        twttr.users.typeahead = twttr.caches.User.get(\"typeahead_friends\"), ((((((b && ((b !== 0)))) && !!twttr.users.typeahead)) ? (this.trigger(\"scribeLocalStorageLatency\", [\"load\",((+(new JSBNG__Date) - c)),]), this.processQueuedUsers(), this.trigger(\"resultsDirty\")) : twttr.API.User.typeaheadSocial(twttr.currentUser.id, {\n                            count: (((($.browser.msie && ((parseInt($.browser.version, 10) === 8)))) ? a.IE8_ACCOUNT_LIMIT : a.ACCOUNT_LIMIT)),\n                            success: function(b) {\n                                ((b.length && (b = a.mapApiUsers(b), a.getBlockedUsers(function() {\n                                    b = a.filterBlockedUsers(b);\n                                    var c = ((twttr.is.def(twttr.users.typeahead) ? twttr.users.typeahead : {\n                                        adjacencyList: {\n                                        },\n                                        userHash: {\n                                        },\n                                        length: 0\n                                    }));\n                                    twttr.users.typeahead = a.preprocessUsers(b, c), a.addCurrentUser();\n                                    var d = +(new JSBNG__Date);\n                                    a.updateStorageCache(), a.trigger(\"scribeLocalStorageLatency\", [\"save\",((+(new JSBNG__Date) - d)),]), a.trigger(\"resultsDirty\");\n                                }), a.processQueuedUsers())));\n                            }\n                        })));\n                    }\n                ;\n                }\n            ;\n            ;\n            },\n            preprocessUsers: function(a, b) {\n                for (var c = 0, d = a.length; ((c < d)); c++) {\n                    var e = a[c];\n                    for (var f = 0, g = e.tokens.length; ((f < g)); f++) {\n                        var i = e.tokens[f].token[0];\n                        if (!i) {\n                            break;\n                        }\n                    ;\n                    ;\n                        ((b.adjacencyList[i] || (b.adjacencyList[i] = []))), (((($.inArray(e.id, b.adjacencyList[i]) === -1)) && b.adjacencyList[i].push(e.id)));\n                    };\n                ;\n                    b.userHash[a[c].id] = a[c];\n                };\n            ;\n                return b.length = ((b.length + a.length)), b;\n            },\n            getBlockedUsers: function(a) {\n                var b = this;\n                blocks = b.get(\"blocks\"), ((blocks ? a(blocks) : twttr.currentUser.blocks(function(c) {\n                    c = c.array;\n                    for (var d = 0, e = c.length; ((d < e)); d++) {\n                        b.blocks[c[d].id] = c[d];\n                    ;\n                    };\n                ;\n                    var f = 3600000;\n                    b.set(\"blocks\", b.blocks, f), a(b.blocks);\n                })));\n            },\n            filterBlockedUsers: function(a) {\n                if (!twttr.is.def(this.blocks[a.id])) {\n                    return a;\n                }\n            ;\n            ;\n            },\n            filterAlreadyDisplayedUsers: function(a) {\n                if (!twttr.is.def(this.userIdsCurrentlyRendered[a.id])) {\n                    return a;\n                }\n            ;\n            ;\n            },\n            renderAccount: function(a) {\n                this.userIdsCurrentlyRendered[a.id] = a;\n                var b = ((twttr.isSSL() ? a.profile_image_url_https : a.profile_image_url));\n                return a.avatar = twttr.helpers.transformProfileImageUrl(b, \"mini\"), a.verified = ((a.verified ? \" \\u003Ci class=\\\"verified\\\"\\u003E\\u003C/i\\u003E\" : \"\")), ((twttr.decider.isAvailable(\"typeahead_debug_info\") ? (isUserLocal = twttr.is.def(a.weight), a.debug_info = twttr.util.supplant(\" title=\\\"{datasource} user, weight/score: {score}\\\"\", {\n                    datasource: ((isUserLocal ? \"local\" : \"remote\")),\n                    score: ((isUserLocal ? a.weight : a.rounded_score))\n                })) : a.debug_info = \"\")), (new twttr.views.TypeaheadAccountItem(a)).html();\n            },\n            processQueuedUsers: function() {\n                for (var a = 0, b = this.addUsersQueue.length; ((a < b)); a++) {\n                    this.addToList(this.addUsersQueue[a]);\n                ;\n                };\n            ;\n            },\n            addToList: $.noop,\n            removeFromList: function(a) {\n                return a;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/GlobalNavTypeahead\", function(a) {\n    using(\"constants\", \"components/Typeahead\", \"components/TypeaheadSearchQueryDatasource\", \"components/TypeaheadAccountsDatasource\").as(function(b, c, _) {\n        var d = twttr.klass(\"twttr.components.GlobalNavTypeahead\", function(a) {\n            var c = {\n                input: $(\"#search-query\"),\n                inputHint: $(\"#search-query-hint\"),\n                datasources: [new b.components.TypeaheadSearchQueryDatasource,new b.components.TypeaheadAccountsDatasource,],\n                select: function(a, b, c, d) {\n                    var e = c.JSBNG__find(\"a\").attr(\"data-shortcut\"), f = c.attr(\"data-user-screenname\"), b = ((c.JSBNG__find(\"a\").attr(\"data-search-query\") || b)), g = ((c.JSBNG__find(\"a\").attr(\"data-query-source\") === \"saved_search_click\")), i = ((g ? twttr.search.searchQuerySource.SAVED_SEARCH_CLICK : twttr.search.searchQuerySource.TYPEAHEAD_CLICK));\n                    ((((!c.JSBNG__find(\"a\").attr(\"data-search-query\") && !f)) && (i = twttr.search.searchQuerySource.TYPED_QUERY))), twttr.search.setLastQuerySource(i);\n                    var j;\n                    ((e ? j = c.JSBNG__find(\"a\")[0].href : ((f ? j = twttr.router.profilePath({\n                        screen_name: f\n                    }) : (twttr.search.$searchQuery.val(b), j = twttr.router.searchResultsPath({\n                        query: b\n                    })))))), ((d ? window.open(j) : twttr.router.routeTo(j))), a.preventDefault();\n                }\n            }, a = twttr.merge({\n            }, c, a);\n            ((((!twttr.isMobile && ((twttr.decider.isAvailable(\"typeahead_global_nav\") || ((twttr.abdecider.choose(\"typeahead_271\") === \"typeahead\")))))) && b.components.Typeahead.call(this, a)));\n        }).subclassOf(b.components.Typeahead);\n        a(d);\n    });\n});\nprovide(\"components/Editor\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        twttr.klass(\"twttr.components.Editor\", function(a, b) {\n            var c = this;\n            this.$container = $(a), this.$container.addClass(\"twttr-editor\"), this.options = ((b || {\n            })), this._defaultContent = ((this.options.defaultContent || \"\")), this._enableAutoGrow = ((this.options.enableAutoGrow || !1)), ((this._isIE7() && (this._enableAutoGrow = !1))), this._autoGrowMinHeight = ((this.options.height || 75));\n            var d = ((this.options.width || \"100%\")), e = ((this.options.height || \"auto\"));\n            this.$editor = $(\"\\u003Ctextarea/\\u003E\").addClass(\"twitter-anywhere-tweet-box-editor\").css({\n                width: d,\n                height: e\n            }).val(this._defaultContent), ((this.options.condensed && this.$container.addClass(\"condensed\"))), this.css = {\n                width: (($.browser.mozilla ? ((d - 2)) : d)),\n                height: e,\n                \"min-height\": e\n            }, this.$container.append(this.$editor), ((this._enableAutoGrow && (this.$editor.css(\"overflow\", \"hidden\"), this.$shadow = this._createShadowForTextArea(this.$editor), this.$shadow.appendTo(this.$editor.parent())))), this._registerEvents();\n        }).methods(twttr.EventProvider).methods({\n            moveCursorToEnd: function() {\n                var a = this.$editor[0];\n                JSBNG__setTimeout(function() {\n                    try {\n                        if (a.createTextRange) {\n                            var b = a.createTextRange();\n                            b.collapse(!0), b.moveStart(\"character\", a.value.length), b.moveEnd(\"character\", a.value.length), b.select();\n                        }\n                         else a.selectionStart = a.value.length;\n                    ;\n                    ;\n                    } catch (c) {\n                    \n                    };\n                ;\n                }, 0);\n            },\n            JSBNG__content: function() {\n                return this.$editor.val().replace(twttr.constants.regexps.dirMark, \"\");\n            },\n            setContent: function(a) {\n                a = ((a || \"\")), this.$editor.val(a), this.trigger(\"didChangeContent\", [a,]);\n            },\n            height: function(a) {\n                this.$editor.css(\"height\", a);\n            },\n            width: function(a) {\n                this.$editor.css(\"width\", a);\n            },\n            JSBNG__focus: function() {\n                this.$editor.JSBNG__focus(), this.moveCursorToEnd();\n            },\n            JSBNG__blur: function() {\n                this.$editor.JSBNG__blur();\n            },\n            toggle: function() {\n                this.$editor.toggle();\n            },\n            reset: function() {\n                this.setContent(\"\");\n            },\n            _tryAutoGrow: function() {\n                var a = this._autoGrowMinHeight, b = 150, c = \"xyz\", d = this.$editor;\n                this._copyCssPropertiesFromTextArea(this.$shadow, d), this.$shadow.text(((d.val() + c)));\n                var e = this.$shadow.height();\n                ((((((e > a)) && ((e <= b)))) ? (d.css(\"overflow\", \"hidden\"), d.height(e)) : ((((e < a)) ? (d.css(\"overflow\", \"hidden\"), d.height(a)) : ((((e > b)) && d.css(\"overflow\", \"auto\")))))));\n            },\n            _isIE7: function() {\n                return (($.browser.msie && ((parseInt($.browser.version, 10) === 7))));\n            },\n            _copyCssPropertiesFromTextArea: function(a, b) {\n                var c = [\"font-family\",\"font-size\",\"font-weight\",\"line-height\",\"padding-bottom\",\"padding-left\",\"padding-right\",\"padding-top\",\"white-space\",\"width\",\"word-wrap\",];\n                $.each(c, function(c, d) {\n                    a.css(d, b.css(d));\n                });\n            },\n            _createShadowForTextArea: function(a) {\n                var b = $(\"\\u003Cdiv /\\u003E\").css(\"display\", \"none\");\n                return this._copyCssPropertiesFromTextArea(b, a), b;\n            },\n            _registerEvents: function() {\n                var a = this;\n                this.$editor.bind(\"focus blur\", function(b) {\n                    a.trigger(b.type, Array.prototype.slice.call(arguments, 1));\n                }), this.$editor.bind(\"keypress\", function(a) {\n                    if (a.ctrlKey) {\n                        return;\n                    }\n                ;\n                ;\n                    a.stopPropagation();\n                }), this.$editor.bind(\"keydown\", function(c) {\n                    if (c.ctrlKey) {\n                        return;\n                    }\n                ;\n                ;\n                    switch (c.keyCode) {\n                      case b.constants.keyCodes.tab:\n                        c.preventDefault(), a.trigger(\"blurFromTab\", [c,]);\n                        break;\n                      case b.constants.keyCodes.esc:\n                        c.preventDefault(), a.trigger(\"blurFromEscape\");\n                        break;\n                      default:\n                        c.stopPropagation();\n                    };\n                ;\n                }), (($.browser.mozilla ? this.$editor.bind(\"input mousedown mouseup\", twttr.bind(this, this._keyEvents)) : this.$editor.bind(\"keydown keyup paste change mousedown mouseup input\", twttr.bind(this, this._keyEvents)))), ((this._enableAutoGrow && this.$editor.bind(\"change cut keyup paste\", twttr.bind(this, this._tryAutoGrow))));\n            },\n            _keyEvents: function(a) {\n                ((((!$.browser.webkit || ((((a.type != \"paste\")) && ((a.type != \"keydown\")))))) ? this._inputCallback(a) : JSBNG__setTimeout(twttr.bind(this, function() {\n                    this._inputCallback(a);\n                }), 0)));\n            },\n            _inputCallback: function(a) {\n                this.trigger(\"didChangeContent\", [this.JSBNG__content(),a,]);\n            }\n        }), twttr.klass(\"twttr.components.RichEditor\", function(a, c) {\n            function d(a) {\n                var b = e.$editor.offset();\n                e.$proxy = $(a.contentWindow.JSBNG__document.body), ((((twttr.i18n && twttr.i18n.rtl)) && (e.$proxy[0].dir = \"rtl\"))), e.$proxy.append(((((\"\\u003Cstyle\\u003E\" + e.constructor.css)) + \"\\u003C/style\\u003E\"))), e._$proxyWrapper = $(\"\\u003Cpre class=\\\"proxy-wrapper\\\"\\u003E\\u003C/pre\\u003E\").appendTo(e.$proxy), e._applyStyles(), e._queue.flush();\n            };\n        ;\n            var e = this;\n            this.supr = twttr.components.Editor, this.supr.apply(this, arguments), this._queue = new b.util.WaitQueue, this._$proxyWrapper = {\n                length: 0\n            }, this.$iframe = $(\"\\u003Ciframe allowtransparency=\\\"false\\\" src=\\\"../../receiver.html\\\" frameborder=\\\"0\\\" tabindex=\\\"-1\\\" role=\\\"presentation\\\" scrolling=\\\"no\\\"/\\u003E\"), this.$iframe.insertBefore(this.$editor), this.$iframe.bind(\"load\", function() {\n                d(this);\n            }), this.$iframe.addClass(\"proxy-editor\"), this.$container.addClass(\"rich-editor\"), this._tweetBoxHeight = 0, $(\"\\u003Cdiv class=\\\"tweet-meta\\\"\\u003E\\u003Cdiv class=\\\"tweetbox-media-icon\\\"/\\u003E\\u003C/div\\u003E\").appendTo(this.$container), this.$mediaicon = this.$container.JSBNG__find(\".tweetbox-media-icon\"), this._foundMedia = !1, this.bind(\"didChangeContent\", twttr.bind(this, this._proxyLinkify));\n        }).subclassOf(twttr.components.Editor).statics({\n            css: \"body {        margin: 0;        width: 482px;        height: 56px;        color: #222;        overflow-x: hidden;        overflow-y: hidden;      }      .proxy-wrapper {        margin: 0;        padding: 0;        font: 14px/18px \\\"Helvetica Neue\\\", Arial, sans-serif;        white-space: pre-wrap;        word-wrap: break-word;      }      a {        color: #0084b4;        text-decoration: none;      }      a.twitter-timeline-link {        background-color: #bedff8;        -moz-border-radius: 5px;        -webkit-border-radius: 5px;        border-radius: 5px;      }      em {        font-style: normal;        display: inline-block;        width: 2px;      }\"\n        }).methods({\n            _applyStyles: function() {\n                this.$editor.css(\"min-height\", this.css.height), this.$proxy.css(\"width\", this.css.width), this.$iframe.css(\"width\", this.css.width);\n            },\n            _growTweetBox: function() {\n                var a = this._$proxyWrapper.height();\n                (($.browser.webkit && (a += 10))), ((((a !== this._tweetBoxHeight)) && (this.$editor.height(a), this.$iframe.height(a), this.trigger(\"heightChange\")))), this._tweetBoxHeight = a;\n            },\n            _replaceAndys: function(a) {\n                return a.replace(/&amp;/g, \"&\");\n            },\n            _proxyLinkify: function() {\n                this._queue.add(twttr.bind(this, function() {\n                    var a = ((b.util.linkify(this._replaceAndys(h(this.JSBNG__content()))) + \"\\u003Cem\\u003E&nbsp;\\u003C/em\\u003E\"));\n                    this._$proxyWrapper.html(a), this._growTweetBox(), this._showMediaIcon();\n                }));\n            },\n            _showMediaIcon: function() {\n                var a = twttr.txt.extractUrls(this.JSBNG__content()), b;\n                for (var c = 0; ((c < a.length)); c++) {\n                    var d = a[c];\n                    b = twttr.media.matchInstance(d);\n                    if (b) {\n                        var e = ((twttr.is.fn(b.icon) ? b.icon() : b.icon));\n                        this.$mediaicon.addClass(e), this._foundMedia = !0;\n                        return;\n                    }\n                ;\n                ;\n                };\n            ;\n                ((((!b && this._foundMedia)) && (this.$mediaicon[0].className = \"tweetbox-media-icon\", this._foundMedia = !1)));\n            },\n            reset: function() {\n                this.supr.prototype.reset.apply(this, arguments), this._$proxyWrapper.html(\"\"), this._applyStyles();\n            }\n        }), a(twttr.components.Editor);\n    });\n});\nprovide(\"TweetBox\", function(a) {\n    using(\"_\", \"util\", \"constants\", \"components/TweetboxAutocomplete\", \"mixins/urlShortener\", \"mixins/photoBox\").as(function(b, _) {\n        var c = {\n            condensed: !0,\n            condensedContent: \"\",\n            closeAfterSuccess: !0,\n            defaultContent: !1,\n            width: 560,\n            height: 56,\n            autocomplete: !0,\n            autocompleteSuggestionLimit: 10,\n            displayError: !0,\n            template: {\n                show_geo: !0,\n                show_title: !0,\n                title: _(\"What\\u2019s happening?\"),\n                button_text: _(\"Tweet\"),\n                api_url: ((((window.JSBNG__location.protocol + \"//\")) + twttr.domains.upload))\n            },\n            enableDraft: !1,\n            statusAction: \"update\",\n            draggable: !0\n        }, d = 1, e = {\n        }, f = {\n            update: \"Status\",\n            reply: \"Status\",\n            dm: \"DirectMessage\",\n            directMessage: \"DirectMessage\"\n        }, g = /^(?:d|m|dm)\\s+[@＠]?([a-zA-Z0-9_]{1,20}) /;\n        twttr.klass(\"twttr.TweetBox\", function(a, f) {\n            var g = this;\n            c.template.title = _(\"What\\u2019s happening?\"), c.template.button_text = _(\"Tweet\"), c.template.post_authenticity_token = twttr.API.getConfig().postAuthenticityToken, this.options = twttr.merge({\n            }, c, ((f || {\n            })), !0), this.places = [], this._explainLinkShortening = ((twttr.is.def(this.options.explainLinkShortening) ? this.options.explainLinkShortening : !0)), this._isButtonEnabled = !1, this._hasWarned = !0, this._hasSuperWarned = !1, this._hasNoWarned = !1;\n            var i = {\n                defaultContent: ((((this._getDraftTweet() || this.options.condensedContent)) || this.options.defaultContent)),\n                width: this.options.width,\n                height: this.options.height,\n                enableAutoGrow: ((this.options.enableAutoGrow || !1))\n            };\n            this.id = ((this.options.id || d++)), e[this.id] = this, this.$container = $(a), this.view = (new twttr.views.TweetBox(this.options.template)).render(a, \"append\");\n            var j = ((((twttr.decider.isAvailable(\"phoenix_tweetbox_talon\") && twttr.decider.isAvailable(\"phoenix_rich_editor\"))) && !$.browser.msie)), k = ((j ? \"RichEditor\" : \"Editor\"));\n            this.editor = new twttr.components[k](this.$container.JSBNG__find(\".text-area-editor\"), i), this.$counter = this.$find(\".tweet-counter\"), this.$tweetButton = this.$container.JSBNG__find(\".tweet-button\"), this.$title = this.$container.JSBNG__find(\"h2\"), ((this.options.autocomplete && (this.autocomplete = new b.components.TweetboxAutocomplete(this)))), this._updateDraftTweet = twttr.bind(this, this._updateDraftTweet), ((((((!this.options.condensed || ((!this.options.condensedContent && this.options.defaultContent)))) || ((i.defaultContent !== ((this.options.condensedContent || this.options.defaultContent)))))) ? this.open() : this.editor.JSBNG__blur())), ((twttr.is.def(this.options.dynamicTitle) && (this._dynamicTitle = this.options.dynamicTitle))), this._registerUrlShortenerEvents(), this.registerEvents(), this._initPhotobox(), this._toggleCounterState(null, ((i.defaultContent || \"\")));\n        }).mixin(twttr.mixins.i18nTweetBox, twttr.mixins.urlShortener, twttr.mixins.photoBox).statics({\n            JSBNG__focus: function(a) {\n                e[a].editor.JSBNG__focus();\n            },\n            _getDefaultContentForReply: function(a, b, c) {\n                var d = !1, e = ((a ? a.JSBNG__find(\"a.twitter-atreply\") : [])), f = ((((\"@\" + b)) + \" \"));\n                if (e.length) {\n                    d = !0;\n                    var g = [];\n                    e.each(function(a, d) {\n                        var e = $(this).text().replace(\"@\", \"\");\n                        ((((((!e.match(new RegExp(((((\"^\" + b)) + \"$\"))), \"i\") && !twttr.is.inArray(e, g))) && !e.match(new RegExp(((((\"^\" + c)) + \"$\")), \"i\")))) && g.push(e)));\n                    }), g.unshift(b), f = twttr.map(g, function(a) {\n                        return ((((\"@\" + a)) + \" \"));\n                    }).join(\"\");\n                }\n            ;\n            ;\n                return {\n                    defaultContent: f,\n                    multiple: d\n                };\n            }\n        }).statics(twttr.EventProvider).methods(twttr.EventProvider).methods({\n            $find: function(a) {\n                return this.$container.JSBNG__find(a);\n            },\n            _locked: !1,\n            _dynamicTitle: !0,\n            lock: function() {\n                this._locked = !0;\n            },\n            unlock: function() {\n                this._locked = !1;\n            },\n            JSBNG__focus: function() {\n                this.editor.JSBNG__focus(), this.editor.moveCursorToEnd();\n            },\n            _getTextLength: function(a) {\n                var c = b.util.displayLength(a);\n                return c;\n            },\n            _noPhotosPresent: function() {\n                return ((!this.turkey || ((this.turkey && !this.turkey.hasItems()))));\n            },\n            _toggleButtonState: function(a, b) {\n                var c = this._getTextLength(b), d = ((this.options.defaultContent || \"\"));\n                ((((((((c > 140)) || (($.trim(this.getTweetContent()) == $.trim(d))))) && this._noPhotosPresent())) ? ((this._isButtonEnabled && (this._isButtonEnabled = !1, this.$tweetButton.addClass(\"disabled\").removeClass(\"primary-btn\")))) : ((this._isButtonEnabled || (this._isButtonEnabled = !0, this.$tweetButton.removeClass(\"disabled\").addClass(\"primary-btn\"))))));\n            },\n            _toggleCounterState: function(a, b) {\n                var c = this._getTextLength(b);\n                this._updateCounter(c), ((((((c > 120)) && ((c < 130)))) ? ((this._hasWarned || (this._hasWarned = !0, this._hasSuperWarned = !1, this._hasNoWarned = !1, this.$counter.addClass(\"warn\").removeClass(\"superwarn\")))) : ((((c >= 130)) ? ((this._hasSuperWarned || (this._hasSuperWarned = !0, this._hasWarned = !1, this._hasNoWarned = !1, this.$counter.addClass(\"superwarn\").removeClass(\"warn\")))) : ((this._hasNoWarned || (this._hasNoWarned = !0, this._hasSuperWarned = !1, this._hasWarned = !1, this.$counter.removeClass(\"superwarn\").removeClass(\"warn\"))))))));\n            },\n            _updateCounter: function(a) {\n                this.$counter.val(((140 - a)));\n            },\n            open: function() {\n                var a = this;\n                if (this._isOpen) {\n                    return;\n                }\n            ;\n            ;\n                this._isOpen = !0, this.$container.JSBNG__find(\".tweet-box\").removeClass(\"condensed\");\n                var b = this._getDraftTweet();\n                ((b ? this.setTweetContent(b) : ((twttr.is.string(this.options.defaultContent) && this.setTweetContent(this.options.defaultContent))))), this.editor.bind(\"didChangeContent\", this._updateDraftTweet), this.trigger(\"open\");\n                var c = {\n                };\n                ((((twttr.audit.currentPage() == \"profile\")) && (c.profile_id = twttr.profileUser.id)));\n                var d = ((((a.options.statusAction === \"directMessage\")) || a.editor.JSBNG__content().match(g)));\n                ((d || (((((((twttr.profileUser && twttr.profileUser.verified)) && ((twttr.app.currentPageName() == \"profile\")))) && twttr.abdecider.track(\"replies_stripped_on_verified_profiles_222\", \"compose_tweet\"))), trackClient({\n                    component: \"tweetbox\",\n                    action: \"compose_tweet\"\n                }, c))));\n            },\n            close: function() {\n                if (!this._isOpen) {\n                    return;\n                }\n            ;\n            ;\n                ((this.options.condensed && this.$container.JSBNG__find(\".tweet-box\").addClass(\"condensed\"))), this.editor.unbind(\"didChangeContent\", this._updateDraftTweet), ((this.turkey && this.turkey.reset())), this.trigger(\"close\"), this._isOpen = !1;\n            },\n            disable: function() {\n                this.close(), this.editor.$editor.val(\"\"), this.editor.$editor.bind(\"keypress\", function(a) {\n                    a.preventDefault();\n                });\n            },\n            getTweetContent: function() {\n                return this.editor.JSBNG__content();\n            },\n            setTweetContent: function(a) {\n                this._setDraftTweet(a), this.editor.setContent(a);\n            },\n            resetTweetContent: function() {\n                this.editor.reset(), this._setDraftTweet(null), this.$container.JSBNG__find(\"textarea\").val(this.options.condensedContent);\n            },\n            _tweet: function() {\n                this.trigger(\"readyToTweet\"), this.tweet();\n            },\n            tweet: function() {\n                var a = this._shouldTweet();\n                ((a.shouldTweet && (this.setTweetBoxToBusyState(), this._setDraftTweet(null), this.trigger(\"sendingTweet\", {\n                    action: this.options.statusAction\n                }), this.makeRequest.apply(this, a.args)))), ((a.msg && (((this.options.displayError && twttr.showError(a.msg))), this.trigger(\"error\", [a.msg,])))), ((a.redirectToProfile && twttr.router.routeTo(twttr.router.profilePath({\n                    screen_name: a.redirectToProfile\n                }))));\n            },\n            _getDraftTweet: function() {\n                return ((this.options.enableDraft ? twttr.app.caches.draftTweets.get(((((this.options.enableDraft === !0)) ? window.JSBNG__location.href : this.options.enableDraft))) : null));\n            },\n            _setDraftTweet: function(a) {\n                if (this.options.enableDraft) {\n                    var b = ((((this.options.enableDraft === !0)) ? window.JSBNG__location.href : this.options.enableDraft));\n                    ((a ? twttr.app.caches.draftTweets.set(b, a, 86400000) : twttr.app.caches.draftTweets.remove(b)));\n                }\n            ;\n            ;\n            },\n            _updateDraftTweet: function() {\n                this._setDraftTweet(this.getTweetContent());\n            },\n            _shouldTweet: function() {\n                var a = [], c = this.options.statusAction, d = f[c], e = $.trim(this.editor.JSBNG__content());\n                if (((((((this.options.condensedContent && ((e == $.trim(this.options.condensedContent))))) || ((this.options.defaultContent && ((e == $.trim(this.options.defaultContent))))))) && this._noPhotosPresent()))) {\n                    return {\n                        shouldTweet: !1\n                    };\n                }\n            ;\n            ;\n                if (((this._sendingStatus || this._locked))) {\n                    return {\n                        shouldTweet: !1\n                    };\n                }\n            ;\n            ;\n                var g = ((this.turkey && this.turkey.hasItems()));\n                if (((((((c === \"update\")) && this.editor.JSBNG__content().match(b.constants.regexps.usernameWithSpace))) && !g))) {\n                    var i = RegExp.$1;\n                    return this.$container.JSBNG__find(\".tweet-spinner\").show(), this.$container.JSBNG__find(\".tweet-counter\").hide(), {\n                        shouldTweet: !1,\n                        redirectToProfile: i\n                    };\n                }\n            ;\n            ;\n                if (((this._getTextLength(e) > 140))) {\n                    return {\n                        shouldTweet: !1,\n                        msg: (new twttr.views.TooLongErrorMessage({\n                            is_dm: ((c === \"directMessage\"))\n                        })).html()\n                    };\n                }\n            ;\n            ;\n                if (((this._getTextLength(e) === 0))) {\n                    return {\n                        shouldTweet: !1\n                    };\n                }\n            ;\n            ;\n                if (((c == \"directMessage\"))) {\n                    if (((!twttr.is.def(this.options.data.getUser()) || twttr.is.blank(this.options.data.getUser())))) {\n                        return {\n                            shouldTweet: !1,\n                            msg: _(\"Whoops! You forgot to type in a username.\")\n                        };\n                    }\n                ;\n                }\n            ;\n            ;\n                var j = this, k = this._getRequestOptions();\n                ((this.options.inReplyToStatusId && twttr.merge(k, {\n                    in_reply_to_status_id: this.options.inReplyToStatusId\n                })));\n                if (twttr.geo.JSBNG__location) {\n                    var l = ((twttr.geo.JSBNG__location.isLocationOn() && twttr.geo.JSBNG__location.cityId()));\n                    ((l && (k.place_id = l)));\n                }\n            ;\n            ;\n                k.timeout = function(a) {\n                    a.retry();\n                };\n                switch (c) {\n                  case \"update\":\n                    a = [this.getTweetContent(),k,];\n                    break;\n                  case \"reply\":\n                    k.impression_id = this.options.data.impressionId, a = [this.options.data.tweetId,this.getTweetContent(),k,];\n                    break;\n                  case \"directMessage\":\n                    c = \"send\", a = [this.options.data.getUser(),this.getTweetContent(),k,];\n                };\n            ;\n                return {\n                    shouldTweet: !0,\n                    args: [d,c,a,]\n                };\n            },\n            setTweetBoxToBusyState: function() {\n                this.$container.JSBNG__find(\".tweetbox-counter-tipsy\").hide(), this.$container.JSBNG__find(\".tweet-spinner\").show(), this.$container.JSBNG__find(\".tweet-counter\").hide(), this.$tweetButton.addClass(\"disabled\");\n            },\n            unSetTweetBoxToBusyState: function() {\n                this.$container.JSBNG__find(\".tweet-spinner\").hide(), this.$container.JSBNG__find(\".tweet-counter\").show(), this.$container.JSBNG__find(\".tweetbox-counter-tipsy\").show(), this.$tweetButton.removeClass(\"disabled\");\n            },\n            _getRequestOptions: function() {\n                var a = this, b = ((((a.options.statusAction === \"directMessage\")) || a.editor.JSBNG__content().match(g)));\n                return {\n                    complete: function() {\n                        a.unSetTweetBoxToBusyState(), a._sendingStatus = !1;\n                    },\n                    success: function(c, d) {\n                        var e = \"\";\n                        ((a.options.closeAfterSuccess && a.close())), ((b || (a.trigger(\"tweetSuccess\", [c,a.options.statusAction,]), a.constructor.trigger(\"tweetSuccess\", [c,a.options.statusAction,]), e = ((((a.options.inReplyToStatusId || ((c.text.indexOf(\"@\") == 0)))) ? \"send_reply\" : \"send_tweet\"))))), a.editor.reset(), a.places = [], delete a.options.inReplyToStatusId;\n                        var f = {\n                            item_ids: [c.id,]\n                        };\n                        ((twttr.profileUser && (f.profile_id = twttr.profileUser.id)));\n                        var g = ((a.options.id || \"unspecified-tweetbox\"));\n                        ((((g.indexOf(\"send-message-box\") != -1)) && (g = \"send-message-box\"))), ((b ? (a.trigger(\"dmSuccess\", [c,a.options.statusAction,]), trackClient({\n                            component: \"direct_message\",\n                            action: \"send_dm\"\n                        }, f)) : trackClient({\n                            component: g,\n                            action: e\n                        }, f))), ((a.options.condensed && a.$container.JSBNG__find(\".tweet-box\").addClass(\"condensed\"))), a.resetTweetContent();\n                    },\n                    error: function(c) {\n                        a.$tweetButton.removeClass(\"disabled\");\n                        if (((twttr.isT1 && b))) {\n                            var d = twttr.errors.errorCodeFromResponse(c);\n                        }\n                         else {\n                            var d = twttr.helpers.showErrorFromResponse(c, ((b ? \"dm\" : \"tweet\")));\n                        }\n                    ;\n                    ;\n                        a.trigger(((b ? \"dmError\" : \"tweetError\")), [d,]);\n                    }\n                };\n            },\n            makeRequest: function(a, b, c) {\n                this._sendingStatus = !0, twttr.API[a][b].apply(twttr.API[a], c);\n            },\n            destroy: function() {\n                this.trigger(\"destroy\");\n            },\n            collapseOnBlur: function() {\n                if (this.preventBlur) {\n                    return;\n                }\n            ;\n            ;\n                var a = this.editor.JSBNG__content(), b = ((((a === this.options.defaultContent)) || ((a === \"\"))));\n                ((((b && this._noPhotosPresent())) && (this.close(), this.editor.setContent(((((this.options.condensedContent || this.options.defaultContent)) || \"\"))), $(JSBNG__document).unbind(\"click.tweetbox\"))));\n            },\n            registerEvents: function() {\n                var a = this;\n                this.$tweetButton.addClass(\"disabled\"), this.editor.bind(\"JSBNG__focus\", function(b) {\n                    JSBNG__setTimeout(function() {\n                        a.open(), ((twttr.geo.JSBNG__location && twttr.geo.JSBNG__location.JSBNG__onFocusTweetBox(a.$container)));\n                    }, 0);\n                }), ((twttr.isT1 && (this.editor.bind(\"JSBNG__blur\", function() {\n                    a.collapseOnBlur();\n                }), this.editor.bind(\"JSBNG__focus\", function() {\n                    $(JSBNG__document).unbind(\"click.tweetbox\"), $(JSBNG__document).bind(\"click.tweetbox\", function(b) {\n                        (($(b.target).is(\".tweet-box, .tweet-box *\") || a.collapseOnBlur()));\n                    });\n                }), this.$container.bind(\"mouseenter\", function() {\n                    a.preventBlur = !0;\n                }), this.$container.bind(\"mouseleave\", function() {\n                    a.preventBlur = !1;\n                })))), this.editor.bind(\"didChangeContent\", twttr.bind(this, this._toggleButtonState)), this.editor.bind(\"didChangeContent\", twttr.bind(this, this._toggleCounterState)), this.registerTextDirEvents(), this.editor.bind(\"blurFromTab\", function(b, c) {\n                    ((twttr.components.Autocomplete._isCompletionsOpen || a.$container.JSBNG__find(\".tweet-button\").JSBNG__focus()));\n                }), this.editor.bind(\"blurFromEscape\", function(b) {\n                    ((twttr.components.Autocomplete._isCompletionsOpen || (a.preventBlur = !1, a.editor.JSBNG__blur(), a.trigger(\"blurFromEscape\"))));\n                }), ((((!this.options.condensedContent && ((this.options.defaultContent.length > 0)))) && (this.editor.trigger(\"didChangeContent\", [this.options.defaultContent,]), JSBNG__setTimeout(twttr.bind(this, function() {\n                    this.open(), this.JSBNG__focus(), this.editor.$editor.trigger(jQuery.JSBNG__Event(\"keyup\"));\n                }), 0)))), this.$tweetButton.bind(\"keypress\", twttr.bind(this, function(a) {\n                    a.stopPropagation();\n                    if (((((a.keyCode === b.constants.keyCodes.enter)) || ((a.charCode === b.constants.charCodes.space))))) {\n                        return this._tweet(), a.preventDefault(), this.JSBNG__blur(), !1;\n                    }\n                ;\n                ;\n                })).bind(\"click\", function(b) {\n                    a._tweet(), this.JSBNG__blur(), b.preventDefault();\n                });\n                var d, e, f, i;\n                if (((((this.options.statusAction == \"update\")) || ((this.options.statusAction == \"reply\"))))) {\n                    this.bind(\"titleChanged\", function(b, c, d) {\n                        a.$tweetButton[0].childNodes[0].nodeValue = ((((d == \"dm\")) ? _(\"Send Message\") : _(\"Tweet\")));\n                    }), ((this._dynamicTitle && this.editor.bind(\"didChangeContent\", twttr.bind(this, function(a, j) {\n                        if (j.match(g)) {\n                            if (!d) {\n                                d = !0, e = f = i = !1;\n                                var k = RegExp.$1, l = _(\"Message {{username}}\", {\n                                    username: k\n                                });\n                                this.$title.html(l), this.trigger(\"titleChanged\", [l,\"dm\",]);\n                            }\n                        ;\n                        ;\n                        }\n                         else if (((((this.options.statusAction == \"reply\")) && j.match(new RegExp(((((\"[@\\uff20]\" + this.options.data.screenName)) + \" \"))))))) {\n                            if (!e) {\n                                e = !0, d = f = i = !1;\n                                var l = _(\"Reply to @{{username}}\", {\n                                    username: this.options.data.screenName\n                                });\n                                this.$title.html(l), this.trigger(\"titleChanged\", [l,\"reply\",]);\n                            }\n                        ;\n                        ;\n                        }\n                         else if (j.match(b.constants.regexps.usernameWithAt)) {\n                            if (!f) {\n                                f = !0, d = e = i = !1;\n                                var l = _(\"Tweet to {{username}}\", {\n                                    username: RegExp.$1\n                                });\n                                this.$title.html(l), this.trigger(\"titleChanged\", [l,\"mention\",]);\n                            }\n                        ;\n                        ;\n                        }\n                         else ((i || (i = !0, d = e = f = !1, this.$title.html(c.template.title), this.trigger(\"titleChanged\", [c.template.title,\"update\",]))));\n                        \n                        \n                    ;\n                    ;\n                    }))));\n                }\n            ;\n            ;\n                ((twttr.geo.JSBNG__location && twttr.geo.JSBNG__location.JSBNG__onRegisterTweetBox(this.$container, this.options.whenGeoPopupOpens))), this.trigger(\"ready\");\n            }\n        }), a(twttr.TweetBox);\n    });\n});\nprovide(\"components/TweetboxAutocomplete\", function(a) {\n    using().as(function() {\n        twttr.klass(\"twttr.components.TweetboxAutocomplete\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            this.tweetbox = a, this.places = a.places, this.autocomplete = new twttr.components.Autocomplete({\n                input: a.editor.$editor,\n                textarea: !0,\n                limit: a.options.autocompleteSuggestionLimit\n            }), this.autocomplete.bind(\"select\", function(a) {\n                b.tweetbox.editor.trigger(\"didChangeContent\", [b.tweetbox.editor.JSBNG__content(),]);\n            }), this.tweetbox.editor.bind(\"heightChange\", twttr.bind(this.autocomplete, this.autocomplete.position)), a.bind(\"open\", function(a) {\n                twttr.components.Autocomplete.getAutocompletedUsers(), b.autocomplete.position();\n            }), a.$container.delegate(\".geo-insert-place-button\", \"click\", twttr.bind(this, function(a) {\n                return this.autocomplete.insertPlace(), !1;\n            }));\n        }), a(twttr.components.TweetboxAutocomplete);\n    });\n});\nprovide(\"shortcuts_t1\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.shortcuts = {\n            delegateToApp: function() {\n                $(JSBNG__document).bind(\"keypress\", function(a) {\n                    return twttr.app.currentPage().send(\"JSBNG__onkeypress\", [a,]);\n                }), $(JSBNG__document).bind(\"keyup\", function(a) {\n                    return twttr.app.currentPage().send(\"JSBNG__onkeyup\", [a,]);\n                }), $(JSBNG__document).bind(\"keydown\", function(a) {\n                    return twttr.app.currentPage().send(\"JSBNG__onkeydown\", [a,]);\n                });\n            },\n            focusSearchBox: function(a) {\n                a.preventDefault(), $(\"#search-query\").JSBNG__focus(), scribble(\"search-box-focus\", {\n                    input: \"keyboard\"\n                });\n            },\n            initCombos: function() {\n                twttr.shortcuts.currentKey = null;\n                var a = [], b = {\n                    65: \"a\",\n                    67: \"c\",\n                    68: \"d\",\n                    71: \"g\",\n                    76: \"l\",\n                    85: \"u\",\n                    82: \"r\",\n                    83: \"s\",\n                    80: \"p\",\n                    72: \"h\",\n                    70: \"f\",\n                    86: \"v\",\n                    88: \"x\",\n                    77: \"m\"\n                };\n                $(JSBNG__document).keydown(function(a) {\n                    if (twttr.helpers.isModifier(a)) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((twttr.shortcuts.verify(a) && $(a.target).is(\":not(input)\"))) ? a.preventDefault() : twttr.shortcuts.currentKey = null));\n                }), twttr.augmentString(\"twttr.shortcuts.combo\", function(b, c) {\n                    a.push({\n                        keys: b,\n                        fn: c\n                    });\n                }), twttr.augmentString(\"twttr.shortcuts.verify\", function(c) {\n                    var d = c.keyCode, e = !1;\n                    for (var f = 0; ((f < a.length)); f++) {\n                        var g = a[f];\n                        if (((b[d] === g.keys[0]))) {\n                            e = !0, twttr.shortcuts.currentKey = b[d];\n                            break;\n                        }\n                    ;\n                    ;\n                        if (((((b[d] === g.keys[1])) && ((twttr.shortcuts.currentKey === g.keys[0]))))) {\n                            e = !0, twttr.shortcuts.currentKey = null, g.fn();\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    return e;\n                }), twttr.shortcuts.combo([\"g\",\"u\",], function() {\n                    scribble(\"open-goto-user-dialog\", {\n                        input: \"keyboard\"\n                    }), twttr.components.Autocomplete.getAutocompletedUsers(), twttr.dialogs.goToUser().open();\n                });\n                if (twttr.loggedIn) {\n                    function c() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toStream: \"connect\"\n                        }), twttr.router.routeTo(twttr.router.connectPath());\n                    };\n                ;\n                    function d() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toStream: \"activity\"\n                        }), twttr.router.routeTo(twttr.router.networkActivityPath());\n                    };\n                ;\n                    function e() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toStream: \"mentions\"\n                        }), twttr.router.routeTo(twttr.router.mentionsPath());\n                    };\n                ;\n                    ((twttr.decider.isActivityEnabled() ? (twttr.shortcuts.combo([\"g\",\"a\",], d), twttr.shortcuts.combo([\"g\",\"c\",], c), twttr.shortcuts.combo([\"g\",\"r\",], e)) : twttr.shortcuts.combo([\"g\",\"r\",], e))), twttr.shortcuts.combo([\"g\",\"d\",], function() {\n                        scribble(\"switch-page\", {\n                            input: \"keyboard\",\n                            toPage: \"discover\"\n                        }), twttr.router.routeTo(twttr.router.discoverPath());\n                    }), twttr.shortcuts.combo([\"g\",\"l\",], function() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toPage: \"lists\"\n                        }), twttr.router.routeTo(twttr.router.listsPath());\n                    }), twttr.shortcuts.combo([\"g\",\"p\",], function() {\n                        scribble(\"switch-page\", {\n                            input: \"keyboard\",\n                            toPage: \"profile\"\n                        }), twttr.router.routeTo(twttr.router.profilePath({\n                            screen_name: twttr.currentUser.screenName\n                        }));\n                    }), twttr.shortcuts.combo([\"g\",\"m\",], function() {\n                        scribble(\"switch-page\", {\n                            input: \"keyboard\",\n                            toPage: \"messages\"\n                        }), twttr.dialogs.directMessage({\n                            origin: \"message-dialog-hotkey\"\n                        }).open().switchToConversationListView();\n                    }), twttr.shortcuts.combo([\"g\",\"h\",], function() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toStream: \"JSBNG__home\"\n                        }), twttr.router.routeTo(twttr.router.homePath());\n                    }), twttr.shortcuts.combo([\"g\",\"f\",], function() {\n                        scribble(\"switch-stream\", {\n                            input: \"keyboard\",\n                            toStream: \"favorites\"\n                        }), twttr.router.routeTo(twttr.router.favoritesPath());\n                    }), twttr.shortcuts.combo([\"g\",\"s\",], function() {\n                        scribble(\"switch-page\", {\n                            input: \"keyboard\",\n                            toPage: \"settings\"\n                        }), twttr.router.routeTo(twttr.router.settingsPath());\n                    }), ((twttr.decider.isAvailable(\"phoenix_facets\") && (twttr.shortcuts.combo([\"s\",\"p\",], function() {\n                        scribble(\"open-search-facets-dialog\", {\n                            input: \"keyboard\",\n                            facetsType: \"photos\"\n                        }), twttr.dialogs.searchFacets(\"photos\").open();\n                    }), twttr.shortcuts.combo([\"s\",\"v\",], function() {\n                        scribble(\"open-search-photos-dialog\", {\n                            input: \"keyboard\",\n                            facetsType: \"videos\"\n                        }), twttr.dialogs.searchFacets(\"videos\").open();\n                    })))), twttr.shortcuts.combo([\"g\",\"x\",], function() {\n                        ((twttr.decider.isAvailable(\"muteUsers\") && (twttr.components.Autocomplete.getAutocompletedUsers(), (new twttr.widget.MuteDialog).open())));\n                    });\n                }\n            ;\n            ;\n            },\n            initSecrets: function() {\n                ((twttr.loggedIn && (twttr.provide(\"twttr.secrets\"), twttr.secrets.secretSauce = function(a, b) {\n                    $(JSBNG__document).bind(\"keydown\", b.split(\"-\\u003E\"), function(b) {\n                        ((twttr.decider.isAvailable(a) && (twttr.secrets[a] = !twttr.secrets[a])));\n                    });\n                }, twttr.secrets.secretSauce(\"hideMentions\", \"x-\\u003Eo\"), twttr.secrets.secretSauce(\"allMedia\", \"x-\\u003Ei\"))));\n            },\n            openDialogs: function(a) {\n                if (((!twttr.loggedIn || twttr.shortcuts.currentKey))) {\n                    return;\n                }\n            ;\n            ;\n                if (((twttr.helpers.isModifier(a) || $(a.target).is(\"input\")))) {\n                    return;\n                }\n            ;\n            ;\n                ((((a.keyCode === 77)) ? (twttr.dialogs.directMessage({\n                    origin: \"message-dialog-hotkey\"\n                }).open().switchToNewMessageView(), scribble(\"dialog-direct-message\", {\n                    input: \"keyboard\"\n                }), a.preventDefault()) : ((((a.keyCode === 78)) && ((new twttr.widget.TweetDialog({\n                    draggable: !0,\n                    template: {\n                        title: _(\"What\\u2019s happening?\")\n                    },\n                    origin: \"new-tweet-hotkey\"\n                })).open().JSBNG__focus(), scribble(\"dialog-new-tweet\", {\n                    input: \"keyboard\"\n                }), a.preventDefault())))));\n            },\n            closeDialogs: function(a) {\n                ((((((((a.keyCode === b.constants.keyCodes.escape)) && twttr.widget.Dialog.currentModal)) && twttr.widget.Dialog.currentModal.options.closable)) && (twttr.widget.Dialog.close(), a.stopPropagation(), a.preventDefault())));\n            },\n            openKeyboardDialog: function(a) {\n                ((((a.which === b.constants.charCodes.questionMark)) && (a.preventDefault(), twttr.dialogs.keyboardShortcuts().toggle(), scribble(\"shortcut-dialog\", {\n                    input: \"keyboard\"\n                }))));\n            }\n        }, twttr.app.waitForSignal(\"init\", function() {\n            $(JSBNG__document).bind(\"keydown\", twttr.shortcuts.openDialogs), $(JSBNG__document).bind(\"keydown\", twttr.shortcuts.closeDialogs), $(JSBNG__document).bind(\"keypress\", \"/\", twttr.shortcuts.focusSearchBox), $(JSBNG__document).bind(\"keypress\", twttr.shortcuts.openKeyboardDialog), twttr.shortcuts.delegateToApp(), twttr.shortcuts.initCombos(), twttr.shortcuts.initSecrets(), $(\"a.js-keyboard-shortcut-trigger\").live(\"click\", function(a) {\n                a.preventDefault(), twttr.dialogs.keyboardShortcuts().open();\n            });\n        }), a(twttr.shortcuts);\n    });\n});\nprovide(\"stork\", function(a) {\n    using(\"util\").as(function(b) {\n        function c(a) {\n            return function(b) {\n                if (twttr.stork.isEnabled()) {\n                    return a(((\"stork.\" + b)));\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        twttr.provide(\"twttr.stork\", twttr.merge({\n            init: function() {\n                ((((twttr.isT1 && twttr.decider.isAvailable(\"stork_guidance\"))) && (this.EXPIRE_TIME = 1209600000, twttr.caches.User.set(\"stork.enabled\", !0, this.EXPIRE_TIME), $.cookie(\"help_pips\", \"1\", {\n                    path: \"/\"\n                }), $.each(twttr.stork.STORKS, function(a, b) {\n                    twttr.caches.User.set(((\"stork.\" + b.counter)), 0, twttr.stork.EXPIRE_TIME);\n                }))));\n            },\n            STORKS: [{\n                id: \"expand_photo\",\n                counter: \"expand_tweet\",\n                icon: \"stork-help\",\n                matcher: function(a) {\n                    return ((a.JSBNG__find(\".js-sm-icon.sm-image\").length > 0));\n                },\n                promptHtml: _(\"There\\u2019s a photo in this Tweet. Check it out.\"),\n                explainHtml: _(\"\\u003Cp\\u003EYou\\u2019ll also find music, videos, and replies inside Tweets, so keep expanding them.\\u003C/p\\u003E\"),\n                promptHighlight: \".original-tweet .js-view-details\",\n                explainHighlight: \"remove\",\n                explainOn: \"expanded.tweet\",\n                dismissOn: \"collapsed.tweet\"\n            },{\n                id: \"expand_video\",\n                counter: \"expand_tweet\",\n                icon: \"stork-help\",\n                matcher: function(a) {\n                    return ((a.JSBNG__find(\".js-sm-icon.sm-video\").length > 0));\n                },\n                promptHtml: _(\"There\\u2019s a video in this Tweet. Check it out.\"),\n                explainHtml: _(\"You\\u2019ll also find photos, music, and replies inside Tweets, so keep expanding them.\"),\n                promptHighlight: \".original-tweet .js-view-details\",\n                explainHighlight: \"remove\",\n                explainOn: \"expanded.tweet\",\n                dismissOn: \"collapsed.tweet\"\n            },{\n                id: \"retweet_profile\",\n                counter: \"retweet_profile\",\n                icon: \"stork-help\",\n                matcher: function(a) {\n                    return ((a.JSBNG__find(\"[data-retweet-id]\").length > 0));\n                },\n                explainHtml: _(\"\\u003Cp\\u003EA \\u003Cstrong\\u003Eretweet\\u003C/strong\\u003E is a Tweet that was shared by someone you\\u2019re following.\\u003C/p\\u003E \\u003Cp\\u003EThe author of that Tweet may be someone you don\\u2019t follow, so it\\u2019s a great way to check out somebody new.\\u003C/p\\u003E\"),\n                explainHighlight: \".stream-item-footer .context .js-retweet-text\",\n                explainOn: \"expanded.tweet\",\n                dismissOn: \"profile_popup.tweet collapsed.tweet\"\n            },{\n                id: \"hashtag\",\n                counter: \"hashtag\",\n                icon: \"stork-help\",\n                matcher: function(a) {\n                    return ((a.JSBNG__find(\".original-tweet .js-tweet-text .twitter-hashtag\").length > 0));\n                },\n                explainHtml: _(\"\\u003Cp\\u003EThe # symbol makes this word a \\u003Cstrong\\u003Ehashtag\\u003C/strong\\u003E. People add hashtags to their Tweets to give them topics.\\u003C/p\\u003E \\u003Cp\\u003EClick on it to find other Tweets with the same hashtag.\\u003C/p\\u003E\"),\n                explainHighlight: \".original-tweet .js-tweet-text .twitter-hashtag\",\n                explainOn: \"expanded.tweet\",\n                dismissOn: {\n                    selector: \".js-tweet-text .twitter-hashtag\",\n                    JSBNG__event: \"click\"\n                }\n            },{\n                id: \"mention\",\n                counter: \"mention\",\n                icon: \"stork-help\",\n                matcher: function(a) {\n                    return ((a.JSBNG__find(\".original-tweet .js-tweet-text .twitter-atreply\").length > 0));\n                },\n                explainHtml: _(\"\\u003Cp\\u003EThe @ symbol is used to \\u003Cstrong\\u003Emention\\u003C/strong\\u003E another person by username. Mentions call attention to someone and can start a conversation.\\u003C/p\\u003E \\u003Cp\\u003EClick on it to see that user\\u2019s profile.\\u003C/p\\u003E\"),\n                explainHighlight: \".original-tweet .js-tweet-text .twitter-atreply\",\n                explainOn: \"expanded.tweet\",\n                dismissOn: {\n                    selector: \".js-tweet-text .twitter-atreply\",\n                    JSBNG__event: \"click\"\n                }\n            },],\n            getValue: c(function(a) {\n                return ((twttr.caches.User.get(a) || 0));\n            }),\n            incrValue: c(function(a) {\n                var b = ((twttr.caches.User.get(a) || 0));\n                twttr.caches.User.set(a, ((b + 1)), twttr.stork.EXPIRE_TIME);\n            }),\n            isEnabled: function() {\n                return ((twttr.isT1 && twttr.caches.User.get(\"stork.enabled\")));\n            },\n            storkifyTweets: function(a) {\n                if (!this.isEnabled()) {\n                    return;\n                }\n            ;\n            ;\n                var b = [];\n                $.each(twttr.stork.STORKS, function(a, c) {\n                    ((((twttr.stork.getValue(c.counter) == 0)) && b.push(c)));\n                });\n                var c = a.JSBNG__find(\".js-stream-item\").slice(0, 10), d = !!c.JSBNG__find(\".js-pip\").length;\n                if (d) {\n                    return;\n                }\n            ;\n            ;\n                c.each(function(a, c) {\n                    var d = $(c), e = !1;\n                    if (((d.attr(\"data-promoted\") || ((d.JSBNG__find(\"[data-promoted]\").length > 0))))) {\n                        return;\n                    }\n                ;\n                ;\n                    $.each(b, function(a, b) {\n                        if (b.matcher(d)) {\n                            var c = new twttr.components.StorkPip(d, b);\n                            return e = !0, !1;\n                        }\n                    ;\n                    ;\n                    });\n                    if (e) {\n                        return !1;\n                    }\n                ;\n                ;\n                });\n            }\n        }, twttr.EventProvider)), a(twttr.stork);\n    });\n});\nprovide(\"streams/ActivityStream\", function(a) {\n    using().as(function(b) {\n        twttr.stream(\"twttr.streams.ActivityStream\", function(a, b) {\n            twttr.streams.Stream.apply(this, arguments), this.page = 0, this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent)), this.registerTweetActionEvents(), this.registerUserActionEvents(), this.updateI18nDisplay(), this.initComponentEvents();\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.componentEvents, twttr.mixins.SinceMaxPagination, twttr.mixins.PollingStream, twttr.mixins.tweetActionable, twttr.mixins.i18nTweet, twttr.mixins.userActionable, twttr.mixins.activityStreamEvents, twttr.mixins.streamablePageWithInlineMedia).deciderKey(function() {\n            return twttr.decider.isActivityEnabled();\n        }).pollingDeciderKey(function() {\n            return twttr.decider.isActivityEnabled();\n        }).methods({\n            PAGE_SIZE: 20,\n            timeouts: {\n                ACTIVE: 15000,\n                INACTIVE: 90000\n            },\n            itemViewClass: \"ActivityItem\",\n            streamItemType: \"activity\",\n            additionalStreamItemClass: function(a) {\n                return ((\"js-activity js-activity-\" + a.JSBNG__event));\n            },\n            _idForItem: function(a, b) {\n                return ((((b === \"first\")) ? a.maxPosition : a.minPosition));\n            },\n            _pollShouldFetch: function() {\n                var a = $(\".stream-container\").offset().JSBNG__top, b = $(window).scrollTop();\n                return ((b <= a));\n            },\n            streamItemId: function(a) {\n                return [a.minPosition,a.maxPosition,a.JSBNG__event,a.timestamp,].join(\"_\");\n            },\n            update: function() {\n            \n            },\n            beforeSwitchingAway: function() {\n                this.stopPeriodicFetcher();\n            },\n            afterFirstSwitchingTo: function(a) {\n                var b = this;\n                this.startPeriodicFetcher(), this._loadedStreamOnce = !0, this.isLoadingMore(), this.fetcher(!0, function(c, d) {\n                    c.render(), c.doneLoadingMore(), ((((d !== twttr.streams.SUCCESS)) ? (b._scribeResults(\"error\", [], {\n                        status_code: 502\n                    }), b._showError(d)) : b.fetchUntilScreenIsFull())), ((a ? a() : $.noop));\n                }), ((twttr.isT1 && this.addInlineMediaIcons(this.$node)));\n            },\n            afterSwitchingToAgain: function(a) {\n                this.fetcher(twttr.bind(this, function(b) {\n                    var c = this.newItemsCount;\n                    ((((this.newItemsCount > 0)) && this.showNewItems(this.newItemsCount))), this.restartFetcher(), ((a ? a() : $.noop));\n                }));\n            },\n            showNewItems: function(a, b) {\n                this._showNewItems();\n            },\n            _showNewItems: function(a) {\n                var b = this.$streamItems();\n                this.beforeShowNewItems(), ((((this.newItemsCount > this.NEW_ITEMS_COUNT_MAX)) && (b.empty(), this.items = this.items.slice(0, this.NEW_ITEMS_COUNT_CUTOFF), this.newItemsCount = this.NEW_ITEMS_COUNT_CUTOFF)));\n                var c = this.items.slice(0, this.newItemsCount), d = this._renderItems(c);\n                ((((!a && ((this.newItemsCount > 0)))) && this.JSBNG__onGotNewItems(c))), ((a && this.JSBNG__onGotInitialResults(this.items)));\n                var e = d.children();\n                e.hide(), b.prepend(d), e.fadeIn(), this.newItemsCount = 0, this.JSBNG__onShowNewItems(d), this.trigger(\"newItemsCountChanged\", [0,]);\n            },\n            JSBNG__onShowNewItems: function(a) {\n                ((twttr.isT1 && this.addInlineMediaIcons(a))), twttr.streams.Stream.prototype.JSBNG__onShowNewItems.apply(this, arguments), this.updateI18nDisplay(), this.trigger(\"JSBNG__onShowNewItems\", a);\n            },\n            JSBNG__onShowOldItems: function(a) {\n                ((twttr.isT1 && this.addInlineMediaIcons(a))), twttr.streams.Stream.prototype.JSBNG__onShowOldItems.apply(this, arguments), this.updateI18nDisplay(), this.trigger(\"JSBNG__onShowOldItems\", a);\n            },\n            unshift: function(a) {\n                ((twttr.is.array(a) || (a = Array.prototype.slice.call(arguments))));\n                for (var b = 0, c = a.length; ((b < c)); ++b) {\n                    a[b].sync(\"for_stream\", this.constructor.activityType);\n                ;\n                };\n            ;\n                twttr.streams.Stream.prototype.unshift.call(this, a);\n            },\n            push: function(a) {\n                ((twttr.is.array(a) || (a = Array.prototype.slice.call(arguments))));\n                for (var b = 0, c = a.length; ((b < c)); ++b) {\n                    a[b].sync(\"for_stream\", this.constructor.activityType);\n                ;\n                };\n            ;\n                twttr.streams.Stream.prototype.push.call(this, a);\n            },\n            _getStreamErrorComponent: function(a) {\n                return ((((a === twttr.streams.PROTECTED)) ? new twttr.components.ProtectedUser({\n                    screen_name: this.params.screenName\n                }) : twttr.streams.Stream.prototype._getStreamErrorComponent.apply(this, arguments)));\n            },\n            _scribeResults: function(a, b, c) {\n                var d = [], e = [];\n                twttr.each(b, function(a) {\n                    var b = [a.minPosition,a.maxPosition,a.JSBNG__event,a.timestamp,].join(\"_\");\n                    e.push(b), d.push(((a.position || a.minPosition)));\n                });\n                if (((((a == \"error\")) || ((((a == \"initial\")) && !d.length))))) {\n                    var f = {\n                        item_count: 0,\n                        event_value: 0,\n                        cursor_or_page: this._sinceId,\n                        referring_event: a\n                    };\n                    ((((((((a == \"error\")) && c)) && c.status_code)) && (f.status_code = c.status_code))), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: ((((a == \"error\")) ? \"error\" : \"no_results\"))\n                    }, f);\n                }\n                 else ((((a != \"initial\")) && this.scribbler.scribe({\n                    component: \"stream\",\n                    action: a\n                }, {\n                    item_count: d.length,\n                    cursor_or_page: this._sinceId\n                })));\n            ;\n            ;\n                ((d.length && this.scribbler.scribe({\n                    component: \"stream\",\n                    action: \"results\"\n                }, {\n                    item_ids: d,\n                    item_names: e,\n                    item_count: d.length,\n                    event_value: d.length,\n                    cursor_or_page: this._sinceId,\n                    referring_event: a\n                })));\n            },\n            showActivitySupplements: function(a) {\n                var b = a.closest(\".stream-item\");\n                b.JSBNG__find(\".hidden-supplement\").removeClass(\"hidden-supplement\").addClass(\"hidden-supplement-expanded\"), b.JSBNG__find(\".sub-stream-item-hidden\").removeClass(\"sub-stream-item-hidden\").addClass(\"sub-stream-item-showing\"), b.JSBNG__find(\".view-all-supplements\").removeClass(\"show\").addClass(\"hide\");\n            },\n            hideActivitySupplements: function(a) {\n                var b = a.closest(\".stream-item\");\n                b.JSBNG__find(\".hidden-supplement-expanded\").removeClass(\"hidden-supplement-expanded\").addClass(\"hidden-supplement\"), b.JSBNG__find(\".sub-stream-item-showing\").removeClass(\"sub-stream-item-showing\").addClass(\"sub-stream-item-hidden\"), b.JSBNG__find(\".view-all-supplements\").removeClass(\"hide\").addClass(\"show\");\n            },\n            oldShowActivitySupplements: function(a) {\n                var b = a.closest(\".stream-item\"), c = b.JSBNG__find(\".sub-stream-item\"), d = c.filter(\".sub-stream-item-hidden\"), e = b.JSBNG__find(\".stream-item-activity\"), f = c.length, g = d.length;\n                a.removeClass(\"show\").addClass(\"hide\"), b.addClass(\"parent\");\n                var i;\n                for (var j = ((f - g)); ((j < f)); ++j) {\n                    i = b.clone(), i.JSBNG__find(\".view-all-supplements\").remove(), i.addClass(\"expanded\"), i.JSBNG__find(\".activity-supplement \\u003E div\").each(function(a, b) {\n                        var c = $(b);\n                        ((((a != j)) ? c.remove() : c.removeClass(\"sub-stream-item-hidden\")));\n                    }), b.after(i);\n                ;\n                };\n            ;\n            },\n            oldHideActivitySupplements: function(a) {\n                var b = a.closest(\".stream-item\"), c = b.JSBNG__find(\".stream-item-activity\");\n                b.removeClass(\"parent\"), b.nextUntil(\".stream-item:not('.expanded')\").remove(), a.removeClass(\"hide\").addClass(\"show\");\n            }\n        }).click({\n            \".stream-item-activity .activity-count\": function(a, b) {\n                var c = b.closest(\".stream-item\");\n                return c.JSBNG__find(\".sub-stream-item-hidden\").removeClass(\"sub-stream-item-hidden\"), c.JSBNG__find(\".activity-secondary-supplement\").show(), b.JSBNG__find(\"span\").unwrap(), !1;\n            },\n            \".stream-item-activity-network .stream-item-activity-header\": function(a, b) {\n                if (!twttr.isT1) {\n                    return;\n                }\n            ;\n            ;\n                var c = b.JSBNG__find(\".view-all-supplements\");\n                ((c.get(0) && ((c.hasClass(\"show\") ? this.showActivitySupplements(c) : this.hideActivitySupplements(c)))));\n            },\n            \"div.js-activity .view-all-supplements\": function(a, b) {\n                return ((twttr.isT1 ? ((b.hasClass(\"show\") ? this.showActivitySupplements(b) : this.hideActivitySupplements(b))) : ((b.hasClass(\"show\") ? this.oldShowActivitySupplements(b) : this.oldHideActivitySupplements(b))))), a.stopPropagation(), a.preventDefault(), !1;\n            },\n            \".js-activity .hidden-supplement\": function(a, b) {\n                this.showActivitySupplements(b);\n            }\n        }), a(twttr.streams.ActivityStream);\n    });\n});\nprovide(\"streams/ActivityByUserStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.ActivityByUserStream\").subclassOf(twttr.streams.ActivityStream).statics({\n            activityType: \"profile_activity\"\n        }).methods({\n            update: function(a) {\n                twttr.API.User.JSBNG__find(this.params.screenName).activity(a);\n            },\n            _setTitle: function(a) {\n                a(_(\"Activity by {{screen_name}}\", {\n                    screen_name: this.params.screenName\n                }));\n            }\n        }), a(twttr.streams.ActivityByUserStream);\n    });\n});\nprovide(\"streams/ActivityByNetworkStream\", function(a) {\n    using(\"streams/ActivityStream\").as(function(b) {\n        twttr.stream(\"twttr.streams.ActivityByNetworkStream\").subclassOf(b.streams.ActivityStream).statics({\n            activityType: \"activity\"\n        }).methods({\n            afterFirstSwitchingTo: function() {\n                b.streams.ActivityStream.prototype.afterFirstSwitchingTo.apply(this, arguments);\n            },\n            JSBNG__onShowNewItems: function(a) {\n                b.streams.ActivityStream.prototype.JSBNG__onShowNewItems.apply(this, arguments);\n            },\n            JSBNG__onShowOldItems: function(a) {\n                b.streams.ActivityStream.prototype.JSBNG__onShowOldItems.apply(this, arguments);\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"Favorites, follows, retweets, and more by people you follow will appear here.\");\n            },\n            update: function(a) {\n                twttr.currentUser.networkActivity(a);\n            },\n            _setTitle: function(a) {\n                ((twttr.isT1 ? a(_(\"Activity\")) : a(_(\"Favorites, follows, retweets, and more by people you follow\"))));\n            }\n        }), a(twttr.streams.ActivityByNetworkStream);\n    });\n});\nprovide(\"streams/ActivityOfMeStream\", function(a) {\n    using().as(function(b) {\n        twttr.stream(\"twttr.streams.ActivityOfMeStream\").subclassOf(twttr.streams.ActivityStream).mixin(twttr.mixins.newStreamItemsBar).statics({\n            activityType: \"your_activity\"\n        }).methods({\n            itemForRender: function(a) {\n                return ((a.isMention ? a.targetObjects.get(0) : ((a.isReply ? a.targets.get(0) : a))));\n            },\n            additionalStreamItemClass: function(a) {\n                var b = twttr.streams.ActivityStream.prototype.additionalStreamItemClass.apply(this, arguments);\n                return ((((twttr.isT1 && ((a.isReply || a.isMention)))) && (b += \" expanding-stream-item\"))), b;\n            },\n            itemViewClass: function(a) {\n                return ((((a.isMention || a.isReply)) ? twttr.views.StreamTweet : twttr.views.ActivityItem));\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"@mentions, favorites, follows and more on you and your Tweets will appear here.\");\n            },\n            _afterItemsRendered: function(a) {\n                twttr.helpers.ellipsify(a.JSBNG__find(\".activity-truncated-tweet .tweet-row\"));\n            },\n            JSBNG__onShowNewItems: function(a) {\n                twttr.streams.ActivityStream.prototype.JSBNG__onShowNewItems.apply(this, arguments), this.$find(\".js-new-tweets-bar\").remove(), this._afterItemsRendered(a);\n            },\n            JSBNG__onShowOldItems: function(a) {\n                twttr.streams.ActivityStream.prototype.JSBNG__onShowOldItems.apply(this, arguments), this._afterItemsRendered(a);\n            },\n            update: function(a) {\n                ((((!twttr.isT1 && $.cookie(\"should_filter_mentions\"))) && (a.filter = [\"mention\",\"reply\",]))), twttr.currentUser.inboundActivity(a);\n            },\n            newStreamItemsBarPhrase: function(a) {\n                return ((((a == 1)) ? _(\"1 New interaction\") : _(\"{{count}} New interactions\", {\n                    count: a\n                })));\n            },\n            _setTitle: function(a) {\n                ((twttr.isT1 ? a(_(\"Interactions\")) : a((new twttr.views.ActivityOfMeStreamTitle({\n                })).html())));\n            },\n            showNewItems: function(a, b) {\n                ((b ? this.showNewStreamItemsBar(a) : this._showNewItems()));\n            },\n            afterSwitchingToAgain: function(a) {\n                twttr.streams.ActivityStream.prototype.afterSwitchingToAgain.apply(this, arguments), this.afterSwitchingTo();\n            },\n            afterFirstSwitchingTo: function(a) {\n                twttr.streams.ActivityStream.prototype.afterFirstSwitchingTo.apply(this, arguments);\n                var b = this;\n                ((this._attachedTweetBarEvent || (this._attachedTweetBarEvent = !0, this.dom().delegate(\".js-new-tweets-bar\", \"click\", function() {\n                    b._showNewItems();\n                })))), this.afterSwitchingTo();\n            },\n            afterSwitchingTo: function() {\n                this.updateI18nDisplay();\n                var a = this, b = this.$node.closest(\".stream-manager\").JSBNG__find(\"#show_mentions_only\"), c = !!$.cookie(\"should_filter_mentions\");\n                b.attr(\"checked\", ((c ? \"checked\" : null))), JSBNG__setTimeout(function() {\n                    b.JSBNG__one(\"click\", function() {\n                        return c = !c, $.cookie(\"should_filter_mentions\", ((c || null)), {\n                            expires: 3650\n                        }), b.attr(\"checked\", ((c ? \"checked\" : null))), trackClient({\n                            component: \"mentions_filter\",\n                            action: ((c ? \"select\" : \"deselect\"))\n                        }), a.trigger(\"reloadCurrentStream\", [a.constructor,]), !1;\n                    });\n                }, 0);\n            }\n        }), a(twttr.streams.ActivityOfMeStream);\n    });\n});\nprovide(\"streams/AllSubscriptions\", function(a) {\n    using(\"_\", \"streams/ListStream\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.AllSubscriptions\", function(a, b) {\n            twttr.streams.ListStream.apply(this, arguments), this._registerEvents(a);\n        }).subclassOf(twttr.streams.ListStream).methods({\n            API_METHOD: \"allLists\",\n            _setTitle: function(a) {\n                a(_(\"Lists\"));\n            },\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.ListsStreamViewToggler(!1));\n            },\n            _setHeaderButton: function(a, b) {\n                ((twttr.helpers.isCurrentUser(b.screenName) && a(new twttr.views.CreateListButton)));\n            },\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You aren't following any lists yet.\") : _(\"@{{screen_name}} isn't following any lists yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c) {\n                        return ((twttr.helpers.isCurrentUser(a.screenName) ? c : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.List, \"create follow\", b), this._registerRemoveFromStreamEvent(twttr.API.List, \"delete unfollow\", b, \"uri\"), this._registerUpdateStreamEvent(twttr.API.List, \"update\", b);\n                }\n            ;\n            ;\n            }\n        }), a();\n    });\n});\nprovide(\"streams/AllSubscriptionsUser\", function(a) {\n    using(\"_\", \"streams/AllSubscriptions\").as(function(b, _) {\n        twttr.stream(\"twttr.streams.AllSubscriptionsUser\", function(a, b) {\n            twttr.streams.AllSubscriptions.apply(this, arguments);\n        }).subclassOf(twttr.streams.AllSubscriptions).methods({\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.ProfileListsStreamViewToggler(!0, {\n                    screen_name: b.screenName\n                }));\n            }\n        }), a();\n    });\n});\nprovide(\"media\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.media\");\n        var c = {\n        };\n        twttr.aug(twttr.media, {\n            match: function(a) {\n                if (twttr.is.nil(a)) {\n                    return;\n                }\n            ;\n            ;\n                var b, d, e;\n                return (((d = c[a]) ? d.mediaType : ($.each(twttr.media.types, function(b, f) {\n                    if (!f.isEnabled()) {\n                        return !0;\n                    }\n                ;\n                ;\n                    $.each(f.matchers, function(b, g) {\n                        d = ((twttr.is.regex(g) ? a.match(g) : g(a)));\n                        if (d) {\n                            return c[a] = {\n                                mediaType: f,\n                                matchLabel: b,\n                                match: RegExp.$1\n                            }, e = f, !1;\n                        }\n                    ;\n                    ;\n                    });\n                    if (d) {\n                        return !1;\n                    }\n                ;\n                ;\n                }), e)));\n            },\n            matchInstance: function(a, b) {\n                var d = this.match(a);\n                if (d) {\n                    return new d({\n                        url: a,\n                        matchLabel: c[a].matchLabel,\n                        slug: c[a].match,\n                        tweet: b\n                    });\n                }\n            ;\n            ;\n            },\n            expand: function(a, b) {\n                twttr.urlResolver.expand(a, function(a) {\n                    b(a);\n                });\n            },\n            mediaTypes: function(a, b) {\n                var c = [], d = {\n                }, e = function(a, b) {\n                    var e = twttr.media.match(b);\n                    if (e) {\n                        d[b] = e;\n                        return;\n                    }\n                ;\n                ;\n                    c.push(a);\n                };\n                $.each(a, e);\n                if (((c.length === 0))) {\n                    b(d);\n                    return;\n                }\n            ;\n            ;\n                twttr.media.expand(c, function(a) {\n                    $.each(a, e), b(d);\n                });\n            },\n            extractUrls: function(a) {\n                var b = {\n                };\n                return ((a.entities ? (((a.entities.urls && $.each(a.entities.urls, function(a, c) {\n                    ((c.url && (b[c.url] = ((c.expanded_url || c.url)))));\n                }))), twttr.media.extractMedia(a, b), b) : ($.each(twttr.txt.extractUrls(a.text), function(a, c) {\n                    ((b[c] || (b[c] = c)));\n                }), b)));\n            },\n            extractMedia: function(a, b) {\n                return ((((a.entities && a.entities.media)) && $.each(a.entities.media, function(a, c) {\n                    ((((((c.type && ((c.type == \"photo\")))) && c.display_url)) && (b[c.display_url] = c.display_url)));\n                }))), b;\n            },\n            hasMedia: function(a) {\n                var b = ((((a.entities && a.entities.media)) && a.entities.media.length)), c = twttr.Cards.prototype.hasCards(a);\n                return ((b || c));\n            },\n            resolveImageUrl: function(a, b, c, d) {\n                var e = this;\n                c = ((c || {\n                }));\n                var f = twttr.media.matchInstance(a, c.tweet), g = ((c.error ? c.error : $.noop));\n                if (((f && f.getImageURL))) {\n                    if (((c.filter && ((c.filter(f) !== !0))))) {\n                        g(\"your filter function filtered out this media\");\n                        return;\n                    }\n                ;\n                ;\n                    f.getImageURL(b, function(a) {\n                        ((((!twttr.is.nil(a) && twttr.is.def(a))) ? c.success(a) : g(\"getImageUrl did not return a resolvedURL\")));\n                    }, d);\n                }\n                 else g(\"url did not match any media types\");\n            ;\n            ;\n            },\n            iconType: function(a, b) {\n                var d = new b({\n                    url: a,\n                    matchLabel: c[a].matchLabel,\n                    slug: c[a].match\n                });\n                return d.icon();\n            },\n            getViewMediaCookie: function() {\n                var a = $.cookie(\"show_all_inline_media\");\n                return !!a;\n            },\n            setViewMediaCookie: function() {\n                $.cookie(\"show_all_inline_media\", !0);\n            },\n            matchCache: c\n        }), a(twttr.media);\n    });\n});\nprovide(\"media/Iconifier\", function(a) {\n    using(\"media\").as(function(b) {\n        twttr.provide(\"twttr.media\");\n        var c = twttr.klass(\"twttr.media.Iconifier\", function(a, b) {\n            var c = this, d = $(a);\n            d.attr(\"media\", !0), ((twttr.isT1 && c.iconifyGeo(d))), ((twttr.decider.isAvailable(\"platform_enable_cards\") && (c.iconifyNativeMedia(d.JSBNG__find(\".js-stream-tweet.has-native-media\")), c.iconifyCards(d.JSBNG__find(\".js-stream-tweet.has-cards:not(.iconified)\"))))), c.iconify(d.JSBNG__find(\".js-stream-tweet a.twitter-timeline-link\").get(), !0, b);\n        });\n        c.methods({\n            expand: function(a, c) {\n                var d = [], e = [];\n                $.each(a, function(a, b) {\n                    d.push(b.href);\n                }), b.media.expand(d, function(b) {\n                    var d;\n                    $.each(a, function(a, c) {\n                        d = b[c.href], ((d && (c.setAttribute(\"data-ultimate-url\", d), e.push(c))));\n                    }), c(e);\n                });\n            },\n            iconifyGeo: function(a) {\n                var b = this, c = a.JSBNG__find(\"div.js-stream-tweet[data-geo=\\\"true\\\"] span.js-icon-container\"), d = (new twttr.views.InlineMediaIcon({\n                    is_geo: !0\n                })).html();\n                c.each(function() {\n                    var a = $(this);\n                    a.append(d), b.updateHandleText(a, \"geo\");\n                });\n            },\n            iconifyNativeMedia: function(a) {\n                var b = this;\n                a.each(function() {\n                    var a = $(this), c = a.JSBNG__find(\"span.js-icon-container\"), d = \"photo\";\n                    b.updateHandleText(a, d), b.addSmallIcon(c, d, d), a.addClass(\"iconified\");\n                });\n            },\n            iconifyCards: function(a) {\n                var b = this;\n                a.each(function() {\n                    var a = $(this), c = a.JSBNG__find(\"span.js-icon-container\"), d = a.data(\"card-type\");\n                    b.updateHandleText(a, d), b.addSmallIcon(c, d, d), a.addClass(\"iconified\");\n                });\n            },\n            preloadTwimgs: function(a) {\n                if (twttr.decider.isAvailable(\"phoenix_preload_twimgs\")) {\n                    var b = a.closest(\"div.js-stream-tweet\").attr(\"data-item-id\");\n                    twttr.API.Status.JSBNG__find(b, function(b) {\n                        ((((b.entities && b.entities.media)) && twttr.each(b.entities.media, function(b) {\n                            var c = new JSBNG__Image;\n                            c.src = ((twttr.isSSL() ? b.media_url_https : b.media_url)), a.trigger(\"preloadedImage\", [c,]);\n                        })));\n                    });\n                }\n            ;\n            ;\n            },\n            iconify: function(a, c, d) {\n                var e = this, f = [];\n                $.each(a, function(a, d) {\n                    var g = $(d), i = g.closest(\"div.js-stream-tweet\"), j = ((((d.getAttribute(\"data-ultimate-url\") || d.getAttribute(\"data-expanded-url\"))) || d.href)), k = b.media.match(j);\n                    if (((twttr.abdecider.choose(\"long_tweet_urls_248\") === \"long\"))) {\n                        var l = j.replace(/^https?:\\/\\//, \"\");\n                        ((((l.length > 32)) && (l = ((l.slice(0, 29) + \"...\"))))), g.html(l);\n                    }\n                ;\n                ;\n                    if (((k || !c))) {\n                        var m = 0;\n                        switch (twttr.abdecider.choose(\"long_tweet_urls_2_259\")) {\n                          case \"p25\":\n                            m = 1002242;\n                            break;\n                          case \"p50\":\n                            m = 1002264;\n                            break;\n                          case \"p75\":\n                            m = 1002285;\n                            break;\n                          case \"p100\":\n                            m = 1;\n                            break;\n                          case \"control\":\n                        \n                          default:\n                            m = 0;\n                        };\n                    ;\n                        if (((m && ((Math.JSBNG__random() <= m))))) {\n                            var l = j.replace(/^https?:\\/\\//, \"\");\n                            ((((l.length > 32)) && (l = ((l.slice(0, 29) + \"...\"))))), g.attr(\"data-long_tweet_urls_2_259\", \"expanded\"), g.html(l);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    if (!k) {\n                        f.push(d);\n                        return;\n                    }\n                ;\n                ;\n                    var n = !!g.parents().filter(function(a, b) {\n                        return $(b).hasClass(\"js-old-content\");\n                    }).length;\n                    if (n) {\n                        return;\n                    }\n                ;\n                ;\n                    g.data(\"media-type\", k);\n                    var o = b.media.iconType(j, k), p = i.JSBNG__find(\".js-icon-container\");\n                    ((((p.JSBNG__find(((((\"[data-media-class=\\\"\" + o)) + \"\\\"]\"))).length === 0)) && (((!g.closest(\".js-stream-tweet:not(.iconified)\").length || (e.addSmallIcon(p, o, k._name.toLowerCase()), e.updateHandleText(p, o)))), ((((k._name.toLowerCase() === \"CopiedTwimg\")) && e.preloadTwimgs(p))))));\n                }), ((((c && ((f.length > 0)))) ? this.expand(f, function(a) {\n                    e.iconify(a, !1, d);\n                }) : ((d && d()))));\n            },\n            addSmallIcon: function(a, b, c) {\n                (new twttr.views.InlineMediaIcon({\n                    icon: b,\n                    media_name: c,\n                    is_image: ((b === \"photo\")),\n                    is_video: ((((b === \"video\")) || ((b === \"player\")))),\n                    is_audio: ((((b === \"song\")) || ((b === \"album\")))),\n                    is_summary: ((b === \"summary\")),\n                    is_embed: ((((((b === \"generic\")) || ((b === \"software\")))) || ((b === \"tweet\"))))\n                })).render(a, \"append\");\n            },\n            updateHandleText: function(a, b) {\n                if (!twttr.decider.isExpando()) {\n                    return;\n                }\n            ;\n            ;\n                var c = a.data(\"placename\");\n                ((c ? (c = _(\"from {{placename}}\", {\n                    placename: c\n                }), c = [c,c,]) : c = [_(\"View location\"),_(\"Hide location\"),]));\n                var d = {\n                    photo: [_(\"View photo\"),_(\"Hide photo\"),],\n                    video: [_(\"View video\"),_(\"Hide video\"),],\n                    generic: [_(\"View media\"),_(\"Hide media\"),],\n                    song: [_(\"View song\"),_(\"Hide song\"),],\n                    album: [_(\"View album\"),_(\"Hide album\"),],\n                    software: [_(\"View app\"),_(\"Hide app\"),],\n                    tweet: [_(\"View tweet\"),_(\"Hide tweet\"),],\n                    geo: c,\n                    player: [_(\"View media\"),_(\"Hide media\"),],\n                    summary: [_(\"View summary\"),_(\"Hide summary\"),]\n                }[b], e = \"tweet_anatomy_hide_view_179\", f = twttr.abdecider.choose(e);\n                ((((f !== \"hide\")) && ((((f === \"always\")) ? (((d || (d = [_(\"View details\"),_(\"Hide details\"),]))), ((d && a.show().parent().JSBNG__find(\"span.js-view-details\").html(d[0]).end().JSBNG__find(\"span.js-hide-details\").html(d[1])))) : ((d && a.show().parent().JSBNG__find(\"span.js-view-details\").html(d[0]).end().JSBNG__find(\"span.js-hide-details\").html(d[1])))))));\n            }\n        }), a(c);\n    });\n});\nprovide(\"media/Embedder\", function(a) {\n    using(\"media\").as(function(b) {\n        var c = twttr.klass(\"twttr.media.Embedder\", function(a, b) {\n            this.tweet = a, this.options = ((b || {\n            })), this.options.preProcess = ((this.options.preProcess || function(a, b) {\n                b();\n            })), this.options.postProcess = ((this.options.postProcess || function() {\n            \n            })), this.options.beforeRender = ((this.options.beforeRender || function(a, b) {\n                b({\n                    shouldRender: !0\n                });\n            })), this.options.afterRender = ((this.options.afterRender || function() {\n            \n            }));\n        });\n        c.mixin(twttr.mixins.tweetFlagging), c.methods({\n            expand: function(a, c) {\n                var d = [];\n                b.media.expand(a, function(a) {\n                    $.each(a, function(a, b) {\n                        d.push(b);\n                    }), c(d);\n                });\n            },\n            render: function(a) {\n                var c = this, d = twttr.Cards.prototype;\n                if (((twttr.decider.isAvailable(\"platform_coerce_native_media_to_cards\") && d.hasCardPhotoEntities(this.tweet)))) {\n                    $(this.tweet.entities.media).each(function(a, b) {\n                        c.embed(b.url, twttr.media.types.nativePhoto, b);\n                    });\n                }\n                 else {\n                    if (((!d.hasCardPhotoEntities(this.tweet) && d.hasCards(this.tweet)))) ((d.hasPhotos(this.tweet) ? c.embed(this.tweet.cards.photos[0].url, twttr.media.types.photo, this.tweet.cards) : ((d.hasPlayers(this.tweet) ? c.embed(this.tweet.cards.players[0].url, twttr.media.types.player, this.tweet.cards) : ((d.hasSummaries(this.tweet) && c.embed(this.tweet.cards.summaries[0].url, twttr.media.types.summary, this.tweet.cards)))))));\n                     else {\n                        var e = b.media.extractUrls(this.tweet), f = this.embedMatchedAndReturnUnmatched(e);\n                        ((f.length && this.expand(f, function(a) {\n                            c.embedMatchedAndReturnUnmatched(a);\n                        })));\n                    }\n                ;\n                }\n            ;\n            ;\n                ((a && a()));\n            },\n            embedMatchedAndReturnUnmatched: function(a) {\n                var c = this, d = [];\n                return $.each(a, function(a, e) {\n                    var f = b.media.match(e);\n                    ((f ? c.embed(e, f) : d.push(a)));\n                }), d;\n            },\n            embedThumbnail: function(a) {\n                var c = this, d = b.media.match(a);\n                if (!d) {\n                    return;\n                }\n            ;\n            ;\n                var e = new d({\n                    url: a,\n                    matchLabel: b.media.matchCache[a].matchLabel,\n                    slug: b.media.matchCache[a].match,\n                    size: this.options.size\n                });\n                e.process(function() {\n                    e.renderThumbnail(c.options.DOMContainer);\n                });\n            },\n            embed: function(a, c, d) {\n                var e = this, f;\n                ((d ? f = new c({\n                    url: a,\n                    tweet: this.tweet,\n                    mediaEntity: d\n                }) : f = new c({\n                    url: a,\n                    matchLabel: b.media.matchCache[a].matchLabel,\n                    slug: b.media.matchCache[a].match,\n                    tweet: this.tweet\n                }))), e.options.preProcess(f, function(b) {\n                    f.process(function() {\n                        e.options.postProcess(f, ((b || {\n                        }))), e.options.beforeRender(f, function(b) {\n                            var c = (new twttr.views.MediaTypeContainer({\n                                url: a,\n                                media_type: f.constructor._name,\n                                media_type_class: f.constructor._name.toLowerCase()\n                            })).$html(), d = c.data(\"url-id\");\n                            e.options.DOMContainer.JSBNG__find(((((\"div[data-url-id=\\\"\" + d)) + \"\\\"]\"))).remove().end().append(c), f.render(c);\n                            if (((!f.data || !f.data.is_card))) {\n                                ((e.tweetFlaggable(e.tweet) && c.append(f.flaggable()))), c.append(f.attribution());\n                            }\n                        ;\n                        ;\n                            JSBNG__setTimeout(function() {\n                                c.closest(\".tweet\").delegate(\".flaggable\", \"click\", function(a) {\n                                    e.flagLinkClicked(a, e.tweet);\n                                });\n                            }, 0), e.options.afterRender(f, ((b || {\n                            }))), twttr.images.addPrivacyCover(c.JSBNG__find(\"a img\"));\n                        });\n                    }, ((b || {\n                    })), d);\n                });\n            }\n        }), a(c);\n    });\n});\nprovide(\"media/mediaType\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.media.MediaType\", function(a) {\n            this.url = a.url, this.matchLabel = a.matchLabel, this.slug = a.slug, this.tweet = ((a.tweet || null)), this.options = ((a || {\n            })), this.JSBNG__location = new b.util.Location(this.url), this.data = {\n            };\n        }), twttr.mediaType = function(a, c) {\n            var d = ((\"twttr.media.types.\" + a)), e = twttr.klass(d, function() {\n                twttr.media.MediaType.apply(this, arguments);\n            });\n            e.subclassOf(twttr.media.MediaType).statics({\n                partnerName: a,\n                domain: ((c.domain || \"\")),\n                attributionName: ((c.attributionName || a)),\n                skipAttributionInDiscovery: ((c.skipAttributionInDiscovery || !1)),\n                title: ((c.title || null)),\n                _icon: ((c.icon || \"generic\")),\n                deciderKey: ((c.deciderKey || null)),\n                screenName: ((c.screenName || null)),\n                aspectRatio: ((c.aspectRatio || b.constants.videos.fullscreen)),\n                height: c.height,\n                ssl: ((c.ssl || !1)),\n                isEnabled: function() {\n                    return ((this.deciderKey ? ((twttr.decider && twttr.decider.isAvailable(this.deciderKey))) : !0));\n                },\n                attributionTemplate: ((c.attributionTemplate || \"MediaAttribution\")),\n                validActions: $.extend({\n                    resizeFrame: !0\n                }, c.validActions),\n                enableAPI: ((c.enableAPI || !1)),\n                addMatchers: function(a) {\n                    for (var c in a) {\n                        this.matchers[c] = b.util.regexSupplant(a[c]);\n                    ;\n                    };\n                ;\n                },\n                flagActionTemplate: ((c.flagActionTemplate || ((((((((\"\\u003Cspan class='flag-container'\\u003E\\u003Ca href='#' class='flaggable' alternateText='\" + _(\"Un-flag this media\"))) + \"'\\u003E\")) + _(\"Flag this media\"))) + \"\\u003C/a\\u003E\\u003C/span\\u003E\"))))\n            }).methods({\n                process: ((c.process || function() {\n                \n                })),\n                JSBNG__content: ((c.JSBNG__content || function() {\n                \n                })),\n                getImageURL: ((c.getImageURL || function() {\n                \n                })),\n                partnerName: a,\n                metadata: function(a) {\n                    if (twttr.is.fn(c.metadata)) {\n                        return c.metadata.apply(this, [a,]);\n                    }\n                ;\n                ;\n                },\n                calcHeight: function(a, b) {\n                    ((b || (b = this.constructor.aspectRatio)));\n                    var c = parseInt(b.split(\":\")[0], 10), d = parseInt(b.split(\":\")[1], 10), e = 30;\n                    return ((Math.round(((a * ((d / c))))) + e));\n                },\n                resizeHtmlEmbed: function(a, b, c, d) {\n                    if (((((((a && b)) && b.maxwidth)) && ((b.maxwidth < c))))) {\n                        var e = Math.round(((((b.maxwidth * d)) / c)));\n                        a = a.replace(new RegExp(((((\"width=(\\\"?)\" + c)) + \"(?=\\\\D|$)\")), \"g\"), ((\"width=$1\" + b.maxwidth))).replace(new RegExp(((((\"height=(\\\"?)\" + d)) + \"(?=\\\\D|$)\")), \"g\"), ((\"height=$1\" + e)));\n                    }\n                ;\n                ;\n                    return a;\n                },\n                useOpaqueModeForFlash: function(a) {\n                    return a.replace(/(<\\/object>)/, \"\\u003Cparam name=\\\"wmode\\\" value=\\\"opaque\\\"\\u003E$1\").replace(/(<embed .*?)(\\/?>)/, \"$1 wmode=\\\"opaque\\\"$2\");\n                },\n                icon: function() {\n                    return ((twttr.is.fn(this.constructor._icon) ? this.constructor._icon.call(this, this.url) : this.constructor._icon));\n                },\n                flaggable: function() {\n                    return ((((((!twttr.loggedIn || !c.flaggable)) || !twttr.decider.isAvailable(\"media_flagging\"))) ? !1 : $(Mustache.to_html(this.constructor.flagActionTemplate))));\n                },\n                attribution: function() {\n                    return ((((c.attribution && twttr.is.fn(c.attribution))) ? c.attribution.call(this) : (new twttr.views[this.constructor.attributionTemplate]({\n                        url: this.domainUrl(),\n                        icon_url: this.iconUrl(),\n                        title: ((((this.data.attribution_title || this.constructor.title)) || this.constructor._name)),\n                        media_type: this.constructor._name\n                    })).html()));\n                },\n                iconUrl: function() {\n                    return ((this.data.attribution_icon || twttr.assets.path(((((\"/images/partner-favicons/\" + this.constructor._name)) + \".png\")))));\n                },\n                domainUrl: function() {\n                    return ((this.data.attribution_url || this.constructor.domain));\n                },\n                attributionName: function() {\n                    return this.constructor.attributionName;\n                },\n                hasAttributionInDiscovery: function() {\n                    return !this.constructor.skipAttributionInDiscovery;\n                },\n                render: function(a) {\n                    if (((c.render && twttr.is.fn(c.render)))) {\n                        return c.render.call(this, a);\n                    }\n                ;\n                ;\n                    var b = this.JSBNG__content();\n                    if ((($.browser.msie && (($.browser.version <= 8))))) $(a).html(b);\n                     else {\n                        b = ((((\"\\u003Cdiv class='tweet-media'\\u003E\" + b)) + \"\\u003C/div\\u003E\"));\n                        var d = new twttr.platform.SandboxedApplication(this.constructor, {\n                            tweet: this.tweet,\n                            originalUrl: this.url\n                        }), e = {\n                            DOMContainer: a,\n                            htmlContent: b,\n                            height: this.data.height,\n                            width: this.data.width,\n                            security: this.constructor.ssl\n                        };\n                        d.run(e);\n                    }\n                ;\n                ;\n                },\n                JSBNG__content: function() {\n                    return ((((c.JSBNG__content && twttr.is.fn(c.JSBNG__content))) ? c.JSBNG__content.call(this) : \"\"));\n                },\n                renderThumbnail: function(a) {\n                    var b = this;\n                    this.metadata(function(c) {\n                        c.alt = b.constructor.title;\n                        var d = Mustache.to_html(\"\\u003Cimg src=\\\"{{image}}\\\" alt=\\\"{{alt}}\\\" title=\\\"{{title}}\\\" /\\u003E\", c);\n                        $(a).append(d);\n                    });\n                },\n                renderIframe: function(a, b) {\n                    t = \"\\u003Ciframe src='{{url}}' width='{{width}}' height='{{height}}'\\u003E\\u003C/iframe\\u003E\", $(a).append(Mustache.to_html(t, $.extend({\n                        url: b\n                    }, this.data)));\n                },\n                renderEmbeddedApplication: function(a, b) {\n                    var c = new twttr.platform.EmbeddedApplication(this.constructor, {\n                        tweet: this.tweet,\n                        originalUrl: this.url\n                    }), d = {\n                        DOMContainer: a,\n                        height: this.data.height,\n                        width: this.data.width\n                    };\n                    c.run(b, d);\n                }\n            }), e.matchers = ((c.matchers || {\n            }));\n            for (var f in e.matchers) {\n                (function() {\n                    var a = f;\n                    e.matchers[a] = b.util.regexSupplant(e.matchers[a]);\n                })();\n            ;\n            };\n        ;\n            return e;\n        }, a(twttr.mediaType);\n    });\n});\nprovide(\"media/expandodo\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        function c(a) {\n            return ((a.expanded_url.replace(/^https?:\\/\\//, \"//\") + \"/large\"));\n        };\n    ;\n        function d(a) {\n            ((a && (a.profile_path = ((\"/\" + a.screen_name)))));\n        };\n    ;\n        function e(a) {\n            var b = [\"players\",\"summaries\",\"photos\",], c, e, f, g;\n            for (c = 0; ((c < b.length)); c++) {\n                g = a[b[c]];\n                if (((g && g.length))) {\n                    for (e = 0; ((e < g.length)); e++) {\n                        f = g[e], d(f.author_user), d(f.site_user);\n                    ;\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function f(a, b, c) {\n            this.data = c, this.data.is_card = !0, e(this.data), a();\n        };\n    ;\n        function g(a, b, c) {\n            var d = this;\n            ((((c && c.source_status_id_str)) ? twttr.API.Status.JSBNG__find(c.source_status_id_str, function(e) {\n                i(c, e.user, function(c) {\n                    f.apply(d, [a,b,c,]);\n                });\n            }) : i(c, !1, function(c) {\n                f.apply(d, [a,b,c,]);\n            })));\n        };\n    ;\n        function i(a, b, d) {\n            var e = j(a.sizes.medium.w, a.sizes.medium.h, m, l), f = {\n                photos: [{\n                    url: c(a),\n                    title: !1,\n                    description: !1,\n                    images: {\n                        web: {\n                            image_url: a.media_url_https,\n                            width: e.width,\n                            height: e.height\n                        }\n                    },\n                    twimg_attribution: !0,\n                    permalink_continuity: !0\n                },]\n            };\n            ((b && (f.photos[0].author_user = {\n                id_str: b.id,\n                screen_name: b.screenName,\n                JSBNG__name: b.JSBNG__name,\n                profile_image_url: b.profileImageUrl,\n                profile_image_url_https: b.profileImageUrlHttps\n            }))), d(f);\n        };\n    ;\n        function j(a, b, c, d) {\n            return ((((((b >= a)) && ((b > d)))) ? (a *= ((d / b)), b = d) : ((((((a > b)) && ((a > c)))) && (b *= ((c / a)), a = c))))), {\n                width: Math.ceil(a),\n                height: Math.ceil(b)\n            };\n        };\n    ;\n        function k(a) {\n            $(a).append(Mustache.to_html(twttr.templates.cards_base, this.data, twttr.templates));\n        };\n    ;\n        var l = 375, m = 435;\n        twttr.mediaType(\"photo\", {\n            icon: \"photo\",\n            process: f,\n            render: k\n        }), twttr.mediaType(\"nativePhoto\", {\n            icon: \"photo\",\n            attribute: !1,\n            process: g,\n            render: k\n        }), twttr.mediaType(\"summary\", {\n            icon: \"summary\",\n            process: f,\n            render: k\n        }), twttr.mediaType(\"player\", {\n            icon: \"player\",\n            process: f,\n            render: k\n        }), a();\n    });\n});\nprovide(\"platform/BaseApplication\", function(a) {\n    using(\"_\").as(function(b, _) {\n        (function() {\n            function a(a) {\n                var b = twttr.platform.runningApplications[a];\n                ((b && (b.JSBNG__stop(), delete twttr.platform.runningApplication[a])));\n            };\n        ;\n            ((twttr.platform || (twttr.platform = {\n            }))), twttr.platform.application_types = {\n                embedded: \"embedded\"\n            }, twttr.platform.runningApplications = {\n            };\n            var b = 50, c = 3600000, d = {\n                trends: !0,\n                \"geo/nearby_places\": !0,\n                \"statuses/retweets/:id\": !0,\n                \"followers/ids\": !0,\n                \"geo/id/:id\": !0,\n                \"geo/search\": !0,\n                \"lists/statuses\": !0,\n                \"users/suggestions\": !0,\n                \"friendships/show\": !0,\n                \"statuses/show\": !0,\n                \"trends/current\": !0,\n                \"geo/similar_places\": !0,\n                \"statuses/user_timeline\": !0,\n                \"friends/ids\": !0,\n                \"trends/:woeid\": !0,\n                \"statuses/followers\": !0,\n                \"statuses/friends\": !0,\n                \"statuses/public_timeline\": !0,\n                \"users/show\": !0\n            }, e = {\n                \"users/search\": !0,\n                \"users/typeahead\": !0,\n                \":user/lists/subscriptions\": !0,\n                \"statuses/network_timeline\": !0,\n                \"statuses/friends_timeline\": !0,\n                \":user/:list_id/members\": !0,\n                \":user/lists/memberships\": !0,\n                \"statuses/:id/retweeted_by/ids\": !0,\n                \":user/lists\": !0,\n                \"statuses/mentions\": !0,\n                \"geo/reverse_geocode\": !0,\n                \"friendships/exists\": !0,\n                \":user/:list_id/members/:id\": !0,\n                search: !0,\n                \"statuses/retweeted_to_me\": !0,\n                \"statuses/retweets_of_me\": !0,\n                \"statuses/retweeted_by_me\": !0,\n                \":user/:list_id/subscribers\": !0,\n                \":user/:list_id/subscribers/:id\": !0,\n                \"favorites/:id\": !0,\n                \"statuses/:id/retweeted_by\": !0,\n                \"account/verify_credentials\": !0,\n                \"users/lookup\": !0,\n                \"trends/weekly\": !0,\n                \"trends/daily\": !0,\n                \"statuses/home_timeline\": !0,\n                \"lists/show\": !0\n            };\n            twttr.platform.events = {\n                resize: function() {\n                    var a = this;\n                    $(window).bind(((\"resize.\" + this.config._name)), function() {\n                        var b = $(\"div.details-pane.opened\");\n                        ((((b.length !== 0)) && a.socket.trigger(\"resize\", b.width())));\n                    });\n                }\n            }, twttr.platform.interfaceActions = {\n                openTab: function(a) {\n                    window.open(a.url, \"_blank\");\n                },\n                openProfile: function(a, b) {\n                    twttr.app.currentPage().send(\"loadUserInDetailsPane\", [this.config.screenName,{\n                    },], function() {\n                        a(!0);\n                    }, function() {\n                        b(\"Profile pane not available or no registered screen name\");\n                    });\n                },\n                tweet: function(a, b, c) {\n                    (new twttr.widget.TweetDialog({\n                        defaultContent: a,\n                        draggable: !0,\n                        template: {\n                            title: _(\"What\\u2019s happening?\")\n                        },\n                        origin: \"new-tweet-titlebar-button\"\n                    })).open().JSBNG__focus();\n                },\n                notify: function(a, b) {\n                    twttr.Notifications.notify(a.type, a.subject, a.message, a.icon, function() {\n                        b(a);\n                    });\n                },\n                resizeFrame: function(a) {\n                    this.DOMContainer.firstChild.style.height = ((a + \"px\"));\n                },\n                bind: function(a, b, c) {\n                    var d = twttr.platform.events[a];\n                    ((d ? (d.call(this), b(!0)) : c(\"You tried to bind to an event that is not bindable\")));\n                },\n                unbind: function(a, b, c) {\n                    var d = twttr.platform.events[a];\n                    ((d ? ($(window).unbind(((((a + \".\")) + this.config._name))), b(!0)) : c(\"You tried to unbind from an event that is not bindable\")));\n                }\n            };\n            var f = 0, g = twttr.klass(\"twttr.platform.BaseApplication\", function(a) {\n                this.limiter = 0, this.interval = (new JSBNG__Date).getTime(), this.socket = null, this.config = a, this.minimized = !1, this.id = ++f;\n            });\n            g.methods({\n                run: function(a, b) {\n                    var c = this;\n                    this.options = ((b || {\n                    })), this.url = a;\n                    var d = ((b.DOMContainer || $(JSBNG__document.body)));\n                    ((((d instanceof jQuery)) && (this.DOMContainer = d[0]))), this.socket = new easyXDM.Rpc({\n                        remote: this.url,\n                        container: this.DOMContainer,\n                        props: {\n                            width: ((b.width || \"100%\")),\n                            height: ((b.height || 0))\n                        },\n                        JSBNG__onReady: function() {\n                            twttr.platform.runningApplications[c.id] = c, c.limiter = 0, c.interval = (new JSBNG__Date).getTime();\n                            var a = c.initialData();\n                            c.socket.initialize(a), ((b.loaded && b.loaded.call(c)));\n                        }\n                    }, {\n                        local: {\n                            api: twttr.bind(this, this.api),\n                            ui: twttr.bind(this, this.ui),\n                            log: twttr.bind(this, this.log)\n                        },\n                        remote: {\n                            trigger: {\n                            },\n                            initialize: {\n                            }\n                        }\n                    });\n                },\n                initialData: function() {\n                    var a = {\n                    }, b = $(\"div.details-pane.opened\");\n                    return ((((b.length !== 0)) && (a.size = b.width()))), ((((twttr.currentUser && twttr.currentUser.profileLinkColor)) && (a.styles = [[\"a\",[\"color\",((\"#\" + twttr.currentUser.profileLinkColor)),],],]))), a;\n                },\n                JSBNG__stop: function() {\n                    this.socket.destroy();\n                },\n                maximize: function() {\n                    ((this.minimized && (this.minimized = !1, this.run(this.url, this.options))));\n                },\n                minimize: function() {\n                    this.JSBNG__stop(), this.attribution = $(this.DOMContainer).JSBNG__find(\".media-attribution\").detach(), this.minimized = !0;\n                },\n                isRateLimited: function() {\n                    var a = (new JSBNG__Date).getTime();\n                    return ((((((a - this.interval)) > c)) ? (this.limiter = 0, this.interval = a, !1) : ((this.limiter >= b))));\n                },\n                isPermitted: function() {\n                    return !0;\n                },\n                isProtectedEndpoint: function(a) {\n                    return ((((twttr.currentUser[\"protected\"] && !this.isPermitted(this.socket.origin))) ? !0 : ((((!d[a] && !e[a])) ? !0 : !1))));\n                },\n                log: function(a, b, c, d) {\n                    ((twttr.is.fn(b) && (d = c, c = b, b = {\n                    }))), b = ((b || {\n                    })), c = ((c || $.noop)), d = ((d || $.noop));\n                    if (this.minimized) {\n                        return d(\"You cannot log information while your application is minimized\");\n                    }\n                ;\n                ;\n                    scribble(\"partner_event\", {\n                        partner: this.config._name,\n                        origin: this.socket.origin,\n                        eventName: a,\n                        data: b\n                    }), c(!0);\n                },\n                api: function(a, b, c, d) {\n                    d = ((d || $.noop));\n                    if (this.minimized) {\n                        return d(\"You cannot access the API while your application is minimized\");\n                    }\n                ;\n                ;\n                    if (!this.config.enableAPI) {\n                        return d(\"You do not have API Access\");\n                    }\n                ;\n                ;\n                    if (!!this.isRateLimited()) {\n                        return d(\"You have been rate-limited.\");\n                    }\n                ;\n                ;\n                    this.limiter++;\n                    if (this.isProtectedEndpoint(a)) {\n                        return d(\"You do not have access to that endpoint.\");\n                    }\n                ;\n                ;\n                    ((twttr.is.fn(b) && (d = c, c = b, b = []))), twttr.API.util.makeRemoteRequest(a, b, {\n                        success: function(a) {\n                            ((c && c(a)));\n                        },\n                        error: function(a) {\n                            ((d && d(a)));\n                        }\n                    });\n                },\n                ui: function(a, b, c, d) {\n                    ((twttr.is.fn(b) && (d = c, c = b, b = {\n                    }))), b = ((b || {\n                    })), c = ((c || $.noop)), d = ((d || $.noop));\n                    if (!this.config.validActions[a]) {\n                        return d(\"This is not a valid UI action.\");\n                    }\n                ;\n                ;\n                    if (this.minimized) {\n                        return d(\"You cannot access interface components while your application is minimized\");\n                    }\n                ;\n                ;\n                    scribble(\"partner_ui_action\", {\n                        partner: this.config._name,\n                        origin: this.socket.origin,\n                        actionName: a,\n                        data: b\n                    }), twttr.platform.interfaceActions[a].apply(this, [b,c,d,]);\n                }\n            });\n        })(), a(twttr.platform.BaseApplication);\n    });\n});\nprovide(\"platform/EmbeddedApplication\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.platform.EmbeddedApplication\", function(a, b) {\n            b = ((b || {\n            })), twttr.platform.BaseApplication.apply(this, arguments), this.tweet = ((b.tweet || null)), this.originalUrl = ((b.originalUrl || null)), this.applicationType = twttr.platform.application_types.embedded;\n        });\n        c.subclassOf(twttr.platform.BaseApplication), c.methods({\n            initialData: function() {\n                var a = twttr.platform.BaseApplication.prototype.initialData.call(this);\n                return a;\n            },\n            log: function(a, b, c, d) {\n                ((twttr.is.fn(b) && (d = c, c = b, b = {\n                }))), b.original_url = this.originalUrl, twttr.platform.BaseApplication.prototype.log.apply(this, arguments);\n            }\n        }), a(c);\n    });\n});\nprovide(\"platform/SandboxedApplication\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.platform.SandboxedApplication\", function(a, b) {\n            twttr.platform.EmbeddedApplication.apply(this, arguments);\n        }).subclassOf(twttr.platform.EmbeddedApplication).statics({\n            remoteUrl: function(a) {\n                var b = twttr.domains.local.match(/localhost/), c = \"/details_pane_content_sandbox.html\";\n                return ((b ? ((\"http://localhost:3000\" + c)) : twttr.assets.path(c, {\n                    isSSL: ((twttr.isSSL() && a))\n                })));\n            }\n        }).methods({\n            run: function(a) {\n                twttr.platform.EmbeddedApplication.prototype.run.call(this, twttr.platform.SandboxedApplication.remoteUrl((($.browser.msie || a.security))), a);\n            },\n            initialData: function() {\n                var a = twttr.platform.EmbeddedApplication.prototype.initialData.call(this);\n                return ((((twttr.currentUser && twttr.currentUser.profileLinkColor)) && a.styles.push([\".sandboxed-media a\",[\"color\",((\"#\" + twttr.currentUser.profileLinkColor)),],]))), $.extend({\n                }, a, {\n                    htmlContent: this.options.htmlContent\n                });\n            }\n        }), a(twttr.platform.SandboxedApplication);\n    });\n});\nprovide(\"sandboxedAjax\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.AjaxSandboxer\", function() {\n            this._nextRequestId = 0, this._requests = {\n            }, this._sockets = [null,null,];\n        }).statics({\n            TIMEOUT: 5000\n        }).methods({\n            send: function(a) {\n                ((a.timeout || (a.timeout = twttr.AjaxSandboxer.TIMEOUT))), ((this._useSandbox() ? this._sendWithSandbox(a) : this._sendWithoutSandbox(a)));\n            },\n            _useSandbox: function() {\n                return twttr.isSSL();\n            },\n            _sendWithSandbox: function(a) {\n                security = !!((a.url.match(/^https:/) || ((twttr.isSSL() && a.url.match(/^\\/\\//))))), (($.browser.msie && (security = 1))), index = ((security ? 0 : 1)), ((this._sockets[index] || (this._sockets[index] = this._generateSocket(this._remoteUrl(security)))));\n                var b = this._generateSandboxRequest(a);\n                this._sockets[index].JSBNG__postMessage(JSON.stringify(b));\n            },\n            _sendWithoutSandbox: function(a) {\n                $.ajax(a);\n            },\n            _generateSandboxRequest: function(a) {\n                var b = ++this._nextRequestId;\n                a = twttr.merge({\n                }, a);\n                var c = {\n                    id: b,\n                    callbacks: {\n                        success: a.success,\n                        error: a.error,\n                        before: a.before,\n                        complete: a.complete\n                    },\n                    request: {\n                        id: b,\n                        data: a\n                    }\n                };\n                return delete a.success, delete a.error, delete a.complete, delete a.before, this._requests[b] = c, c.request;\n            },\n            _remoteUrl: function(a) {\n                var b = \"/jsonp_sandbox.html\";\n                return ((twttr.domains.local.match(/localhost/) ? ((\"http://localhost:3000\" + b)) : twttr.assets.path(b, {\n                    isSSL: a\n                })));\n            },\n            _generateSocket: function(a) {\n                var b = this;\n                return new easyXDM.Socket({\n                    remote: a,\n                    JSBNG__onMessage: function(a, c) {\n                        var d = JSON.parse(a), e = b._requests[d.id];\n                        ((((e && e.callbacks[d.callbackName])) && e.callbacks[d.callbackName].apply(null, d.callbackArgs))), ((((d.callbackName === \"complete\")) && delete b._requests[d.id]));\n                    }\n                });\n            }\n        }), twttr.sandboxedAjax = new twttr.AjaxSandboxer, a(twttr.sandboxedAjax);\n    });\n});\nprovide(\"media/types\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        function c(a) {\n            return ((twttr.isSSL() ? a.replace(/^http:/, \"https:\") : a));\n        };\n    ;\n        twttr.provide(\"twttr.regexps\", {\n            protocol: /(?:https?\\:\\/\\/)/,\n            protocol_no_ssl: /(?:http\\:\\/\\/)/,\n            optional_protocol: /(?:(?:https?\\:\\/\\/)?(?:www\\.)?)/,\n            protocol_subdomain: /(?:(?:https?\\:\\/\\/)?(?:[\\w\\-]+\\.))/,\n            optional_protocol_subdomain: /(?:(?:https?\\:\\/\\/)?(?:[\\w\\-]+\\.)?)/,\n            wildcard: /[a-zA-Z0-9_#\\.\\-\\?\\&\\=\\/]+/,\n            itunes_protocol: /(?:https?\\:\\/\\/)?(?:[a-z]\\.)?itunes\\.apple\\.com(?:\\/[a-z][a-z])?/\n        }), twttr.mediaType(\"Youtube\", {\n            title: \"YouTube\",\n            icon: \"video\",\n            domain: \"//www.youtube.com\",\n            ssl: !0,\n            flaggable: !0,\n            height: 359,\n            matchers: {\n                tinyUrl: /^#{optional_protocol}?youtu\\.be\\/([a-zA-Z0-9_\\-\\?\\&\\=\\/]+)/i,\n                standardUrl: /^#{optional_protocol}?youtube\\.com\\/watch[a-zA-Z0-9_\\-\\?\\&\\=\\/]+/i\n            },\n            process: function(a, b) {\n                this.data.width = ((((b && b.maxwidth)) || 390)), this.data.height = ((((b && b.maxwidth)) ? this.calcHeight(b.maxwidth) : 307)), ((this.url.match(this.constructor.matchers.tinyUrl) ? (this.data.id = this.JSBNG__location.pathname.replace(/\\//g, \"\"), a()) : ((this.JSBNG__location.search.match(/[\\?\\&]v\\=([\\w\\-]+)(?:\\&|$)/) && (this.data.id = this.JSBNG__location.query(\"v\"), a())))));\n            },\n            metadata: function(a) {\n                var c = {\n                    image: b.util.supplant(\"//img.youtube.com/vi/{id}/0.jpg\", this.data)\n                };\n                a(c);\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    c.metadata(function(a) {\n                        ((((a && a.image)) ? b(a.image) : b(null)));\n                    });\n                });\n            },\n            render: function(a) {\n                this.renderIframe(a, ((((((twttr.proto + \"://www.youtube.com/embed/\")) + this.data.id)) + \"?wmode=opaque\")));\n            }\n        }), twttr.mediaType(\"Twitter\", {\n            icon: \"tweet\",\n            domain: \"//twitter.com\",\n            ssl: !0,\n            skipAttributionInDiscovery: !0,\n            matchers: {\n                permalink: /^#{optional_protocol}?twitter\\.com\\/(?:#!?\\/)?\\w{1,20}\\/status\\/(\\d+)[\\/]?$/i\n            },\n            process: function(a) {\n                var b = this;\n                twttr.API.Status.JSBNG__find(this.slug, function(c) {\n                    b.data.tweet = c, ((twttr.isT1 ? using(\"//platform.twitter.com/js/vendor/twt/dist/twt.all.min.js\", \"css!//platform.twitter.com/twt/twt.css\", function() {\n                        if (!window.twt) {\n                            return;\n                        }\n                    ;\n                    ;\n                        for (var c = twttr.languages.length; c--; ) {\n                            if (twttr.languages[c].current) {\n                                twt.settings.lang = twttr.languages[c].code;\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        var d = twt.tweet(b.data.tweet.attributes);\n                        b.tweetHtml = d.html(), a();\n                    }).load() : a()));\n                });\n            },\n            render: function(a) {\n                if (!twttr.isT1) $(a).append((new twttr.views.EmbeddedTweet(this.data.tweet)).html());\n                 else {\n                    var b = this;\n                    $(a).append(Mustache.to_html(\"\\u003Cdiv class='tweet-embed'\\u003E{{{tweet}}}\\u003C/div\\u003E\", {\n                        tweet: b.tweetHtml\n                    }));\n                }\n            ;\n            ;\n            }\n        }), twttr.mediaType(\"CopiedTwimg\", {\n            icon: \"photo\",\n            domain: \"//twitter.com\",\n            ssl: !0,\n            flaggable: !0,\n            deciderKey: \"photo_copy_paste_inception\",\n            skipAttributionInDiscovery: !0,\n            attributionTemplate: \"PhotobucketAttribution\",\n            matchers: {\n                media: /^#{optional_protocol}?twitter\\.com\\/(?:#!?\\/)?\\w{1,20}\\/status\\/(\\d+)\\/photo\\/\\d*$/i\n            },\n            getImageURL: function() {\n                twttr.media.types.Twimg.prototype.getImageURL.apply(this, arguments);\n            },\n            metadata: function() {\n                twttr.media.types.Twimg.prototype.metadata.apply(this, arguments);\n            },\n            process: function(a) {\n                var b = this;\n                twttr.API.Status.JSBNG__find(this.slug, function(c) {\n                    b.data.tweet = c, ((((c.entities && c.entities.media)) && $.each(c.entities.media, function(a, c) {\n                        if (((c.expanded_url.indexOf(b.slug) > -1))) {\n                            return b.foundMedia = c, !1;\n                        }\n                    ;\n                    ;\n                    })));\n                    var d;\n                    ((twttr.isSSL() ? d = b.foundMedia.media_url_https : d = b.foundMedia.media_url)), b.data.src = d, b.data.url = b.foundMedia.expanded_url, b.data.JSBNG__name = b.constructor._name, a();\n                });\n            },\n            render: function(a) {\n                var b = this.data.tweet;\n                if (!this.foundMedia) {\n                    return;\n                }\n            ;\n            ;\n                var c = {\n                    JSBNG__name: \"copied-twimg\",\n                    time_ago: twttr.helpers.timeAgo(twttr.helpers.parseDateString(b.createdAt), !0),\n                    url: this.foundMedia.url,\n                    media_url: ((twttr.isSSL() ? this.foundMedia.media_url_https : this.foundMedia.media_url)),\n                    screen_name: b.user.screenName\n                }, d = $(a);\n                d.append((new twttr.views.CopiedTwimg(c)).html()), d.JSBNG__find(\".inline-media-image img\").bind(\"load\", function() {\n                    $(this).closest(\".media-instance-container\").width(this.width);\n                }), ((twttr.app.isOnPage(\"permalink\") && d.JSBNG__find(\".user-profile-link\").click(function() {\n                    return twttr.router.routeTo(twttr.router.profilePath({\n                        screen_name: $(this).data(\"screen-name\")\n                    })), !1;\n                })));\n            }\n        }), twttr.mediaType(\"Twimg\", {\n            icon: \"photo\",\n            domain: \"//twitter.com\",\n            attributionName: \"Twitter\",\n            flaggable: !0,\n            ssl: !0,\n            skipAttributionInDiscovery: !0,\n            matchers: {\n                twimg: /^#{optional_protocol}?p\\.twimg\\.com\\/[a-zA-Z0-9_-]+\\.(?:jpg|png|gif)$/i,\n                media: /^#{optional_protocol}?pic\\.twitter\\.com\\/[a-zA-Z0-9]+$/i\n            },\n            attributionTemplate: \"PhotobucketAttribution\",\n            getImageURL: function(a, c) {\n                var d = this;\n                this.process(function() {\n                    d.metadata(function(d) {\n                        if (((d && d.image))) {\n                            var e = d.image;\n                            ((((a == b.constants.imageSizes.small)) ? e += \":thumb\" : ((((a == b.constants.imageSizes.large)) && (e += \":large\"))))), c(e);\n                        }\n                         else c(null);\n                    ;\n                    ;\n                    });\n                });\n            },\n            metadata: function(a) {\n                a({\n                    image: this.data.src,\n                    JSBNG__name: this.data.JSBNG__name,\n                    expandedUrl: this.data.url\n                });\n            },\n            process: function(a, b) {\n                var d = twttr.media.types.Twimg.matchers, e = this, f, g;\n                if (this.url.match(d.twimg)) this.data.src = c(this.url), this.data.url = c(this.url), this.data.displayUrl = this.url, this.data.JSBNG__name = this.constructor._name;\n                 else {\n                    if (((!this.tweet || !this.tweet.entities.media))) {\n                        a();\n                        return;\n                    }\n                ;\n                ;\n                    var i = $.map(this.tweet.entities.media, function(a) {\n                        return a.display_url;\n                    });\n                    if ((($.inArray(this.url, i) < 0))) {\n                        a();\n                        return;\n                    }\n                ;\n                ;\n                    $.each(this.tweet.entities.media, function() {\n                        if (((this.display_url == e.url))) {\n                            g = this;\n                            return;\n                        }\n                    ;\n                    ;\n                    });\n                    if (!g) {\n                        a();\n                        return;\n                    }\n                ;\n                ;\n                    ((twttr.isSSL() ? f = g.media_url_https : f = g.media_url)), this.data.src = f, this.data.url = ((((b && ((b.linkLarge === !0)))) ? ((g.expanded_url + \"/large\")) : g.url)), this.data.displayUrl = g.display_url, this.data.JSBNG__name = this.constructor._name;\n                }\n            ;\n            ;\n                a();\n            },\n            render: function(a) {\n                var b = \"\\u003Cdiv class=\\\"twimg\\\"\\u003E                \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{url}}\\\" target=\\\"_blank\\\" title=\\\"{{displayUrl}}\\\"\\u003E                  \\u003Cimg src=\\\"{{src}}\\\" alt=\\\"{{displayUrl}}\\\"/\\u003E                 \\u003C/a\\u003E              \\u003C/div\\u003E\";\n                $(a).append(Mustache.to_html(b, this.data));\n            }\n        }), twttr.mediaType(\"Ustream\", {\n            icon: \"video\",\n            domain: \"http://ustream.tv\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                recorded: /^#{optional_protocol}?ustream\\.tv\\/(recorded\\/(?:\\d+))/i,\n                channel: /^#{optional_protocol}?ustream\\.tv\\/(channel\\/(?:[\\w\\-]+)\\/?)/i\n            },\n            metadata: function(a) {\n                var b = null;\n                ((((((this.data && this.data.imageUrl)) && this.data.imageUrl.small)) && (b = this.data.imageUrl.small))), a({\n                    title: this.data.title,\n                    description: ((this.data.description ? twttr.helpers.truncate(this.data.description, 255, \"...\") : \"\")),\n                    image: b\n                });\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    c.metadata(function(a) {\n                        b(a.image);\n                    });\n                });\n            },\n            process: function(a, b) {\n                var c = this;\n                this.data.width = ((((b && b.maxwidth)) || 390)), this.data.height = this.calcHeight(this.data.width), ((((this.slug.match(this.constructor.re.channel) || this.slug.match(this.constructor.re.video))) && twttr.sandboxedAjax.send({\n                    url: ((((\"http://api.ustream.tv/json/channel/\" + RegExp.$1)) + \"/getInfo\")),\n                    dataType: \"jsonp\",\n                    data: {\n                        key: this.constructor.API_KEY,\n                        maxwidth: this.data.width\n                    },\n                    success: function(b) {\n                        ((((b !== null)) && (c.data.type = \"channel\", c.data.embed = c.useOpaqueModeForFlash(b.embedTag), c.data.imageUrl = b.imageUrl))), a();\n                    }\n                })));\n            },\n            JSBNG__content: function() {\n                return ((((this.data.type === \"channel\")) ? this.data.embed : Mustache.to_html(this.constructor.templates[this.data.type], this.data)));\n            }\n        }).statics({\n            API_KEY: \"12ab548e85128e0d3182ba3a346c3428\",\n            re: {\n                video: /^recorded\\/(\\d+)/,\n                channel: /^channel\\/([\\w\\-]+)\\/?/\n            },\n            templates: {\n                video: \"        \\u003Cobject width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"\\u003E          \\u003Cparam name=\\\"flashvars\\\" value=\\\"autoplay=false&amp;vid={{videoId}}&amp;\\\"/\\u003E          \\u003Cparam name=\\\"allowfullscreen\\\" value=\\\"true\\\"/\\u003E          \\u003Cparam name=\\\"allowscriptaccess\\\" value=\\\"always\\\"/\\u003E          \\u003Cparam name=\\\"wmode\\\" value=\\\"opaque\\\"/\\u003E          \\u003Cparam name=\\\"src\\\" value=\\\"http://www.ustream.tv/flash/video/{{videoId}}\\\"/\\u003E          \\u003Cembed            flashvars=\\\"loc=%2F&amp;autoplay=false&amp;vid={{videoId}}&amp;\\\"            width=\\\"{{width}}\\\"            height=\\\"{{height}}\\\"            allowfullscreen=\\\"true\\\"            allowscriptaccess=\\\"always\\\"            wmode=\\\"opaque\\\"            src=\\\"http://www.ustream.tv/flash/video/{{videoId}}\\\"            type=\\\"application/x-shockwave-flash\\\" /\\u003E        \\u003C/object\\u003E\"\n            }\n        }), twttr.mediaType(\"Vevo\", {\n            icon: \"video\",\n            domain: \"http://vevo.com\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                standardVideo: /^#{optional_protocol}?vevo\\.com\\/watch\\/[\\w-]+\\/[\\w-]+\\/([a-zA-Z0-9_]+)/i\n            },\n            process: function(a, b) {\n                this.data.id = this.slug, this.data.width = ((((b && b.maxwidth)) || 390)), this.data.height = this.calcHeight(this.data.width), a();\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cobject width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"\\u003E                \\u003Cparam name=\\\"movie\\\" value=\\\"http://www.vevo.com/VideoPlayer/Embedded?videoId={{id}}&playlist=false&autoplay=0&playerId=62FF0A5C-0D9E-4AC1-AF04-1D9E97EE3961&playerType=embedded\\\"/\\u003E                \\u003Cparam name=\\\"bgcolor\\\" value=\\\"#000000\\\"/\\u003E                \\u003Cparam name=\\\"allowFullScreen\\\" value=\\\"true\\\"/\\u003E                \\u003Cparam name=\\\"allowScriptAccess\\\" value=\\\"always\\\"/\\u003E                \\u003Cparam name=\\\"wmode\\\" value=\\\"opaque\\\"/\\u003E                \\u003Cembed                  src=\\\"http://www.vevo.com/VideoPlayer/Embedded?videoId={{id}}&playlist=false&autoplay=0&playerId=62FF0A5C-0D9E-4AC1-AF04-1D9E97EE3961&playerType=embedded\\\"                   type=\\\"application/x-shockwave-flash\\\"                   allowfullscreen=\\\"true\\\"                   allowscriptaccess=\\\"always\\\"                   wmode=\\\"opaque\\\"                   width=\\\"{{width}}\\\"                   height=\\\"{{height}}\\\"                   bgcolor=\\\"#000000\\\" /\\u003E              \\u003C/object\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"Flickr\", {\n            icon: \"photo\",\n            favicon: ((twttr.isSSL() ? \"https://secure.flickr.com/favicon.ico\" : \"http://www.flickr.com/favicon.ico\")),\n            domain: ((twttr.isSSL() ? \"https://secure.flickr.com\" : \"http://www.flickr.com\")),\n            deciderKey: \"phoenix_flickr_details\",\n            flaggable: !0,\n            matchers: {\n                profile: /^#{optional_protocol}?flickr\\.com\\/(?:photos|people)\\/([\\w\\@\\-]+)\\/?$/i,\n                photo: /^#{optional_protocol}?flickr\\.com\\/photos\\/[\\w\\@\\-]+\\/(\\d+)\\/?/i,\n                sets: /^#{optional_protocol}?flickr\\.com\\/photos\\/(?:[\\w\\@\\-]+)\\/sets\\/(\\d+)\\/?(?:show\\/?)?$/i,\n                galleries: /^#{optional_protocol}?flickr\\.com\\/photos\\/([\\w\\@\\-]+)\\/galleries\\/(\\d+)\\/?$/i,\n                pool: /^#{optional_protocol}?flickr\\.com\\/groups\\/([\\w\\@\\-]+)\\/?(?:pool\\/|discuss\\/)?$/i\n            },\n            ssl: !0,\n            metadata: function(a) {\n                var b;\n                ((((this.data.photos && ((this.data.photos.length >= 1)))) ? (b = this.data.photos[0], a({\n                    image: Mustache.to_html(\"//farm{{farm}}.static.flickr.com/{{server}}/{{id}}_{{secret}}.jpg\", b),\n                    title: this.data.title,\n                    description: this.data.description,\n                    author: {\n                        JSBNG__name: this.data.author_name,\n                        url: this.data.author_url\n                    }\n                })) : a(null)));\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    c.metadata(function(a) {\n                        ((((a && a.image)) ? b(a.image) : b(null)));\n                    });\n                });\n            },\n            process: function(a, b) {\n                this.data.width = ((((b && b.maxwidth)) || 390)), this.data.height = this.calcHeight(this.data.width), this.data.domain = this.constructor.domain;\n                var c = twttr.media.types.Flickr.matchers, d = this, e = this.url;\n                if (e.match(c.photo)) {\n                    var f = RegExp.$1;\n                    this.makeRequest({\n                        data: {\n                            method: \"flickr.photos.getInfo\",\n                            photo_id: f\n                        },\n                        success: function(b) {\n                            ((b.photo && (d.data.author_name = b.photo.owner.realname, d.data.author_url = ((((d.constructor.domain + \"/photos/\")) + b.photo.owner.nsid)), ((((b.photo.media && ((b.photo.media == \"video\")))) && (d.data.isVideo = !0))), d.data.photos = [b.photo,]))), a();\n                        }\n                    });\n                }\n                 else ((e.match(c.sets) ? this._makeSetRequest(RegExp.$1, a) : ((e.match(c.profile) ? this.lookUpUserPhotos(RegExp.$1, this.slug, a) : ((e.match(c.pool) ? this._makeGroupRequestByName(RegExp.$1, a) : ((e.match(c.galleries) && this.makeRequest({\n                    data: {\n                        method: \"flickr.urls.lookupGallery\",\n                        url: ((((((\"flickr.com/photos/\" + RegExp.$1)) + \"/galleries/\")) + RegExp.$2))\n                    },\n                    success: function(b) {\n                        var c = b.gallery.id;\n                        d.makeRequest({\n                            data: {\n                                method: \"flickr.galleries.getPhotos\",\n                                gallery_id: c\n                            },\n                            success: function(b) {\n                                d.data.photos = b.photos.photo.slice(0, 16), d.data.isGallery = 1, a();\n                            }\n                        });\n                    }\n                })))))))));\n            ;\n            ;\n                return;\n            },\n            JSBNG__content: function() {\n                var a = \"\", b = twttr.media.types.Flickr;\n                if (((this.data.photos.length == 1))) if (this.data.isVideo) {\n                    var c = this.data.photos[0];\n                    c.domain = this.data.domain, a += Mustache.to_html(b.templates.video, c);\n                }\n                 else this.data.photos[0].href = this.data.photos[0].urls.url[0]._content, a += Mustache.to_html(b.templates.photo, this.data.photos[0]);\n                \n                 else {\n                    a = ((((\"\\u003Cdiv class=\\\"flickr-group\\\"\\u003E\" + this.createThumbList(this.data.photos))) + \"\\u003C/div\\u003E\"));\n                    if (this.data.isGallery) {\n                        return a;\n                    }\n                ;\n                ;\n                    var d;\n                    ((this.data.set_id ? d = b.photoSetFlashVars : ((this.data.group_id ? d = b.photoGroupFlashVars : d = b.photoUserFlashVars)))), d = twttr.merge({\n                    }, b.defaultSlideshowFlashVars, d, !0);\n                    var e = [];\n                    jQuery.each(d, function(a, b) {\n                        e.push(((((a + \"=\")) + b)));\n                    }), e = Mustache.to_html(e.join(\"&\"), this.data), a += Mustache.to_html(b.templates.slideshow, {\n                        flashvars: e,\n                        domain: this.data.domain\n                    });\n                }\n            ;\n            ;\n                return a;\n            }\n        }).statics({\n            API_KEY: \"2a56884b56a00758525eaa2fee16a798\",\n            SECRET: \"7c794fe3256175b6\",\n            REST_DOMAIN: \"//widgets.platform.twitter.com\",\n            defaultSlideshowFlashVars: {\n                lang: \"en-us\",\n                offsite: !0,\n                minH: 100,\n                minW: 100\n            },\n            templates: {\n                video: \"\\u003Cobject width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"                   type=\\\"application/x-shockwave-flash\\\"                   data=\\\"{{domain}}/apps/video/stewart.swf?v=71377\\\"                   classid=\\\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\\\"\\u003E                   \\u003Cparam name=\\\"flashvars\\\" value=\\\"intl_lang=en-us&photo_secret={{secret}}&photo_id={{id}}\\\"/\\u003E                   \\u003Cparam name=\\\"movie\\\" value=\\\"{{domain}}/apps/video/stewart.swf?v=71377\\\"/\\u003E                   \\u003Cparam name=\\\"bgcolor\\\" value=\\\"#000000\\\"/\\u003E                   \\u003Cparam name=\\\"allowFullScreen\\\" value=\\\"true\\\"/\\u003E                   \\u003Cparam name=\\\"wmode\\\" value=\\\"opaque\\\"/\\u003E                   \\u003Cembed                     type=\\\"application/x-shockwave-flash\\\"                     src=\\\"{{domain}}/apps/video/stewart.swf?v=71377\\\"                     bgcolor=\\\"#000000\\\"                     allowfullscreen=\\\"true\\\"                     wmode=\\\"opaque\\\"                     flashvars=\\\"intl_lang=en-us&photo_secret={{secret}}&photo_id={{id}}\\\"                     height=\\\"{{height}}\\\"                     width=\\\"{{width}}\\\" /\\u003E                 \\u003C/object\\u003E\",\n                photo: \"\\u003Cdiv class=\\\"flickr-photo\\\"\\u003E                   \\u003Ca href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                     \\u003Cimg src=\\\"//farm{{farm}}.static.flickr.com/{{server}}/{{id}}_{{secret}}.jpg\\\"/\\u003E                   \\u003C/a\\u003E                 \\u003C/div\\u003E\",\n                set: \"\\u003Ca href=\\\"{{href}}\\\" style=\\\"text-decoration:none;\\\" target=\\\"_blank\\\"\\u003E                \\u003Cimg class=\\\"flickr-thumb\\\" src=\\\"//farm{{farm}}.static.flickr.com/{{server}}/{{id}}_{{secret}}_s.jpg\\\"/\\u003E              \\u003C/a\\u003E\",\n                slideshow: \"\\u003Cembed type=\\\"application/x-shockwave-flash\\\"                             src=\\\"{{domain}}/apps/slideshow/show.swf?v=107931\\\"                             width=\\\"{{width}}\\\"                             height=\\\"{{height}}\\\"                             id=\\\"slideShowMovie\\\"                             bgcolor=\\\"#000000\\\"                             quality=\\\"high\\\"                             allowfullscreen=\\\"true\\\"                             allowscriptaccess=\\\"always\\\"                             wmode=\\\"opaque\\\"                             flashvars={{flashvars}} /\\u003E\"\n            },\n            photoUserFlashVars: {\n                user_id: \"{{user_id}}\",\n                page_show_back_url: \"/photos/{{user_name}}/\",\n                page_show_url: \"/photos/{{user_name}}/show/\"\n            },\n            photoGroupFlashVars: {\n                group_id: \"{{group_id}}\",\n                page_show_url: \"/groups/{{group_id}}/pool/show/\",\n                page_show_back_url: \"/groups/{{group_id}}/pool/\"\n            },\n            photoSetFlashVars: {\n                set_id: \"{{set_id}}\",\n                page_show_back_url: \"/photos/{{user_name}}/sets/{{set_id}}/\",\n                page_show_url: \"/photos/{{user_name}}/sets/{{set_id}}/show/\"\n            }\n        }).methods({\n            base58: function(a) {\n                var b = \"123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ\", c = a.length, d = 0, e = 1;\n                for (var f = ((c - 1)); ((f >= 0)); f--) {\n                    d += ((e * b.indexOf(a[f]))), e *= b.length;\n                ;\n                };\n            ;\n                return d;\n            },\n            lookUpUserPhotos: function(a, b, c) {\n                var d = this;\n                this.makeRequest({\n                    data: {\n                        method: \"flickr.urls.lookupUser\",\n                        url: ((\"flickr.com/photos/\" + a))\n                    },\n                    success: function(b) {\n                        if (((b.stat === \"fail\"))) {\n                            c();\n                            return;\n                        }\n                    ;\n                    ;\n                        var e = b.user.id, f = b.user.username._content;\n                        d.makeRequest({\n                            data: {\n                                method: \"flickr.people.getPublicPhotos\",\n                                user_id: e\n                            },\n                            success: function(b) {\n                                d.data.photos = b.photos.photo.slice(0, 16), d.data.user_id = e, d.data.user_name = a, d.data.author_name = f, d.data.author_url = ((((d.constructor.domain + \"/photos/\")) + e)), c();\n                            }\n                        });\n                    }\n                });\n            },\n            createThumbList: function(a) {\n                var b = \"http://www.flickr.com/photos\", c = this;\n                return $.map(a, function(a, c) {\n                    return a.href = [b,a.owner,a.id,].join(\"/\"), Mustache.to_html(twttr.media.types.Flickr.templates.set, a);\n                }).join(\"\");\n            },\n            _makeGroupRequestByName: function(a, b) {\n                this.makeRequest({\n                    data: {\n                        method: \"flickr.urls.lookupGroup\",\n                        url: ((\"flickr.com/groups/\" + a))\n                    },\n                    success: twttr.bind(this, function(a) {\n                        this._makeGroupRequestById(a.group.id, b);\n                    })\n                });\n            },\n            _makeGroupRequestById: function(a, b) {\n                this.makeRequest({\n                    data: {\n                        method: \"flickr.groups.pools.getPhotos\",\n                        group_id: a\n                    },\n                    success: twttr.bind(this, function(c) {\n                        this.data.photos = c.photos.photo.slice(0, 16), this.data.group_id = a, b();\n                    })\n                });\n            },\n            _makeSetRequest: function(a, b) {\n                this.makeRequest({\n                    data: {\n                        method: \"flickr.photosets.getPhotos\",\n                        photoset_id: a\n                    },\n                    success: twttr.bind(this, function(a) {\n                        var c = a.photoset.owner;\n                        this.data.photos = a.photoset.photo.slice(0, 16), twttr.each(this.data.photos, function(a) {\n                            a.owner = c;\n                        }), this.data.set_id = a.photoset.id, this.data.user_name = c, this.data.author_name = a.photoset.ownername, this.data.author_url = ((((this.constructor.domain + \"/photos/\")) + a.photoset.owner)), b();\n                    })\n                });\n            },\n            makeRequest: function(a) {\n                var b = {\n                    url: ((twttr.media.types.Flickr.REST_DOMAIN + \"/services/rest\")),\n                    dataType: \"jsonp\",\n                    jsonp: \"jsoncallback\",\n                    data: {\n                        format: \"json\",\n                        api_key: twttr.media.types.Flickr.API_KEY\n                    },\n                    success: function(a) {\n                    \n                    }\n                };\n                twttr.sandboxedAjax.send(twttr.merge({\n                }, b, a, !0));\n            }\n        }), twttr.mediaType(\"DeviantArt\", {\n            title: \"deviantART\",\n            icon: \"photo\",\n            domain: \"http://deviantart.com\",\n            flaggable: !0,\n            matchers: {\n                canonical: /^(#{protocol}?(?:[\\w\\-]+\\.)deviantart\\.com\\/art\\/(?:[\\w\\@-]+))/i,\n                oldStyle: /^(#{protocol}?(?:[\\w\\-]+\\.)deviantart\\.com\\/deviation\\/(?:[\\w\\@-]+))/i,\n                gallery: /^(#{protocol}?(?:[\\w\\-]+\\.)deviantart\\.com\\/gallery\\/#\\/d(?:[\\w\\@-]+))/i,\n                favMe: /^(#{protocol}?fav\\.me\\/(?:[\\w\\@-]+))/i,\n                oldView: /^(#{protocol}?(?:[\\w\\-]+\\.)deviantart\\.com\\/view\\/(?:[\\w\\@-]+))/i\n            },\n            process: function(a, b) {\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://backend.deviantart.com/oembed\",\n                    data: {\n                        url: this.slug,\n                        format: \"jsonp\",\n                        maxwidth: b.maxwidth\n                    },\n                    dataType: \"jsonp\",\n                    success: twttr.bind(this, function(b) {\n                        this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, this.data.src = b.thumbnail_url, this.data.author_name = b.author_name, this.data.author_url = b.author_url, a();\n                    })\n                });\n            },\n            attribution: function() {\n                var a = \"         \\u003Cdiv class='media-attribution'\\u003E           \\u003Cspan\\u003Evia\\u003C/span\\u003E            \\u003Ca target='_blank' class='media-attribution-link' href='{{author_url}}'\\u003E{{author_name}}\\u003C/a\\u003E            from \\u003Cimg src='{{icon_url}}'/\\u003E           \\u003Ca target='_blank' data-media-type='{{media_type}}' class='media-attribution-link' href='{{url}}'\\u003E{{title}}\\u003C/a\\u003E         \\u003C/div\\u003E\";\n                return Mustache.to_html(a, {\n                    url: this.constructor.domain,\n                    icon_url: twttr.assets.path(\"/partner-favicons/DeviantArt.ico\"),\n                    title: ((this.constructor.title || this.constructor._name)),\n                    media_type: this.constructor._name,\n                    author_name: this.data.author_name,\n                    author_url: this.data.author_url\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"deviantart\\\"\\u003E                \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                  \\u003Cimg src=\\\"{{src}}\\\"/\\u003E                \\u003C/a\\u003E              \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"Vimeo\", {\n            icon: \"video\",\n            domain: \"//vimeo.com\",\n            ssl: !0,\n            flaggable: !0,\n            height: 150,\n            matchers: {\n                video: /^#{optional_protocol}?vimeo\\.com\\/(\\d+)/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((((c.data && c.data.thumbnail_url)) ? b(c.data.thumbnail_url) : b(null)));\n                });\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), this.data.video_id = this.slug, twttr.sandboxedAjax.send({\n                    url: \"//vimeo.com/api/oembed.json\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: ((\"http://vimeo.com/\" + this.slug)),\n                        width: ((b.maxwidth || 446))\n                    },\n                    success: function(b) {\n                        c.data.thumbnail_url = b.thumbnail_url, c.data.width = b.width, c.data.height = b.height, a();\n                    }\n                });\n            },\n            render: function(a) {\n                this.renderIframe(a, ((\"//player.vimeo.com/video/\" + this.data.video_id.replace(/[^0-9]/g, \"\"))));\n            }\n        }), twttr.mediaType(\"Etsy\", {\n            icon: \"photo\",\n            domain: \"http://etsy.com\",\n            ssl: !1,\n            matchers: {\n                itemListing: /^#{optional_protocol}?etsy\\.com\\/listing\\/(\\d+)/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((((((c.data && c.data.images)) && ((c.data.images.length > 0)))) ? b(c.data.images[0].url_170x135) : b(null)));\n                });\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), this.data.itemId = this.slug, this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, twttr.sandboxedAjax.send({\n                    url: ((((\"http://openapi.etsy.com/v2/public/listings/\" + this.slug)) + \".js\")),\n                    dataType: \"jsonp\",\n                    data: {\n                        detail_level: \"high\",\n                        api_key: \"qev732j7b8j44eg5pqsb38k4\",\n                        includes: \"Images(url_170x135):6\",\n                        fields: \"listing_id,title,price,currency_code,quantity\",\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        var d = b.results[0];\n                        c.data.title = d.title;\n                        switch (d.currency_code) {\n                          case \"USD\":\n                            c.data.price = ((((d.quantity + \" for $\")) + ((d.price || 0))));\n                            break;\n                          default:\n                            c.data.price = ((((((((d.quantity + \" for \")) + ((d.price || 0)))) + \" \")) + d.currency_code));\n                        };\n                    ;\n                        c.data.images = d.Images;\n                        var e = $.map(d.Images, function(a, b) {\n                            return ((((\"\\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" target=\\\"_blank\\\" href=\\\"{{href}}\\\"\\u003E                      \\u003Cimg class=\\\"thumb\\\" src=\\\"\" + a.url_170x135)) + \"\\\"/\\u003E                    \\u003C/a\\u003E\"));\n                        }).join(\"\"), f = ((((\"            \\u003Cdiv class=\\\"etsy\\\"\\u003E              \\u003Ch3\\u003E{{title}}\\u003C/h3\\u003E              \\u003Cp\\u003E{{price}}\\u003C/p\\u003E              \\u003Cp\\u003E\" + e)) + \"\\u003C/p\\u003E            \\u003C/div\\u003E\"));\n                        c.data.html = Mustache.to_html(f, c.data), a();\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.html;\n            }\n        }), twttr.mediaType(\"Photozou\", {\n            icon: \"photo\",\n            domain: \"http://photozou.jp\",\n            flaggable: !0,\n            matchers: {\n                photo: /^#{optional_protocol}?photozou\\.(?:com|jp)\\/photo\\/show\\/\\d+\\/(\\d+)/i\n            },\n            ssl: !1,\n            getImageURL: function(a, c, d) {\n                var e = this;\n                this.process(function() {\n                    ((((e.data && e.data.src)) ? ((((((d && ((d < 120)))) || ((a == b.constants.imageSizes.small)))) ? c(e.data.smallSrc) : c(e.data.src))) : c(null)));\n                });\n            },\n            process: function(a) {\n                this.data.src = ((\"http://photozou.jp/p/img/\" + this.slug)), this.data.smallSrc = ((\"http://photozou.jp/p/thumb/\" + this.slug)), this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, a();\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"photozou\\\"\\u003E                 \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                   \\u003Cimg src=\\\"{{src}}\\\"/\\u003E                 \\u003C/a\\u003E               \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"TwitPic\", {\n            icon: \"photo\",\n            domain: \"//twitpic.com\",\n            flaggable: !0,\n            matchers: {\n                media: /^#{optional_protocol}?twitpic\\.com\\/(?!(?:place|photos|events)\\/)([a-zA-Z0-9\\?\\=\\-]+)/i\n            },\n            ssl: !0,\n            process: function(a) {\n                this.data.src = this.slug, this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, a();\n            },\n            getImageURL: function(a, c) {\n                if (this.slug) {\n                    var d = \"\";\n                    ((((a == b.constants.imageSizes.medium)) ? d = ((\"//twitpic.com/show/thumb/\" + this.slug)) : ((((a == \"small\")) ? d = ((\"//twitpic.com/show/mini/\" + this.slug)) : d = ((\"//twitpic.com/show/iphone/\" + this.slug)))))), c(d);\n                }\n                 else c(null);\n            ;\n            ;\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"twitpic\\\"\\u003E                 \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                   \\u003Cimg src=\\\"//twitpic.com/show/large/{{src}}\\\"/\\u003E                 \\u003C/a\\u003E              \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"Twitgoo\", {\n            icon: \"photo\",\n            domain: \"http://twitgoo.com\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                image: /^#{optional_protocol}?twitgoo\\.com\\/(?!a\\/)([a-zA-Z0-9\\-\\?\\=]+)/i\n            },\n            getImageURL: function(a, c) {\n                ((this.slug ? c(b.util.supplant(\"http://twitgoo.com/{src}/img\", {\n                    src: this.slug\n                })) : c(null)));\n            },\n            process: function(a) {\n                this.data.src = this.slug, this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, a();\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"twitgoo\\\"\\u003E                 \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                   \\u003Cimg src=\\\"http://twitgoo.com/{{src}}/img\\\"/\\u003E                 \\u003C/a\\u003E               \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"DailyBooth\", {\n            icon: \"photo\",\n            domain: \"//dailybooth.com\",\n            ssl: !0,\n            matchers: {\n                photo1: /^#{optional_protocol}?dailybooth\\.com\\/(u\\/\\w+)/i,\n                photo2: /^#{optional_protocol}?dailybooth\\.com\\/(\\w+\\/\\w+)/i\n            },\n            getImageURL: function(a, c) {\n                var d = this;\n                this.process(function() {\n                    ((d.data ? ((((a === b.constants.imageSizes.original)) ? c(d.data.src) : c(d.data.smallImage))) : c(null)));\n                });\n            },\n            process: function(a) {\n                var b = this;\n                this.data.href = c(this.url), this.data.JSBNG__name = this.constructor._name;\n                if (this.slug.match(/^u\\/(\\w+)/)) var d = parseInt(RegExp.$1, 36), e = this.getBaseTen(d)\n                 else {\n                    var e = this.slug.match(/\\w+\\/(\\w+)/);\n                    if (!e) {\n                        a();\n                        return;\n                    }\n                ;\n                ;\n                    e = e[1];\n                }\n            ;\n            ;\n                twttr.sandboxedAjax.send({\n                    url: ((((\"//api.dailybooth.com/v1/picture/\" + e)) + \".json\")),\n                    dataType: \"jsonp\",\n                    type: \"get\",\n                    success: function(d) {\n                        b.data.src = c(d.urls.large), b.data.smallImage = c(d.urls.small), a();\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"dailybooth\\\"\\u003E                 \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                   \\u003Cimg src=\\\"{{src}}\\\"/\\u003E                 \\u003C/a\\u003E               \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }).methods({\n            getBaseTen: function(a) {\n                if (Number.prototype.toFixed) a = a.toFixed(5), a = parseFloat(a);\n                 else {\n                    var b = Math.floor(a), c = ((a - b));\n                    a = ((b + ((Math.round(((c * 100000000000000))) / 100000000000000))));\n                }\n            ;\n            ;\n                return a;\n            }\n        }), twttr.mediaType(\"YFrog\", {\n            domain: \"//yfrog.com\",\n            ssl: !0,\n            flaggable: !0,\n            icon: function(a) {\n                var b = this.slug.charAt(((this.slug.length - 1)));\n                switch (b) {\n                  case \"j\":\n                \n                  case \"p\":\n                \n                  case \"b\":\n                \n                  case \"t\":\n                \n                  case \"g\":\n                    return \"photo\";\n                  case \"z\":\n                \n                  case \"f\":\n                \n                  case \"s\":\n                    return \"video\";\n                };\n            ;\n            },\n            matchers: {\n                media: /^#{optional_protocol}?yfrog\\.(?:com|ru|com\\.tr|it|fr|co\\.il|co\\.uk|com\\.pl|pl|eu|us)\\/(\\w+)/i\n            },\n            getImageURL: function(a, c) {\n                ((this.slug ? ((((this.icon() === \"video\")) ? c(b.util.supplant(\"//yfrog.com/{id}:frame\", {\n                    id: this.slug\n                })) : ((((a === b.constants.imageSizes.small)) ? c(b.util.supplant(\"//yfrog.com/{id}:twthumb\", {\n                    id: this.slug\n                })) : c(b.util.supplant(\"//yfrog.com/{id}:tw1\", {\n                    id: this.slug\n                })))))) : c(null)));\n            },\n            process: function(a) {\n                this.data.media_id = this.slug, this.data.href = this.url.replace(/\\/$/, \"\"), this.data.JSBNG__name = this.constructor._name, a();\n            },\n            JSBNG__content: function() {\n                var a, b = this.data.media_id.charAt(((this.data.media_id.length - 1)));\n                if (((((((((((b == \"j\")) || ((b == \"p\")))) || ((b == \"b\")))) || ((b == \"t\")))) || ((b == \"g\"))))) {\n                    a = \"\\u003Cdiv class=\\\"yfrog\\\"\\u003E               \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                 \\u003Cimg src=\\\"//yfrog.com/{{media_id}}:iphone\\\"\\u003E               \\u003C/a\\u003E             \\u003C/div\\u003E\";\n                }\n                 else {\n                    if (((((((b == \"z\")) || ((b == \"f\")))) || ((b == \"s\"))))) {\n                        a = \"\\u003Cembed                src=\\\"//yfrog.com/{{media_id}}:embed\\\"                width=\\\"100%\\\"                allowFullScreen=\\\"true\\\"                wmode=\\\"transparent\\\"                type=\\\"application/x-shockwave-flash\\\"/\\u003E\";\n                    }\n                ;\n                }\n            ;\n            ;\n                return ((a || (a = \"\"))), Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"Lockerz\", {\n            icon: \"photo\",\n            domain: \"//www.lockerz.com\",\n            ssl: !0,\n            matchers: {\n                tweetphoto: /^#{optional_protocol}?tweetphoto\\.com\\/(\\d+)/i,\n                plixi: /^#{protocol}?(?:(?:m|www)\\.)?plixi\\.com\\/p\\/(\\d+)/i,\n                lockerz: /^#{protocol}?(?:(?:m|www)\\.)?lockerz\\.com\\/s\\/([0-9\\?\\=\\- ]+)/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((((c.data && c.data.src)) ? b(c.data.src) : b(null)));\n                });\n            },\n            process: function(a) {\n                this.data.src = ((\"//api.plixi.com/api/tpapi.svc/imagefromurl?size=medium&url=\" + encodeURIComponent(this.url))), this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, a();\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"lockerz\\\"\\u003E                 \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                   \\u003Cimg src=\\\"{{src}}\\\" /\\u003E                 \\u003C/a\\u003E              \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"Kiva\", {\n            icon: \"generic\",\n            domain: \"http://www.kiva.org\",\n            ssl: !1,\n            matchers: {\n                project: /^#{optional_protocol}?kiva\\.org\\/lend\\/(\\d+)/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://www.kiva.org/services/oembed\",\n                    dataType: \"jsonp\",\n                    jsonp: \"jsonp\",\n                    data: {\n                        url: ((\"http://www.kiva.org/lend/\" + this.slug)),\n                        format: \"jsonp\",\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        c.data.html = b.html, a();\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.html;\n            }\n        }), twttr.mediaType(\"TwitVid\", {\n            icon: \"video\",\n            domain: \"//www.twitvid.com\",\n            ssl: !0,\n            flaggable: !0,\n            favicon: \"//www.twitvid.com/favicon.ico\",\n            matchers: {\n                video: /^#{optional_protocol}?twitvid\\.com\\/([a-zA-Z0-9_\\-\\?\\=]+)/i\n            },\n            process: function(a, b) {\n                this.data.media_id = this.slug, this.data.width = ((((b && b.maxwidth)) || 425)), this.data.height = this.calcHeight(this.data.width), a();\n            },\n            metadata: function(a) {\n                a({\n                    image: b.util.supplant(\"//www.twitvid.com/{media_id}:largethumb\", this.data)\n                });\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    c.metadata(function(a) {\n                        ((((a && a.image)) ? b(a.image) : b(null)));\n                    });\n                });\n            },\n            render: function(a) {\n                this.renderIframe(a, ((((twttr.proto + \"://www.twitvid.com/embed.php?autoplay=0&guid=\")) + this.data.media_id)));\n            }\n        }), twttr.mediaType(\"GoogleVideo\", {\n            icon: \"video\",\n            domain: \"http://video.google.com\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                video: /^#{optional_protocol}video\\.google\\.com\\/([a-zA-Z0-9_\\-\\?\\=\\&\\#]+)/i\n            },\n            process: function(a, b) {\n                this.data.width = 400, this.data.height = 326, ((((((b && b.maxwidth)) && ((b.maxwidth < this.data.width)))) && (this.data.width = b.maxwidth, this.data.height = Math.round(((((b.maxwidth * 326)) / 400)))))), ((this.slug.match(/#docid=(\\-?\\d+)/) ? (this.data.doc_id = RegExp.$1, a()) : ((this.slug.match(/\\?docid=(\\-?\\d+)/) && (this.data.doc_id = RegExp.$1, a())))));\n            },\n            JSBNG__content: function() {\n                var a = \"         \\u003Cembed type=\\\"application/x-shockwave-flash\\\"                 id=\\\"VideoPlayback\\\"                 src=\\\"http://video.google.com/googleplayer.swf?docid={{doc_id}}&hl=en&fs=true\\\"                 style=\\\"width:{{width}}px;height:{{height}}px\\\"                 allowFullScreen=\\\"true\\\"                 allowScriptAccess=\\\"always\\\"                wmode=\\\"opaque\\\" /\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"JustinTV\", {\n            icon: \"video\",\n            domain: \"http://justin.tv\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                embed: /^#{protocol_no_ssl}([a-zA-Z0-9_\\-\\?\\=]*\\.)?justin\\.tv\\/[a-zA-Z0-9]+(\\/b\\/\\d+)?\\/?(\\?\\w*?)?(#\\w*)?$/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((((c.data && c.data.thumbnail_url)) ? b(c.data.thumbnail_url) : b(null)));\n                });\n            },\n            process: function(a, b) {\n                var c = this, d = 400, e = 300;\n                twttr.sandboxedAjax.send({\n                    url: \"http://api.justin.tv/api/embed/from_url.json\",\n                    dataType: \"jsonp\",\n                    jsonp: \"jsonp\",\n                    data: {\n                        url: c.url,\n                        maxwidth: ((((b && b.maxwidth)) || d))\n                    },\n                    success: function(f) {\n                        ((f.error || (c.data.embed = c.useOpaqueModeForFlash(c.resizeHtmlEmbed(f.html, b, d, e)), ((f.thumbnail_url && (c.data.thumbnail_url = f.thumbnail_url))), a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Kickstarter\", {\n            icon: \"generic\",\n            domain: \"//kickstarter.com\",\n            ssl: !0,\n            matchers: {\n                project: /^#{optional_protocol}?(kickstarter\\.com\\/projects\\/[a-zA-Z0-9_\\-]+\\/[a-zA-Z0-9_\\-]+)/i\n            },\n            process: function(a) {\n                this.data.height = \"380px\", this.data.width = \"220px\", a();\n            },\n            render: function(a) {\n                var b = this.slug;\n                ((((b.slice(-1) !== \"/\")) && (b += \"/\"))), b += \"widget/card.html\", this.renderIframe(a, ((((twttr.proto + \"://www.\")) + b)));\n            }\n        }), twttr.mediaType(\"MTV\", {\n            icon: \"video\",\n            domain: \"http://mtv.com\",\n            ssl: !1,\n            matchers: {\n                video: /^#{optional_protocol}?mtv\\.com\\/videos\\/([a-z0-9\\-\\_]+\\/)+[0-9]+\\/[a-z0-9\\-\\_]+\\.jhtml(#[a-z0-9\\=\\&]+)?/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://www.mtv.com/videos/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.url = b.url, ((((b.width > 315)) ? (c.data.width = 315, c.data.height = Math.floor(((((b.height * 315)) / b.width)))) : (c.data.height = b.height, c.data.width = b.width))), a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cobject width=\\\"{{width}}\\\" height=\\\"{{height}}\\\"\\u003E                \\u003Cparam name=\\\"movie\\\" value=\\\"{{url}}\\\"/\\u003E                \\u003Cparam name=\\\"allowFullScreen\\\" value=\\\"true\\\"/\\u003E                \\u003Cparam name=\\\"allowscriptaccess\\\" value=\\\"always\\\"/\\u003E                \\u003Cparam name=\\\"wmode\\\" value=\\\"opaque\\\"/\\u003E                \\u003Cembed src=\\\"{{url}}\\\"                        type=\\\"application/x-shockwave-flash\\\"                        allowscriptaccess=\\\"always\\\"                        allowfullscreen=\\\"true\\\"                        wmode=\\\"opaque\\\"                        width=\\\"{{width}}\\\"                        height=\\\"{{height}}\\\"/\\u003E              \\u003C/object\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"WashingtonPost\", {\n            icon: \"video\",\n            domain: \"http://washingtonpost.com\",\n            matchers: {\n                video: /(^(?:#{protocol}?(?:[\\w\\-\\_]+\\.))?washingtonpost\\.com\\/wp-dyn\\/content\\/video\\/\\d{4}\\/\\d{2}\\/\\d{2}\\/VI\\d+\\.html(#{wildcard})?)/i\n            },\n            ssl: !1,\n            process: function(a, b) {\n                var c = this, d = 400, e = 225;\n                twttr.sandboxedAjax.send({\n                    url: \"http://specials.washingtonpost.com/tv/info.json\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: ((((b && b.maxwidth)) || d))\n                    },\n                    success: function(f) {\n                        ((f.error || (c.data.embed = c.useOpaqueModeForFlash(c.resizeHtmlEmbed(f.html, b, d, e)), c.data.width = f.width, c.data.height = f.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"MSNBC\", {\n            icon: \"video\",\n            domain: \"http://msnbc.com\",\n            ssl: !1,\n            matchers: {\n                video: /(^(?:#{protocol}?(?:[\\w\\-\\_]+\\.))?msnbc\\.msn\\.com\\/id\\/\\d{1,8}\\/vp\\/\\d{1,8}(#{wildcard})?)/i\n            },\n            process: function(a, b) {\n                var c = this, d = 420, e = 245;\n                twttr.sandboxedAjax.send({\n                    url: \"http://www.polls.newsvine.com/_labs/twitter/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        format: \"jsonp\",\n                        url: this.url,\n                        maxwidth: ((((b && b.maxwidth)) || d))\n                    },\n                    success: function(f) {\n                        ((f.error || (c.data.embed = c.resizeHtmlEmbed(f.html, b, d, e), c.data.width = f.width, c.data.height = f.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"CNN\", {\n            icon: \"video\",\n            domain: \"http://cnn.com\",\n            title: \"CNN Video\",\n            ssl: !1,\n            deciderKey: \"phoenix_cnn_details\",\n            matchers: {\n                video: /(^(?:#{protocol}?(?:(?:www|edition|us)\\.)?)?cnn\\.com\\/video\\/[\\?|#]\\/#{wildcard})/i\n            },\n            process: function(a, b) {\n                var c = this, d = this.url, e = 416, f = 374, g = d.split(\"?\");\n                ((((g.length > 2)) && (g.pop(), d = g.join(\"?\")))), twttr.sandboxedAjax.send({\n                    url: \"http://newspulse.cnn.com/widget/json/twitter-video\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        format: \"jsonp\",\n                        maxwidth: ((((b && b.maxwidth)) || e)),\n                        url: d\n                    },\n                    success: function(d) {\n                        ((d.error || (c.data.embed = c.resizeHtmlEmbed(d.html, b, e, f), c.data.attribution_url = \"http://cnn.com/video\", c.data.width = d.width, c.data.height = d.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Apple\", {\n            icon: ((twttr.isT1 ? function() {\n                switch (this.matchLabel) {\n                  case \"song\":\n                    return \"song\";\n                  case \"album\":\n                    return \"album\";\n                  case \"music_video\":\n                \n                  case \"video\":\n                \n                  case \"movie\":\n                \n                  case \"tv\":\n                    return \"video\";\n                  case \"software\":\n                    return \"software\";\n                  case \"JSBNG__event\":\n                \n                  case \"preorder\":\n                \n                  case \"playlist\":\n                \n                  case \"ping_playlist\":\n                \n                  case \"podcast\":\n                \n                  case \"book\":\n                \n                  default:\n                    return \"generic\";\n                };\n            ;\n            } : \"song\")),\n            domain: \"http://itunes.apple.com\",\n            deciderKey: \"phoenix_apple_itunes\",\n            matchers: {\n                song: /^#{itunes_protocol}(?:\\/album)\\/.*\\?i=/i,\n                album: /^#{itunes_protocol}(?:\\/album)\\//i,\n                JSBNG__event: /^#{itunes_protocol}\\/event\\//i,\n                music_video: /^#{itunes_protocol}(?:\\/music-video)\\//i,\n                video: /^#{itunes_protocol}(?:\\/video)\\//i,\n                software: /^#{itunes_protocol}(?:\\/app)\\//i,\n                playlist: /^#{itunes_protocol}(?:\\/imix)\\//i,\n                ping_playlist: /^#{itunes_protocol}(?:\\/imixes)\\?/i,\n                preorder: /^#{itunes_protocol}(?:\\/preorder)\\//i\n            },\n            ssl: !1,\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((((c.data && c.data.src)) ? b(c.data.src) : b(null)));\n                });\n            },\n            enableAPI: !1,\n            validActions: {\n                resizeFrame: !0,\n                bind: !0,\n                unbind: !0\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://itunes.apple.com/WebObjects/MZStore.woa/wa/remotePreview\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.src = b.src, c.data.attribution_icon = b.attribution_icon, c.data.attribution_url = b.attribution_url, c.data.attribution_title = \"iTunes\", ((b.favicon && (c.data.attribution_icon = b.favicon))), ((b.faviconLink && (c.data.attribution_url = b.faviconLink))), ((b.height && (c.data.height = b.height))), a())));\n                    }\n                });\n            },\n            render: function(a) {\n                this.renderEmbeddedApplication(a, this.data.src);\n            }\n        });\n        var d = {\n            _queue: [],\n            push: function(a, b) {\n                ((((b === !0)) ? this._queue.unshift(a) : this._queue.push(a))), this._process();\n            },\n            _process: function() {\n                var a = this;\n                if (this._isProcessing) {\n                    return;\n                }\n            ;\n            ;\n                this._isProcessing = !0, JSBNG__setTimeout(function() {\n                    var b = a._queue.shift();\n                    a._isProcessing = !1, ((b && (b(), a._process())));\n                }, 200);\n            }\n        };\n        twttr.mediaType(\"Instagram\", {\n            icon: \"photo\",\n            domain: \"//instagr.am\",\n            title: \"Instagram\",\n            deciderKey: \"phoenix_instagram_and_friends\",\n            ssl: !0,\n            height: 301,\n            matchers: {\n                video: /^#{optional_protocol_subdomain}?(?:instagr\\.am|instagram\\.com)\\/p\\/([a-zA-Z0-9_\\-]+\\/?)/i\n            },\n            getImageURL: function(a, c) {\n                var d = this;\n                this.process(function() {\n                    if (((d.data && d.data.href))) {\n                        var e = b.constants.imageSizes;\n                        ((((((a === e.small)) || ((a === e.medium)))) ? c(d.data.smallSrc) : c(d.data.src)));\n                    }\n                     else c(null);\n                ;\n                ;\n                }, {\n                    size: a\n                });\n            },\n            process: function(a, c) {\n                this.data.href = Mustache.to_html(\"{{domain}}/p/{{slug}}\", {\n                    domain: this.constructor.domain,\n                    slug: this.slug\n                }), this.data.src = b.util.joinPath(this.data.href, \"media/?size=l\"), this.data.smallSrc = b.util.joinPath(this.data.href, \"media/?size=t\"), this.data.JSBNG__name = this.constructor._name, d.push(a, ((c && ((c.size === b.constants.imageSizes.large)))));\n            },\n            JSBNG__content: function() {\n                var a = \"        \\u003Cdiv class=\\\"instagram\\\"\\u003E          \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E            \\u003Cimg src=\\\"{{src}}\\\"/\\u003E          \\u003C/a\\u003E        \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"Rdio\", {\n            icon: \"song\",\n            domain: \"//rdio.com\",\n            ssl: !0,\n            matchers: {\n                rdio: /^#{optional_protocol}(?:rd\\.io|rdio\\.com)\\/#{wildcard}/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//rdio.com/api/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: ((b.maxwidth || 390))\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = c.resizeHtmlEmbed(b.html), a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    b(this.url);\n                }, {\n                    maxwidth: 500\n                });\n            }\n        }), twttr.mediaType(\"Dipdive\", {\n            domain: \"http://dipdive.com\",\n            ssl: !1,\n            deciderKey: \"phoenix_dipdive_details\",\n            matchers: {\n                photos: /^#{optional_protocol_subdomain}?dipdive\\.com\\/(((?:member\\/[a-zA-Z0-9\\-]+\\/)?pictures\\/([0-9]+))|(v\\/[a-zA-Z0-9]+))/i,\n                videos: /^#{optional_protocol_subdomain}?dipdive\\.com\\/(((?:member\\/[a-zA-Z0-9\\-]+\\/)?media\\/([0-9]+))|(v\\/[a-zA-Z0-9]+))/i\n            },\n            icon: function(a) {\n                return ((this._icon ? this._icon : (((this.url.match(/pictures/) ? this._icon = \"photo\" : this._icon = \"video\")), this._icon)));\n            },\n            process: function(a, b) {\n                var c = this, d = 425, e = 385;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://api.dipdive.com/oembed.jsonp\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: ((((b && b.maxwidth)) || d))\n                    },\n                    success: function(f) {\n                        ((f.error || (((((f.type === \"photo\")) ? (c.data.type = \"photo\", c.data.href = f.url, c.data.JSBNG__name = c.constructor._name) : (c.data.embed = c.resizeHtmlEmbed(f.html, b, d, e), c.data.width = f.width, c.data.height = f.height))), a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                var a;\n                return ((((this.data.type === \"photo\")) ? (a = \"\\u003Cdiv class=\\\"dipdive\\\"\\u003E               \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                 \\u003Cimg src=\\\"{{href}}\\\"/\\u003E               \\u003C/a\\u003E             \\u003C/div\\u003E\", Mustache.to_html(a, this.data)) : this.data.embed));\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"SlideShare\", {\n            icon: \"generic\",\n            domain: \"http://slideshare.com\",\n            ssl: !0,\n            deciderKey: \"phoenix_instagram_and_friends\",\n            matchers: {\n                slides: /^#{optional_protocol}?slideshare\\.(?:com|net)\\/[a-zA-Z0-9\\.]+\\/[a-zA-Z0-9-]+\\/?#{wildcard}?/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"https://www.slideshare.net/api/oembed/2\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        format: \"json\",\n                        maxwidth: ((b.maxwidth || 390))\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = c.resizeHtmlEmbed(b.html), c.data.attribution_url = b.author_url, c.data.attribution_title = b.author_name, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"BlipTV\", {\n            icon: \"video\",\n            domain: \"//blip.tv\",\n            flaggable: !0,\n            title: \"blip.tv\",\n            ssl: !1,\n            deciderKey: \"phoenix_instagram_and_friends\",\n            matchers: {\n                videos: /^#{optional_protocol}?blip\\.tv\\/(?:(?:file\\/[\\w-]+)|(?:(?:[\\w-]+\\/)?[\\w-]+-(?:\\d+)))\\/?/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    b(c.data.thumbnail_url);\n                });\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//blip.tv/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = b.html, c.data.thumbnail_url = b.thumbnail_url, c.data.width = b.width, c.data.height = b.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Livestream\", {\n            icon: \"video\",\n            domain: \"http://www.livestream.com\",\n            ssl: !1,\n            flaggable: !0,\n            matchers: {\n                wwwlivestream: /^#{optional_protocol}?livestream\\.com\\/[\\w_]+(\\/#{wildcard})?/i,\n                livestream: /^#{protocol}?livestre\\.am\\/[\\w_]+(\\/#{wildcard})?/i,\n                twitcam: /^#{protocol}?twitcam\\.(?:livestream\\.)com\\/[\\w_]+(\\/#{wildcard})?/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://www.livestream.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = b.html, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"WallStreetJournal\", {\n            icon: \"video\",\n            domain: \"http://online.wsj.com\",\n            title: \"The Wall Street Journal Digital Network\",\n            ssl: !1,\n            matchers: {\n                video: /^#{protocol}?online\\.wsj\\.com\\/video\\/[A-Z0-9a-z\\-]+\\/[A-Z0-9a-z\\-]+\\.html/i\n            },\n            process: function(a, b) {\n                var c = this, d = 450, e = 344;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://online.wsj.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: ((((b && b.maxwidth)) || d))\n                    },\n                    success: function(f) {\n                        ((f.error || (c.data.embed = c.useOpaqueModeForFlash(c.resizeHtmlEmbed(f.html, b, d, e)), c.data.width = f.width, c.data.height = f.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Hulu\", {\n            icon: \"video\",\n            domain: \"http://www.hulu.com\",\n            ssl: !1,\n            height: 253,\n            matchers: {\n                video: /^#{optional_protocol}?hulu\\.com\\/w(atch)?\\/([a-zA-Z0-9]+)/i\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    b(c.data.thumbnail_url);\n                });\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://www.hulu.com/api/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = c.useOpaqueModeForFlash(b.html), c.data.thumbnail_url = b.thumbnail_url, c.data.width = b.width, c.data.height = b.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"NHL\", {\n            icon: \"video\",\n            domain: \"http://www.nhl.com\",\n            ssl: !1,\n            matchers: {\n                video: /^#{protocol}?video\\.([a-z]{4,11}\\.)?nhl\\.com\\/videocenter\\/console\\?(((catid=-?\\d+&)?id=\\d+)|(hlg=\\d{8},\\d,\\d{1,4}(&event=[A-Z0-9]{4,6})?)|(hlp=\\d{5,10}(&event=[A-Z0-9]{4,6})?))/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://video.nhl.com/videocenter/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = c.useOpaqueModeForFlash(b.html), c.data.width = b.width, c.data.height = b.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Meetup\", {\n            icon: \"generic\",\n            domain: \"//www.meetup.com\",\n            deciderKey: \"phoenix_local_meetup\",\n            ssl: !0,\n            matchers: {\n                anevent: /^#{protocol_no_ssl}?(?:(((www|dev)\\.){0,2}?meetup.com)|meetu.ps)\\/(?:u\\/)?[\\w\\-]{3,}(?:[a-zA-Z0-9_#\\.\\-\\?\\&\\=\\/]+)/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//api.meetup.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.html = b.html, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.html;\n            }\n        }), twttr.mediaType(\"Plancast\", {\n            icon: \"generic\",\n            domain: \"//plancast.com\",\n            deciderKey: \"phoenix_local_plancast\",\n            ssl: !0,\n            matchers: {\n                anevent: /^#{protocol}?(?:[a-z0-9]+\\.)?plancast\\.com\\/p\\/(?:[a-z0-9]+)\\/?$/i\n            },\n            enableAPI: !1,\n            validActions: {\n                resizeFrame: !0,\n                bind: !0,\n                unbind: !0\n            },\n            process: function(a, b) {\n                var d = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//plancast.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (d.data.src = c(b.src), ((b.height && (d.data.height = b.height))), a())));\n                    }\n                });\n            },\n            render: function(a) {\n                this.renderEmbeddedApplication(a, this.data.src);\n            }\n        }), twttr.mediaType(\"Gowalla\", {\n            icon: \"generic\",\n            domain: \"//www.gowalla.com\",\n            deciderKey: \"phoenix_local_gowalla\",\n            ssl: !0,\n            matchers: {\n                anevent: /^#{protocol}?(((go)?wal.la)\\/([chpnt])\\/\\w+\\/?|gowalla.com\\/(trips|challenges|checkins|pins)\\/\\d+\\/?)/i\n            },\n            enableAPI: !1,\n            validActions: {\n                resizeFrame: !0,\n                bind: !0,\n                unbind: !0\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//gowalla.com/api/twitter_oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.src = b.src, ((b.height && (c.data.height = b.height))), a())));\n                    }\n                });\n            },\n            render: function(a) {\n                this.renderEmbeddedApplication(a, this.data.src);\n            }\n        }), twttr.mediaType(\"Foursquare\", {\n            icon: \"generic\",\n            domain: \"//www.foursquare.com\",\n            deciderKey: \"phoenix_local_foursquare\",\n            ssl: !0,\n            matchers: {\n                anevent: /^#{optional_protocol}?foursquare\\.com\\/([a-zA-Z0-9\\-]+)\\/checkin\\/(#{wildcard})/i\n            },\n            enableAPI: !1,\n            validActions: {\n                resizeFrame: !0,\n                bind: !0,\n                unbind: !0\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"https://api.foursquare.com/services/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.src = b.src, ((b.height && (c.data.height = b.height))), a())));\n                    }\n                });\n            },\n            render: function(a) {\n                this.renderEmbeddedApplication(a, this.data.src);\n            }\n        }), twttr.mediaType(\"Amazon\", {\n            icon: \"generic\",\n            domain: \"//www.amazon.com\",\n            deciderKey: \"phoenix_amazon_details\",\n            ssl: !0,\n            matchers: {\n                review: /^#{protocol}?www\\.amazon\\.(com|de|fr|ca|it|(?:co\\.(?:jp|uk)))(?:(?!(\\/[^\\/]*)?\\/[bs][\\/\\?]|\\/gp\\/browse\\.html|\\/aw\\/ri\\/|\\/gp\\/search|\\/search|\\/gp\\/feature|\\/gp\\/goldbox|\\/gp\\/registry))(?:#{wildcard}?)/i\n            },\n            enableAPI: !1,\n            validActions: {\n                resizeFrame: !0,\n                bind: !0,\n                unbind: !0\n            },\n            process: function(a, b) {\n                var c = twttr.media.types.Amazon.matchers, d = this, e = this.url;\n                b = ((b || {\n                })), matches = e.match(c.review), ((matches[1] && twttr.sandboxedAjax.send({\n                    url: ((((\"//www.amazon.\" + matches[1])) + \"/gp/twitter/oembed\")),\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (d.data.src = b.src, ((b.height && (d.data.height = b.height))), a())));\n                    }\n                })));\n            },\n            render: function(a) {\n                this.renderEmbeddedApplication(a, this.data.src);\n            }\n        }), twttr.mediaType(\"AolVideo\", {\n            icon: \"video\",\n            domain: \"http://www.aol.com\",\n            title: \"Aol\",\n            deciderKey: \"phoenix_aol_video\",\n            matchers: {\n                video: /^#{protocol_no_ssl}?share\\.aolvideo\\.com\\/twitter\\.php\\?video\\=(#{wildcard})/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://share.aolvideo.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.embed = b.html, c.data.width = b.width, c.data.height = b.height, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                return this.data.embed;\n            }\n        }), twttr.mediaType(\"Photobucket\", {\n            icon: \"photo\",\n            domain: \"http://photobucket.com\",\n            flaggable: !0,\n            matchers: {\n                user_groups: /^#{protocol}?(?:g?(?:i|s)(?:\\d+|mg))\\.photobucket\\.com\\/(?:albums|groups)\\/(?:#{wildcard})/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"http://photobucket.com/oembed\",\n                    type: \"GET\",\n                    dataType: \"jsonp\",\n                    data: {\n                        url: this.url.replace(/^([^?]*[^/])(?=\\?)/, \"$1/\"),\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((b.error || (c.data.href = b.url, c.data.JSBNG__name = c.constructor._name, a())));\n                    }\n                });\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    b(c.data.href);\n                });\n            },\n            render: function(a) {\n                var b = \"        \\u003Cdiv class=\\\"photobucket\\\"\\u003E          \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E            \\u003Cimg src=\\\"{{href}}\\\"/\\u003E          \\u003C/a\\u003E        \\u003C/div\\u003E\";\n                $(a).append(Mustache.to_html(b, this.data));\n            }\n        }), twttr.mediaType(\"With\", {\n            icon: \"photo\",\n            domain: ((twttr.isSSL() ? \"https://with.me\" : \"http://with.me\")),\n            ssl: !0,\n            deciderKey: \"phoenix_withme_details\",\n            matchers: {\n                project: /^#{optional_protocol}?with\\.me[\\/\\?]\\??[a-zA-Z0-9]+$/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                })), twttr.sandboxedAjax.send({\n                    url: \"//with.me/services/oembed\",\n                    dataType: \"jsonp\",\n                    type: \"GET\",\n                    data: {\n                        url: this.url,\n                        maxwidth: b.maxwidth\n                    },\n                    success: function(b) {\n                        ((((!b.error && b.hasOwnProperty(\"url\"))) && (c.data.href = c.url, c.data.src = b.url, c.data.title = b.title, a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"           \\u003Cdiv class=\\\"with-me\\\"\\u003E             \\u003Ca class=\\\"inline-media-image\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E               \\u003Cimg src=\\\"{{src}}\\\"/\\u003E             \\u003C/a\\u003E           \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"Facebook\", {\n            icon: \"photo\",\n            domain: ((twttr.isSSL() ? \"https://facebook.com\" : \"http://facebook.com\")),\n            ssl: !0,\n            deciderKey: \"phoenix_facebook_details\",\n            matchers: {\n                project: /^#{optional_protocol}?facebook\\.com\\/([a-zA-Z0-9_#\\.\\-\\?\\&\\=\\/])*pid=(#{wildcard})/i\n            },\n            process: function(a, b) {\n                var c = \"https://www.facebook.com/twitter/photo/?id={{id}}&l={{l}}&pid={{pid}}\", d = this;\n                d.data.href = this.url;\n                var e = twttr.util.paramsFromUrl(this.url);\n                ((((((((e && e.id)) && e.l)) && e.pid)) && (d.data.src = Mustache.to_html(c, e), a())));\n            },\n            getImageURL: function(a, b) {\n                var c = this;\n                this.process(function() {\n                    ((c.data.src ? b(c.data.src) : b(null)));\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"            \\u003Cdiv class=\\\"facebook-dp\\\"\\u003E              \\u003Ca class=\\\"inline-media-image\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                \\u003Cimg src=\\\"{{src}}\\\"/\\u003E              \\u003C/a\\u003E            \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"WordPress\", {\n            icon: \"generic\",\n            domain: \"//wordpress.com\",\n            ssl: !0,\n            deciderKey: \"phoenix_wordpress_details\",\n            matchers: {\n                tinyUrl: /^#{optional_protocol}?(?:[a-z0-9]+\\.)?wp\\.me[\\/\\?][a-zA-Z0-9_#\\.\\-\\?\\&\\=\\/]+$/i,\n                standardUrl: /^#{optional_protocol}?(?:[a-z0-9]+\\.)?wordpress\\.com[\\/\\?][a-zA-Z0-9_#\\.\\-\\?\\&\\=\\/]+$/i\n            },\n            process: function(a, b) {\n                var c = this;\n                b = ((b || {\n                }));\n                var d = \"//public-api.wordpress.com/oembed/1.0/?for=twitter.com&as_article=true\", e = {\n                    url: this.url\n                };\n                ((twttr.app.isOnPage(\"permalink\") || (e.maxwidth = 433))), twttr.sandboxedAjax.send({\n                    url: d,\n                    dataType: \"jsonp\",\n                    type: \"GET\",\n                    data: e,\n                    success: function(b) {\n                        ((((!b.error && b.title)) && (c.data.href = c.url, ((((b.thumbnail_url && ((b.thumbnail_url.indexOf(\"http:\") >= 0)))) && (b.thumbnail_url = b.thumbnail_url.replace(\"http\", \"https\")))), c.data = twttr.merge(c.data, b), a())));\n                    }\n                });\n            },\n            JSBNG__content: function() {\n                var a = \"                  \\u003Cdiv id=\\\"wp-details\\\" class=\\\"component\\\"\\u003E\\u003Cdiv class=\\\"wp-inset\\\"\\u003E                  \\u003Ca href=\\\"{{href}}\\\" class=\\\"wp-link\\\" target=\\\"_blank\\\"\\u003E                  \\u003Ch1 class=\\\"wp-news-headline\\\"\\u003E{{title}}\\u003C/h1\\u003E\\u003C/a\\u003E                  \\u003Cp class=\\\"wp-news-description\\\"\\u003E{{{body}}}\\u003C/p\\u003E                  {{#thumbnail_url}}                  \\u003Cdiv\\u003E\\u003Ca class=\\\"inline-media-image\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                  \\u003Cimg class=\\\"wp-img\\\" src=\\\"{{thumbnail_url}}\\\"/\\u003E                  \\u003C/a\\u003E\\u003C/div\\u003E                  {{/thumbnail_url}}                  \\u003C/div\\u003E\\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            },\n            flaggable: !0\n        }), twttr.mediaType(\"WhoSay\", {\n            domain: \"//www.whosay.com\",\n            ssl: !0,\n            flaggable: !0,\n            deciderKey: \"phoenix_whosay_details\",\n            icon: \"photo\",\n            matchers: {\n                media: /^#{optional_protocol}?whosay\\.com\\/[^\\/\\s]+\\/photos\\/(\\d+)/i\n            },\n            getImageURL: function(a, c) {\n                if (this.slug) {\n                    if (((a === b.constants.imageSizes.medium))) {\n                        return c(b.util.supplant(\"//d1au12fyca1yp1.cloudfront.net/{id}/{id}_melt.jpg\", {\n                            id: this.slug\n                        }));\n                    }\n                ;\n                ;\n                    if (((a === b.constants.imageSizes.large))) {\n                        return c(b.util.supplant(\"//d1au12fyca1yp1.cloudfront.net/{id}/{id}_lalt.jpg\", {\n                            id: this.slug\n                        }));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                c(null);\n            },\n            process: function(a) {\n                this.data.href = this.url, this.data.JSBNG__name = this.constructor._name, this.data.src = b.util.supplant(\"//d1au12fyca1yp1.cloudfront.net/{id}/{id}_melt.jpg\", {\n                    id: this.slug\n                }), a();\n            },\n            JSBNG__content: function() {\n                var a = \"\\u003Cdiv class=\\\"whosay\\\"\\u003E                  \\u003Ca class=\\\"inline-media-image\\\" data-inline-type=\\\"{{name}}\\\" href=\\\"{{href}}\\\" target=\\\"_blank\\\"\\u003E                    \\u003Cimg alt=\\\"\\\" src=\\\"{{src}}\\\"\\u003E                  \\u003C/a\\u003E                \\u003C/div\\u003E\";\n                return Mustache.to_html(a, this.data);\n            }\n        }), twttr.mediaType(\"Pepsi\", {\n            domain: \"//www.pepsi.com\",\n            ssl: !0,\n            deciderKey: \"phoenix_pepsi_details\",\n            icon: \"video\",\n            matchers: {\n                media: /^#{optional_protocol}?pepsi\\.com\\/(NickiMinajNOW)/i\n            },\n            process: function(a) {\n                this.data.width = 432, this.data.height = 243, a();\n            },\n            render: function(a) {\n                var b = \"https://tremolossl-a.akamaihd.net/clients/twitter/20120814_nickiminaj/twitter/index.html\";\n                this.renderIframe(a, b);\n            }\n        }), a();\n    });\n});\nprovide(\"geo/Map\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.geo.Map\", function(a, b) {\n            var c = this;\n            if (!twttr.geo.mapsAvailable()) {\n                return;\n            }\n        ;\n        ;\n            var d = {\n                mapTypeId: google.maps.MapTypeId.ROADMAP,\n                disableDefaultUI: !0,\n                scrollwheel: !1,\n                navigationControl: !0,\n                navigationControlOptions: {\n                    position: google.maps.ControlPosition.TOP_LEFT,\n                    style: google.maps.NavigationControlStyle.SMALL\n                }\n            };\n            c.map = new google.maps.Map(a.get(0), twttr.merge(d, b)), c.bounds = new google.maps.LatLngBounds, c.initialized = !0, c.$canvas = a, c.addListener(\"tilesloaded\", function() {\n                c.resize();\n            });\n        }).methods({\n            addListener: function(a, b) {\n                google.maps.JSBNG__event.addListener(this.map, a, b);\n            },\n            createOverlay: function(a) {\n                function b() {\n                    this.setMap(c.map);\n                };\n            ;\n                var c = this;\n                b.prototype = new google.maps.OverlayView, b.prototype.JSBNG__onAdd = function() {\n                \n                }, b.prototype.JSBNG__onRemove = function() {\n                \n                }, b.prototype.draw = function() {\n                    ((a && (JSBNG__setTimeout(a, 0), a = null)));\n                }, c.mapOverlay = new b;\n            },\n            getProjection: function() {\n                var a = this.mapOverlay;\n                return ((a && a.getProjection()));\n            },\n            latLngToContainerPoint: function(a) {\n                var b = this;\n                a = b.normalizeLatLng(a);\n                var c = b.getProjection();\n                return ((c ? c.fromLatLngToContainerPixel(a) : null));\n            },\n            latLngToOverlayPoint: function(a) {\n                var b = this;\n                a = b.normalizeLatLng(a);\n                var c = b.getProjection();\n                return ((c ? c.fromLatLngToDivPixel(a) : null));\n            },\n            containerPointToLatLng: function(a, b) {\n                return this.getProjection().fromContainerPixelToLatLng(new google.maps.Point(a, b));\n            },\n            extendBounds: function(a) {\n                this.bounds.extend(a);\n            },\n            normalizeLatLng: function(a) {\n                return (($.isArray(a) ? new google.maps.LatLng(a[1], a[0]) : a));\n            },\n            addPoint: function(a, b) {\n                var c = this;\n                a = c.normalizeLatLng(a), c.extendBounds(a);\n                var d = twttr.geo.POI_MARKER_SIZE, e = twttr.geo.POI_MARKER_HOTSPOT, f = new google.maps.MarkerImage(\"/phoenix/img/pin.png\", new google.maps.Size(d.width, d.height), null, new google.maps.Point(e.x, e.y));\n                c.marker = new google.maps.Marker({\n                    flat: !0,\n                    icon: f,\n                    map: c.map,\n                    position: a,\n                    clickable: !1,\n                    zIndex: 2\n                });\n                if (b) {\n                    var g = new google.maps.MarkerImage(b, null, null, new google.maps.Point(13, 32), new google.maps.Size(24, 24));\n                    c.avatar = new google.maps.Marker({\n                        flat: !0,\n                        icon: g,\n                        map: c.map,\n                        position: a,\n                        zIndex: 3\n                    });\n                }\n            ;\n            ;\n            },\n            addPoi: function(a, b) {\n                var c = twttr.is.fn(b);\n                a = this.normalizeLatLng(a), this.extendBounds(a);\n                var d = new google.maps.MarkerImage(\"/phoenix/img/poi-pin.png\", null, null, new google.maps.Point(twttr.geo.POI_MARKER_HOTSPOT.x, twttr.geo.POI_MARKER_HOTSPOT.y)), e = new google.maps.Marker({\n                    flat: !0,\n                    icon: d,\n                    map: this.map,\n                    position: a,\n                    draggable: c,\n                    clickable: c,\n                    zIndex: 2\n                });\n                return ((c && google.maps.JSBNG__event.addListener(e, \"position_changed\", function() {\n                    var a = e.getPosition();\n                    b(a.lat(), a.lng());\n                }))), e;\n            },\n            addFocusablePoint: function(a, b, c) {\n                var d = this;\n                a = d.normalizeLatLng(a), d.extendBounds(a);\n                var e = new google.maps.MarkerImage(\"/phoenix/img/place-minor10x.png\", new google.maps.Size(10, 10), new google.maps.Point(10, 0), new google.maps.Point(5, 5)), f = new google.maps.MarkerImage(\"/phoenix/img/place-minor10x.png\", new google.maps.Size(10, 10), null, new google.maps.Point(5, 5)), g = new google.maps.Marker({\n                    flat: !0,\n                    icon: f,\n                    map: d.map,\n                    position: a,\n                    clickable: ((b !== undefined)),\n                    zIndex: 2\n                });\n                return ((b && (google.maps.JSBNG__event.addListener(g, \"mouseover\", function(c) {\n                    b(!0, d.latLngToContainerPoint(a));\n                }), google.maps.JSBNG__event.addListener(g, \"mouseout\", function(c) {\n                    b(!1, d.latLngToContainerPoint(a));\n                })))), ((c && google.maps.JSBNG__event.addListener(g, \"click\", function(a) {\n                    c();\n                }))), function(a) {\n                    ((a ? (g.setIcon(e), g.setZIndex(3)) : (g.setIcon(f), g.setZIndex(2))));\n                };\n            },\n            extendBoundsToIncludeCircle: function(a, b) {\n                if (((b < 200))) {\n                    return;\n                }\n            ;\n            ;\n                var c = new google.maps.Circle({\n                    map: null,\n                    center: this.normalizeLatLng(a),\n                    radius: b,\n                    clickable: !1,\n                    fillColor: \"#0040FF\",\n                    fillOpacity: 1075137,\n                    strokeColor: \"#2929D4\",\n                    strokeOpacity: 1075177,\n                    strokeWeight: 1075193,\n                    zIndex: 1\n                }), d = c.getBounds();\n                this.extendBounds(d.getNorthEast()), this.extendBounds(d.getSouthWest());\n            },\n            addPlacePolygon: function(a) {\n                a = a[0];\n                var b = [];\n                for (var c = 0; ((c < a.length)); c++) {\n                    var d = this.normalizeLatLng(a[c]);\n                    b.push(d), this.extendBounds(d);\n                };\n            ;\n                new google.maps.Polygon({\n                    path: b,\n                    strokeColor: \"#FF0000\",\n                    strokeOpacity: 1075500,\n                    strokeWeight: 1075516,\n                    fillColor: \"#FF0000\",\n                    fillOpacity: 1075551,\n                    map: this.map\n                });\n            },\n            isEmpty: function() {\n                return this.bounds.isEmpty();\n            },\n            adjustBounds: function(a, b) {\n                var c = this;\n                if (this.isEmpty()) {\n                    return;\n                }\n            ;\n            ;\n                c.fitBounds(c.bounds, a, b);\n            },\n            MIN_LAT: -85.05113,\n            MAX_LAT: 85.05113,\n            X_FROM_LNG: ((256 / 360)),\n            Y_FROM_RADIANS: ((-256 / ((2 * Math.PI)))),\n            DEGREES_FROM_RADIANS: ((180 / Math.PI)),\n            MAX_CONTENT_WIDTH_RATIO: 1075852,\n            MAX_CONTENT_HEIGHT_RATIO: 1075880,\n            _worldXFromLng: function(a) {\n                return ((a * this.X_FROM_LNG));\n            },\n            _worldYFromLat: function(a) {\n                var b = this;\n                a = Math.max(b.MIN_LAT, Math.min(b.MAX_LAT, a));\n                var c = Math.sin(((a / b.DEGREES_FROM_RADIANS)));\n                return ((((Math.log(((((1 + c)) / ((1 - c))))) * 1076088)) * b.Y_FROM_RADIANS));\n            },\n            _lngFromWorldX: function(a) {\n                return ((a / this.X_FROM_LNG));\n            },\n            _latFromWorldY: function(a) {\n                var b = ((2 * Math.atan(Math.exp(((a / this.Y_FROM_RADIANS))))));\n                return ((((b - ((1076249 * Math.PI)))) * this.DEGREES_FROM_RADIANS));\n            },\n            _zoomFromPixelDelta: function(a, b, c) {\n                var d = Math.floor(((Math.log(Math.abs(((a / b)))) / Math.LN2)));\n                return ((isNaN(d) ? c : Math.max(0, Math.min(c, d))));\n            },\n            fitBounds: function(a, b, c) {\n                var d = this;\n                d.bounds = a;\n                var e = a.getNorthEast(), f = a.getSouthWest(), g = d._worldXFromLng(f.lng()), i = d._worldXFromLng(e.lng()), j = d._worldYFromLat(e.lat()), k = d._worldYFromLat(f.lat()), l = d._zoomFromPixelDelta(((d.$canvas.width() * d.MAX_CONTENT_WIDTH_RATIO)), ((i - g)), b), m = d._zoomFromPixelDelta(((d.$canvas.height() * d.MAX_CONTENT_HEIGHT_RATIO)), ((k - j)), b);\n                d.map.setZoom(Math.min(l, m));\n                if (!c) {\n                    var n = d._latFromWorldY(((((j + k)) * 1076839)));\n                    c = new google.maps.LatLng(n, a.getCenter().lng());\n                }\n            ;\n            ;\n                d.map.setCenter(d.normalizeLatLng(c));\n            },\n            getCenter: function() {\n                return this.map.getCenter();\n            },\n            resize: function() {\n                google.maps.JSBNG__event.trigger(this.map, \"resize\");\n            }\n        }), a(twttr.geo.Map);\n    });\n});\nprovide(\"geo/Location\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.geo.Location\", function() {\n            var a = this;\n            a.$empty = a.$fakeFocus = a.$dropdown = a.$input = a.$helpText = $([]), a.clearLocation(), a.closeDropdownClick = function(b) {\n                var c = a.$dropdown.get(0);\n                ((((((c && ((b.target !== c)))) && !$.contains(c, b.target))) && a.closeDropdown()));\n            };\n        }).statics({\n            GEO_WEBCLIENT_COOKIE: \"geo_webclient\",\n            MS_WAIT_BETWEEN_GET_LOCATIONS: 900000,\n            LOCATION_URL: \"/account/location.json\"\n        }).methods({\n            JSBNG__onRegisterTweetBox: function(a, b) {\n                var c = this, d = a.JSBNG__find(\".geo-control\");\n                c.showGeoState(), d.JSBNG__find(\"a.geo-location\").click(function(a) {\n                    a.preventDefault(), ((d.JSBNG__find(\".geo-location-dropdown\").length || JSBNG__setTimeout(function() {\n                        $(\".geo-control .geo-icon\").tipsy(\"hide\"), ((c.isLocationOn() ? (c.openDropdown(d), ((b && b()))) : ((c.isGeoEnabled() ? c.turnLocationOn() : (new twttr.widget.GeoPromoDialog).show()))));\n                    }, 0)));\n                }), d.JSBNG__find(\".geo-icon\").tipsy({\n                    gravity: \"nw\",\n                    offset: 5,\n                    fade: !0,\n                    opacity: 1077978,\n                    title: function() {\n                        return ((c.isLocationOn() ? \"\" : h(_(\"Add your location\"))));\n                    }\n                });\n            },\n            JSBNG__onFocusTweetBox: function(a) {\n                ((((((this.isLocationOn() && !this.isUpdatingLocation())) && ((!this.cityId() || ((((this.now() - this.lastLocationTime)) >= this.constructor.MS_WAIT_BETWEEN_GET_LOCATIONS)))))) && this.updateLocation()));\n            },\n            clearLocation: function() {\n                this.JSBNG__location = {\n                }, this.cache = {\n                }, this.searchKeyShowing = null, this.$dropdown.remove(\".override-location\"), this.lastMessage = \"\", this.lastFetchId = null;\n            },\n            isUpdatingLocation: function() {\n                return !!this.lastFetchId;\n            },\n            updateLocation: function(a) {\n                var c = this;\n                if (!c.isGeoUiAllowed()) {\n                    c.processNewLocation(null);\n                    return;\n                }\n            ;\n            ;\n                ((c.isUpdatingLocation() || (c.clearLocation(), c.showGeoState(((a ? _(\"Changing location...\") : _(\"Getting location...\")))))));\n                var d = {\n                };\n                c.lastFetchId = d, twttr.currentUser.geoLocation({\n                    override_place_id: a,\n                    spoof_ip: b.util.params().spoof_ip,\n                    success: function(a) {\n                        ((((c.lastFetchId === d)) && c.processNewLocation(a)));\n                    },\n                    error: function(a) {\n                        if (((c.lastFetchId === d))) {\n                            var b = ((a.JSBNG__status && ((a.JSBNG__status === 503))));\n                            c.processNewLocation(((b ? {\n                                JSBNG__status: \"busy\"\n                            } : null)));\n                        }\n                    ;\n                    ;\n                    }\n                });\n            },\n            places: function() {\n                return ((((this.JSBNG__location && this.JSBNG__location.places)) || []));\n            },\n            place: function() {\n                return ((this.places()[0] || {\n                }));\n            },\n            cityId: function() {\n                var a = this.place();\n                return ((((a.full_name && a.id)) || \"\"));\n            },\n            cityName: function() {\n                var a = this.place();\n                return ((((a.id && a.full_name)) || \"\"));\n            },\n            isGeoUiAllowed: function() {\n                return ((twttr.decider.isAvailable(\"geo_ui\") && twttr.decider.isAvailable(\"geo_location\")));\n            },\n            isGeoEnabled: function() {\n                return ((twttr.currentUser && twttr.currentUser.geoEnabled));\n            },\n            isLocationOn: function() {\n                return ((this.isGeoEnabled() && !!$.cookie(this.constructor.GEO_WEBCLIENT_COOKIE)));\n            },\n            turnLocationOn: function() {\n                $.cookie(this.constructor.GEO_WEBCLIENT_COOKIE, \"1\", {\n                    expires: 3650\n                }), this.updateLocation();\n            },\n            turnLocationOff: function() {\n                $.cookie(this.constructor.GEO_WEBCLIENT_COOKIE, null), this.clearLocation(), this.showGeoState();\n            },\n            processNewLocation: function(a) {\n                var b = this;\n                b.lastFetchId = null;\n                var c = ((a && a.JSBNG__status));\n                if (((((c === \"busy\")) || ((c === \"ok\"))))) {\n                    b.lastLocationTime = this.now();\n                }\n            ;\n            ;\n                b.JSBNG__location = a, b.cache = {\n                }, b.showGeoState(((((b.cityName() || ((((c === \"unresolved\")) && _(\"Unknown location\"))))) || _(\"Location service unavailable\")))), b.inputChanged(), b.showPlaceSuggestions();\n            },\n            now: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            showGeoState: function(a) {\n                var b = this.isLocationOn();\n                this.lastMessage = ((((b && ((a || this.lastMessage)))) || \"\"));\n                var c = ((this.lastMessage !== \"\"));\n                $(\"span.geo-control span.geo-icon\").toggleClass(\"geo-icon-on\", b).toggleClass(\"geo-icon-ok\", ((b && !!this.cityId()))), twttr.helpers.ellipsify($(\"span.geo-control span.geo-text\").html(h(this.lastMessage)), !0), $(\"span.geo-control span.geo-dropdown-icon\").toggle(c).css(\"visibility\", \"visible\");\n            },\n            openDropdown: function(a) {\n                var b = this;\n                b.closeDropdown(), $(JSBNG__document).add(\"textarea\").bind(\"click\", b.closeDropdownClick);\n                var c = (new twttr.views.GeoLocationDropdown).$html();\n                b.$dropdown = c, b.$input = c.JSBNG__find(\"input\"), b.$helpText = c.JSBNG__find(\".help-text\"), b.$helpText.click(function(a) {\n                    a.preventDefault(), a.stopPropagation(), b.$input.JSBNG__focus();\n                }), c.JSBNG__find(\".geo-turn-off-item a\").bind(\"select\", function() {\n                    b.closeDropdown(), b.turnLocationOff();\n                }).click(function(a) {\n                    a.preventDefault(), $(this).trigger(\"select\");\n                }), c.JSBNG__find(\".glass\").click(function(a) {\n                    a.stopPropagation(), b._updateSearchResults(!0);\n                }), c.delegate(\".override-location a\", \"select\", function() {\n                    b.updateLocation($(this).attr(\"data-place-id\")), b.closeDropdown();\n                }).delegate(\".override-location a\", \"click\", function(a) {\n                    a.preventDefault(), $(this).trigger(\"select\");\n                }).delegate(\".focusable\", \"mousemove\", function() {\n                    b.setFakeFocus($(this));\n                }).delegate(\".focused\", \"mouseout\", function() {\n                    b.setFakeFocus(b.$empty);\n                });\n                var d = a.JSBNG__find(\".geo-icon\"), e = d.position(), f = Math.round(((e.JSBNG__top + d.JSBNG__outerHeight())));\n                c.css({\n                    left: e.left,\n                    JSBNG__top: f\n                }), b.searchKeyShowing = null, b.showPlaceSuggestions(), b.setupInput(), a.append(c), b.$input.JSBNG__focus().select();\n            },\n            closeDropdown: function() {\n                this.$dropdown.remove(), this.$fakeFocus = this.$empty, $(JSBNG__document).add(\"textarea\").unbind(\"click\", this.closeDropdownClick);\n            },\n            showSearchError: function(a) {\n                this.$dropdown.JSBNG__find(\".location-error\").text(a);\n            },\n            showPlaceSuggestions: function() {\n                var a = this.$dropdown, b = (new twttr.views.GeoLocationDropdownItems({\n                    places: this.places()\n                })).html();\n                a.JSBNG__find(\".override-location\").remove(), a.JSBNG__find(\".geo-turn-off-item\").before(b), a.JSBNG__find(\".override-location:first\").addClass(\"checked-item padding-above\"), this.updateMenuSeparators();\n            },\n            updateMenuSeparators: function() {\n                var a = this.$dropdown;\n                a.JSBNG__find(\".location-search-result:first\").addClass(\"padding-above\"), a.JSBNG__find(\".override-location:last,\").addClass(\"separator-below\"), a.JSBNG__find(\".location-search-result:last\").addClass(\"separator-below\"), a.JSBNG__find(\"li:last\").removeClass(\"separator-below\");\n            },\n            setupInput: function() {\n                var a = this;\n                a.$input.click(function(a) {\n                    a.stopPropagation();\n                }).keydown(function(c) {\n                    c.stopPropagation();\n                    if (((c.keyCode === b.constants.keyCodes.escape))) {\n                        a.closeDropdown();\n                    }\n                     else {\n                        switch (c.keyCode) {\n                          case b.constants.keyCodes.upArrow:\n                            a.arrowUp(), a.arrowKeyDownEvent = !0, c.preventDefault();\n                            break;\n                          case b.constants.keyCodes.downArrow:\n                            a.arrowDown(), a.arrowKeyDownEvent = !0, c.preventDefault();\n                            break;\n                          case b.constants.keyCodes.enter:\n                            ((a.hasFakeFocus() ? a.$fakeFocus.JSBNG__find(\"a\").trigger(\"select\") : a.updateSearchResults(!0)));\n                          default:\n                            a.inputChanged();\n                        };\n                    }\n                ;\n                ;\n                }).keypress(function(c) {\n                    c.stopPropagation();\n                    if (((((c.charCode === 0)) && !a.arrowKeyDownEvent))) {\n                        switch (c.keyCode) {\n                          case b.constants.keyCodes.upArrow:\n                            a.arrowUp(), c.preventDefault();\n                            break;\n                          case b.constants.keyCodes.downArrow:\n                            a.arrowDown(), c.preventDefault();\n                        };\n                    }\n                ;\n                ;\n                    a.arrowKeyDownEvent = !1;\n                }).keyup(function(a) {\n                    a.stopPropagation();\n                }).change(function() {\n                    a.inputChanged();\n                }).mousedown(function() {\n                    a.setFakeFocus(a.$empty);\n                }).JSBNG__focus(function() {\n                    a.setFakeFocus(a.$empty);\n                });\n            },\n            arrowUp: function() {\n                var a = this.$fakeFocus.prevAll(\".focusable:first\");\n                ((a.length || (a = this.$dropdown.JSBNG__find(\".focusable:last\")))), this.setFakeFocus(a);\n            },\n            arrowDown: function() {\n                var a = this.$fakeFocus.nextAll(\".focusable:first\");\n                ((a.length || (a = this.$dropdown.JSBNG__find(\".focusable:first\")))), this.setFakeFocus(a);\n            },\n            hasFakeFocus: function() {\n                return !!this.$fakeFocus.length;\n            },\n            setFakeFocus: function(a) {\n                this.$fakeFocus.removeClass(\"focused\"), this.$fakeFocus = a.addClass(\"focused\");\n            },\n            inputChanged: function() {\n                var a = this;\n                JSBNG__setTimeout(function() {\n                    ((((((a.$input.val() || \"\")) !== \"\")) && a.$helpText.hide())), JSBNG__setTimeout(function() {\n                        a.updateSearchResults(!1);\n                    }, 0);\n                }, 0);\n            },\n            updateSearchResults: function(a) {\n                var b = this, c = ((b.$input.val() || \"\"));\n                ((((a && c)) ? b.enterQuery = c : ((((c !== b.enterQuery)) && (b.enterQuery = null)))));\n                if (b.isUpdatingLocation()) {\n                    return;\n                }\n            ;\n            ;\n                var d = !b.enterQuery, e = ((((d ? \"~\" : \"=\")) + c));\n                ((((e != b.searchKeyShowing)) && b.setFakeFocus(b.$empty)));\n                if (((((((b.searchKeyShowing === e)) || ((b.searchKeySearching === e)))) || ((d && b.searchKeySearching))))) {\n                    return;\n                }\n            ;\n            ;\n                var f = ((c ? b.cache[e] : []));\n                ((f ? b.showSearchResults(f, e) : b.search(e)));\n            },\n            centroid: function() {\n                var a = this.place();\n                if (((((!a.bounding_box || ((a.bounding_box.type !== \"Polygon\")))) || !a.bounding_box.coordinates))) {\n                    return null;\n                }\n            ;\n            ;\n                var b = a.bounding_box.coordinates[0];\n                return ((((!b || ((b.length !== 4)))) ? null : {\n                    lat: ((((b[0][1] + b[2][1])) * 1084687)),\n                    lon: ((((b[0][0] + b[2][0])) * 1084712))\n                }));\n            },\n            search: function(a) {\n                var b = this, c = ((a.charAt(0) === \"~\")), d = a.substr(1);\n                b.$dropdown.addClass(\"geo-location-dropdown-searching\"), b.searchKeySearching = a, b.showSearchError(_(\"Searching places...\")), twttr.API.Place.search(twttr.merge({\n                    max_results: 5,\n                    granularity: \"neighborhood\",\n                    autocomplete: ((c ? \"true\" : \"false\")),\n                    query: d,\n                    full_geom: \"false\",\n                    success: function(c) {\n                        var d = twttr.geo.placesFromApi(c);\n                        b.cache[a] = d, ((((b.searchKeySearching === a)) && (b.searchKeySearching = null, b.showSearchError(\"\")))), b.$dropdown.removeClass(\"geo-location-dropdown-searching\"), b.updateSearchResults();\n                    },\n                    error: function() {\n                        b.$dropdown.removeClass(\"geo-location-dropdown-searching\"), ((((b.searchKeySearching === a)) ? (b.showSearchError(_(\"Location service unavailable\")), b.searchKeySearching = null) : b.updateSearchResults()));\n                    }\n                }, b.centroid()));\n            },\n            showSearchResults: function(a, b) {\n                this.searchKeyShowing = b, ((((((a.length === 0)) && ((b.length > 1)))) && this.showSearchError(_(\"No search results\")))), this.$dropdown.JSBNG__find(\".location-search-result\").remove();\n                var c = (new twttr.views.GeoLocationDropdownItems({\n                    places: a,\n                    for_search_results: !0\n                })).html();\n                this.$dropdown.JSBNG__find(\".query-location\").after(c), this.updateMenuSeparators();\n            }\n        }), twttr.app.waitForSignal(\"init\", function(a) {\n            twttr.geo.JSBNG__location = new twttr.geo.Location;\n        }), a(twttr.geo.Location);\n    });\n});\nprovide(\"control/Dropdown\", function(a) {\n    using().as(function(b) {\n        (function() {\n            var a = {\n                view: \"Control\"\n            };\n            twttr.klass(\"twttr.control.Base\", function(b) {\n                this.options = $.extend({\n                }, a, b), this.itemView = twttr.views.DefaultDropdownItem, ((this.options.itemView && (this.itemView = ((twttr.is.string(this.options.itemView) ? twttr.views[this.options.itemView] : this.options.itemView)))));\n            }).methods(twttr.EventProvider).methods({\n                render: function(a, b) {\n                    var c = this.viewData();\n                    this.view = new twttr.views[this.options.view](c), this.$dropdown = this.view.$html(), $(a)[b](this.$dropdown);\n                },\n                viewData: function() {\n                    return this.options;\n                }\n            }), twttr.augmentString(\"twttr.helpers.control\", function(a, b) {\n                var c = twttr.klass(((\"twttr.control.\" + a)), b);\n                return c.subclassOf(twttr.control.Base), c;\n            }), function() {\n                var a = {\n                    direction: \"left\",\n                    view: \"Dropdown\"\n                }, b = [];\n                twttr.helpers.control(\"Dropdown\", function(c, d) {\n                    b.push(this), this.$controller = $(c);\n                    var d = $.extend({\n                    }, a, d);\n                    this.items = ((d.items || [])), twttr.control.Dropdown.uber.constructor.call(this, d), this.registerEvents();\n                }).statics({\n                    _registeredHtmlClick: !1,\n                    caches: {\n                    },\n                    createCache: function(a) {\n                        this.caches[a] = {\n                        };\n                    },\n                    closeAll: function() {\n                        twttr.each(b, function(a) {\n                            a.close();\n                        });\n                    }\n                }).methods({\n                    defaultDividerView: twttr.views.DefaultDropdownDivider,\n                    registerEvents: function() {\n                        this.$controller.bind(\"click\", twttr.bind(this, function(a) {\n                            this.toggle();\n                        }));\n                    },\n                    applyDirection: function() {\n                        this.$dropdown.css({\n                            left: ((((this.options.direction == \"left\")) ? \"0\" : \"auto\")),\n                            right: ((((this.options.direction == \"right\")) ? \"0\" : \"auto\"))\n                        });\n                    },\n                    flushItems: function() {\n                        this.$dropdown.empty(), this.items = [];\n                    },\n                    setItemsFromCallback: function() {\n                        var a = this;\n                        a.flushItems(), a.itemsCallback(function(b) {\n                            a.addItems(b), a.registerItemHandlers();\n                        });\n                    },\n                    disable: function() {\n                        this.close(), this.$controller.unbind(\"click\");\n                    },\n                    enable: function() {\n                        this.registerEvents();\n                    },\n                    open: function(a) {\n                        this.constructor.closeAll(), ((this.itemsCallback && this.setItemsFromCallback())), this.$controller.addClass(\"open\").addClass(\"button-active\"), this.$dropdown.css({\n                            JSBNG__top: ((this.$container ? this.$container.JSBNG__outerHeight() : this.$controller.JSBNG__outerHeight())),\n                            visibility: \"visible\"\n                        }), ((a && this.$dropdown.css({\n                            opacity: 0\n                        }).animate({\n                            opacity: 1\n                        }, {\n                            duration: 500,\n                            queue: !1\n                        })));\n                        var b = twttr.bind(this, function(a) {\n                            ((((((this.$controller.get(0) !== a.target)) && !$.contains(this.$controller.get(0), a.target))) && ($(\"#doc\").unbind(\"click\", b), this.close())));\n                        });\n                        $(\"#doc\").bind(\"click\", b);\n                    },\n                    close: function(a) {\n                        if (a) {\n                            var b = this;\n                            this.$dropdown.animate({\n                                opacity: 0\n                            }, 500, function() {\n                                b.$controller.removeClass(\"open\").removeClass(\"button-active\"), b.$dropdown.css(\"visibility\", \"hidden\"), b.$dropdown.css(\"opacity\", 1);\n                            });\n                        }\n                         else this.$controller.removeClass(\"open\").removeClass(\"button-active\"), this.$dropdown.css(\"visibility\", \"hidden\");\n                    ;\n                    ;\n                    },\n                    toggle: function() {\n                        ((this.$controller.hasClass(\"open\") ? this.close() : this.open()));\n                    },\n                    addItem: function(a, b, c) {\n                        b = ((b || \"appendTo\")), this.items.push(a);\n                        var d = this.getItemView(a).$html();\n                        return ((((((b == \"insertBefore\")) || ((b == \"insertAfter\")))) ? d[b](c) : d[b](this.$dropdown))), d;\n                    },\n                    addItems: function(a) {\n                        var b = this;\n                        b.items = b.items.concat(a);\n                        var c = twttr.map(b.items, function(a) {\n                            return b.getItemView(a).html();\n                        });\n                        $(c.join(\"\")).appendTo(b.$dropdown);\n                    },\n                    itemsFrom: function(a) {\n                        this.itemsCallback = a;\n                    },\n                    registerItemHandlers: function() {\n                        var a = this.$dropdown.children();\n                        for (var b = 0; ((b < this.items.length)); b++) {\n                            var c = this.items[b];\n                            if (!c.handlers) {\n                                continue;\n                            }\n                        ;\n                        ;\n                            $.each(c.handlers, function(c, d) {\n                                var e = $(a[b]), f = [c,];\n                                ((twttr.is.array(d) ? f = f.concat(d) : f.push(d))), e.bind.apply(e, f);\n                            });\n                        };\n                    ;\n                    },\n                    render: function(a, b, c) {\n                        if (((((b === \"before\")) || ((b === \"after\"))))) {\n                            ((this.$controller.parent().hasClass(\"drop-down-container\") ? this.$container = this.$controller.parent() : this.$container = this.$controller.wrap(\"\\u003Cdiv class=\\\"drop-down-container\\\"/\\u003E\").parent()));\n                        }\n                    ;\n                    ;\n                        return twttr.control.Base.prototype.render.apply(this, arguments), ((c && (((this.constructor.caches[c.key] || (this.constructor.caches[c.key] = {\n                        }))), this.constructor.caches[c.key][c.id] = !0))), this.registerItemHandlers(), this.applyDirection(), this;\n                    },\n                    getItemView: function(a) {\n                        return ((a.itemView ? new twttr.views[a.itemView](a) : ((a.divider ? new this.defaultDividerView : new this.itemView(a)))));\n                    },\n                    viewData: function() {\n                        var a = this, b = twttr.map(this.items, function(b, c) {\n                            return a.getItemView(b).html();\n                        });\n                        return {\n                            items: b.join(\"\")\n                        };\n                    }\n                });\n            }();\n        })(), a(twttr.control.Dropdown);\n    });\n});\nprovide(\"widget/Dialog\", function(a) {\n    using(\"constants\", \"util\").as(function(b) {\n        twttr.provide(\"twttr.dialogs\"), twttr.dialogs.defaultOptions = {\n            modal: !1,\n            stackPreviousModal: !1,\n            draggable: !1,\n            closable: !0,\n            closeOnClickOutside: !1,\n            closeOnNavigate: !1,\n            destroyOnClose: !0,\n            css: {\n                width: 500,\n                height: \"auto\"\n            },\n            fixed: !0,\n            template: {\n                container_id: null,\n                title: null,\n                footer: null,\n                JSBNG__content: null\n            }\n        };\n        var c = !1, d = function() {\n            c = !0;\n            var a = $(\"\\u003Cdiv\\u003E\", {\n                height: 100,\n                width: 100,\n                position: \"absolute\",\n                JSBNG__top: -300,\n                left: -300\n            }).prependTo($(\"body\")), b = $(\"\\u003Cdiv\\u003E\", {\n                height: 200\n            }).appendTo(a);\n            a.css(\"overflow-y\", \"JSBNG__scroll\");\n            var d = ((a.width() - b.width()));\n            a.remove(), $(\"head\").append(((((\"\\u003Cstyle\\u003E          .modal-enabled,          .modal-enabled .global-nav-inner {            margin-right: \" + d)) + \"px        } \\u003C/style\\u003E\")));\n        }, e = twttr.klass(\"twttr.widget.Dialog\", function(a) {\n            var c = this;\n            this.options = twttr.merge({\n            }, twttr.dialogs.defaultOptions, ((a || {\n            })), !0), this.options.template.closable = this.options.closable, this._isOpen = !1, this.view = new twttr.views[((this.options.view || this.constructor._name))](this.options), ((twttr.isT1 ? (this.options.modal = !0, this.$container = this.view.render(((this.options.node || $(\".twttr-dialog-wrapper\"))), \"append\")) : this.$container = this.view.render(((this.options.node || \"body\")), \"append\"))), this.$dialog = this.$container.JSBNG__find(\".twttr-dialog\"), this.$title = this.$container.JSBNG__find(\".twttr-dialog-header h3\"), ((twttr.isT1 ? this.$container.css(twttr.merge({\n                JSBNG__top: $(\".js-banners\").height()\n            }, this.options.css)) : this.$dialog.css(this.options.css))), this.$dialog.attr(\"data-component-term\", b.util.underscore(this.constructor._name)), ((twttr.is.nil(c.options.template.footer) && this.$container.JSBNG__find(\".twttr-dialog-footer\").hide())), ((this.options.draggable && this.applyDraggability())), ((this.options.modal && (this.$overlay = $(\"\\u003Cdiv class=\\\"twttr-dialog-overlay\\\"\\u003E\\u003C/div\\u003E\").appendTo($(\"body\"))))), this._escKeyHandler = function(a) {\n                ((((c.options.closable && ((a.keyCode === b.constants.keyCodes.esc)))) && (c.close(), a.stopPropagation())));\n            };\n            if (((this.options.closeOnClickOutside || this.options.modal))) {\n                this._clickOutsideHandler = function(a) {\n                    ((((!$.contains(c.$container.get(0), a.target) && (($.contains(JSBNG__document.body, a.target) || ((JSBNG__document.body === a.target)))))) && (c.close(), ((c.options.modal || (a.preventDefault(), a.stopPropagation()))))));\n                };\n            }\n        ;\n        ;\n            if (this.options.closeOnNavigate) {\n                var d = twttr.bind(this, this.close);\n                twttr.router.bind(\"routeFollowed\", d), this.bind(\"close\", function() {\n                    twttr.router.unbind(\"routeFollowed\", d);\n                });\n            }\n        ;\n        ;\n            this.registerEvents();\n        }).statics(twttr.EventProvider).statics({\n            currentModal: !1,\n            close: function() {\n                var a = 0;\n                while (((this.currentModal && ((a++ < 8))))) {\n                    this.currentModal.close();\n                ;\n                };\n            ;\n            }\n        }).methods(twttr.EventProvider).methods({\n            $find: function(a) {\n                return this.$container.JSBNG__find(a);\n            },\n            registerEvents: function() {\n                var a = this;\n                this.$find(\"textarea, input[type=text], input[type=password]\").bind(\"keydown keypress keyup\", function(c) {\n                    ((twttr.components.Autocomplete._isCompletionsOpen || (c.stopPropagation(), ((((((c.type === \"keydown\")) && ((c.keyCode === b.constants.keyCodes.esc)))) && a.close())))));\n                }), this.$container.delegate(\".twttr-dialog-close\", \"click\", function(b) {\n                    b.preventDefault(), b.stopPropagation(), a.close();\n                }), twttr.router.bind(\"urlChanged\", this.urlChangedListener = function(b, c) {\n                    a.close();\n                });\n                if ((($.browser.mozilla && (($.browser.version.slice(0, 1) == \"8\"))))) {\n                    var c = null;\n                    this.bind(\"close\", function() {\n                        twttr.$win.scrollTop(c);\n                    }), this.bind(\"open\", function() {\n                        c = twttr.$win.scrollTop();\n                    });\n                }\n            ;\n            ;\n            },\n            applyDraggability: function() {\n                var a = this;\n                this.$container.addClass(\"draggable\").draggable({\n                    cursor: \"move\",\n                    handle: this.$container.JSBNG__find(\".js-twttr-dialog-draggable\"),\n                    start: function() {\n                        a.$container.addClass(\"unselectable\"), $(\"#doc\").addClass(\"unselectable\");\n                    },\n                    JSBNG__stop: function() {\n                        a.$container.removeClass(\"unselectable\"), $(\"#doc\").removeClass(\"unselectable\");\n                    },\n                    cancel: \":input,option,.js-twttr-dialog-not-draggable\"\n                });\n            },\n            toggle: function() {\n                return this[((this._isOpen ? \"close\" : \"open\"))](), this;\n            },\n            open: function() {\n                ((c || d()));\n                var a = this;\n                return ((twttr.widget.Dialog.currentModal && ((((this.options.stackPreviousModal && this.options.modal)) ? (this.previousModal = twttr.widget.Dialog.currentModal, this.previousModal._close()) : twttr.widget.Dialog.close())))), ((this.options.modal && (twttr.widget.Dialog.currentModal = this, this.$overlay.show(), $(\"body\").addClass(\"modal-enabled\")))), this.position(), this.$container.css({\n                    visibility: \"visible\",\n                    display: \"block\"\n                }), this.trigger(\"open\"), twttr.widget.Dialog.trigger(\"open\"), this._isOpen = !0, twttr.$win.bind(\"keydown\", this._escKeyHandler), ((this._clickOutsideHandler && JSBNG__setTimeout(function() {\n                    $(\"body\").bind(\"click\", a._clickOutsideHandler);\n                }, 0))), this;\n            },\n            _close: function() {\n                return ((this.options.modal && (twttr.widget.Dialog.currentModal = !1, this.$overlay.hide(), $(\"body\").removeClass(\"modal-enabled\")))), ((((JSBNG__document.activeElement && $.contains(this.$container.get(0), JSBNG__document.activeElement))) && $(JSBNG__document.activeElement).JSBNG__blur())), this.$container.css({\n                    visibility: \"hidden\",\n                    display: \"none\"\n                }), $(\".tipsy\").remove(), this.trigger(\"close\"), twttr.widget.Dialog.trigger(\"close\"), this._isOpen = !1, twttr.$win.unbind(\"keydown\", this._escKeyHandler), ((this._clickOutsideHandler && $(\"body\").unbind(\"click\", this._clickOutsideHandler))), ((this.previousModal && (this.previousModal.open(), delete this.previousModal))), this;\n            },\n            show: function() {\n                return this.open();\n            },\n            hide: function() {\n                return this._close();\n            },\n            setFooterText: function(a) {\n                this.$find(\".twttr-dialog-footer\").html(a);\n            },\n            setError: function(a) {\n                this.$find(\".twttr-dialog-error\").show().html(_(\"\\u003Cp\\u003E{{message}}\\u003C/p\\u003E\", {\n                    message: a\n                }));\n            },\n            clearError: function() {\n                this.$find(\".twttr-dialog-error\").hide().empty();\n            },\n            position: function() {\n                ((this.options.fixed || this.$container.addClass(\"static\")));\n                var a = $(window).scrollTop(), b = this.$container.JSBNG__innerHeight(), c = $(window).height(), d = Math.round(((((c / 2)) - ((b / 2)))));\n                ((this.options.fixed || (d += a)));\n                var e = this.$container.JSBNG__innerWidth(), f = $(window).width(), g = ((((twttr.i18n && twttr.i18n.rtl)) ? \"right\" : \"left\")), i = Math.round(((((f / 2)) - ((e / 2)))));\n                d = ((((this.options.positioning && this.options.positioning.JSBNG__top)) ? this.options.positioning.JSBNG__top : d)), i = ((((this.options.positioning && this.options.positioning.left)) ? this.options.positioning.left : i));\n                var j = {\n                    JSBNG__top: d\n                };\n                return j[g] = i, this.$container.css(j), this;\n            },\n            destroy: function() {\n                return this._close(), this.remove(), this;\n            },\n            remove: function() {\n                return this.$container.unbind().remove(), ((this.$overlay && this.$overlay.unbind().remove())), this._isOpen = !1, this;\n            },\n            close: function() {\n                return this[((this.options.destroyOnClose ? \"destroy\" : \"_close\"))]();\n            },\n            isOpen: function() {\n                return this._isOpen;\n            }\n        });\n        ((twttr.isT1 && e.methods({\n            position: twttr.util.noopInT1\n        }))), a(e);\n    });\n});\nprovide(\"dialogs\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.aug(twttr.dialogs, {\n            reply: function(a, b) {\n                var c = ((a.dataFields || twttr.TweetBox._getDefaultContentForReply(a.$tweet, a.screenName, twttr.currentUserScreenName))), d = {\n                    multiple: c.multiple,\n                    modal: !0,\n                    draggable: !0,\n                    defaultContent: c.defaultContent,\n                    template: {\n                        title: _(\"Reply to @\\u003Cstrong\\u003E{{screen_name}}\\u003C/strong\\u003E\", {\n                            screen_name: a.screenName\n                        }),\n                        footer: \"\"\n                    },\n                    data: a,\n                    origin: a.origin\n                };\n                return ((b ? d : new twttr.widget.ReplyDialog(d)));\n            },\n            directMessage: function(a) {\n                if (twttr.isT1) {\n                    var b = twttr.widget.DirectMessageDialog.views.newConversation;\n                }\n                 else {\n                    var c = twttr.assets.path(\"sticky/default_profile_images/default_profile_6_mini.png\", {\n                        isVersioned: !1\n                    }), b = {\n                        modal: !1,\n                        draggable: !0,\n                        basic: !1,\n                        template: {\n                            title: ((((((_(\"Message\") + \" \\u003Cdiv\\u003E\\u003Cimg class=\\\"avatar\\\" src=\\\"\")) + c)) + \"\\\"/\\u003E \\u003Cinput class=\\\"twttr-directmessage-input\\\" type=\\\"text\\\"/\\u003E\\u003C/div\\u003E \\u003Cspan class=\\\"twttr-dm-check\\\"/\\u003E\")),\n                            footer: _(\"Tip: you can send a message to anyone who follows you\")\n                        },\n                        origin: a.origin\n                    };\n                }\n            ;\n            ;\n                return new twttr.widget.DirectMessageDialog(b);\n            },\n            dmSingle: function(a) {\n                return ((twttr.isT1 ? new twttr.widget.DirectMessageDialog(twttr.widget.DirectMessageDialog.views.conversation, a.user.screenName) : (twttr.merge(a, {\n                    draggable: !0,\n                    basic: !1,\n                    template: {\n                        title: ((((((\"\\u003Cimg src=\\\"\" + a.user.profile_image_url)) + \"\\\"/\\u003E \")) + _(\"\\u003Cstrong\\u003ESend \\u003Cb\\u003E{{user_name}}\\u003C/b\\u003E a message\\u003C/strong\\u003E\", {\n                            user_name: a.user.JSBNG__name\n                        })))\n                    }\n                }), new twttr.widget.DirectMessageDialogSingle(a))));\n            },\n            keyboardShortcuts: function() {\n                return twttr.dialogs._keyboardShortcuts = ((twttr.dialogs._keyboardShortcuts || new twttr.widget.Dialog({\n                    css: {\n                        width: ((twttr.loggedIn ? 600 : 300))\n                    },\n                    modal: !0,\n                    draggable: !0,\n                    destroyOnClose: !1,\n                    template: {\n                        title: _(\"Keyboard shortcuts\"),\n                        JSBNG__content: (new twttr.views.KeyboardShortcuts).html()\n                    }\n                }))), twttr.dialogs._keyboardShortcuts;\n            },\n            discoverable: function() {\n                var a = twttr.currentUser, b = {\n                    help_url: twttr.router.helpDiscoveryPath(),\n                    email_checked: ((!a.emailDiscoverabilitySet || a.discoverableByEmail)),\n                    phone_checked: ((!a.mobilePhoneDiscoverabilitySet || a.discoverableByMobilePhone))\n                };\n                return new twttr.widget.DiscoveryDialog(twttr.merge(b, a.attributes));\n            },\n            verifyEmail: function(a) {\n                return new twttr.widget.VerifyEmailDialog(a, twttr.currentUser);\n            },\n            retweet: function(a, b, c) {\n                var d, e, f = ((((((twttr.isT1 && twttr.currentUser)) && ((new JSBNG__Date(2012, 6, 3) < new JSBNG__Date(twttr.currentUser.createdAt))))) && ((twttr.abdecider.choose(\"change_deutsch_verbs_229\") === \"change_verbs\"))));\n                ((f ? (d = \"Diesen Tweet mit Deinen Followern teilen?\", e = \"Teilen\") : (d = _(\"Retweet this to your followers?\"), e = _(\"Retweet\"))));\n                var g = {\n                    modal: !0,\n                    draggable: !0,\n                    callback: c,\n                    template: {\n                        title: d,\n                        container_id: \"retweet-dialog\",\n                        footer: \"\",\n                        JSBNG__content: (new twttr.views.Prompt({\n                            ok: e,\n                            cancel: _(\"Cancel\")\n                        })).html()\n                    },\n                    data: {\n                        tweetId: a\n                    },\n                    tweetText: b,\n                    css: {\n                        width: 500\n                    }\n                };\n                return new twttr.widget.RetweetDialog(g);\n            },\n            deleteMessage: function(a) {\n                var b = {\n                    modal: !0,\n                    stackPreviousModal: !0,\n                    draggable: !0,\n                    callback: a,\n                    template: {\n                        title: _(\"Are you sure you want to delete this message?\")\n                    },\n                    css: {\n                        width: 450\n                    }\n                };\n                return new twttr.widget.Prompt(b);\n            },\n            deleteSavedSearch: function(a) {\n                return new twttr.widget.Prompt({\n                    modal: !0,\n                    template: {\n                        title: _(\"Are you sure you want to delete this search?\"),\n                        JSBNG__content: (new twttr.views.Prompt({\n                            ok: _(\"Yes\"),\n                            cancel: _(\"No\")\n                        })).html()\n                    },\n                    callback: a\n                });\n            },\n            goToUser: function() {\n                var a = {\n                    modal: !0,\n                    draggable: !0,\n                    template: {\n                        title: _(\"Go to a person's profile\"),\n                        JSBNG__content: \"\\u003Cinput class=\\\"twttr-goto-user-input\\\" type=\\\"text\\\"/\\u003E\"\n                    },\n                    css: {\n                        width: 450\n                    },\n                    positioning: {\n                        JSBNG__top: 75\n                    }\n                }, c = new twttr.widget.Dialog(a), d = c.$find(\".twttr-goto-user-input\"), e = function(a) {\n                    c.close(), twttr.router.JSBNG__one(\"routed\", function() {\n                        $(\"\\u003Cinput type=\\\"text\\\"/\\u003E\").css({\n                            position: \"absolute\",\n                            JSBNG__top: 0,\n                            left: 0\n                        }).appendTo(\"body\").JSBNG__focus().remove();\n                    });\n                    var b = a.replace(\"@\", \"\").split(\"/\");\n                    ((((b.length === 1)) ? (screen_name = b[0], twttr.API.User.JSBNG__find(screen_name, {\n                        success: function(a) {\n                            twttr.router.routeTo(twttr.router.profilePath({\n                                screen_name: screen_name\n                            }));\n                        },\n                        error: function(a) {\n                            twttr.router.routeTo(twttr.router.userSearchPath({\n                                query: screen_name\n                            }));\n                        }\n                    })) : twttr.router.routeTo(twttr.router.userListPath({\n                        screen_name: b[0],\n                        list_slug: b[1]\n                    }))));\n                }, f = new twttr.components.Autocomplete({\n                    limit: 8,\n                    input: d,\n                    type: \"username\",\n                    preselect: !0,\n                    defaultResults: [{\n                        format: function(a) {\n                            return (new twttr.views.CurrentTextUserAutocompleteItem({\n                                screenname: ((((a.charAt(0) === \"@\")) ? a.substring(1) : a))\n                            })).html();\n                        },\n                        show: function(a, b) {\n                            for (var c in b) {\n                                if (((b[c][1] === a))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            return !0;\n                        }\n                    },]\n                });\n                return f.bind(\"select\", function(a, b, c, d, f, g) {\n                    e(f);\n                }), d.bind(\"keypress\", function(a) {\n                    ((((((a.keyCode === b.constants.keyCodes.enter)) && !f._isCompletionsOpen)) && (a.preventDefault(), e(d.val()))));\n                }), c.bind(\"open\", function() {\n                    d.JSBNG__focus();\n                }), c;\n            },\n            searchFacets: function(a) {\n                if (!twttr.decider.isAvailable(\"phoenix_facets\")) {\n                    return !1;\n                }\n            ;\n            ;\n                var c = {\n                    modal: !0,\n                    draggable: !0,\n                    template: {\n                        title: ((((a === \"photos\")) ? _(\"Search photos\") : _(\"Search videos\"))),\n                        JSBNG__content: \"\\u003Cinput class=\\\"twttr-search-facets-input\\\" type=\\\"text\\\"/\\u003E\"\n                    },\n                    css: {\n                        width: 450\n                    },\n                    positioning: {\n                        JSBNG__top: 75\n                    }\n                }, d = new twttr.widget.Dialog(c), e = d.$find(\".twttr-search-facets-input\");\n                return e.bind(\"keypress\", function(c) {\n                    ((((c.keyCode === b.constants.keyCodes.enter)) && (c.preventDefault(), d.close(), twttr.router.JSBNG__one(\"routed\", function() {\n                        $(\"\\u003Cinput type=\\\"text\\\"/\\u003E\").css({\n                            position: \"absolute\",\n                            JSBNG__top: 0,\n                            left: 0\n                        }).appendTo(\"body\").JSBNG__focus().remove();\n                    }), twttr.router.routeTo(twttr.router.searchFacetsGridPath({\n                        query: e.val(),\n                        mode: a\n                    })))));\n                }), d.bind(\"open\", function() {\n                    e.JSBNG__focus();\n                }), d;\n            },\n            _trendsOptions: function() {\n                return options = {\n                    draggable: !0,\n                    css: {\n                        width: 520\n                    },\n                    template: {\n                        title: _(\"Choose a trend location\")\n                    }\n                };\n            },\n            trends: function() {\n                return arguments.callee._ret = ((arguments.callee._ret || new twttr.widget.TrendsDialog(this._trendsOptions())));\n            },\n            signinOrSignup: function(a) {\n                a = ((a || {\n                }));\n                var c = ((a.follow ? a.follow.screenName : !1)), d = {\n                    screen_name: c,\n                    signup_source: twttr.audit.currentPage()\n                };\n                if (c) {\n                    d.redirect_after_login = twttr.router.profilePath(d);\n                }\n                 else {\n                    if (((((((twttr.audit.currentPage() === \"permalink\")) || ((twttr.audit.currentPage() === \"profile\")))) || ((twttr.audit.currentPage() === \"search\"))))) {\n                        d.redirect_after_login = twttr.audit.currentPath();\n                    }\n                ;\n                }\n            ;\n            ;\n                var e = ((c ? _(\"Sign in to Twitter &amp; follow @{{screen_name}}\", d) : _(\"Sign in to Twitter\")));\n                ((a.justSignup && (d.is_signup_only = !0, d.guest_modal = !0, d.signup_source = twttr.audit.currentPage(), e = ((c ? _(\"Sign up for Twitter &amp; follow @{{screen_name}}\", d) : _(\"Sign up for Twitter\"))))));\n                var f = new twttr.widget.Dialog({\n                    css: {\n                        width: 500\n                    },\n                    modal: !0,\n                    draggable: !0,\n                    template: {\n                        title: e,\n                        JSBNG__content: (new twttr.views.SigninOrSignup(d)).html()\n                    }\n                }), g = f.$find(\"form.signin\"), i = g.JSBNG__find(\".textbox input\");\n                return ((a.justSignup && f.$dialog.addClass(\"signup-only-dialog\"))), twttr.helpers.addHoldingInputEvents(g), twttr.helpers.addFormEvents(g), i.bind(\"keypress\", function(a) {\n                    ((((((a.keyCode === b.constants.keyCodes.enter)) && $(this).val())) && (a.preventDefault(), g.submit())));\n                }), f.bind(\"open\", function() {\n                    i.first().JSBNG__focus();\n                    var b = {\n                        section: \"auth_dialog\",\n                        component: ((a.follow ? \"unauth_follow\" : \"unauth_action\")),\n                        action: \"open\"\n                    };\n                    trackClient(b, twttr.audit.currentPage());\n                }), f.$find(\"form\").bind(\"submit\", function() {\n                    JSBNG__setTimeout(function() {\n                        f.close(), trackClient({\n                            section: \"auth_dialog\",\n                            component: \"signup_form\",\n                            action: \"signup_click\"\n                        }, twttr.audit.currentPage());\n                    }, 0);\n                }), f;\n            },\n            signupModalDialogGuest: function(a, b) {\n                var c = [], d = [], e = 0;\n                for (var f = 0; ((f < a)); f++) {\n                    twttr.API.User.JSBNG__find(twttr.recentlyViewedUsers.stack[((((twttr.recentlyViewedUsers.size() - f)) - 1))], {\n                        success: function(f) {\n                            c.push({\n                                JSBNG__name: f.JSBNG__name,\n                                screen_name: f.screenName,\n                                profile_image_url: f.profileImageUrl,\n                                id: f.id,\n                                description: ((\"@\" + f.screenName)),\n                                count_num: e\n                            }), d.push(f.screenName), e++;\n                            if (((e == a))) {\n                                var g = {\n                                    screen_names: d.join(\",\"),\n                                    signup_source: twttr.audit.currentPage(),\n                                    user_data_list: c,\n                                    guest_modal: !0\n                                }, i = new twttr.widget.Dialog({\n                                    css: {\n                                        width: 575\n                                    },\n                                    modal: !0,\n                                    draggable: !0,\n                                    template: {\n                                        title: _(\"Follow your interests on Twitter!\"),\n                                        JSBNG__content: (new twttr.views.GuestModalSignup(g)).html()\n                                    }\n                                });\n                                $signup = i.$find(\"form.signup-btn\"), $inputs = $signup.JSBNG__find(\".textbox input\"), twttr.helpers.addFormEvents($signup), twttr.helpers.addHoldingInputEvents($signup), i.bind(\"open\", function() {\n                                    $inputs.first().JSBNG__focus();\n                                });\n                                var j = i.$find(\"input[type=checkbox]\");\n                                j.bind(\"click\", function(a) {\n                                    var b = i.$find(\"input[type=checkbox]:checked\"), c = $.map(b, function(a, b) {\n                                        return a.value;\n                                    }).join(\",\");\n                                    $signup.JSBNG__find(\"input[name=follows]\").val(c);\n                                }), i.$find(\"form\").bind(\"submit\", function() {\n                                    i.close(), trackClient({\n                                        section: \"profiles_viewed_dialog\",\n                                        component: \"signup_form\",\n                                        action: \"signup_click\"\n                                    }, twttr.audit.currentPage());\n                                }), b(i);\n                            }\n                        ;\n                        ;\n                        }\n                    });\n                ;\n                };\n            ;\n            },\n            searchOperators: function() {\n                return twttr.dialogs._searchOperators = new twttr.widget.Dialog({\n                    css: {\n                        width: 600\n                    },\n                    modal: !1,\n                    draggable: !0,\n                    template: {\n                        title: _(\"Search Operators\"),\n                        JSBNG__content: (new twttr.views.SearchOperators).html()\n                    }\n                }), twttr.dialogs._searchOperators;\n            },\n            smsCodes: function() {\n                return twttr.dialogs._smsCodes = ((twttr.dialogs._smsCodes || new twttr.widget.Dialog({\n                    modal: !1,\n                    draggable: !0,\n                    template: {\n                        title: _(\"Two-way (sending and receiving) short codes:\"),\n                        JSBNG__content: (new twttr.views.SmsCodes).html()\n                    }\n                }))), twttr.dialogs._smsCodes;\n            },\n            sensitiveFlagConfirmation: function(a) {\n                var b = new twttr.widget.Prompt({\n                    modal: !1,\n                    draggable: !0,\n                    template: {\n                        title: _(\"Flag this media\"),\n                        JSBNG__content: (new twttr.views.SensitiveFlagConfirmation).html()\n                    },\n                    callback: function(c) {\n                        ((c && (((b.$find(\"#sensitive-settings-checkbox\").attr(\"checked\") && twttr.currentUser.updateViewPossiblySensitive(!1, {\n                            success: function() {\n                                twttr.showMessage(_(\"Your media display settings have been changed.\"));\n                            },\n                            error: function(a) {\n                                twttr.showError(_(\"Couldn't set inline media settings.\"));\n                            }\n                        }))), ((b.$find(\"#sensitive-illegal-checkbox\").attr(\"checked\") && a())))));\n                    }\n                });\n                return b;\n            },\n            embedCode: function(a) {\n                return new twttr.widget.EmbedDialog(a);\n            }\n        }), a(twttr.dialogs);\n    });\n});\nprovide(\"widget/TweetDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.TweetDialog\", function(a) {\n            a = twttr.merge({\n                basic: !0,\n                modal: !0,\n                fixed: !0\n            }, a), a.template = twttr.merge({\n                show_geo: !0,\n                container_id: \"tweet_dialog\"\n            }, ((a && a.template))), a = $.extend(!0, {\n                basic: !0,\n                template: {\n                    show_geo: !0,\n                    container_id: \"tweet_dialog\"\n                }\n            }, a), twttr.widget.TweetDialog.uber.constructor.call(this, a), this._ready = !1;\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.view.bind(\"ready\", twttr.bind(this, function() {\n                    this._ready = !0, JSBNG__setTimeout(twttr.bind(this, function() {\n                        this.JSBNG__onReady();\n                    }), 0);\n                })), this.view.tweetBox.bind(\"tweetSuccess\", twttr.bind(this, function(a, b, c) {\n                    ((((((c === \"reply\")) && b.inReplyToScreenName)) ? twttr.showMessage(_(\"Your Tweet to @{{username}} has been sent!\", {\n                        username: b.inReplyToScreenName\n                    })) : (twttr.showMessage(_(\"Your Tweet was posted!\")), $(JSBNG__document).trigger(\"tweetSuccess\", b)))), this.destroy();\n                })), this.view.tweetBox.bind(\"dmSuccess\", twttr.bind(this, function(b, c) {\n                    ((twttr.is.def(twttr.messageManager) && twttr.messageManager.addMessage(c))), twttr.showMessage(_(\"Your message was sent!\")), a.close();\n                })), this.view.tweetBox.bind(\"dmFail\", twttr.bind(this, function(b, c) {\n                    a.close();\n                })), ((this.options.basic && this.view.tweetBox.bind(\"titleChanged\", twttr.bind(this, function(a, b) {\n                    this.$title.html(((b || this.options.template.title)));\n                }))));\n            },\n            JSBNG__onReady: function() {\n                var a = [];\n                return function(b) {\n                    ((b ? a.push(b) : (twttr.each(a, function(a) {\n                        a();\n                    }), a = [])));\n                };\n            }(),\n            open: function() {\n                return twttr.widget.Dialog.prototype.open.call(this), this.JSBNG__onReady(twttr.bind(this, function() {\n                    JSBNG__setTimeout(twttr.bind(this, function() {\n                        ((this.options.defaultContent && (this.JSBNG__focus(), this.setContent(this.options.defaultContent))));\n                    }), 0);\n                })), this;\n            },\n            setContent: function(a) {\n                return this.view.tweetBox.editor.setContent(a), this;\n            },\n            setCaretPosition: function(a, b) {\n                b = ((b || a));\n                var c = this.view.tweetBox.editor.$editor[0];\n                if (c.setSelectionRange) {\n                    c.JSBNG__focus(), c.setSelectionRange(a, b);\n                }\n                 else {\n                    if (c.createTextRange) {\n                        var d = c.createTextRange();\n                        d.collapse(!0), d.moveStart(\"character\", a), d.moveEnd(\"character\", b), d.select();\n                    }\n                ;\n                }\n            ;\n            ;\n            },\n            JSBNG__focus: function() {\n                if (this.options.defaultContent) {\n                    var a = this.view.tweetBox.editor.$editor.val().length;\n                    this.setCaretPosition(a);\n                }\n                 else this.view.tweetBox.editor.JSBNG__focus();\n            ;\n            ;\n                return this;\n            }\n        }), a(twttr.widget.TweetDialog);\n    });\n});\nprovide(\"widget/Prompt\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        var c = ((twttr.isT1 ? \"primary-btn\" : \"selected\"));\n        twttr.klass(\"twttr.widget.Prompt\", function(a) {\n            var b = {\n                view: \"Dialog\",\n                template: {\n                    JSBNG__content: (new twttr.views.Prompt({\n                        ok: _(\"Yes\"),\n                        cancel: _(\"No\")\n                    })).html()\n                }\n            };\n            this.options = twttr.merge({\n            }, b, a, !0), twttr.widget.Prompt.uber.constructor.call(this, this.options);\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.$ok = this.$container.JSBNG__find(\".js-prompt-ok\"), this.$cancel = this.$container.JSBNG__find(\".js-prompt-cancel\"), this.$ok.addClass(c).bind(\"click\", twttr.bind(this, function(a) {\n                    a.preventDefault(), this.close(), this.options.callback(!0);\n                })), this.$cancel.bind(\"click\", twttr.bind(this, function(a) {\n                    a.preventDefault(), this.options.callback(!1), this.close();\n                })), this.$container.bind(\"keypress\", twttr.bind(this, function(a) {\n                    a.stopPropagation();\n                    if (a.metaKey) {\n                        return;\n                    }\n                ;\n                ;\n                    if (((a.keyCode === b.constants.keyCodes.tab))) {\n                        this.$cancel.toggleClass(c), this.$ok.toggleClass(c);\n                    }\n                     else {\n                        if (((((a.keyCode === b.constants.keyCodes.enter)) || ((a.keyCode === b.constants.keyCodes.spacebar))))) {\n                            a.preventDefault(), this.options.callback(this.$ok.hasClass(c)), this.close();\n                        }\n                    ;\n                    }\n                ;\n                ;\n                })), this._$tabInput = $(\"\\u003Cinput type=\\\"text\\\" class=\\\"twttr-hidden-input\\\"/\\u003E\").appendTo(this.$dialog).bind(\"keypress\", function(a) {\n                    a.preventDefault();\n                });\n            },\n            open: function() {\n                return twttr.widget.Dialog.prototype.open.call(this), JSBNG__setTimeout(twttr.bind(this, function() {\n                    this._$tabInput.JSBNG__focus();\n                }), 10), this;\n            }\n        }), a(twttr.widget.Prompt);\n    });\n});\nprovide(\"widget/DeviceSetupDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.DeviceSetupDialog\", function(a) {\n            a = twttr.merge({\n                modal: !0,\n                draggable: !0,\n                css: {\n                    width: 550,\n                    height: \"auto\"\n                },\n                positioning: {\n                    JSBNG__top: 80\n                },\n                template: {\n                    title: _(\"Get notifications and Tweet via SMS\"),\n                    JSBNG__content: (new twttr.views.DeviceSetupDialog).html()\n                }\n            }, ((a || {\n            })), !0), a.view = \"Dialog\", this._fetchStatus();\n            var b = this;\n            this._carriers = twttr.API.Device.carriers({\n                success: function(a) {\n                    b._carriers = a;\n                }\n            }), twttr.widget.Dialog.call(this, a);\n        }).subclassOf(twttr.widget.Dialog).statics({\n            POLLING_DELAY: 15000\n        }).methods({\n            close: function() {\n                this._clearDelayedStatusFetch(), twttr.widget.Dialog.prototype.close.call(this);\n            },\n            _fetchStatus: function() {\n                this._clearDelayedStatusFetch();\n                var a = this;\n                twttr.API.Device.list({\n                    success: twttr.bind(this, this._updateStatus),\n                    error: function(b) {\n                        a.close(), twttr.showError(b.response.error.message);\n                    }\n                });\n            },\n            _fetchStatusDelayed: function() {\n                this._fetchTimeout = window.JSBNG__setTimeout(twttr.bind(this, this._fetchStatus), twttr.widget.DeviceSetupDialog.POLLING_DELAY);\n            },\n            _clearDelayedStatusFetch: function() {\n                ((this._fetchTimeout && (window.JSBNG__clearTimeout(this._fetchTimeout), this._fetchTimeout = null)));\n            },\n            _updateStatus: function(a) {\n                if (((a.length == 0))) this._showCreate();\n                 else {\n                    var b = a[0];\n                    ((b.verified ? this._showVerified(b) : this._showWaiting(b)));\n                }\n            ;\n            ;\n            },\n            _showCreate: function() {\n                var a = this, b = this.$container.JSBNG__find(\".twttr-dialog-device-setup\"), c = new twttr.views.DeviceSetupDialogCreate;\n                b.empty().append(\"\\u003Cdiv class=\\\"loading\\\"\\u003E\\u003C/div\\u003E\"), this._carriers.get(function(d) {\n                    b.empty();\n                    var e = c.render(b, \"append\"), f = e.JSBNG__find(\"select.country-or-region\"), g = e.JSBNG__find(\"select.country-in-region\"), i = e.JSBNG__find(\"select.carrier\"), j = e.JSBNG__find(\"select.language\"), k = !1;\n                    for (var l = 0; ((l < d.regionsAndCountryCodes.length)); ++l) {\n                        var m = d.regionsAndCountryCodes[l];\n                        ((((m[0] == \"-------------\")) ? $(\"\\u003Coption disabled=\\\"disabled\\\"\\u003E\").text(m[0]).val(m[1]).appendTo(f) : $(\"\\u003Coption\\u003E\").text(m[0]).val(m[1]).appendTo(f)));\n                    };\n                ;\n                    var n = function() {\n                        var a = $(this), b = a.JSBNG__find(\"option:selected\"), c = b.text(), f = b.val();\n                        if (d.countries[c]) {\n                            var l = c;\n                            g.empty();\n                            var m = d.countries[l];\n                            for (var o = 0; ((o < m.length)); ++o) {\n                                var p = m[o];\n                                $(\"\\u003Coption\\u003E\").text(p[0]).val(p[1]).appendTo(g);\n                            };\n                        ;\n                            g.parents(\".field\").first().show(), n.call(g.get(0));\n                            return;\n                        }\n                    ;\n                    ;\n                        var q = c;\n                        e.JSBNG__find(\".country-code\").text(f), ((a.hasClass(\"country-or-region\") && (g.empty(), g.parents(\".field\").first().hide()))), i.empty(), j.empty();\n                        var r = d.carriers[q], s = d.languages[q];\n                        k = !1;\n                        if (d.countries[_(\"Satellite\")]) {\n                            for (var o = 0; ((o < d.countries[_(\"Satellite\")].length)); o++) {\n                                if (((d.countries[_(\"Satellite\")][o][0] == q))) {\n                                    k = !0;\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        if (r) {\n                            for (var o = 0; ((o < r.length)); ++o) {\n                                var t = r[o];\n                                $(\"\\u003Coption\\u003E\").text(t.display).val(t.value).appendTo(i);\n                            };\n                        ;\n                            ((k ? i.parents(\".field\").first().hide() : i.parents(\".field\").first().show()));\n                        }\n                         else i.parents(\".field\").first().hide();\n                    ;\n                    ;\n                        if (s) {\n                            for (var o = 0; ((o < s.length)); ++o) {\n                                var u = s[o];\n                                $(\"\\u003Coption\\u003E\").text(u.display).val(u.value).appendTo(j);\n                            };\n                        ;\n                            j.parents(\".field\").first().show();\n                        }\n                         else j.parents(\".field\").first().hide();\n                    ;\n                    ;\n                    };\n                    f.change(n), g.change(n), n.call(f.get(0)), twttr.helpers.addFormEvents(e.JSBNG__find(\"form\"), function(b, c) {\n                        var d = $(this);\n                        c.device_country_intl_prefix = d.JSBNG__find(\".country-code\").text(), d.JSBNG__find(\".error\").removeClass(\"error\"), d.JSBNG__find(\".error-text\").remove(), d.addClass(\"submitting\"), twttr.API.Device.create(c, {\n                            success: function(b) {\n                                d.removeClass(\"submitting\");\n                                var e = b.devices[0];\n                                ((b.duplicate ? a._showDuplicate(e, c) : ((b.errors ? a._showCreateErrors(d, b.errors) : (((k || (e.carrier_name = i.JSBNG__find(\":selected\").text()))), a._showWaiting(e))))));\n                            },\n                            error: function(a) {\n                                d.removeClass(\"submitting\");\n                                var b = a.response.errors;\n                                ((((((b && b.length)) && b[0].message)) ? twttr.showError(b[0].message) : twttr.showError(_(\"Whoops! Something went wrong. Please try again!\"))));\n                            }\n                        });\n                    });\n                });\n            },\n            _showCreateErrors: function(a, b) {\n                var c = b.device;\n                for (var d = 0; ((d < c.length)); ++d) {\n                    var e = c[d], f = a.JSBNG__find(((((\"input[name='device[\" + e[0])) + \"]']\"))), g = f.parents(\".field\").first();\n                    $error = $(\"\\u003Cdiv\\u003E\").addClass(\"error-text\").text(e[1]), g.addClass(\"error\"), g.JSBNG__find(\".label\").first().append($error);\n                };\n            ;\n            },\n            _showDuplicate: function(a, b) {\n                this._updateDeviceForRendering(a);\n                var c = this, d = this.$container.JSBNG__find(\".twttr-dialog-device-setup\");\n                d.empty();\n                var e = (new twttr.views.DeviceSetupDialogDuplicate(a)).render(d, \"append\");\n                e.JSBNG__find(\".retry\").click(function(a) {\n                    a.preventDefault();\n                    var d = $(this);\n                    if (d.hasClass(\"disabled\")) {\n                        return;\n                    }\n                ;\n                ;\n                    d.addClass(\"disabled\"), twttr.API.Device.create(b, {\n                        success: function(a) {\n                            d.removeClass(\"disabled\"), ((a.duplicate || ((a.errors ? c._showCreate() : c._showWaiting(a.devices[0])))));\n                        },\n                        error: function() {\n                            d.removeClass(\"disabled\");\n                        }\n                    });\n                }), e.JSBNG__find(\".cancel-instructions a\").click(function(a) {\n                    a.preventDefault(), c._showCreate();\n                });\n            },\n            _showWaiting: function(a) {\n                this._fetchStatusDelayed();\n                var b = this, c = this.$container.JSBNG__find(\".twttr-dialog-device-setup\"), d = c.JSBNG__find(\".twttr-dialog-device-setup-waiting\");\n                if (d.length) {\n                    return;\n                }\n            ;\n            ;\n                c.empty(), this._updateDeviceForRendering(a), d = (new twttr.views.DeviceSetupDialogWaiting(a)).render(c, \"append\"), d.JSBNG__find(\".refresh a\").click(function(a) {\n                    a.preventDefault(), b._fetchStatus();\n                }), d.JSBNG__find(\".cancel-instructions a\").click(function(c) {\n                    c.preventDefault(), b._clearDelayedStatusFetch(), twttr.API.Device.destroy(a.id, {\n                        success: twttr.bind(b, b._showCreate)\n                    });\n                });\n            },\n            _showVerified: function(a) {\n                var b = this.$container.JSBNG__find(\".twttr-dialog-device-setup\");\n                b.empty(), this._updateDeviceForRendering(a), (new twttr.views.DeviceSetupDialogVerified(a)).render(b, \"append\");\n            },\n            _updateDeviceForRendering: function(a) {\n                a.address_without_country_code = a.address.replace(((\"+\" + a.country_code)), \"\"), a.stop_command = \"Stop\", a.go_command = \"Go\";\n            }\n        }), a(twttr.widget.DeviceSetupDialog);\n    });\n});\nprovide(\"widget/DeviceFollowDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.DeviceFollowDialog\", function(a) {\n            a = twttr.merge({\n                modal: !0,\n                draggable: !0,\n                css: {\n                    width: 500,\n                    height: \"auto\"\n                },\n                positioning: {\n                    JSBNG__top: 200\n                },\n                template: {\n                    title: _(\"Don&#8217;t miss a Tweet.\"),\n                    JSBNG__content: (new twttr.views.WelcomeDeviceFollow).html()\n                }\n            }, ((a || {\n            })), !0), a.view = \"Dialog\", this.JSBNG__onclose = a.JSBNG__onclose, twttr.widget.Dialog.call(this, a);\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.$find(\".device-follow-done-button\").bind(\"click\", twttr.bind(this, function(a) {\n                    trackClient({\n                        component: \"device_follow_dialog\",\n                        action: \"done\"\n                    }), this.close();\n                }));\n            },\n            close: function() {\n                ((this.JSBNG__onclose && this.JSBNG__onclose())), trackClient({\n                    component: \"device_follow_dialog\",\n                    action: \"close\"\n                }), twttr.widget.Dialog.prototype.close.call(this);\n            }\n        }), a(twttr.widget.DeviceFollowDialog);\n    });\n});\nprovide(\"widget/InviteContactsDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.InviteContactsDialog\", function(a, b) {\n            b = ((b || {\n            })), this.routeToHome = b.routeToHome, b.template = ((b.template || {\n            })), b.template.title = ((b.template.title || _(\"Invite your friends who aren't on Twitter\"))), b.template.JSBNG__content = ((b.template.JSBNG__content || \"\")), defaultOptions = {\n                modal: !0,\n                draggable: !0\n            }, b = twttr.merge({\n            }, defaultOptions, b, !0), b.view = \"Dialog\", twttr.widget.Dialog.call(this, b);\n            var c = ((b.JSBNG__onSuccess || $.noop)), d = this, e = {\n                JSBNG__onSuccess: function() {\n                    c.call(d);\n                },\n                JSBNG__onSubmit: function() {\n                    d.clearError();\n                },\n                showError: function(a) {\n                    d.setError(a);\n                },\n                scribbler: b.scribbler,\n                clientEventComponent: \"invite_contacts_dialog\"\n            }, f = new twttr.components.InviteContacts(a, e);\n            this.$container.JSBNG__find(\".twttr-dialog-content\").append(f.$node), this.$container.JSBNG__find(\".twttr-dialog-footer\").remove(), this.$find(\".twttr-dialog-close\").bind(\"click\", function() {\n                ((b.scribbler && b.scribbler.scribe({\n                    component: e.clientEventComponent,\n                    action: \"close\"\n                })));\n            });\n        }).subclassOf(twttr.widget.Dialog).methods({\n            close: function() {\n                this.constructor.uber.close.call(this), ((this.routeToHome && twttr.router.routeTo(twttr.router.homePath())));\n            }\n        }), a(twttr.widget.InviteContactsDialog);\n    });\n});\nprovide(\"widget/ListDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.ListDialog\", function(a) {\n            a = ((a || {\n            })), a.template = ((a.template || {\n            })), a.template.title = ((((a.template.title || a.list)) ? _(\"Edit list details\") : _(\"Create a new list\"))), a.template.JSBNG__content = ((a.template.JSBNG__content || (new twttr.views.ListDialog(a.list)).html())), ((twttr.is.def(a.modal) || (a.modal = !0))), ((twttr.is.def(a.draggable) || (a.draggable = !0))), a.view = \"Dialog\", ((twttr.is.fn(a.JSBNG__onSuccess) || (a.JSBNG__onSuccess = function(a) {\n                twttr.router.routeTo(twttr.router.userListPath({\n                    screen_name: twttr.currentUser.screenName,\n                    list_slug: a.slug\n                }));\n            }))), twttr.widget.Dialog.call(this, a);\n        }).subclassOf(twttr.widget.Dialog).methods({\n            open: function() {\n                twttr.widget.Dialog.prototype.open.call(this), this.$container.JSBNG__find(\"input[name=name]\").JSBNG__focus();\n            },\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.Dialog.prototype.registerEvents.call(this);\n                var b = this.$container.JSBNG__find(\".update-list-button\");\n                this.$container.JSBNG__find(\".field .text\").bind(\"focus blur keyup\", function(a) {\n                    ((this.value.length ? b.removeClass(\"disabled\") : b.addClass(\"disabled\")));\n                }), b.click(function(b) {\n                    if ($(this).hasClass(\"disabled\")) {\n                        return;\n                    }\n                ;\n                ;\n                    $(this).addClass(\"disabled\");\n                    var c = {\n                        JSBNG__name: a.$container.JSBNG__find(\"[name=name]\").val(),\n                        description: a.$container.JSBNG__find(\"[name=description]\").val(),\n                        mode: a.$container.JSBNG__find(\"[name=mode]:checked\").val(),\n                        error: function(b) {\n                            twttr.helpers.showErrorFromResponse(b), $(a).removeClass(\"disabled\");\n                        },\n                        complete: function(b) {\n                            a.close();\n                        }\n                    };\n                    ((a.options.list ? a.options.list.update(twttr.merge(c, {\n                        success: function(b) {\n                            twttr.showMessage(_(\"List updated!\")), a.options.JSBNG__onSuccess(b);\n                        }\n                    })) : twttr.currentUser.lists.create(c.JSBNG__name, twttr.merge(c, {\n                        success: function(b) {\n                            twttr.showMessage(_(\"List created!\")), a.options.JSBNG__onSuccess(b);\n                        }\n                    }))));\n                });\n            },\n            close: function() {\n                this.constructor.uber.close.call(this), this.remove();\n            }\n        }), a(twttr.widget.ListDialog);\n    });\n});\nprovide(\"components/t1/DirectMessageDialog\", function(a) {\n    using(\"widget/Dialog\", \"constants\", \"TweetBox\", function(b, c, d) {\n        var e = twttr.klass(\"twttr.widget.DirectMessageDialog\", function(a, b, c) {\n            twttr.messageManager._fetchMessages(), c = ((c || {\n            })), d = ((c.tweetBox || d)), twttr.widget.Dialog.call(this, {\n                modal: !0,\n                draggable: !0,\n                view: \"DirectMessageDialog\",\n                closeOnNavigate: !0,\n                template: {\n                    footer: !0\n                },\n                positioning: {\n                    JSBNG__top: 55\n                }\n            }), this.initComponentEvents(this.$container);\n            var e = this;\n            twttr.messageManager.bind(\"updatedThread\", function(a, b, c, d) {\n                e._updateConversation(b, c, d);\n            }), twttr.messageManager.bind(\"deletedThread\", function(a, b) {\n                e._deleteThread(b);\n            }), this._hideTweetBox(), this.tweetBox = new d(\".twttr-dialog-container .js-dm-tweetbox\", {\n                data: {\n                    getUser: twttr.bind(this, this._getRecipient)\n                },\n                closeAfterSuccess: !1,\n                condensed: !1,\n                width: 450,\n                height: 56,\n                statusAction: \"directMessage\",\n                displayError: !1,\n                template: {\n                    button_text: _(\"Send message\"),\n                    show_geo: !1,\n                    show_turkey: !1,\n                    show_title: !1\n                }\n            }), this.tweetBox.bind(\"dmSuccess\", function(a, b, c) {\n                twttr.messageManager.addMessage(b, !0), e.switchToConversationView(b.threadId);\n            }), this.tweetBox.bind(\"dmError\", function(a, b) {\n                var b = twttr.errors.getViewForErrorCode(b, \"dm\").html();\n                e._showError($(\"\\u003Cspan\\u003E\").html(b));\n            }), this.tweetBox.bind(\"error\", function(a, b) {\n                e._showError(b);\n            });\n            var e = this;\n            a = ((a || twttr.widget.DirectMessageDialog.views.conversationList)), this.bind(\"close\", function() {\n                twttr.messageManager.unbind(\"updatedThread\"), twttr.messageManager.unbind(\"deletedThread\");\n            }), this.bind(\"open\", function() {\n                switch (a) {\n                  case twttr.widget.DirectMessageDialog.views.newConversation:\n                    e.switchToNewMessageView(b), e._trackClientDialogImpression(\"dm_new_conversation\");\n                    break;\n                  case twttr.widget.DirectMessageDialog.views.conversation:\n                    e.switchToConversationView(b), e._trackClientDialogImpression(\"dm_existing_conversation\");\n                    break;\n                  case twttr.widget.DirectMessageDialog.views.conversationList:\n                \n                  default:\n                    e.switchToConversationListView(), e._trackClientDialogImpression(\"dm_conversation_list\");\n                };\n            ;\n            });\n        }).subclassOf(b).mixin(twttr.mixins.componentEvents, twttr.mixins.i18nTweet).statics({\n            views: {\n                conversationList: 1,\n                conversation: 2,\n                newConversation: 3\n            }\n        }).methods({\n            _getRecipient: function() {\n                var a = this.$find(\".js-dm-conversation[data-thread-id]\").attr(\"data-thread-id\");\n                return ((a || this.$find(\".js-dm-user-autocomplete\").val()));\n            },\n            _trackClientDialogImpression: function(a) {\n                trackClient({\n                    component: a,\n                    action: \"open\"\n                }, {\n                });\n            },\n            _trackClientDelete: function(a) {\n                trackClient({\n                    component: \"direct_message\",\n                    action: \"delete\"\n                }, {\n                    item_ids: [a,],\n                    item_count: 1\n                });\n            },\n            switchToConversationListView: function() {\n                var a = this;\n                this._updateHeader({\n                    conversation_list: !0\n                }), this._hideTweetBox(), twttr.messageManager.getAllThreads(function(b) {\n                    a._updateContent(\"DirectMessageDialogConversationList\", {\n                        threads: b\n                    }), a.$find(\"div.dm-thread-content\").each(function() {\n                        a.updateRtlDisplay($(this));\n                    });\n                });\n            },\n            switchToConversationView: function(a) {\n                var b = this;\n                twttr.messageManager.getThread(a, function(c) {\n                    if (!c) {\n                        b.switchToNewMessageView(a);\n                        return;\n                    }\n                ;\n                ;\n                    var d = c.messages[0], e = ((twttr.helpers.isCurrentUser(d.recipient) ? d.sender : d.recipient));\n                    b._updateHeader({\n                        conversation: !0,\n                        JSBNG__name: e.JSBNG__name\n                    }), b._updateContent(\"DirectMessageDialogConversation\", c), b.$find(\"div.dm-content\").each(function() {\n                        b.updateRtlDisplay($(this));\n                    }), b._showTweetBox(a), b.tweetBox.JSBNG__focus(), b.$find(\"a.js-dm-delete\").tipsy({\n                        gravity: \"s\"\n                    });\n                    var f = b.$find(\".js-dm-conversation\");\n                    f.scrollTop(f[0].scrollHeight), twttr.messageManager.markThreadAsRead(c.threadId);\n                });\n            },\n            switchToNewMessageView: function(a) {\n                var b = this;\n                this._updateHeader({\n                    new_dm: !0\n                }), this._updateContent(\"DirectMessageDialogNew\", {\n                }), twttr.components.Autocomplete.getAutocompletedUsers(function() {\n                    b.autocomplete = new twttr.components.Autocomplete({\n                        limit: 8,\n                        input: b.$find(\".js-dm-user-autocomplete\")\n                    }), b.autocomplete.bind(\"select\", function(a, c, d, e, f, g) {\n                        b._setProfileImageUrl(e), b.switchToConversationView(f), b.tweetBox.JSBNG__focus();\n                    }), b.autocomplete.bind(\"hide\", function() {\n                        ((!b.$find(\".js-dm-user-autocomplete:focus\").length && b._verifyUser()));\n                    }), b._setProfileImageUrl(), b.autocomplete.JSBNG__focus(), ((a && (b.autocomplete.set(a), b._verifyUser())));\n                }), this._showTweetBox();\n            },\n            _updateConversation: function(a, b, c) {\n                var d = this._getCurrentView();\n                switch (d) {\n                  case twttr.widget.DirectMessageDialog.views.conversationList:\n                    this._updateConversationListView(a, b);\n                    break;\n                  case twttr.widget.DirectMessageDialog.views.conversation:\n                    this._updateConversationView(a, b, c);\n                };\n            ;\n            },\n            _deleteThread: function(a) {\n                this.$find(((((\".js-dm-threads .js-dm-thread[data-thread-id=\" + a)) + \"]\"))).remove(), this.$find(((((\".js-dm-conversation[data-thread-id=\" + a)) + \"]\"))).empty();\n            },\n            _updateConversationListView: function(a, b) {\n                var c = this.$find(\".js-dm-threads\"), d = c.JSBNG__find(((((\".js-dm-thread[data-thread-id=\" + a.threadId)) + \"]\"))), e = $((new twttr.views.DirectMessageDialogConversationListItem(a)).html());\n                ((((d.length > 0)) && d.replaceWith(e))), d = e, ((((b === \"new\")) && c.JSBNG__find(\".js-dm-thread-list\").prepend(d)));\n            },\n            _updateConversationView: function(a, b, c) {\n                var d = this.$find(((((\".js-dm-conversation[data-thread-id=\" + a.threadId)) + \"]\")));\n                if (((d.length > 0))) {\n                    var e = d.JSBNG__find(((((\".js-dm-item[data-message-id=\" + c.messageId)) + \"]\")));\n                    switch (b) {\n                      case \"new\":\n                        if (e.length) {\n                            break;\n                        }\n                    ;\n                    ;\n                        d.append((new twttr.views.DirectMessageDialogConversationItem(c.message)).html()), d.animate({\n                            scrollTop: d.attr(\"scrollHeight\")\n                        }, 500);\n                        break;\n                      case \"delete\":\n                        e.remove();\n                    };\n                ;\n                    twttr.messageManager.markThreadAsRead(a.threadId);\n                }\n            ;\n            ;\n            },\n            _getCurrentView: function() {\n                return ((((this.$find(\".js-dm-threads\").length > 0)) ? twttr.widget.DirectMessageDialog.views.conversationList : ((((this.$find(\".js-dm-conversation\").length > 0)) ? twttr.widget.DirectMessageDialog.views.conversation : ((((this.$find(\".js-dm-new\").length > 0)) ? twttr.widget.DirectMessageDialog.views.newConversation : null))))));\n            },\n            _updateHeader: function(a) {\n                return this._replaceDivWithView(\".js-dm-header\", \"DirectMessageDialogHeader\", a);\n            },\n            _setProfileImageUrl: function(a) {\n                a = ((a || twttr.assets.path(\"sticky/default_profile_images/default_profile_6_mini.png\", {\n                    isVersioned: !1\n                }))), this.$find(\"img.js-dm-avatar\").attr(\"src\", a);\n            },\n            _updateContent: function(a, b) {\n                return this._replaceDivWithView(\".js-dm-content\", a, b);\n            },\n            _replaceDivWithView: function(a, b, c) {\n                return this.$find(a).html((new twttr.views[b](c)).html());\n            },\n            _hideTweetBox: function() {\n                this.$find(\".js-dm-tweetbox\").hide();\n            },\n            _showTweetBox: function(a) {\n                this.tweetBox.resetTweetContent(), this.$find(\".js-dm-tweetbox\").show();\n            },\n            _showError: function(a) {\n                var b = this.$find(\".js-dm-error\");\n                b.JSBNG__find(\".dm-error-text\").html(a), b.show();\n            },\n            _hideError: function() {\n                this.$find(\".js-dm-error\").hide();\n            },\n            _verifyUser: function() {\n                var a = this, b = this.$find(\".js-dm-user-autocomplete\").val();\n                this._hideError();\n                if (((!b || twttr.is.blank(b)))) {\n                    return;\n                }\n            ;\n            ;\n                if (!b.match(c.regexps.username)) {\n                    a._setProfileImageUrl(), a._showError(_(\"Whoops! That's not a valid username.\"));\n                    return;\n                }\n            ;\n            ;\n                twttr.API.User.JSBNG__find(b, {\n                    success: function(b) {\n                        twttr.currentUser.relationshipWith(b.screenName, function(c) {\n                            ((c.canDM ? a._setProfileImageUrl(b.profileImageUrl) : a._showError(_(\"You can't send a message to a user who is not following you.\"))));\n                        });\n                    },\n                    error: function(b) {\n                        a._setProfileImageUrl(), a._showError(_(\"Whoops! That user does not exist.\"));\n                    }\n                });\n            }\n        }).click({\n            \".js-dm-thread-link\": function(a) {\n                var b = $(a.currentTarget).attr(\"data-thread-id\");\n                this.switchToConversationView(b), a.preventDefault();\n            },\n            \".js-dm-header-title\": function(a) {\n                this.switchToConversationListView(), a.preventDefault();\n            },\n            \".js-dm-header-new\": function(a) {\n                this.switchToNewMessageView(), a.preventDefault();\n            },\n            \".js-dm-delete\": function(a) {\n                this.$find(\".js-dm-delete\").tipsy(\"hide\"), $(\"div.js-dm-tweetbox\").addClass(\"dm-deleting\");\n                var b = $(a.currentTarget).attr(\"data-message-id\"), c = \".js-dm-delete-confirm\";\n                this._replaceDivWithView(c, \"DirectMessageDeleteConfirm\", {\n                    messageId: b\n                }), $(c).show(), a.preventDefault();\n            },\n            \".js-dm-delete-confirm .js-prompt-ok\": function(a) {\n                var b = $(a.currentTarget).attr(\"data-message-id\"), c = this.$find(\".js-dm-conversation\").attr(\"data-thread-id\");\n                this.$find(((((\".js-dm-item[data-message-id=\" + b)) + \"]\"))).remove(), ((((this.$find(\".js-dm-item\").length == 0)) && this.switchToConversationListView())), $(\"div.js-dm-tweetbox\").removeClass(\"dm-deleting\"), twttr.messageManager.deleteMessage(b, c), this._trackClientDelete(b), a.preventDefault();\n            },\n            \".js-dm-delete-confirm .js-prompt-cancel\": function(a) {\n                var b = $(a.currentTarget).attr(\"data-message-id\");\n                this.$find(((((\".js-dm-item[data-message-id=\" + b)) + \"]\"))).hide(), $(\"div.js-dm-tweetbox\").removeClass(\"dm-deleting\"), a.preventDefault();\n            },\n            \".js-dm-error .js-dismiss\": function(a) {\n                this._hideError(), a.preventDefault();\n            }\n        }).JSBNG__focus({\n            \".twitter-anywhere-tweet-box-editor\": function(a) {\n                ((((this._getCurrentView() === twttr.widget.DirectMessageDialog.views.newConversation)) && (this._verifyUser(), ((this.autocomplete && this.autocomplete.hide())))));\n            }\n        });\n        a(e);\n    });\n});\nprovide(\"widget/MuteDialog\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.MuteDialog\", function() {\n            this.peoples = twttr.caches.User.get(\"muted\"), ((this.peoples || (this.peoples = {\n            })));\n            var a = {\n                fixed: !1,\n                draggable: !0,\n                modal: !1,\n                view: \"Dialog\",\n                template: {\n                    title: _(\"Mute a User\"),\n                    JSBNG__content: (new twttr.views.MuteUsers).html()\n                }\n            };\n            twttr.widget.Dialog.call(this, a);\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.autocomplete = new twttr.components.Autocomplete({\n                    input: this.$find(\".mute-input\"),\n                    limit: 10\n                }), this.currentSelection = {\n                }, this.autocomplete.bind(\"select\", function(b, c, d, e, f, g) {\n                    a.currentSelection.screenName = f, a.currentSelection.userId = g, a.currentSelection.profileImageUrl = e;\n                }), this.$dialog.delegate(\".remove-muted-person\", \"click\", function(b) {\n                    var c = $(this).parent(), d = c.attr(\"data-user-id\");\n                    delete a.peoples[d], twttr.caches.User.set(\"muted\", a.peoples), c.remove();\n                }), this.$find(\".mute-input,.twttr-dialog\").bind(\"keydown\", function(c) {\n                    ((((((c.keyCode === b.constants.keyCodes.enter)) && !twttr.components.Autocomplete._isCompletionsOpen)) && (c.stopPropagation(), a.fetchUser())));\n                }), this.$find(\".button\").bind(\"click\", function(b) {\n                    a.fetchUser();\n                }), this.populateUsers();\n            },\n            fetchUser: function() {\n                var a = this.$find(\"input[type=text]\");\n                twttr.API.User.JSBNG__find(a.val().toString(), twttr.bind(this, function(b) {\n                    a.val(\"\"), $(((((\".stream-tweet[data-user-id=\" + b.id)) + \"]\"))).parent().hide();\n                    var c = {\n                        screenName: b.screenName,\n                        userId: b.id,\n                        profileImageUrl: twttr.helpers.transformProfileImageUrl(b.profileImageUrl, \"mini\")\n                    };\n                    this.peoples[b.id] = c, twttr.caches.User.set(\"muted\", this.peoples), this.populateUsers();\n                }));\n            },\n            populateUsers: function() {\n                var a = [];\n                for (var b in this.peoples) {\n                    a.push(((((((((((((((((\"\\u003Cli data-user-id=\\\"\" + this.peoples[b].userId)) + \"\\\" data-user-screenname=\\\"\")) + this.peoples[b].screenName)) + \"\\\"\\u003E                  \\u003Cimg width=\\\"24\\\" height=\\\"24\\\" src=\\\"\")) + this.peoples[b].profileImageUrl)) + \"\\\"/\\u003E \")) + this.peoples[b].screenName)) + \" \\u003Cspan class=\\\"remove-muted-person\\\"\\u003E&times;\\u003C/span\\u003E\\u003C/li\\u003E\")));\n                ;\n                };\n            ;\n                a = a.join(\"\"), this.$find(\".muted-user-list\").html(a);\n            },\n            open: function() {\n                return twttr.widget.Dialog.prototype.open.call(this), this.$find(\"input[type=text]\").JSBNG__focus(), this;\n            },\n            close: function() {\n                return twttr.widget.Dialog.prototype.close.call(this), this.remove(), this;\n            }\n        }), a(twttr.widget.MuteDialog);\n    });\n});\nprovide(\"widget/DiscoveryDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.DiscoveryDialog\", function(a) {\n            twttr.widget.Dialog.call(this, twttr.merge({\n                modal: !0,\n                draggable: !1,\n                css: {\n                    width: 530\n                }\n            }, a));\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                twttr.widget.Dialog.prototype.registerEvents.call(this);\n                var a = this, b = this.$find(\"form\"), c = function() {\n                    b.JSBNG__find(\"input, textarea\").attr(\"disabled\", \"disabled\"), b.JSBNG__find(\".button\").addClass(\"disabled\");\n                }, d = function() {\n                    twttr.Router.performRedirect(twttr.router.homePath());\n                };\n                twttr.helpers.addFormEvents(b, function(e, f) {\n                    if (b.JSBNG__find(\".button\").hasClass(\"disabled\")) {\n                        return;\n                    }\n                ;\n                ;\n                    c(), twttr.currentUser.updateDiscoverability(f, {\n                        success: function(b) {\n                            twttr.currentUser.sync(\"JSBNG__name\", b.JSBNG__name), twttr.currentUser.sync(\"description\", b.description), twttr.currentUser.sync(\"JSBNG__location\", b.JSBNG__location), twttr.currentUser.sync(\"email_discoverability_set\", b.email_discoverability_set), twttr.currentUser.sync(\"mobile_phone_discoverability_set\", b.mobile_phone_discoverability_set), twttr.currentUser.sync(\"discoverable_by_email\", b.discoverable_by_email), twttr.currentUser.sync(\"discoverable_by_mobile_phone\", b.discoverable_by_mobile_phone), a.destroy(), d();\n                        },\n                        error: function(b) {\n                            twttr.showError(_(\"Whoops! Something went wrong. Please try again!\")), a.destroy();\n                        }\n                    });\n                }), this.$find(\".button.cancel\").bind(\"click\", function() {\n                    c(), d();\n                });\n            }\n        }), a(twttr.widget.DiscoveryDialog);\n    });\n});\nprovide(\"widget/GeoPromoDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.GeoPromoDialog\", function() {\n            twttr.widget.Dialog.call(this, {\n                template: {\n                    title: _(\"Add a location to your tweets\"),\n                    JSBNG__content: (new twttr.views.GeoPromoDialog).html()\n                },\n                view: \"Dialog\",\n                modal: !0,\n                stackPreviousModal: !0\n            });\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.$find(\"#geo_turn_location_on\").click(function() {\n                    a.enableGeoForCurrentUser();\n                }), this.$find(\".geo_dialog_close\").click(function(b) {\n                    b.preventDefault(), a.destroy();\n                });\n            },\n            enableGeoForCurrentUser: function() {\n                var a = this, b = $(\"#geo_promo_dialog_content .geo-progress\"), c = $(\"#geo_promo_dialog_content .geo-unable-to-turn-location-on\");\n                if (b.hasClass(\"geo-spinner\")) {\n                    return;\n                }\n            ;\n            ;\n                b.addClass(\"geo-spinner\"), c.hide(), twttr.currentUser.setGeoEnabled(!0, {\n                    success: function() {\n                        twttr.geo.geoEnabled = !0, a.destroy(), twttr.geo.JSBNG__location.turnLocationOn();\n                    },\n                    error: function() {\n                        b.removeClass(\"geo-spinner\"), c.show();\n                    }\n                });\n            }\n        }), a(twttr.widget.GeoPromoDialog);\n    });\n});\nprovide(\"widget/RetweetDialog\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.widget.RetweetDialog\", function(a) {\n            twttr.widget.RetweetDialog.uber.constructor.call(this, a), this.$dialog.attr(\"type\", \"retweet\"), this.$container.JSBNG__find(\".twttr-dialog-footer\").hide(), twttr.API.Status.JSBNG__find(this.options.data.tweetId, twttr.bind(this, function(b) {\n                var c = new twttr.views.ReplyDialogFooter({\n                    screen_name: b.user.screenName,\n                    text: a.tweetText,\n                    profile_image_url: b.user.profileImageUrl\n                });\n                c.render(this.$container.JSBNG__find(\".twttr-dialog-content\"), \"prepend\");\n            }));\n        }).subclassOf(twttr.widget.Prompt), a();\n    });\n});\nprovide(\"widget/TrendsDialog\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.widget.TrendsDialog\", function(a) {\n            var b = this, a = twttr.merge({\n                view: \"Dialog\",\n                destroyOnClose: !1,\n                template: {\n                    container_id: \"trends_dialog\"\n                }\n            }, a, !0);\n            a.template.title = ((twttr.decider.isAvailable(\"personalized_trends\") ? _(\"Trends\") : _(\"Choose a trend location\"))), twttr.widget.Dialog.call(b, a), b.resetChangeCount(), b.bind(\"close\", function() {\n                b.logClose();\n            }), b.bind(\"open\", function() {\n                trackClient({\n                    section: \"trends_location_dialog\",\n                    action: \"open\"\n                }), b.rerender();\n            }), this.initComponentEvents(this.$container), b.position();\n        }).subclassOf(twttr.widget.Dialog).mixin(twttr.mixins.componentEvents).methods({\n            resetChangeCount: function() {\n                this.changeCount = 0;\n            },\n            logClose: function() {\n                scribble(\"close-trend-location-dialog\", {\n                    woeid: twttr.trendLocations.current.woeid,\n                    change_count: this.changeCount,\n                    input: \"click\"\n                }), this.resetChangeCount();\n            },\n            updateFooter: function(a) {\n                var b = this.$find(\".twttr-dialog-footer\");\n                ((((((twttr.decider.isAvailable(\"personalized_trends\") && !twttr.trendLocations.current.isPersonalized)) || a)) ? (b.html((new twttr.views.TrendsDialogFooter).html()), b.show()) : b.hide()));\n            },\n            rerender: function(a) {\n                var b = this.$container.JSBNG__find(\".twttr-dialog-content\");\n                b.empty(), this.updateFooter(a), (new twttr.views.LocalTrendsNew(twttr.trendLocations.all, a)).render(b, \"append\"), this.markLocation();\n            },\n            registerEvents: function() {\n                var a = this;\n                twttr.widget.TrendsDialog.uber.constructor.prototype.registerEvents.call(a), a.$container.delegate(\"li a\", \"click\", function(b) {\n                    a.changeCurrentLocation($(this), \"dialog\"), b.preventDefault();\n                }), a.$container.delegate(\"a.trend-breadcrumb-location\", \"click\", function(b) {\n                    a.changeCurrentLocation($(this), \"dialog-breadcrumb\"), b.preventDefault();\n                });\n            },\n            position: function() {\n                ((this.options.fixed || this.$dialog.addClass(\"static\")));\n                var a = twttr.app.currentPage().$find(\".dashboard\");\n                if (((twttr.isT1 || ((a.length === 0))))) {\n                    var b = (((($(JSBNG__document).width() + this.$dialog.JSBNG__outerWidth())) / 2));\n                }\n                 else {\n                    var b = Math.max(a.offset().left, this.$dialog.JSBNG__outerWidth());\n                }\n            ;\n            ;\n                var c = $(window).scrollTop(), d = this.$dialog.JSBNG__innerHeight(), e = $(window).height(), f = Math.round(((((e / 2)) - ((d / 2)))));\n                f = Math.max(f, (($(\"#top-stuff\").JSBNG__innerHeight() + 1))), ((this.options.fixed || (f += c))), this.$container.css({\n                    left: ((b - this.$dialog.JSBNG__outerWidth())),\n                    JSBNG__top: f\n                });\n            },\n            changeCurrentLocation: function(a, b) {\n                if (a) {\n                    a.closest(\".twttr-dialog-content\").JSBNG__find(\".selected\").removeClass(\"selected\"), a.addClass(\"selected\");\n                    var c = parseInt(a.attr(\"data-woeid\"), 10);\n                }\n            ;\n            ;\n                twttr.trendLocations.setCurrent({\n                    isPersonalized: !c,\n                    woeid: c,\n                    origin: b\n                }), this.changeCount += 1;\n            },\n            markLocation: function() {\n                var a = twttr.trendLocations.current;\n                if (!a.isPersonalized) {\n                    var b = ((((a && a.woeid)) || 1));\n                    this.$container.JSBNG__find(((((\"[data-woeid=\" + b)) + \"]\"))).addClass(\"selected\");\n                }\n            ;\n            ;\n            }\n        }).click({\n            \".customize-by-location\": function() {\n                this.rerender(!0);\n            },\n            \"button.done\": function() {\n                this.close();\n            },\n            \".select-personalized\": function() {\n                this.changeCurrentLocation(null, \"dialog\"), this.close();\n            }\n        });\n        ((twttr.isT1 && c.methods({\n            position: twttr.util.noopInT1\n        }))), a(c);\n    });\n});\nprovide(\"widget/ReplyDialog\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.widget.ReplyDialog\", function(a) {\n            var a = twttr.merge({\n            }, twttr.dialogs.defaultOptions, a, {\n            }, !0);\n            twttr.widget.ReplyDialog.uber.constructor.call(this, a), this.$dialog.attr(\"type\", \"reply\");\n        }).subclassOf(twttr.widget.TweetDialog).statics({\n            openReplyDialog: !1\n        }).methods({\n            open: function() {\n                return ((this.constructor.openReplyDialog && this.constructor.openReplyDialog.close())), twttr.widget.TweetDialog.prototype.open.call(this), this.constructor.openReplyDialog = this, this.JSBNG__focus(), this;\n            },\n            JSBNG__focus: function() {\n                var a = this.view.tweetBox.editor.$editor.val().length, b = this.view.tweetBox.editor.$editor.val().length;\n                ((this.options.multiple && (a = ((this.options.data.screenName.length + 2))))), this.setCaretPosition(a, b);\n            }\n        }), a(twttr.widget.ReplyDialog);\n    });\n});\nprovide(\"widget/ListMembershipDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.ListMembershipDialog\", function(a, b) {\n            b = twttr.merge({\n                view: \"Dialog\",\n                modal: !0,\n                draggable: !0,\n                css: {\n                    width: 340,\n                    height: \"auto\"\n                },\n                positioning: {\n                    JSBNG__top: 80\n                },\n                template: {\n                    container_id: \"list_membership_dialog\",\n                    title: _(\"Your lists\"),\n                    JSBNG__content: (new twttr.views.AddToListDialog({\n                        screen_name: a.screenName\n                    })).html()\n                }\n            }, ((b || {\n            })), !0), this.makeListItems(a), twttr.widget.Dialog.call(this, b), this.addSpinner();\n        }).subclassOf(twttr.widget.Dialog).methods({\n            makeListItems: function(a) {\n                var b = this;\n                this.getListDialogItems(a, function(a) {\n                    ((b.spinner && b.spinner.hide())), ((((a.length > 1)) && b.$container.JSBNG__find(\".add-to-list-prompt\").show())), b.renderItems(a), b.attachHandlers(a);\n                });\n            },\n            addSpinner: function() {\n                this.spinner = $(\"\\u003Cspan class='spinner' title='{{_i}}Loading...{{/i}}'\\u003E\\u003C/span\\u003E\"), this.spinner.appendTo(this.$container.JSBNG__find(\".twttr-dialog-body\"));\n            },\n            attachHandlers: function(a) {\n                var b = this.$container.JSBNG__find(\".list-membership-container\").children();\n                for (var c = 0; ((c < a.length)); c++) {\n                    var d = a[c];\n                    if (!d.handlers) {\n                        continue;\n                    }\n                ;\n                ;\n                    $.each(d.handlers, function(a, d) {\n                        var e = $(b[c]), f = [a,d,];\n                        e.bind.apply(e, f);\n                    });\n                };\n            ;\n            },\n            renderItems: function(a) {\n                var b = twttr.map(a, function(a) {\n                    return (new twttr.views.CheckboxListItem(a)).html();\n                });\n                $(b.join(\"\")).appendTo(this.$container.JSBNG__find(\".list-membership-container\"));\n            },\n            getListDialogItems: function(a, b) {\n                var c = this;\n                twttr.currentUser.lists({\n                    count: twttr.currentUser.listsLimit,\n                    success: function(d) {\n                        var e = [], f = {\n                        }, g = function(f) {\n                            d.each(function(a) {\n                                e.push(i(a));\n                            }), e.push({\n                                label: _(\"Create a list\"),\n                                icon: \"list\",\n                                className: \"btn create-a-list\",\n                                handlers: {\n                                    click: function() {\n                                        c.destroy(), (new twttr.widget.ListDialog({\n                                            JSBNG__onSuccess: function(b) {\n                                                b.add(a, {\n                                                    success: function(a) {\n                                                        twttr.router.routeTo(twttr.router.userListPath({\n                                                            screen_name: twttr.currentUser.screenName,\n                                                            list_slug: b.slug\n                                                        }));\n                                                    },\n                                                    error: function(a) {\n                                                        twttr.helpers.showErrorFromResponse(a);\n                                                    }\n                                                });\n                                            }\n                                        })).open();\n                                    }\n                                }\n                            }), b(e);\n                        }, i = function(b) {\n                            return {\n                                label: h(b.JSBNG__name),\n                                id: b.id,\n                                user_is_member: f[b.id],\n                                is_private: ((b.mode === \"private\")),\n                                handlers: {\n                                    click: c.handler(b, a)\n                                }\n                            };\n                        };\n                        ((d.length() ? a.memberships({\n                            filter_to_owned_lists: !0,\n                            success: function(a) {\n                                a.each(function(a, b) {\n                                    f[a.id] = !0;\n                                }), g();\n                            }\n                        }) : g()));\n                    }\n                });\n            },\n            handler: function(a, b) {\n                return function(c) {\n                    c.stopPropagation(), c.preventDefault();\n                    var d = $(this).JSBNG__find(\"input[type=checkbox]\"), e = d.attr(\"data-is-checked\"), f = ((!!e && ((e === \"true\")))), g = $(this).JSBNG__find(\"img\");\n                    d.hide(), g.show();\n                    var i = ((f ? \"remove\" : \"add\"));\n                    a[i](b, {\n                        success: function() {\n                            twttr.widget.ListMembershipDialog.trigger(((i + \"ListMember\")), [a,b,]), d.attr(\"data-is-checked\", !f), d.attr(\"checked\", !f);\n                        },\n                        error: function() {\n                            d.attr(\"data-is-checked\", f), d.attr(\"checked\", f), twttr.showError(_(\"There was an error updating the list\"));\n                        },\n                        complete: function() {\n                            g.hide(), d.show();\n                        }\n                    });\n                };\n            }\n        }), a(twttr.widget.ListMembershipDialog);\n    });\n});\nprovide(\"widget/MiniProfileDialog\", function(a) {\n    using(\"components/ProfilePane\", \"components/RecentTweets\", function(b, c) {\n        twttr.klass(\"twttr.widget.MiniProfileDialog\", function(a, d) {\n            var e = this;\n            d = ((d || !1));\n            var f = \"\";\n            ((d && (f = \" js-unclickable unclickable\"))), twttr.widget.Dialog.call(this, {\n                modal: !0,\n                draggable: !0,\n                view: \"Dialog\",\n                closeOnNavigate: !0,\n                template: {\n                    container_id: \"mini-profile\",\n                    title: ((twttr.isT1 ? null : ((\"@\" + a.screenName)))),\n                    JSBNG__content: ((((\"\\u003Cdiv class='expando-profile-popup expanding-stream-item js-expando-profile-popup\" + f)) + \"'/\\u003E\"))\n                },\n                css: {\n                    width: 400\n                },\n                positioning: {\n                    JSBNG__top: 95\n                }\n            });\n            var g = new b(a), i = new c(a);\n            this.$find(\".js-expando-profile-popup\").append(g.$node).append(i.$node), this.$dialog.delegate(\".js-unclickable, .js-unclickable a\", \"click\", function(a) {\n                ((((((!$(a.target).hasClass(\"js-action-follow\") && !$(a.target).hasClass(\"js-action-unfollow\"))) && !$(a.target).hasClass(\"twttr-dialog-close\"))) && (a.stopPropagation(), a.preventDefault())));\n            }).delegate(\".js-mini-profile-user\", \"click\", function() {\n                JSBNG__setTimeout(function() {\n                    e.close();\n                }, 0);\n            });\n        }).subclassOf(twttr.widget.Dialog), a(twttr.widget.MiniProfileDialog);\n    });\n});\nprovide(\"widget/EmbedDialog\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.EmbedDialog\", function(a) {\n            return this.JSBNG__status = a, twttr.widget.Dialog.call(this, {\n                modal: !0,\n                fixed: !1,\n                draggable: !1,\n                destroyOnClose: !0,\n                positioning: {\n                    JSBNG__top: (($(window).scrollTop() + 100))\n                },\n                view: \"Dialog\",\n                template: {\n                    title: _(\"Embed this Tweet\"),\n                    JSBNG__content: (new twttr.views.EmbedDialog).html()\n                }\n            });\n        }).subclassOf(twttr.widget.Dialog).methods({\n            open: function() {\n                function a(a) {\n                    JSBNG__setTimeout(function() {\n                        z.select();\n                    }, 0), l();\n                };\n            ;\n                function b() {\n                    using(\"//platform.twitter.com/js/vendor/twt/dist/twt.all.min.js\", \"css!//platform.twitter.com/twt/twt.css\", function() {\n                        if (!window.twt) {\n                            return;\n                        }\n                    ;\n                    ;\n                        twt.settings.lang = u;\n                        var a = twt.tweet(p.JSBNG__status.attributes, {\n                            expandMedia: !0\n                        });\n                        ((p.JSBNG__status.isReply ? p.JSBNG__status.inReplyTo({\n                            success: function(b) {\n                                A.html(a.inReplyTo(b.attributes).html());\n                            },\n                            error: function() {\n                                A.html(a.html());\n                            }\n                        }) : A.html(a.html())));\n                    }).load();\n                };\n            ;\n                function c(a, b) {\n                    var c = b.JSBNG__find(\".active\");\n                    if (((c[0] == a[0]))) {\n                        return;\n                    }\n                ;\n                ;\n                    c.removeClass(\"active\"), a.addClass(\"active\");\n                };\n            ;\n                function d(a) {\n                    c($(this).prev(), $(a.delegateTarget)), m($(\"input:checked\", w).val()), i();\n                };\n            ;\n                function e(a) {\n                    a.preventDefault();\n                    var b = $(this);\n                    c(b, $(a.delegateTarget));\n                    var d = b.data().target;\n                    m(d), i();\n                };\n            ;\n                function f() {\n                    var a = {\n                        lang: u,\n                        target: $(\".active\", x).data().target,\n                        align: $(\"input:checked\", w).val()\n                    }, b = g(a);\n                    return a.success = j(b), a;\n                };\n            ;\n                function g(a) {\n                    return ((((a.lang + a.target)) + a.align));\n                };\n            ;\n                function i() {\n                    var a = f(), b = g(a), c = {\n                        html: ((((((((\"https://twitter.com/\" + p.JSBNG__status.user.screenName)) + \"/statuses/\")) + p.JSBNG__status.id)) + \"\"))\n                    };\n                    ((t++ || z.addClass(r).attr(r, r)));\n                    if (s[b]) {\n                        return a.success(s[b]);\n                    }\n                ;\n                ;\n                    if (((a.target == \"link\"))) {\n                        return a.success(c);\n                    }\n                ;\n                ;\n                    p.JSBNG__status.oembed(a);\n                };\n            ;\n                function j(b) {\n                    return function(c) {\n                        var d = f();\n                        s[b] = c, ((--t || z.val(s[g(d)].html).removeClass(r).removeAttr(r))), ((q && (q = !1, a())));\n                    };\n                };\n            ;\n                function k() {\n                    var a = {\n                        section: \"embed_code_dialog\",\n                        component: \"embed_tweet_code\",\n                        action: \"open\"\n                    };\n                    trackClient(a, twttr.audit.currentPage());\n                };\n            ;\n                function l() {\n                    var a = {\n                        section: \"embed_code_dialog\",\n                        component: \"embed_tweet_code\",\n                        action: \"JSBNG__focus\"\n                    };\n                    trackClient(a, twttr.audit.currentPage());\n                };\n            ;\n                function m(a) {\n                    var b = {\n                        section: \"embed_code_dialog\",\n                        component: \"embed_tweet_code\",\n                        action: ((\"target_\" + a))\n                    };\n                    trackClient(b, twttr.audit.currentPage());\n                };\n            ;\n                function n(a) {\n                    var b = {\n                        section: \"embed_code_dialog\",\n                        component: \"embed_tweet_code\",\n                        action: ((\"align_\" + a))\n                    };\n                    trackClient(b, twttr.audit.currentPage());\n                };\n            ;\n                function o(a) {\n                    var b = {\n                        section: \"embed_code_dialog\",\n                        component: \"embed_tweet_code\",\n                        action: ((\"language_\" + a))\n                    };\n                    trackClient(b, twttr.audit.currentPage());\n                };\n            ;\n                var p = this, q = !0, r = \"disabled\", s = {\n                }, t = 0, u;\n                twttr.widget.Dialog.prototype.open.call(this);\n                for (var v = twttr.languages.length; v--; ) {\n                    if (twttr.languages[v].current) {\n                        u = twttr.languages[v].code;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                var w = this.$container, x = w.JSBNG__find(\".embed-target\"), y = w.JSBNG__find(\".embed-alignment\"), z = w.JSBNG__find(\"textarea\"), A = w.JSBNG__find(\".embed-preview\");\n                return i(), b(), k(), o(u), x.delegate(\"a\", \"click\", e), y.delegate(\"input\", \"click\", d), z.JSBNG__focus(a), this;\n            },\n            destroy: function() {\n                twttr.widget.Dialog.prototype.destroy.call(this), twttr.router.unbind(\"urlChanged\", this.urlChangedListener), twttr.router.routeTo(twttr.router.permalinkPath({\n                    screen_name: this.JSBNG__status.user.screenName,\n                    id: this.JSBNG__status.id\n                }));\n            }\n        }), a(twttr.widget.EmbedDialog);\n    });\n});\nprovide(\"components/pages/mixins/searchT1\", function(a) {\n    using(\"mixins/sideNavigationT1\", \"components/t1/SearchHeader\", \"components/t1/dashboard/SearchNav\", \"components/SignupCallOut\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.components.pages.mixins.searchT1\", function() {\n            this.mixin(b.mixins.sideNavigationT1).view(twttr.views.SearchPage).addOnSwitchAway(function() {\n                this.removeSearchHeader(), this.removeSearchAssistance();\n            }).addOnSwitchTo(function() {\n                this.registerSearchAssistanceDecider(), ((this.$node.JSBNG__find(\".js-search-header\").length || this.addSearchHeader()));\n            }).addAfterRender(function() {\n                ((this.isNewSearchHeaderAvailable() ? (this.setQuery(this._query), this.focusQuery()) : (this.addSearchHeader(), $(\"#search-query\").val(\"\"))));\n            }).methods({\n                getDashboardComponents: function() {\n                    var a = [];\n                    return ((twttr.loggedIn || a.push(new b.components.SignupCallOut(\"search\", {\n                        query: this._query\n                    })))), this._nav = new b.components.t1.dashboard.SearchNav(this._query), this.trendsComponent = ((this.trendsComponent || new twttr.components.Trends)), a.concat([this._nav,this.trendsComponent,new twttr.components.Footer,]);\n                },\n                noAutoRender: !0,\n                people: function(a, c) {\n                    var d = ((a.query || c.q)), e = ((this._query !== d));\n                    this._query = d;\n                    if (!d) {\n                        return this.routePageTo(this.PATH_ROOT);\n                    }\n                ;\n                ;\n                    ((this.streamManager || this.render({\n                        query: d,\n                        pretty_query: d,\n                        has_relevance_search: !1,\n                        top_mode: !1,\n                        all_mode: !1,\n                        timeline_mode: !1,\n                        with_links_mode: !1\n                    }))), this.streamManager.switchTo(twttr.streams.PeopleSearch, {\n                        query: d,\n                        pathRoot: this.PATH_ROOT,\n                        hideTitle: !1\n                    });\n                    if (e) {\n                        var f = new b.components.t1.dashboard.SearchNav(this._query);\n                        this._nav.$node.replaceWith(f.$node), delete this._nav, this._nav = f;\n                    }\n                ;\n                ;\n                    this.setQuery(d), this.focusQuery(), this.selectCurrentSideNav(), this.removeOnebox(), this.removeSearchAssistance(), this.updatePageTitle(_(\"Twitter / User Search\"));\n                },\n                registerSearchAssistanceDecider: function() {\n                    if (twttr.decider.isAvailable(\"search_assistance\")) {\n                        this._isNewSearchHeaderAvailable = !0, this._isSearchAssistanceAvailable = !0;\n                        return;\n                    }\n                ;\n                ;\n                    var a = twttr.abdecider.choose(\"search_assistance_192\");\n                    this._isNewSearchHeaderAvailable = ((((a === \"no_header_no_assistance\")) || ((a === \"no_header_with_assistance\")))), this._isSearchAssistanceAvailable = ((a === \"no_header_with_assistance\"));\n                },\n                isNewSearchHeaderAvailable: function() {\n                    return !!this._isNewSearchHeaderAvailable;\n                },\n                isSearchAssistanceAvailable: function() {\n                    return !!this._isSearchAssistanceAvailable;\n                },\n                renderRelatedQueries: function(a) {\n                    if (((!$.isArray(a) || !a.length))) {\n                        return;\n                    }\n                ;\n                ;\n                    var b = a.length, c = [], d = [];\n                    for (var e = 0; ((e < b)); e++) {\n                        c[e] = {\n                            search_query_source: twttr.search.searchQuerySource.RELATED_QUERY,\n                            query: this._query,\n                            related_query: a[e].query,\n                            url: twttr.router.searchResultsPath({\n                                query: a[e].query\n                            }),\n                            delimiter: ((((e < ((b - 1)))) ? \", \" : \"\"))\n                        }, d[e] = a[e].query;\n                    ;\n                    };\n                ;\n                    this.$find(\".js-search-header\").append((new twttr.views.RelatedQueries({\n                        related_queries: c\n                    })).html()), trackClient({\n                        section: \"search\",\n                        component: \"related_queries\",\n                        action: \"impression\"\n                    }, {\n                        query: this._query,\n                        item_count: d.length,\n                        item_names: d\n                    });\n                },\n                renderSpellingCorrections: function(a) {\n                    if (((!$.isArray(a) || !a.length))) {\n                        return;\n                    }\n                ;\n                ;\n                    var b = a[0].query, c = [];\n                    if (((a[0].indices && a[0].indices.length))) {\n                        var d = a[0].indices, e = 0, f = b.length;\n                        for (var g = 0; ((g < d.length)); g++) {\n                            c[g] = {\n                                nonhighlighted: b.substring(e, d[g][0]),\n                                highlighted: b.substring(d[g][0], d[g][1])\n                            }, e = d[g][1];\n                        ;\n                        };\n                    ;\n                        c[d.length] = {\n                            nonhighlighted: b.substring(e, f),\n                            highlighted: \"\"\n                        };\n                    }\n                     else c[0] = {\n                        nonhighlighted: \"\",\n                        highlighted: b\n                    };\n                ;\n                ;\n                    this.$find(\".js-stream-header\").before((new twttr.views.SpellingCorrections({\n                        query: this._query,\n                        correction: b,\n                        partitions: c,\n                        url: twttr.router.searchResultsPath({\n                            query: b\n                        }),\n                        search_query_source: twttr.search.searchQuerySource.SPELLING_CORRECTION\n                    })).html()), trackClient({\n                        section: \"search\",\n                        component: \"spelling_corrections\",\n                        action: \"impression\"\n                    }, {\n                        query: this._query,\n                        item_count: a.length,\n                        item_names: a\n                    });\n                },\n                removeSearchAssistance: function() {\n                    this.$find(\".js-spelling-corrections\").remove(), this.$find(\".js-related-queries\").remove();\n                },\n                addSearchHeader: function() {\n                    ((this.isNewSearchHeaderAvailable() || (this._header = new b.components.t1.SearchHeader(this._query), this.$node.prepend(this._header.$node))));\n                },\n                removeSearchHeader: function() {\n                    ((this.isNewSearchHeaderAvailable() || ((this._header && this._header.destroy()))));\n                },\n                setupSavedSearchAction: function() {\n                    var a = twttr.search.isSavedSearch(this._query);\n                    ((a ? this.toggleSavedSearchOn(a) : this.toggleSavedSearchOff()));\n                },\n                toggleSavedSearchOn: function(a) {\n                    ((this.isNewSearchHeaderAvailable() ? (this.$find(\".js-toggle-saved-search-link\").html(_(\"Remove saved search\")).addClass(\"saved\").removeClass(\"not-saved\"), this.$find(\".js-search-title\").html(Mustache.to_html(_(\"Saved search: \\u003Cstrong class=\\\"search-query\\\"\\u003E{{query}}\\u003C/strong\\u003E\"), {\n                        query: this._query\n                    }))) : this._header.toggleSavedSearchOn())), this._savedSearch = a;\n                },\n                toggleSavedSearchOff: function() {\n                    ((this.isNewSearchHeaderAvailable() ? (this.$find(\".js-toggle-saved-search-link\").html(_(\"Save search\")).addClass(\"not-saved\").removeClass(\"saved\"), this.$find(\".js-search-title\").html(Mustache.to_html(_(\"Results for \\u003Cstrong class=\\\"search-query\\\"\\u003E{{query}}\\u003C/strong\\u003E\"), {\n                        query: this._query\n                    }))) : this._header.toggleSavedSearchOff())), this._savedSearch = null;\n                },\n                showSearchMenu: function(a) {\n                    var b = this;\n                    a.addClass(\"open\"), $(JSBNG__document).bind(\"click.button\", function() {\n                        b.hideSearchMenu(a);\n                    });\n                },\n                hideSearchMenu: function(a) {\n                    a.removeClass(\"open\"), $(JSBNG__document).unbind(\"click.button\");\n                },\n                toggleSearchMenu: function(a) {\n                    var b = this.$node.JSBNG__find(\".js-search-dropdown\");\n                    ((b.hasClass(\"open\") ? this.hideSearchMenu(b) : this.showSearchMenu(b)));\n                },\n                setQuery: function(a) {\n                    ((this.isNewSearchHeaderAvailable() ? $(\"#search-query\").val(a) : this._header.setQuery(a)));\n                },\n                focusQuery: function() {\n                    ((this.isNewSearchHeaderAvailable() ? ($(\"#search-query\").addClass(\"JSBNG__focus\"), $(\"#search-query\").JSBNG__blur()) : this._header.focusQuery()));\n                },\n                addDropdownMenu: twttr.util.noopInT1,\n                renderPeopleResults: twttr.util.noopInT1,\n                renderOneboxContainer: function(a) {\n                    this.$find(\".js-onebox-container\").html(a.$node);\n                },\n                removeOnebox: function() {\n                    this.$find(\".js-onebox-container\").empty();\n                },\n                addImpressionData: function(a) {\n                    a.query = this._query;\n                }\n            }).click({\n                \"a.js-toggle-saved-search-link\": function(a, b) {\n                    ((this._savedSearch ? twttr.dialogs.deleteSavedSearch(twttr.bind(this, function(a) {\n                        if (a) {\n                            var b = this._savedSearch;\n                            this._savedSearch.destroy({\n                                before: twttr.bind(this, this.toggleSavedSearchOff),\n                                error: twttr.bind(this, function() {\n                                    this.toggleSavedSearchOn(b), twttr.showError(_(\"Error deleting search\"));\n                                })\n                            });\n                        }\n                    ;\n                    ;\n                    })).open() : twttr.currentUser.savedSearches.create(this._query, {\n                        before: twttr.bind(this, this.toggleSavedSearchOn),\n                        error: twttr.bind(this, function() {\n                            this.toggleSavedSearchOff(), twttr.showError(_(\"Error saving search\"));\n                        })\n                    }))), a.preventDefault();\n                },\n                \"button.js-search-dropdown-button\": function(a, b) {\n                    return this.toggleSearchMenu(), a.preventDefault(), a.stopPropagation(), !1;\n                },\n                \"div.js-related-queries a\": function(a, b) {\n                    trackClient({\n                        section: \"search\",\n                        component: \"related_queries\",\n                        action: \"search\"\n                    }, {\n                        query: b.data(\"query\"),\n                        item_names: [b.data(\"search-assistance\"),]\n                    });\n                },\n                \"div.js-spelling-corrections a\": function(a, b) {\n                    trackClient({\n                        section: \"search\",\n                        component: \"spelling_corrections\",\n                        action: \"search\"\n                    }, {\n                        query: b.data(\"query\"),\n                        item_names: [b.data(\"search-assistance\"),]\n                    });\n                },\n                \"div.js-spelling-corrections div.js-action-dismiss\": function(a, b) {\n                    this.$find(\".js-spelling-corrections\").animate({\n                        opacity: \"0\"\n                    }, 250).slideUp(), trackClient({\n                        section: \"search\",\n                        component: \"spelling_corrections\",\n                        action: \"dismiss\"\n                    }, {\n                        query: b.data(\"query\"),\n                        item_names: [b.data(\"search-assistance\"),]\n                    });\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/pages/ProfileAbstract\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.page(\"twttr.components.pages.ProfileAbstract\").subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage, twttr.mixins.profileHelper).methods({\n            _addAdminTools: function() {\n                if (((twttr.admin && !twttr.helpers.isCurrentUser(this.profileUser)))) {\n                    var a = this;\n                    using(\"\\u003EdefaultViews\", function() {\n                        twttr.admin.addToolsFor(a.profileUser.screenName, a.profileUser.id);\n                    });\n                }\n            ;\n            ;\n            },\n            _highlightNavIfCurrentUser: function(a) {\n                twttr.app.highlightGlobalNav(\"profile\", twttr.helpers.isCurrentUser(a));\n            },\n            _switchToStream: function(a, b) {\n                var c = this;\n                this.unfocusStreamItem(), this.loading(a.screenName), this.getUserInfo(a.screenName, function() {\n                    c._addPromotedData(), ((((!c._renderedScreenName || ((c._renderedScreenName.toLowerCase() !== a.screenName)))) ? c._renderPage() : twttr.themes.loadUserStyleFor(c.profileUser))), c.streamManager.switchTo(a.stream, twttr.merge({\n                        canViewUser: twttr.helpers.canViewUser(c.profileUser)\n                    }, a), b), twttr.components.JapaneseAd.refreshAds(), c.trigger(\"switchedToStream\");\n                }, {\n                    batch: !twttr.loggedIn\n                }, twttr.bind(this, this.noUserFoundCallback)), this.focusStreamTab(a.tab), ((twttr.isT1 || trackClient({\n                    action: \"impression\"\n                }, {\n                    profile_id: ((twttr.profileUser && twttr.profileUser.id)),\n                    context: \"profile\"\n                })));\n            },\n            loading: function(a) {\n                a = a.toLowerCase();\n                if (this.preRendered) {\n                    this.preRenderedScreenName = this.$find(\"div.profile-header\").attr(\"data-screen-name\").toLowerCase();\n                    if (((this.preRenderedScreenName == a))) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                if (((!this._renderedScreenName || ((this._renderedScreenName.toLowerCase() !== a))))) {\n                    ((((this.streamManager && this.streamManager.getCurrent())) && this.streamManager.getCurrent().$node.detach())), this.$node.children().empty(), $(\"div.tipsy\").remove();\n                }\n            ;\n            ;\n            },\n            _renderPage: function() {\n                ((((this.profileUser.screenName.toLowerCase() !== this.preRenderedScreenName)) && twttr.themes.loadUserStyleFor(this.profileUser))), this._addAdminTools(), this.render({\n                    can_view: twttr.helpers.canViewUser(this.profileUser),\n                    screen_name: this.profileUser.screenName,\n                    social_context: this._isSocialContextAvailable()\n                }), this._renderedScreenName = this.profileUser.screenName, this.renderUserInfo(), this._followingDropDown = null, this._followersDropDown = null;\n            },\n            noAutoRender: !0\n        });\n        ((twttr.isT1 ? c.methods({\n            renderUserInfo: twttr.util.noopInT1\n        }) : c.methods({\n            renderUserInfo: function() {\n                var a = this, b = this.profileUser;\n                this.panes.push(new twttr.views.Dashboard(\"profile.dashboard\", b.attributes));\n                var c = new twttr.components.ProfileActions(b);\n                c.$node.appendTo(this.$find(\".profile-actions-container\"));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/pages/Search\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"components/pages/mixins/searchT1\" : \"components/pages/mixins/searchP1\")), \"util\", \"constants\").as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.components.pages.Search\").subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage).view(twttr.views.SearchPage).addOnSwitchAway(function() {\n            twttr.search.clear(), ((this.trendsComponent && this.trendsComponent.stopUpdatePolling()));\n        }).addOnSwitchTo(function() {\n            twttr.themes.loadCurrentUserStyle(), ((this.trendsComponent && this.trendsComponent.startUpdatePolling()));\n        }).addAfterRender(function() {\n            this.addDashboardComponents(this.getDashboardComponents()), ((this.trendsComponent && this.trendsComponent.registerEventHandlers()));\n        }).statics({\n            addSearchClickLogging: function(a, b) {\n                if (a.length) {\n                    var c = {\n                    };\n                    b.tweet_click_info = c, c.tweet_id = a.attr(\"data-tweet-id\"), c.pos = a.closest(\".stream-item\").prevAll(\".stream-item\").length, c.type = ((a.is(\".promoted-tweet\") ? \"promoted\" : ((a.is(\".top-tweet\") ? \"popular\" : \"recent\"))));\n                }\n            ;\n            ;\n            }\n        }).methods({\n            realtime: function(a, b) {\n                var c = ((a.query || b.q));\n                ((twttr.decider.isAvailable(\"phoenix_search_relevance\") ? this.updatePageTitle(_(\"Twitter / Search - {{{query}}} - All Tweets\", {\n                    query: c\n                })) : this.updatePageTitle(_(\"Twitter / Search - {{{query}}}\", {\n                    query: c\n                })))), this.enterMode(c, \"tweets\");\n            },\n            timeline: function(a, b) {\n                var c = ((a.query || b.q)), d = _(\"Twitter / Timeline Search - {{{query}}}\", {\n                    query: c\n                });\n                ((((twttr.abdecider.choose(\"timeline_copy_317\") === \"stream\")) && (d = _(\"Twitter / Stream Search - {{{query}}}\", {\n                    query: c\n                })))), this.updatePageTitle(d), this.enterMode(c, \"timeline\");\n            },\n            links: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.search({\n                        query: \"links\"\n                    });\n                }\n            ;\n            ;\n                this.updatePageTitle(_(\"Twitter / Search - {{{query}}} - Tweets with links\", {\n                    query: c\n                })), this.enterMode(c, \"links\");\n            },\n            searchShow: function(a, b) {\n                if (((twttr.decider.isAvailable(\"swift_events\") && twttr.decider.isAvailable(\"swift_events_search\")))) {\n                    var c = twttr.griffin.isEvent(a.query);\n                    twttr.griffin.setNoRedirectOnSearch(c, !0);\n                }\n            ;\n            ;\n                this.search(a, b);\n            },\n            search: function(a, b) {\n                if (((((!twttr.currentUser && !twttr.decider.isAvailable(\"phoenix_search_relevance_logged_out\"))) || ((twttr.currentUser && !twttr.decider.isAvailable(\"phoenix_search_relevance\")))))) {\n                    this.realtime(a, b);\n                    return;\n                }\n            ;\n            ;\n                ((((((b && ((b.partner == \"mozilla\")))) && ((b.source == \"desktop-search\")))) && (a.query = a.query.replace(/\\+/g, \" \")))), this.query = ((a.query || b.q)), ((((this.query === !0)) && (this.query = !1))), this.updatePageTitle(_(\"Twitter / Search - {{{query}}}\", {\n                    query: this.query\n                })), this.enterMode(this.query, \"relevance\", b);\n            },\n            placeTweetSearch: function(a) {\n                var b = a.place_name, c = a.place_id;\n                this.updatePageTitle(_(\"Twitter / Tweets at {{placeName}}\", {\n                    placeName: b\n                })), this._placeName = b, this.enterMode(((\"place:\" + c)), \"placeTweetSearch\");\n            },\n            noAutoRender: !0,\n            enterMode: function(a, b, c) {\n                twttr.search.latestQuery = a, c = ((c || {\n                }));\n                if (!a) {\n                    twttr.router.redirectTo(twttr.router.searchHomePath());\n                    return;\n                }\n            ;\n            ;\n                ((twttr.isT1 || trackClient({\n                    action: \"impression\"\n                }, {\n                    query: a\n                }))), this.unfocusStreamItem(), twttr.SearchAPI.flushCache();\n                var d = this;\n                d._mode = b;\n                if (((a !== this._query))) {\n                    this._query = a, ((((!twttr.isT1 && twttr.loggedIn)) && (this.setupSavedSearchAction(), this.registerSavedSearchListeners()))), ((this.streamManager && this.streamManager.$node.detach()));\n                    var e = !1;\n                    ((twttr.currentUser ? e = twttr.decider.isAvailable(\"phoenix_search_relevance\") : e = twttr.decider.isAvailable(\"phoenix_search_relevance_logged_out\")));\n                    var f = ((b == \"placeTweetSearch\"));\n                    this.render({\n                        query: a,\n                        pretty_query: ((((f && this._placeName)) || a)),\n                        has_relevance_search: e,\n                        top_mode: ((b == \"relevance\")),\n                        all_mode: ((b == \"tweets\")),\n                        timeline_mode: ((b == \"timeline\")),\n                        with_links_mode: ((b == \"links\"))\n                    });\n                }\n                 else ((twttr.decider.isAvailable(\"phoenix_search_dropdown\") && this.$find(\".stream-tabs\").empty().append((new twttr.views.SearchPageTabs({\n                    top_mode: ((b == \"relevance\")),\n                    all_mode: ((b == \"tweets\")),\n                    timeline_mode: ((b == \"timeline\")),\n                    with_links_mode: ((b == \"links\"))\n                })).html())));\n            ;\n            ;\n                ((twttr.decider.isAvailable(\"phoenix_search_dropdown\") && this.addDropdownMenu(this._query, this.$find(\".stream-tab-dropdown\")))), this.streamManager.switchTo(twttr.streams.Search, {\n                    query: a,\n                    pretty_query: ((this._placeName || a)),\n                    mode: b,\n                    hideTitle: !0,\n                    debug: c.debug,\n                    experimentId: c.experimentId,\n                    is_new_search_header_available: this.isNewSearchHeaderAvailable()\n                }), this.focusStreamTab(b), this.focusQuery(a), ((((twttr.router.getCurrentRoute().JSBNG__name === \"searchRealtime\")) ? this.selectSideNav(\"searchResults\") : this.selectCurrentSideNav())), ((((twttr.isT1 && twttr.loggedIn)) && (this.setupSavedSearchAction(), this.registerSavedSearchListeners()))), this.addSearchExtras(), this.renderPeopleResults();\n            },\n            focusQuery: function(a) {\n                twttr.search.focusQuery(a);\n            },\n            isNewSearchHeaderAvailable: function() {\n                return !1;\n            },\n            isSearchAssistanceAvailable: function() {\n                return !1;\n            },\n            removeSearchAssistance: $.noop,\n            isOneboxAvailable: function() {\n                return ((!!this._query && twttr.decider.isAvailable(\"JSBNG__onebox\")));\n            },\n            renderOnebox: function(a) {\n                if (((a.length() === 0))) {\n                    return;\n                }\n            ;\n            ;\n                var c, d = a.get(0), e = twttr.components.JSBNG__onebox[b.util.capitalize(d.type)];\n                if (!e) {\n                    return;\n                }\n            ;\n            ;\n                var c = new e(d, this._query);\n                if (((!c || ((c.$node.children().size() == 0))))) {\n                    return;\n                }\n            ;\n            ;\n                this.renderOneboxContainer(c, d), this.$find(\"div.JSBNG__onebox\").show(), c.render();\n                var f = ((c.items || []));\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: d.type,\n                    action: \"impression\"\n                }, {\n                    item_count: f.length,\n                    item_ids: f,\n                    query: this._query\n                });\n            },\n            addSearchExtras: function() {\n                var a = this, b = a.isSearchAssistanceAvailable(), c = a.isOneboxAvailable();\n                if (((!c && !b))) {\n                    return;\n                }\n            ;\n            ;\n                ((c && this.$find(\"div.JSBNG__onebox\").hide()));\n                var d = twttr.search.getLastQuerySource(), e = {\n                    is_t1: twttr.isT1,\n                    statuses: !1,\n                    stories: c,\n                    related_queries: b,\n                    spelling_corrections: b,\n                    query_source: d,\n                    success: function(d) {\n                        a.removeSearchAssistance(), ((c && a.renderOnebox(d.stories))), ((b && (((d.spellingCorrections && a.renderSpellingCorrections(d.spellingCorrections))), ((((!d.spellingCorrections.length && d.relatedQueries)) && a.renderRelatedQueries(d.relatedQueries))))));\n                    }\n                };\n                ((this._query && twttr.API.Search.search(this._query, e)));\n            },\n            setupSavedSearchAction: function() {\n                var a = this;\n                twttr.currentUser.savedSearches(function(b) {\n                    var c = b.filter(function(b) {\n                        return ((b.query === a._query));\n                    });\n                    ((c.length() ? a.toggleSavedSearchOn(c.first()) : a.toggleSavedSearchOff()));\n                });\n            },\n            registerSavedSearchListeners: function() {\n                var a = this;\n                twttr.API.SavedSearch.bind(\"create\", function(b, c) {\n                    ((((c.query == a._query)) && a.toggleSavedSearchOn(c)));\n                }), twttr.API.SavedSearch.bind(\"delete\", function(b, c) {\n                    ((((c.query == a._query)) && a.toggleSavedSearchOff()));\n                });\n            },\n            _getSearchHandlers: function(a, b) {\n                return {\n                    click: function() {\n                        twttr.router.routeTo(twttr.router[b]({\n                            query: a\n                        }));\n                    }\n                };\n            }\n        });\n        d.mixin(c), a(d);\n    });\n});\nprovide(\"components/pages/SearchHome\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.page(\"twttr.components.pages.SearchHome\").view(twttr.views.SearchHome).click({\n            \".operators a:not(.advanced-search)\": function(a) {\n                a.preventDefault(), twttr.dialogs.searchOperators().open();\n            },\n            \".operators a.advanced-search\": function(a) {\n                twttr.search.latestQuery = this.$find(\"input:text[name=q]\").val();\n            }\n        }).addAfterRender(function() {\n            this.$find(\".bottompart\").append((new twttr.components.Footer).$node);\n        }).addOnSwitchTo(function() {\n            twttr.themes.clear();\n        }).methods({\n            noAutoRender: !0,\n            initSearchForm: function() {\n                var a = this.$find(\".search form\"), b = a.is(\".advanced-search form\");\n                twttr.helpers.addFormEvents(a, function(a, c) {\n                    var d = $(this), e = ((b ? twttr.search.serializeAdvancedForm(d) : c.q));\n                    ((e ? (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch(e)) : twttr.showMessage(_(\"Enter your query before submitting the search form!\"))));\n                }), twttr.search.formifyLatestQuery(a);\n                if (b) {\n                    var c = a.JSBNG__find(\"input[name=near]\"), d = a.JSBNG__find(\"fieldset.geo div.sel\");\n                    ((c.val() ? d.show() : c.JSBNG__one(\"keyup change\", function() {\n                        d.slideDown();\n                    })));\n                }\n            ;\n            ;\n            },\n            languages: function() {\n                return this.searchLanguages().sort(function(a, b) {\n                    return a = a.localized_name.toLowerCase(), b = b.localized_name.toLowerCase(), ((((a == b)) ? 0 : ((((a < b)) ? -1 : 1))));\n                });\n            },\n            searchLanguages: function() {\n                return [{\n                    code: \"am\",\n                    localized_name: _(\"Amharic\"),\n                    JSBNG__name: \"\\u12a0\\u121b\\u122d\\u129b\"\n                },{\n                    code: \"ar\",\n                    localized_name: _(\"Arabic\"),\n                    JSBNG__name: \"\\u0627\\u0644\\u0639\\u0631\\u0628\\u064a\\u0629\"\n                },{\n                    code: \"bg\",\n                    localized_name: _(\"Bulgarian\"),\n                    JSBNG__name: \"\\u0411\\u044a\\u043b\\u0433\\u0430\\u0440\\u0441\\u043a\\u0438\"\n                },{\n                    code: \"bn\",\n                    localized_name: _(\"Bengali\"),\n                    JSBNG__name: \"\\u09ac\\u09be\\u0982\\u09b2\\u09be\"\n                },{\n                    code: \"bo\",\n                    localized_name: _(\"Tibetan\"),\n                    JSBNG__name: \"\\u0f56\\u0f7c\\u0f51\\u0f0b\\u0f66\\u0f90\\u0f51\"\n                },{\n                    code: \"chr\",\n                    localized_name: _(\"Cherokee\"),\n                    JSBNG__name: \"\\u13e3\\u13b3\\u13a9\"\n                },{\n                    code: \"da\",\n                    localized_name: _(\"Danish\"),\n                    JSBNG__name: \"Dansk\"\n                },{\n                    code: \"de\",\n                    localized_name: _(\"German\"),\n                    JSBNG__name: \"Deutsch\"\n                },{\n                    code: \"dv\",\n                    localized_name: _(\"Maldivian\"),\n                    JSBNG__name: \"\\u078b\\u07a8\\u0788\\u07ac\\u0780\\u07a8\"\n                },{\n                    code: \"el\",\n                    localized_name: _(\"Greek\"),\n                    JSBNG__name: \"\\u0395\\u03bb\\u03bb\\u03b7\\u03bd\\u03b9\\u03ba\\u03ac\"\n                },{\n                    code: \"en\",\n                    localized_name: _(\"English\"),\n                    JSBNG__name: \"English\"\n                },{\n                    code: \"es\",\n                    localized_name: _(\"Spanish\"),\n                    JSBNG__name: \"Espa\\u00f1ol\"\n                },{\n                    code: \"fa\",\n                    localized_name: _(\"Persian\"),\n                    JSBNG__name: \"\\u0641\\u0627\\u0631\\u0633\\u06cc\"\n                },{\n                    code: \"fi\",\n                    localized_name: _(\"Finnish\"),\n                    JSBNG__name: \"Suomi\"\n                },{\n                    code: \"fr\",\n                    localized_name: _(\"French\"),\n                    JSBNG__name: \"Fran\\u00e7ais\"\n                },{\n                    code: \"gu\",\n                    localized_name: _(\"Gujarati\"),\n                    JSBNG__name: \"\\u0a97\\u0ac1\\u0a9c\\u0ab0\\u0abe\\u0aa4\\u0ac0\"\n                },{\n                    code: \"iw\",\n                    localized_name: _(\"Hebrew\"),\n                    JSBNG__name: \"\\u05e2\\u05d1\\u05e8\\u05d9\\u05ea\"\n                },{\n                    code: \"hi\",\n                    localized_name: _(\"Hindi\"),\n                    JSBNG__name: \"\\u0939\\u093f\\u0902\\u0926\\u0940\"\n                },{\n                    code: \"hu\",\n                    localized_name: _(\"Hungarian\"),\n                    JSBNG__name: \"Magyar\"\n                },{\n                    code: \"hy\",\n                    localized_name: _(\"Armenian\"),\n                    JSBNG__name: \"\\u0540\\u0561\\u0575\\u0565\\u0580\\u0565\\u0576\"\n                },{\n                    code: \"in\",\n                    localized_name: _(\"Indonesian\"),\n                    JSBNG__name: \"Bahasa Indonesia\"\n                },{\n                    code: \"is\",\n                    localized_name: _(\"Icelandic\"),\n                    JSBNG__name: \"\\u00cdslenska\"\n                },{\n                    code: \"it\",\n                    localized_name: _(\"Italian\"),\n                    JSBNG__name: \"Italiano\"\n                },{\n                    code: \"iu\",\n                    localized_name: _(\"Inuktitut\"),\n                    JSBNG__name: \"\\u1403\\u14c4\\u1483\\u144e\\u1450\\u1466\"\n                },{\n                    code: \"ja\",\n                    localized_name: _(\"Japanese\"),\n                    JSBNG__name: \"\\u65e5\\u672c\\u8a9e\"\n                },{\n                    code: \"ka\",\n                    localized_name: _(\"Georgian\"),\n                    JSBNG__name: \"\\u10e5\\u10d0\\u10e0\\u10d7\\u10e3\\u10da\\u10d8\"\n                },{\n                    code: \"km\",\n                    localized_name: _(\"Khmer\"),\n                    JSBNG__name: \"\\u1781\\u17d2\\u1798\\u17c2\\u179a\"\n                },{\n                    code: \"kn\",\n                    localized_name: _(\"Kannada\"),\n                    JSBNG__name: \"\\u0c95\\u0ca8\\u0ccd\\u0ca8\\u0ca1\"\n                },{\n                    code: \"ko\",\n                    localized_name: _(\"Korean\"),\n                    JSBNG__name: \"\\ud55c\\uad6d\\uc5b4\"\n                },{\n                    code: \"lo\",\n                    localized_name: _(\"Lao\"),\n                    JSBNG__name: \"\\u0ea5\\u0eb2\\u0ea7\"\n                },{\n                    code: \"lt\",\n                    localized_name: _(\"Lithuanian\"),\n                    JSBNG__name: \"Lietuvi\\u0173\"\n                },{\n                    code: \"ml\",\n                    localized_name: _(\"Malayalam\"),\n                    JSBNG__name: \"\\u0d2e\\u0d32\\u0d2f\\u0d3e\\u0d33\\u0d02\"\n                },{\n                    code: \"my\",\n                    localized_name: _(\"Myanmar\"),\n                    JSBNG__name: \"\\u1019\\u103c\\u1014\\u103a\\u1019\\u102c\\u1018\\u102c\\u101e\\u102c\"\n                },{\n                    code: \"ne\",\n                    localized_name: _(\"Nepali\"),\n                    JSBNG__name: \"\\u0928\\u0947\\u092a\\u093e\\u0932\\u0940\"\n                },{\n                    code: \"nl\",\n                    localized_name: _(\"Dutch\"),\n                    JSBNG__name: \"Nederlands\"\n                },{\n                    code: \"no\",\n                    localized_name: _(\"Norwegian\"),\n                    JSBNG__name: \"Norsk\"\n                },{\n                    code: \"or\",\n                    localized_name: _(\"Oriya\"),\n                    JSBNG__name: \"\\u0b13\\u0b21\\u0b3c\\u0b3f\\u0b06\"\n                },{\n                    code: \"pa\",\n                    localized_name: _(\"Panjabi\"),\n                    JSBNG__name: \"\\u0a2a\\u0a70\\u0a1c\\u0a3e\\u0a2c\\u0a40\"\n                },{\n                    code: \"pl\",\n                    localized_name: _(\"Polish\"),\n                    JSBNG__name: \"Polski\"\n                },{\n                    code: \"pt\",\n                    localized_name: _(\"Portuguese\"),\n                    JSBNG__name: \"Portugu\\u00eas\"\n                },{\n                    code: \"ru\",\n                    localized_name: _(\"Russian\"),\n                    JSBNG__name: \"\\u0420\\u0443\\u0441\\u0441\\u043a\\u0438\\u0439\"\n                },{\n                    code: \"si\",\n                    localized_name: _(\"Sinhala\"),\n                    JSBNG__name: \"\\u0dc3\\u0dd2\\u0d82\\u0dc4\\u0dbd\"\n                },{\n                    code: \"sv\",\n                    localized_name: _(\"Swedish\"),\n                    JSBNG__name: \"Svenska\"\n                },{\n                    code: \"ta\",\n                    localized_name: _(\"Tamil\"),\n                    JSBNG__name: \"\\u0ba4\\u0bae\\u0bbf\\u0bb4\\u0bcd\"\n                },{\n                    code: \"te\",\n                    localized_name: _(\"Telugu\"),\n                    JSBNG__name: \"\\u0c24\\u0c46\\u0c32\\u0c41\\u0c17\\u0c41\"\n                },{\n                    code: \"th\",\n                    localized_name: _(\"Thai\"),\n                    JSBNG__name: \"\\u0e44\\u0e17\\u0e22\"\n                },{\n                    code: \"tr\",\n                    localized_name: _(\"Turkish\"),\n                    JSBNG__name: \"T\\u00fcrk\\u00e7e\"\n                },{\n                    code: \"ur\",\n                    localized_name: _(\"Urdu\"),\n                    JSBNG__name: \"\\ufe8d\\ufead\\ufea9\\ufeed\"\n                },{\n                    code: \"vi\",\n                    localized_name: _(\"Vietnamese\"),\n                    JSBNG__name: \"Ti\\u1ebfng Vi\\u1ec7t\"\n                },{\n                    code: \"zh\",\n                    localized_name: _(\"Chinese\"),\n                    JSBNG__name: \"\\u4e2d\\u6587\"\n                },];\n            },\n            index: function() {\n                this.updatePageTitle(_(\"Twitter / Search\")), this.render(), this.initSearchForm(), this.$find(\"input\").JSBNG__focus();\n                var a = new twttr.components.Trends;\n                this.$find(\".trends-container\").append(a.$node);\n            },\n            advanced: function() {\n                if (!twttr.decider.isAvailable(\"advanced_search\")) {\n                    return twttr.router.routeTo(twttr.router.searchHomePath());\n                }\n            ;\n            ;\n                this.updatePageTitle(_(\"Twitter / Advanced Search\")), this.render({\n                    languages: this.languages(),\n                    is_advanced: !0\n                }), this.initSearchForm();\n            }\n        }), a(twttr.components.pages.SearchHome);\n    });\n});\nprovide(\"components/pages/Front\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass.page(\"twttr.components.pages.Front\", function() {\n            twttr.components.Page.apply(this, arguments);\n        }).methods({\n            $find: function(a) {\n                return $(\"#front-container\").JSBNG__find(a);\n            }\n        }).view(twttr.views.Nothing).addAfterRender(function() {\n            this.$find(\"a[href=\\\"/#olympics\\\"]\").click(function() {\n                trackClient({\n                    page: \"front\",\n                    section: \"\",\n                    action: \"click\"\n                }, \"olympics\");\n            }), ((((twttr.pageLocale === \"de\")) && twttr.abdecider.choose(\"localized_image_germany_loggedout_front_page_294\")));\n            var a = this.$find(\".js-front-signup form\");\n            a.JSBNG__find(\"input[type=text], input[type=password]\").JSBNG__focus(function() {\n                trackClient({\n                    section: \"signup_callout\",\n                    component: $(this).attr(\"JSBNG__name\").split(/[\\[|\\]]/)[1],\n                    action: \"focus_field\"\n                });\n            }), a.submit(function() {\n                trackClient({\n                    section: \"signup_callout\",\n                    component: \"form\",\n                    action: \"signup_click\"\n                });\n            }), twttr.helpers.addFormEvents(a);\n            var b = this.$find(\".js-front-signin form\"), c = a.data(\"front_page_full_signup_256_bucket\");\n            ((c && (b = $(\".js-front-signin form\")))), ((((JSBNG__document.activeElement.tagName.toLowerCase() != \"input\")) && b.JSBNG__find(\".email-input\").JSBNG__focus())), b.submit(function() {\n                trackClient({\n                    section: \"login_callout\",\n                    component: \"form\",\n                    action: \"login_click\"\n                });\n            }), twttr.helpers.addFormEvents(b);\n            if (c) {\n                twttr.helpers.addHoldingInputEvents(b);\n                var d = b.parent(\".js-front-signin\"), e = a.parent(\".js-front-signup\");\n                e.bind(\"collapsed\", function() {\n                    d.animate({\n                        JSBNG__top: \"230px\"\n                    }, function() {\n                        d.removeClass(\"shrink\"), d.addClass(\"grow\");\n                    });\n                }), ((((a.data(\"front_page_full_signup_256_bucket\") === \"login_form_below\")) && e.bind(\"signupFocus\", function() {\n                    if (e.hasClass(\"expanded\")) {\n                        return;\n                    }\n                ;\n                ;\n                    d.addClass(\"shrink\"), d.removeClass(\"grow\"), JSBNG__setTimeout(function() {\n                        d.animate({\n                            JSBNG__top: \"175px\"\n                        }, 100, function() {\n                            a.trigger(\"loginHide\");\n                        });\n                    }, 400);\n                })));\n            }\n        ;\n        ;\n        }).addOnSwitchAway(function() {\n            twttr.themes.loadDefaultTheme();\n        }).methods({\n            index: function(a, b) {\n                if (b.in_reply_to_status_id) {\n                    twttr.router.routeTo(twttr.router.loginRedirectPath({\n                        redirect_after_login: ((\"/\" + window.JSBNG__location.search))\n                    }));\n                    return;\n                }\n            ;\n            ;\n                ((window._scribedFrontImpression ? window._scribedFrontImpression = !1 : (((($(\".front-card.event-takeover\").length > 0)) ? trackClient({\n                    page: \"front\",\n                    section: \"\",\n                    action: \"impression\"\n                }, \"olympics\") : trackClient({\n                    page: \"front\",\n                    section: \"\",\n                    action: \"impression\"\n                }, \"front\"))))), this.updatePageTitle(_(\"Twitter\")), twttr.themes.loadFrontPageTheme();\n            }\n        });\n        ((twttr.isT1 ? c.addAfterRender(function() {\n            var a = $(\".js-front-language form\");\n            a.submit(function() {\n                trackClient({\n                    section: \"language_dropdown\",\n                    component: \"form\",\n                    action: \"select\"\n                }, {\n                    event_info: this.lang.value\n                });\n            });\n        }) : c.addAfterRender(function() {\n            this.$find(\".bottompart\").empty().append((new twttr.components.LanguageLinks).$node.fadeIn()).append((new twttr.components.CountrySelect).$node.fadeIn()).append((new twttr.components.Footer).$node);\n        }).addOnSwitchTo(function() {\n            twttr.$elements.page.css(\"padding-top\", \"\");\n        }))), a(c);\n    });\n});\nprovide(\"components/pages/Login\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _, c) {\n        var d = ((twttr.abdecider.choose(\"remember_me_checked_default_all_users_341\") == \"checked\")), e = ((((jQuery.cookie(\"remember_checked\") == \"1\")) || ((((jQuery.cookie(\"remember_checked\") == null)) && d)))), f = twttr.klass.page(\"twttr.components.pages.Login\").view(twttr.views.LoginPage).addBeforeRender(function() {\n            this.updatePageTitle(_(\"Sign in to Twitter\")), twttr.themes.clear();\n        }).addAfterRender(function() {\n            if (twttr.loggedIn) twttr.showMessage(_(\"You are already logged in!\")), twttr.router.routeTo(twttr.router.homePath());\n             else {\n                twttr.helpers.addFormEvents(this.$find(\"form.js-signin\")), this.$find(\"p.js-forgot a[title]\").tipsy({\n                    gravity: \"se\"\n                });\n                var a = this.$find(\".js-bottompart\");\n                ((twttr.isT1 ? twttr.helpers.addHoldingInputEvents(this.$find(\"form\")) : a.append((new twttr.components.LanguageLinks).$node).append((new twttr.components.CountrySelect).$node))), a.append((new twttr.components.Footer).$node);\n                var b = this.$find(\".username input\").JSBNG__focus();\n                JSBNG__setTimeout(function() {\n                    b.JSBNG__focus();\n                }, 1);\n            }\n        ;\n        ;\n        }).addOnSwitchTo(function() {\n            twttr.themes.loadDefaultTheme();\n        }).methods({\n            noAutoRender: !0,\n            index: function(a, b) {\n                this.render({\n                    redirect_after_login: ((a.redirect_after_login || b.redirect_after_login)),\n                    password_reset_title: _(\"If you remember your password, try logging in with your email\"),\n                    remember_checked: e\n                }), trackClient({\n                    section: \"\",\n                    component: \"\",\n                    action: \"impression\"\n                }, \"login\");\n            },\n            error: function(a, b) {\n                this.render({\n                    redirect_after_login: ((a.redirect_after_login || b.redirect_after_login)),\n                    username_or_email: b.username_or_email,\n                    remember_checked: e\n                }), ((twttr.loggedIn || ((((a.error == \"captcha\")) ? (this._addCaptcha(), twttr.showMessage(_(\"We gotta check... are you human?\")), trackClient({\n                    section: \"form\",\n                    component: \"captcha\",\n                    action: \"show\"\n                }, \"login\")) : (twttr.showError(_(\"Wrong Username/Email and password combination.\")), trackClient({\n                    section: \"form\",\n                    component: \"username_password\",\n                    action: \"validation_error\"\n                }, \"login\"))))));\n            },\n            loginRequired: function() {\n                twttr.router.routeTo(twttr.router.loginRedirectPath({\n                    redirect_after_login: twttr.Router.getCurrentPath()\n                })), twttr.showMessage(_(\"You must log in to do that!\"));\n            },\n            _addCaptcha: function() {\n                var a = this;\n                using(b.constants.recaptcha.srcUrl).load().then(function() {\n                    Recaptcha.create(b.constants.recaptcha.publicKey, a.$find(\".js-signin .js-captcha\")[0], {\n                        lang: twttr.pageLocale,\n                        theme: \"white\"\n                    });\n                });\n            }\n        });\n        a(twttr.components.pages.Login);\n    });\n});\nprovide(\"components/pages/Logout\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.page(\"twttr.components.pages.Logout\").view(twttr.views.LogoutPage).addAfterRender(function() {\n            twttr.helpers.addFormEvents(this.$find(\"form.signout\")), this.$find(\".cancel\").click(function() {\n                return twttr.router.routeTo(twttr.router.homePath()), !1;\n            });\n            var a = this.$find(\".bottompart\");\n            ((twttr.isT1 || a.append((new twttr.components.LanguageLinks).$node).append((new twttr.components.CountrySelect).$node))), a.append((new twttr.components.Footer).$node);\n        }).methods({\n            index: function(a, b) {\n                if (!twttr.loggedIn) {\n                    return ((twttr.decider.isAvailable(\"mobile_download_gallery_logged_out\") ? twttr.router.routeTo(\"/download?logged_out=1\") : twttr.router.routeTo(twttr.router.homePath())));\n                }\n            ;\n            ;\n                this.updatePageTitle(_(\"Twitter / Sign out of Twitter\")), twttr.themes.loadCurrentUserStyle();\n            }\n        }), a(twttr.components.pages.Logout);\n    });\n});\nprovide(\"components/pages/Profile\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"components/pages/mixins/profileT1\" : \"components/pages/mixins/profileP1\")), ((twttr.isT1 ? \"mixins/t1/emptyTimelineRecommendations\" : \"mixins/emptyTimelineRecommendations\")), \"constants\").as(function(b, _, c, d) {\n        var e = twttr.klass(\"twttr.components.pages.Profile\").subclassOf(twttr.components.pages.ProfileAbstract).view(twttr.views.ProfilePage).containerCssClass(\"profile-container\").mixin(c, d).methods({\n            checkWithheld: function() {\n                ((((((((((twttr.decider.isAvailable(\"phoenix_pctd\") && twttr.profileUser)) && !!twttr.profileUser.withheldScope)) && ((twttr.profileUser.withheldScope === \"user\")))) && !twttr.helpers.isCurrentUser(twttr.profileUser.id))) ? this.renderWithheld() : this.renderNotWithheld()));\n            },\n            renderWithheld: function() {\n                $(\"#page-container\").removeClass(\"profile-container\").addClass(\"wrapper-permalink permalink-container withheld\");\n            },\n            renderNotWithheld: function() {\n                $(\"#page-container\").addClass(\"profile-container\").removeClass(\"wrapper-permalink permalink-container withheld\");\n            },\n            userWasBlocked: function(a, b) {\n                ((((b.screenName === twttr.profileUser.screenName)) && $(\".profile-actions-container a.js-direct-message-action, .profile-actions-container div.js-direct-message-action\").remove()));\n            },\n            getUserInfo: function(a, b, c) {\n                if (((this.profileUser && ((a == this.profileUser.screenName))))) {\n                    twttr.profileUser = this.profileUser, ((twttr.is.def(this.profileUser.promotedContent) && (twttr.promotedAccount = {\n                        id: this.profileUser.id,\n                        impressionId: this.profileUser.promotedContent.impression_id\n                    }))), ((b && b()));\n                    return;\n                }\n            ;\n            ;\n                var d = ((this.preRendered ? this.$find(\"div.profile-header\").attr(\"data-user\") : null));\n                if (d) {\n                    data = JSON.parse(d), this.profileUser = twttr.profileUser = new twttr.anywhere.api.models.User(data), ((b && b()));\n                    return;\n                }\n            ;\n            ;\n                return twttr.components.pages.ProfileAbstract.prototype.getUserInfo.apply(this, arguments);\n            },\n            profile: function(a, b) {\n                var c = this, d = a.screen_name.toLowerCase().replace(/^@/, \"\");\n                this.loading(d), this.getUserInfo(d, function() {\n                    c.updatePageTitle(_(\"{{fullName}} ({{screenName}}) on Twitter\", {\n                        fullName: c.profileUser.JSBNG__name,\n                        screenName: d\n                    })), c._highlightNavIfCurrentUser(d), c.selectCurrentSideNav(), ((((b.banner_preview_url && twttr.helpers.isCurrentUser(c.profileUser))) && (c.bannerPreviewUrl = b.banner_preview_url))), c._switchToStream({\n                        screenName: d,\n                        stream: c.initialProfileStream(),\n                        tab: \"tweets\"\n                    }), c.checkWithheld();\n                }, {\n                    batch: !twttr.loggedIn,\n                    profiler: !0\n                }, twttr.bind(this, this.noUserFoundCallback));\n            },\n            message: function(a) {\n                this.profile(a), a = ((a || {\n                })), twttr.API.User.JSBNG__find(a.screen_name, function(b) {\n                    twttr.dialogs.dmSingle({\n                        user: {\n                            screenName: a.screen_name,\n                            user_id: b.attributes.id,\n                            JSBNG__name: b.attributes.JSBNG__name,\n                            profile_image_url: b.attributes.profile_image_url\n                        },\n                        origin: a.origin\n                    }).open();\n                });\n            },\n            favorites: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.getUserInfo(b, twttr.bind(this, function() {\n                    ((twttr.helpers.canViewUser(this.profileUser) ? (this.updatePageTitle(_(\"Twitter / {{screenName}}'s Favorites\", {\n                        screenName: b\n                    })), this._highlightNavIfCurrentUser(b), this.selectCurrentSideNav(), this._switchToStream({\n                        screenName: b,\n                        stream: twttr.streams.Favorites,\n                        tab: \"favorites\"\n                    })) : twttr.router.routeTo(twttr.router.profilePath({\n                        screen_name: this.profileUser.screenName\n                    }))));\n                }), {\n                    batch: !twttr.loggedIn,\n                    profiler: !0\n                });\n            },\n            profile_activity: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.getUserInfo(b, twttr.bind(this, function() {\n                    ((twttr.helpers.canViewUser(this.profileUser) ? (this.updatePageTitle(_(\"Twitter / {{screenName}}'s Activity\", {\n                        screenName: b\n                    })), this._highlightNavIfCurrentUser(b), this._switchToStream({\n                        screenName: b,\n                        stream: twttr.streams.ActivityByUserStream,\n                        tab: \"activity\"\n                    })) : twttr.router.routeTo(twttr.router.profilePath({\n                        screen_name: this.profileUser.screenName\n                    }))));\n                }), {\n                    batch: !twttr.loggedIn,\n                    profiler: !0\n                });\n            },\n            followers: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.updatePageTitle(_(\"Twitter / People who follow {{screenName}}\", {\n                    screenName: b\n                })), this._highlightNavIfCurrentUser(b), this.selectCurrentSideNav(), this._switchToStream({\n                    screenName: b,\n                    stream: twttr.streams.Followers,\n                    tab: \"followers\"\n                });\n            },\n            following: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.updatePageTitle(_(\"Twitter / People {{screenName}} is following\", {\n                    screenName: b\n                })), this._highlightNavIfCurrentUser(b), this.selectCurrentSideNav(), this.JSBNG__one(\"switchedToStream\", twttr.bind(this, this.insertEmptyTimeline)), this._switchToStream({\n                    screenName: b,\n                    stream: twttr.streams.Friends,\n                    tab: \"following\"\n                });\n            },\n            youBothFollow: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.getUserInfo(b, twttr.bind(this, function() {\n                    this.updatePageTitle(_(\"Twitter / People you and @{{screenName}} both follow\", {\n                        screenName: b\n                    })), this._highlightNavIfCurrentUser(b), this._switchToStream({\n                        screenName: b,\n                        stream: twttr.streams.SocialContextStream,\n                        socialContextType: \"followsInCommonWith\",\n                        tab: \"following\"\n                    });\n                }));\n            },\n            followersYouFollow: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.getUserInfo(b, twttr.bind(this, function() {\n                    this.updatePageTitle(_(\"Twitter / People you follow who follow @{{screenName}}\", {\n                        screenName: b\n                    })), this._highlightNavIfCurrentUser(b), this.selectSideNav(\"userFollowers\"), this._switchToStream({\n                        screenName: b,\n                        stream: twttr.streams.SocialContextStream,\n                        socialContextType: \"followingFollowersOf\",\n                        tab: \"followers\"\n                    });\n                }));\n            },\n            lists: function(a) {\n                var b = this._defaultedScreenName(a.screen_name);\n                this.getUserInfo(b, twttr.bind(this, function() {\n                    ((twttr.helpers.canViewUser(this.profileUser) ? (this.updatePageTitle(_(\"Twitter / {{screenName}}'s Lists\", {\n                        screenName: b\n                    })), this._highlightNavIfCurrentUser(b), this.selectCurrentSideNav(), this._switchToStream({\n                        screenName: b,\n                        stream: twttr.streams.OwnLists,\n                        tab: \"lists\"\n                    })) : twttr.router.routeTo(twttr.router.profilePath({\n                        screen_name: this.profileUser.screenName\n                    }))));\n                }), {\n                    batch: !twttr.loggedIn,\n                    profiler: !0\n                });\n            },\n            subscriptions: function(a) {\n                var b = a.screen_name;\n                this.updatePageTitle(_(\"Twitter / Lists {{screenName}} is following\", {\n                    screenName: b\n                })), this._highlightNavIfCurrentUser(b), this._switchToStream({\n                    screenName: b,\n                    stream: twttr.streams.Subscriptions,\n                    tab: \"lists\"\n                });\n            },\n            followerRequests: function(a) {\n                var b = twttr.util.params().uid;\n                ((((b && !twttr.helpers.isCurrentUser(+b))) && twttr.router.redirectTo(((\"/?badLinkRecipient=\" + b)))));\n                var c = this._defaultedScreenName(a.screen_name);\n                if (!twttr.helpers.isCurrentUser(c)) twttr.router.routeTo(twttr.router.profilePath({\n                    screen_name: c\n                }));\n                 else {\n                    this.updatePageTitle(_(\"Twitter / My follower requests\")), this.selectCurrentSideNav(), this._highlightNavIfCurrentUser(c), this._switchToStream({\n                        screenName: c,\n                        stream: twttr.streams.FollowerRequests,\n                        tab: \"pending\"\n                    });\n                    if (!this.didBindUserBlockedEvent) {\n                        this.didBindUserBlockedEvent = !0;\n                        var d = this;\n                        twttr.API.User.bind(\"block\", function() {\n                            d.streamManager.resetCache();\n                        });\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            listDeleted: function(a) {\n                this.streamManager.getCurrent().remove(a.uri);\n            },\n            dashStatsTitle: function() {\n                return ((twttr.helpers.isProfileUser() ? _(\"About you\") : null));\n            },\n            shouldShowTweetBox: function() {\n                return ((((twttr.loggedIn && !twttr.helpers.isProfileUser())) && twttr.decider.isAvailable(\"profile_tweetbox\")));\n            },\n            renderTweetbox: function() {\n                if (((this.tweetBox && ((this._renderedScreenName === twttr.profileUser.screenName))))) {\n                    return this.tweetBoxNode;\n                }\n            ;\n            ;\n                var a = this;\n                this.$find(\"div.profile-tweet-box-placeholder\").remove();\n                if (this.shouldShowTweetBox()) {\n                    var b = this.tweetBoxNode = $(\"\\u003Cdiv class=\\\"profile-tweet-box\\\"/\\u003E\"), c = ((\"@\" + this.profileUser.screenName));\n                    this.$find(\".profile-actions-container\").addClass(\"preceeding-profile-tweet-box\").after(b), this.tweetBox = new twttr.TweetBox(b.empty(), twttr.merge({\n                        defaultContent: ((c + \" \")),\n                        id: \"profile-tweet-box\",\n                        condensed: !0,\n                        enableDraft: twttr.isT1,\n                        enableAutoGrow: twttr.isT1,\n                        statusAction: \"update\"\n                    }, this.getTweetBoxOptions())), this.tweetBox.bind(\"tweetSuccess\", function(a, b) {\n                        ((b.inReplyToScreenName ? twttr.showMessage(_(\"Your Tweet to @{{username}} has been sent!\", {\n                            username: b.inReplyToScreenName\n                        })) : twttr.showMessage(_(\"Your Tweet was posted!\"))));\n                    });\n                }\n            ;\n            ;\n                return b;\n            },\n            getTweetbox: function() {\n                return this.tweetBox;\n            },\n            initialProfileStream: function() {\n                return ((((twttr.isT1 && twttr.streams.Profile.shouldDisplay())) ? twttr.streams.Profile : twttr.streams.User));\n            },\n            noUserFoundCallback: function() {\n                this._renderedScreenName = null, ((this.streamManager && (this.streamManager.switchOut(), this.streamManager.setCurrent(null))));\n            }\n        }).addOnSwitchAway(function() {\n            ((twttr.admin && twttr.admin.removeTools())), this.renderNotWithheld(), twttr.API.User.unbind(\"block\", this.userWasBlocked);\n        }).addAfterRender(function() {\n            if (!window.JSBNG__location.hash) {\n                return;\n            }\n        ;\n        ;\n            var a = twttr.util.paramsFromUrl(window.JSBNG__location.hash);\n            ((((a && a.protected_redirect)) && (window.JSBNG__location.hash = window.JSBNG__location.hash.replace(\"?protected_redirect=true\", \"\"), twttr.showError(_(\"Sorry, you are not authorized to see this status.\")))));\n        }).addAfterRender(function() {\n            ((((this.preRendered && !this.didEmptyDashboard)) && (this.$find(\"div.dashboard\").empty(), this.didEmptyDashboard = !0))), this.addDashboardComponents(this.getDashboardComponents());\n        });\n        a(e);\n    });\n});\nprovide(\"components/pages/List\", function(a) {\n    using(\"_\", \"util\", ((twttr.isT1 ? \"components/pages/mixins/listT1\" : \"components/pages/mixins/listP1\")), \"streams/List\", \"streams/ListMembers\", \"streams/ListFollowers\", \"components/SignupCallOut\", function(_, b, c, d, e, f, g) {\n        var i = twttr.klass(\"twttr.components.pages.List\").subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage).methods(twttr.EventProvider).methods({\n            list: function(a) {\n                a = b.camelizeObject(a), this.updatePageTitle(_(\"Twitter / @{{screenName}}/{{listSlug}}\", a)), this.switchToStream(d, a), this.selectCurrentSideNav(), this.focusStreamTab(\"tweets\");\n            },\n            members: function(a) {\n                a = b.camelizeObject(a), this.updatePageTitle(_(\"Twitter / @{{screenName}}/{{listSlug}} - Following\", a)), this.switchToStream(e, a), this.selectCurrentSideNav(), this.focusStreamTab(\"members\");\n            },\n            followers: function(a) {\n                a = b.camelizeObject(a), this.updatePageTitle(_(\"Twitter / @{{screenName}}/{{listSlug}} - Followers\", a)), this.switchToStream(f, a), this.selectCurrentSideNav(), this.focusStreamTab(\"followers\");\n            },\n            noAutoRender: !0,\n            listDeleted: function(a) {\n                twttr.showMessage(_(\"List deleted\")), twttr.router.routeTo(twttr.router.homePath());\n            },\n            listUpdated: function(a) {\n                twttr.router.routeTo(twttr.router.userListPath({\n                    screen_name: twttr.currentUser.screenName,\n                    list_slug: a.slug\n                }));\n            },\n            _getList: function(a) {\n                var b = this;\n                if (((!this.listOwnerName || !this.listId))) {\n                    throw \"You tried to use _getList before defining .listOwnerName and .listId\";\n                }\n            ;\n            ;\n                twttr.API.User.JSBNG__find(this.listOwnerName, function(c) {\n                    c.lists.JSBNG__find(b.listId, function(b) {\n                        a(b, c);\n                    });\n                });\n            },\n            switchToStream: function(a, b) {\n                var c = this, d = function() {\n                    c.trigger(\"notFound\");\n                };\n                this.loading(b.screenName, b.listSlug), twttr.API.User.JSBNG__find(b.screenName, {\n                    success: function(e) {\n                        twttr.profileUser = e, e.lists.JSBNG__find(b.listSlug, {\n                            success: function(d) {\n                                c.listId = d.id, c.listOwnerName = d.user.screenName, c._listSlug = d.slug, c.fullName = d.fullName;\n                                var e = new twttr.views.List(d);\n                                twttr.themes.loadUserStyleFor(d.user), ((((c._renderedListId !== d.id)) && (c.render({\n                                    list: e\n                                }), c._registerEvents(d), c._renderedListId = d.id))), c.streamManager.switchTo(a, b);\n                            },\n                            error: d\n                        });\n                    },\n                    error: d\n                });\n            },\n            loading: function(a, b) {\n                this.unfocusStreamItem(), ((((((this._listSlug !== b)) && ((this.listOwnerName !== a)))) && this.$node.children().empty()));\n            }\n        }).addAfterRender(function() {\n            var a = this;\n            this._getList(function(b, c) {\n                a.owner = c, ((twttr.loggedIn || a.addDashboardComponent(new g(\"list\", {\n                    profileUser: c\n                })))), a.addDashboardComponents(a.getDashboardComponents(b)), ((((a.owner && !twttr.isT1)) && trackClient({\n                    action: \"impression\"\n                }, {\n                    profile_id: a.owner.id,\n                    message: b.slug\n                })));\n            });\n        }).mixin(c);\n        a(i);\n    });\n});\nprovide(\"components/pages/Permalink\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.pages.Permalink\").subclassOf(twttr.components.Page).view(twttr.views.PermalinkPage).addOnSwitchAway(function() {\n            twttr.$elements.page.css(\"padding-top\", \"\"), twttr.widget.Dialog.close();\n        }).methods({\n            permalink: function(a) {\n                this.loadPage(a);\n            },\n            loadPage: function(a, b) {\n                var c = this;\n                twttr.widget.Dialog.close();\n                if (((this._renderedTweetId == a.id))) {\n                    return ((b && b.call(this)));\n                }\n            ;\n            ;\n                this._renderedTweetId = a.id, this.loading();\n                var d = function(b) {\n                    ((((b.JSBNG__status == 403)) ? twttr.router.routeTo(twttr.router.profilePath({\n                        screen_name: a.screen_name\n                    })) : c.trigger(\"notFound\")));\n                }, e = function(d) {\n                    c.tweetComponent = new twttr.components.PermalinkTweet(d), c.tweetComponent.$node.appendTo(c.$find(\".components-middle\")), c.tweetComponent.bind(\"deleted\", function() {\n                        ((twttr.app.isOnPage(\"permalink\") && twttr.router.routeTo(twttr.router.homePath())));\n                    });\n                    if (((a.photo_index && !twttr.decider.isAvailable(\"phoenix_turkey_permalink\")))) {\n                        c.trigger(\"notFound\");\n                        return;\n                    }\n                ;\n                ;\n                    var e = c.$find(\".permalink\");\n                    if (c.tweetComponent.renderWithheld()) e.addClass(\"withheld\");\n                     else {\n                        ((c.tweetComponent.renderCreatorWithheld() ? e.addClass(\"withheld-creator\") : e.removeClass(\"withheld-creator\")));\n                        var f = c.$find(\"div.js-tweet-media-container\");\n                        c.mediaComponent = new twttr.components.Media(d, f.width(), {\n                            linkLarge: !0\n                        }), c.mediaComponent.$node.appendTo(f);\n                        var g = new twttr.components.InReplyTo(d), i = new twttr.components.TweetGeoSmall(d), j = new twttr.components.Footer(\"slim\"), k = new twttr.components.MachineTranslatedTweet(d);\n                        g.$node.appendTo(c.$find(\".components-above\"));\n                        if (!twttr.isT1) {\n                            var l = new twttr.components.MentionedInTweet(d);\n                            l.$node.appendTo(c.$find(\".components-below\"));\n                        }\n                    ;\n                    ;\n                        c.renderActivity(d), i.$node.appendTo(c.$find(((twttr.isT1 ? \".components-middle .permalink-inner\" : \".components-below\")))), c.renderReplies(d), j.$node.appendTo(c.$find(\".permalink-footer\")), k.$node.appendTo(c.$find(\"div.js-machine-translated-tweet-container\")), e.removeClass(\"withheld\"), ((b && b.call(c)));\n                    }\n                ;\n                ;\n                    if (!twttr.loggedIn) {\n                        var m = new twttr.components.SignupCallOut(\"permalink\", {\n                            profileUser: d.user\n                        });\n                        ((twttr.isT1 ? m.$node.prependTo(c.$find(\".permalink-footer\")) : m.$node.appendTo(c.$find(\".permalink-header\")))), twttr.$elements.page.css(\"padding-top\", \"30px\");\n                    }\n                ;\n                ;\n                };\n                twttr.API.Status.JSBNG__find(a.id, {\n                    success: function(a) {\n                        c.JSBNG__status = a, c.updatePageTitle(_(\"Twitter / @{{screenName}}: {{{truncatedText}}} ...\", {\n                            screenName: a.user.screenName,\n                            truncatedText: a.text.slice(0, 26)\n                        })), twttr.themes.loadUserStyleFor(a.user), c.render(), ((twttr.loggedIn ? twttr.currentUser.relationshipWith(a.user.screenName, {\n                            success: function(b) {\n                                a.user.following = b.following, a.user.attributes.following = b.following, a.attributes.user.following = b.following, e(a);\n                            },\n                            error: d\n                        }) : (a.user.following = !1, a.user.attributes.following = !1, a.attributes.user.following = !1, e(a)))), trackClient({\n                            component: \"tweet\",\n                            action: \"results\"\n                        }, {\n                            item_ids: [a.id,],\n                            item_count: 1,\n                            event_value: 1\n                        });\n                    },\n                    error: d\n                }), trackClient({\n                    action: \"impression\"\n                });\n            },\n            loading: function() {\n                this.$find(\".permalink\").empty();\n            }\n        }).methods({\n            noAutoRender: !0\n        }).click({\n            \".js-tweets-at-this-place\": function(a, b) {\n                var c = b.attr(\"data-place-id\"), d = b.attr(\"data-place-name\");\n                return ((((c && d)) && twttr.router.routeTo(twttr.router.placeTweetSearchPath({\n                    place_id: c,\n                    place_name: d\n                })))), a.stopPropagation(), a.preventDefault(), !1;\n            },\n            \"a[data-twitter-media-url='true']\": function(a) {\n                a.stopPropagation();\n            }\n        }).keydown({\n            f: function(a) {\n                (($(a.target).is(\":not(input)\") && this.tweetComponent.faveTweet(\"keyboard\")));\n            },\n            r: function(a) {\n                (($(a.target).is(\":not(input)\") && (this.tweetComponent.replyTweet(\"keyboard\"), a.preventDefault())));\n            },\n            t: function(a) {\n                (($(a.target).is(\":not(input)\") && this.tweetComponent.retweetTweet(\"keyboard\")));\n            }\n        });\n        ((twttr.isT1 ? c.containerCssClass(\"wrapper-permalink\").methods({\n            renderReplies: function(a) {\n                var b = this;\n                new twttr.components.Conversation(a, null, function(c) {\n                    var d = new twttr.components.Replies(a, null, c.resultGroups);\n                    d.$node.appendTo(b.$find(\".components-below\")), new twttr.components.InlineReplyBox(b.tweetComponent.$node.JSBNG__find(\".tweet\"), b.$find(\".components-below\"), d.$node, 481, 425);\n                });\n            },\n            permalinkWithEmbedDialog: function(a) {\n                this.loadPage(a, this.showEmbedDialog);\n            },\n            showEmbedDialog: function() {\n                ((twttr.decider.isAvailable(\"embed_code_dialog\") && twttr.dialogs.embedCode(this.JSBNG__status).open()));\n            },\n            renderActivity: twttr.util.noopInT1\n        }).click({\n            \"a.embed-link\": function(a) {\n                a.preventDefault(), a.stopPropagation(), twttr.router.routeTo(twttr.router.embedDialogPermalinkPath({\n                    screen_name: this.JSBNG__status.user.screenName,\n                    id: this.JSBNG__status.id\n                }));\n            }\n        }) : c.containerCssClass(\"permalink-container\").methods({\n            permalinkWithEmbedDialog: twttr.util.noopInP1,\n            showEmbedDialog: twttr.util.noopInP1,\n            renderReplies: twttr.util.noopInP1,\n            renderActivity: function(a) {\n                var b = ((twttr.decider.isActivityEnabled() && twttr.decider.isAvailable(\"activity_social_context\"))), c = new twttr.components[((b ? \"TweetActivity\" : \"Retweeters\"))](a);\n                c.$node.appendTo(this.$find(\".components-below\"));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/pages/WhoToFollow\", function(a) {\n    using(\"_\", \"constants\", \"streams/SuggestionCategoryMembersStream\").as(function(b, _) {\n        twttr.klass.page(\"twttr.components.pages.WhoToFollow\", function() {\n            twttr.components.Page.apply(this, arguments), this.dashboardNeedsToBeCreated = !1;\n        }).mixin(twttr.mixins.streamablePage).mixin(twttr.mixins.discoveryHelper).view(twttr.views.WhoToFollow).addAfterRender(function() {\n            this._rendered = !0;\n            var a = this;\n            this._createDashboard(!0), twttr.helpers.addFormEvents(this.$find(\".who-to-follow-header form\"), function() {\n                var b = twttr.audit.currentAction(), c = this.q.value, d;\n                ((((twttr.audit.currentPage() == \"welcome\")) ? d = twttr.components.pages.Welcome.ROUTES_TO_STEP[b] : d = twttr.components.pages.WhoToFollow.ROUTES_TO_STEP[b])), ((((c != \"\")) && (trackClient({\n                    component: \"user_search_form\",\n                    action: \"search\"\n                }, {\n                    step: d,\n                    query: c\n                }), a.routePageTo(a.PATH_ROOT, \"Search\", {\n                    query: c\n                }))));\n            });\n        }).addOnSwitchTo(function() {\n            this._createDashboard(), trackClient({\n                section: \"\",\n                component: \"\",\n                action: \"impression\"\n            });\n        }).addOnSwitchAway(function() {\n            twttr.API.User.unbind(\"follow.RecentlyFollowedComponent\"), twttr.recentlyViewedUsers.unbind(\"push.RecentlyViewedComponent\"), this.dashboardNeedsToBeCreated = !0, this._rendered = !1, this.$find(\".dashboard \\u003E .component\").remove();\n        }).statics({\n            ROUTES_TO_STEP: {\n                whoToFollow: \"suggestions\",\n                suggestions: \"suggestions\",\n                interests: \"interests\",\n                category: \"interests\",\n                \"import\": \"import\",\n                matches: \"import\",\n                search: \"search\"\n            }\n        }).methods({\n            switchToStream: function() {\n                var a = this.streamManager.switchTo.apply(this.streamManager, arguments);\n                return a;\n            },\n            search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.routePageTo(this.PATH_ROOT);\n                }\n            ;\n            ;\n                this._switchTabAndRender(\"search\", c), this.updatePageTitle(_(\"Twitter / User Search\")), trackClient({\n                    action: \"impression\"\n                }, {\n                    context: \"search\",\n                    query: c\n                });\n                var d = twttr.Scribbler.clientEvent.spawn({\n                    context: \"search\",\n                    query: c\n                });\n                this.switchToStream(twttr.streams.PeopleSearch, {\n                    query: c,\n                    scribbler: d,\n                    pathRoot: this.PATH_ROOT\n                });\n            },\n            suggestions: function(a, b) {\n                if (!twttr.loggedIn) {\n                    return this.trigger(\"loginRequired\");\n                }\n            ;\n            ;\n                this._switchTabAndRender(\"suggestions\"), this.updatePageTitle(_(\"Twitter / Who to follow / Suggestions\")), trackClient({\n                    action: \"impression\"\n                }, \"suggestions\");\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"suggestions\"\n                });\n                if (twttr.decider.isAvailable(\"whotofollow_recommendations\")) {\n                    var d = this.switchToStream(twttr.streams.UserRecommendationsStream, {\n                        scribbler: c,\n                        pathRoot: this.PATH_ROOT\n                    });\n                    ((d && d.setStreamManager(this.streamManager)));\n                }\n                 else twttr.router.redirectTo(twttr.router.whoToFollowInterestsPath());\n            ;\n            ;\n            },\n            interests: function(a, b) {\n                this._switchTabAndRender(\"interests\"), this.updatePageTitle(_(\"Twitter / Who to follow / Interests\")), trackClient({\n                    action: \"impression\"\n                }, \"interests\");\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"interests\"\n                }), d = {\n                    scribbler: c,\n                    pathRoot: this.PATH_ROOT\n                };\n                this.switchToStream(twttr.streams.SuggestionCategoriesStream, this.localizeQuery(d, b));\n            },\n            category: function(a, c) {\n                var d = this, e = function(a) {\n                    if (!a) {\n                        return d.routePageTo(d.PATH_ROOT, \"Interests\");\n                    }\n                ;\n                ;\n                    var e = twttr.Scribbler.clientEvent.spawn({\n                        context: \"interests\",\n                        query: a.slug\n                    });\n                    d._switchTabAndRender(\"interests\"), d.updatePageTitle(_(\"Twitter / Who to follow / Interests / {{category}}\", {\n                        category: a.JSBNG__name\n                    })), d.switchToStream(b.streams.SuggestionCategoryMembersStream, d.localizeQuery({\n                        category: f,\n                        suggestionCategory: a,\n                        scribbler: e,\n                        pathRoot: d.PATH_ROOT\n                    }, c));\n                }, f = ((a.category || c.category));\n                trackClient({\n                    action: \"impression\"\n                }, {\n                    query: f,\n                    context: \"interests\"\n                });\n                var g = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP;\n                ((g ? e(g[f]) : twttr.API.SuggestionCategory.getAll(this.localizeQuery({\n                    success: function(a) {\n                        a = twttr.streams.SuggestionCategoriesStream.filterTopTweetsCategories(a), twttr.streams.SuggestionCategoriesStream.cacheCategories(a);\n                        var b = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP[f];\n                        e(b);\n                    }\n                }, c))));\n            },\n            \"import\": function(a, b) {\n                if (!twttr.loggedIn) {\n                    return this.trigger(\"loginRequired\");\n                }\n            ;\n            ;\n                this._switchTabAndRender(\"import\", \"\", \"services\"), this.updatePageTitle(_(\"Twitter / Who to follow / Find friends\")), trackClient({\n                    action: \"impression\"\n                }, \"import\");\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                }), d = this.localizeQuery({\n                    scribbler: c,\n                    pathRoot: this.PATH_ROOT\n                }, b), e = this.switchToStream(twttr.streams.ContactImportServices, d);\n                ((e && e.setStreamManager(this.streamManager)));\n            },\n            matches: function() {\n                if (!twttr.loggedIn) {\n                    return this.trigger(\"loginRequired\");\n                }\n            ;\n            ;\n                this._switchTabAndRender(\"import\", \"\", \"matches\"), this.updatePageTitle(_(\"Twitter / Who to follow / Find friends / Results\")), trackClient({\n                    action: \"impression\"\n                }, \"import\");\n                var a = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                });\n                this.switchToStream(twttr.streams.ContactImportMatches, {\n                    scribbler: a,\n                    pathRoot: this.PATH_ROOT\n                });\n            },\n            localizeQuery: function(a, b) {\n                return ((b.lang && (a.lang = b.lang))), ((b.country && (a.country = b.country))), ((b.city && (a.city = b.city))), a.top_tweets = !0, a;\n            },\n            PATH_ROOT: \"whoToFollow\",\n            noAutoRender: !0,\n            _createDashboard: function(a) {\n                if (((a || this.dashboardNeedsToBeCreated))) {\n                    this.addDashboardComponents(this._dashboardComponents()), this.dashboardNeedsToBeCreated = !1;\n                }\n            ;\n            ;\n            },\n            _dashboardComponents: function() {\n                var a = twttr.Scribbler.clientEvent.spawn({\n                    context: function() {\n                        var a = twttr.audit.currentAction();\n                        return ((((twttr.audit.currentPage() == \"welcome\")) ? twttr.components.pages.Welcome.ROUTES_TO_STEP[a] : twttr.components.pages.WhoToFollow.ROUTES_TO_STEP[a]));\n                    }\n                });\n                if (!twttr.loggedIn) {\n                    return [new twttr.components.SignupCallOut(\"who_to_follow\"),new twttr.components.Footer,];\n                }\n            ;\n            ;\n                var b = twttr.abdecider.choose(\"wtf_with_less_122\"), c = [new twttr.components.RecentlyFollowed,new twttr.components.RecentlyViewed,new twttr.components.InviteFriends(a),new twttr.components.RelatedServices,new twttr.components.Footer,];\n                return ((((b == \"empty_dashboard\")) ? c = [] : ((((b == \"no_recent_follow\")) ? c = [new twttr.components.RecentlyViewed,new twttr.components.InviteFriends(a),new twttr.components.RelatedServices,new twttr.components.Footer,] : ((((b == \"no_recent_view\")) ? c = [new twttr.components.RecentlyFollowed,new twttr.components.InviteFriends(a),new twttr.components.RelatedServices,new twttr.components.Footer,] : ((((b == \"no_invite_friends\")) ? c = [new twttr.components.RecentlyFollowed,new twttr.components.RecentlyViewed,new twttr.components.RelatedServices,new twttr.components.Footer,] : ((((b == \"no_related_services\")) ? c = [new twttr.components.RecentlyFollowed,new twttr.components.RecentlyViewed,new twttr.components.InviteFriends(a),new twttr.components.Footer,] : ((((b == \"invite_friends_only\")) && (c = [new twttr.components.InviteFriends(a),]))))))))))))), c;\n            },\n            _switchTabAndRender: function(a, b, c) {\n                ((this._rendered || this.render()));\n                var d = this.$find(\".who-to-follow-header form input\");\n                ((b ? d.val(b).addClass(\"actasfocused\").JSBNG__focus() : d.val(\"\").removeClass(\"actasfocused\").JSBNG__blur())), this.focusStreamTab(a, c), this.$find(\".who-to-follow-stream\").removeClass().addClass(((((\"who-to-follow-stream who-to-follow-\" + a)) + \"-stream\"))), twttr.themes.loadDefaultTheme();\n            }\n        }), a(twttr.components.pages.WhoToFollow);\n    });\n});\nprovide(\"components/pages/WebPersonalizationPreview\", function(a) {\n    using(\"_\", \"constants\", \"components/WebPersonalizationSettings\", \"components/Footer\").as(function(b, _) {\n        var c = twttr.klass.page(\"twttr.components.pages.WebPersonalizationPreview\").view(twttr.views.WebPersonalizationPreview).containerCssClass(\"wrapper-narrow\").methods({\n            preview: function(a, c) {\n                if (((!twttr.decider.isAvailable(\"personalization_preview\") && !c.force_bq))) {\n                    return twttr.router.redirectTo(twttr.router.whoToFollowInterestsPath());\n                }\n            ;\n            ;\n                this.updatePageTitle(_(\"Twitter / Web Personalization Preview\")), ((twttr.inEU && trackClient({\n                    element: \"eu\",\n                    action: \"impression\"\n                }))), ((twttr.doNotTrack && trackClient({\n                    element: \"dnt\",\n                    action: \"impression\"\n                }))), twttr.themes.loadDefaultTheme(), this.$node.empty();\n                var d = new b.components.WebPersonalizationSettings;\n                d.$node.appendTo(this.$node), d.bind(\"disallow\", function(a) {\n                    twttr.router.routeTo(twttr.router.homePath());\n                }), (new b.components.Footer(\"slim\")).$node.appendTo(this.$node);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/pages/404\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.pages.404\").subclassOf(twttr.components.Page).view(twttr.views[\"404Page\"]).containerCssClass(\"error-page\").methods({\n            notFound: function(a) {\n                this.render(), this.updatePageTitle(_(\"Twitter / ?\")), twttr.themes.loadCurrentUserStyle();\n            }\n        }).methods({\n            noAutoRender: !0\n        }).addAfterRender(function() {\n            var a = this, b = new twttr.components.Footer(\"slim\");\n            this.$find(\"div.four-oh-four-footer\").remove(), b.$node.appendTo(this.$find(\".four-oh-four\")), twttr.helpers.addFormEvents(this.$find(\".user-search-form\"), function() {\n                var a = this.q.value;\n                ((((a != \"\")) && ((twttr.isT1 ? twttr.router.routeTo(twttr.router.userSearchPath({\n                    query: a\n                })) : twttr.router.routeTo(twttr.router.whoToFollowSearchPath({\n                    query: a\n                }))))));\n            }), a.$find(\".user-search-form\").addClass(\"ready\");\n        }), a(twttr.components.pages[404]);\n    });\n});\nprovide(\"components/pages/403\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.pages.403\").subclassOf(twttr.components.Page).view(twttr.views.SuspendedUserPage).containerCssClass(\"error-page\").methods({\n            suspendedUser: function(a) {\n                this.render(), this.updatePageTitle(_(\"Twitter / Suspended\")), twttr.themes.loadCurrentUserStyle();\n            }\n        }).methods({\n            noAutoRender: !0\n        }), a(twttr.components.pages[403]);\n    });\n});\nprovide(\"components/pages/PlaceT1\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.pages.PlaceT1\", function() {\n            twttr.components.Page.apply(this, arguments);\n        }).subclassOf(twttr.components.Page).methods({\n            tweets: function(a) {\n                var b = this;\n                twttr.API.Place.JSBNG__find(a.place_id, {\n                    success: function(a) {\n                        twttr.router.redirectTo(twttr.geo.getPlaceFullAddressAndMapLink(a.data()).map_link);\n                    },\n                    error: function(a) {\n                        b.trigger(\"notFound\");\n                    }\n                });\n            },\n            noAutoRender: !0\n        });\n        a(c);\n    });\n});\nprovide(\"components/pages/RateLimit\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.pages.RateLimit\").subclassOf(twttr.components.Page).view(twttr.views.RateLimitPage).methods({\n            tooMuch: function(a) {\n                this.render(), this.updatePageTitle(_(\"Twitter / Error\")), twttr.themes.loadDefaultTheme();\n            }\n        }).methods({\n            noAutoRender: !0\n        }).containerCssClass(\"four-twenty-container\"), a(twttr.components.pages.RateLimit);\n    });\n});\nprovide(\"components/pages/mixins/welcomeLearnFlowT1\", function(a) {\n    using().as(function() {\n        twttr.klass.mixin(\"twttr.components.pages.mixins.welcomeLearnFlowT1\", function() {\n            return this.click({\n                \".js-account-group\": function(a, b) {\n                    a.stopPropagation(), a.preventDefault(), this.showMiniProfile(b.closest(\".js-actionable-user\").data(\"user-id\")), twttr.scribbles.logViewProfileDetails.call(b, a);\n                },\n                \".js-who-to-follow-search .js-submit\": function() {\n                    trackClient({\n                        component: \"user_search_form\",\n                        element: \"search_button\",\n                        action: \"click\"\n                    });\n                }\n            }).methods({\n                showMiniProfile: function(a) {\n                    twttr.API.User.JSBNG__find(a, function(a) {\n                        using(\"widget/MiniProfileDialog\", function(b) {\n                            (new b(a, !0)).open();\n                        });\n                    });\n                },\n                _slideDrawer: function(a, b) {\n                    ((a ? $(\".js-welcome-dashboard\").show() : $(\".js-welcome-dashboard\").hide())), ((b && b()));\n                },\n                _customRenderStep: function(a) {\n                    ((((a == \"matches\")) ? this.$find(\".js-back-to-import\").show() : this.$find(\".js-back-to-import\").hide()));\n                },\n                _pulseFollowButton: function() {\n                \n                },\n                _resizeFlow: function() {\n                    var a = (((((((((($(window).height() - $(\".js-flow-step\").JSBNG__outerHeight())) - $(\".js-welcome-stream-header\").JSBNG__outerHeight())) - $(\"div.js-stream-header\").JSBNG__outerHeight())) - (($(\".js-back-to-import:visible\").JSBNG__outerHeight() || 0)))) - 114));\n                    ((((a > 100)) && $(\".stream-manager-container\").css(\"max-height\", a)));\n                    var b = (((((((($(window).height() - $(\".js-welcome-faux-tweet-stream\").height())) - $(\".js-content-header\").height())) - 153)) + 30));\n                    ((((b > 20)) && $(\".route-welcome .content-main .stream-end-inner\").css(\"padding-bottom\", b)));\n                },\n                _getNextButtonText: function(a) {\n                    return ((a ? _(\"Done\") : _(\"Next\")));\n                },\n                _setTheme: function() {\n                    twttr.themes.loadDefaultTheme();\n                }\n            }).addOnSwitchTo(function() {\n                twttr.cache.local.shownWelcomeFlow = !0;\n            });\n        }), a();\n    });\n});\nprovide(\"components/pages/WelcomeLearnFlow\", function(a) {\n    using(\"streams/SuggestionCategoryMembersDashboardStream\", \"stork\").as(function(b) {\n        twttr.klass.page(\"twttr.components.pages.WelcomeLearnFlow\", function() {\n            twttr.components.Page.apply(this, arguments), this._steps = this._firstStep = null;\n            var a = twttr.Router.getCurrentQueryStringParams();\n            this._resurrect = !!a.resurrect;\n            var b = [];\n            for (var c = 0; ((c < b.length)); ++c) {\n                var d = twttr.abdecider.choose(b[c]);\n                if (((d != \"\"))) {\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            ((d || (this._bucket = a.welcomeBucket))), this._showIntro = !0, this._showProgress = !0, this.PROFILE_SIZE_LIMIT = 716800;\n        }).subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage).mixin(twttr.mixins.discoveryHelper).mixin(twttr.mixins.welcomeScribing).mixin(((twttr.isT1 ? twttr.components.pages.mixins.welcomeLearnFlowT1 : twttr.components.pages.mixins.welcomeLearnFlowP1))).view(twttr.views.WelcomeLearnFlow).click({\n            \".user-content-image, .display-name, .screen-name\": function(a) {\n                $(a.target).closest(\".stream-item-content\").JSBNG__find(\".more-info\").slideDown();\n            },\n            \".glass .submit\": function(a) {\n                $(a.target).closest(\"form\").submit();\n            },\n            \".js-tweet-1, .js-tweet-2, .js-skip-tweets\": function(a) {\n                return this._nextGameRound($(a.target)), !1;\n            },\n            \".js-image-error .js-dismiss\": function() {\n                this._hideImageError();\n            },\n            \".js-back-to-stream .js-button\": function() {\n                this.$find(\".js-welcome-search input[type='text']\").val(\"\");\n                var a = this._steps[this._currentSearchStepId].route;\n                twttr.router.routeTo(a);\n            },\n            \".js-full-results-link\": function(a) {\n                var b = (($(a.target).data(\"query\") || \"\"));\n                trackClient({\n                    section: \"search\",\n                    element: \"full_results_link\",\n                    action: \"click\"\n                }, {\n                    query: b\n                }), this.routePageTo(this.PATH_ROOT, \"Search\", {\n                    query: b\n                });\n            },\n            \".js-skip-link\": function(a) {\n                if (this._shouldShowInvite()) {\n                    this._inviteStepDialog();\n                    if (((twttr.abdecider.choose(\"welcome_aggressive_invite_modal_345\") === \"invite_step\"))) {\n                        return !1;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                var b = this, c = $(a.target), d = this._steps[this._currentStepId], e = function() {\n                    b._scribeStepCompletion(\"skip\"), ((b._isOnLastStep() ? b.finish() : twttr.router.routeTo(c.attr(\"href\"))));\n                };\n                return ((((d && d.skip_handler)) ? d.skip_handler(e) : window.JSBNG__setTimeout(e, 0))), !1;\n            },\n            \".js-next-btn\": function(a) {\n                var b = this, c = $(a.target);\n                if (c.is(\".disabled\")) {\n                    return !1;\n                }\n            ;\n            ;\n                if (this._shouldShowInvite()) {\n                    this._inviteStepDialog();\n                    if (((twttr.abdecider.choose(\"welcome_aggressive_invite_modal_345\") === \"invite_step\"))) {\n                        return !1;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                var d = this._steps[this._currentStepId], e = function() {\n                    b._scribeStepCompletion(\"done\"), ((b._isOnLastStep() ? b.finish() : twttr.router.routeTo(c.attr(\"href\"))));\n                }, f;\n                return ((((b._lastStream && b._lastStream.deferFollows)) ? f = function() {\n                    d.suppress_follow_progress = !0, b._addNextDisableReason(\"prefollowing\"), b._lastStream.commitPrefollows(function() {\n                        d.suppress_follow_progress = !1, e();\n                    });\n                } : f = e)), ((((d && d.next_handler)) ? d.next_handler(f) : window.JSBNG__setTimeout(f, 0))), !1;\n            },\n            \".js-action-follow-all-listed\": function(a) {\n                var b = this, c = $(a.target);\n                if (c.hasClass(\"disabled\")) {\n                    return;\n                }\n            ;\n            ;\n                trackClient({\n                    component: \"stream\",\n                    action: \"follow_all\"\n                });\n                var d = b._lastStream.usersToFollow();\n                if (((d.length === 0))) {\n                    return;\n                }\n            ;\n            ;\n                c.addClass(\"disabled\"), b._onFollowAll(d, {\n                    complete: function() {\n                        c.removeClass(\"disabled\");\n                    }\n                }), a.preventDefault();\n            }\n        }).addOnSwitchTo(function() {\n            this.updatePageTitle(_(\"Twitter / Welcome\")), twttr.app.resetPadding(), this.setWelcomeSkipCookie(), this._setSteps(), ((((twttr.abdecider.choose(\"growth_stork_persistent_239\") != \"no_stork\")) && twttr.stork.init())), ((twttr.decider.isAvailable(\"welcome_timeline_stats\") && (twttr.streams.Home.scribeTweetDensity = !0, twttr.components.pages.Home.scribeScroll = !0)));\n            var a = this;\n            twttr.API.User.bind(\"follow_request.WelcomeLearnFlow prefollow_request.WelcomeLearnFlow\", {\n                before: function(b) {\n                    var c = a._steps[a._currentStepId];\n                    ((c.suppress_follow_progress || a._updateProgress(1)));\n                }\n            }), twttr.API.User.bind(\"follow.WelcomeLearnFlow prefollow.WelcomeLearnFlow\", {\n                before: function(b) {\n                    var c = a._steps[a._currentStepId];\n                    ((c.suppress_follow_progress || a._updateProgress(1)));\n                },\n                success: function(b, c) {\n                    a._previewFollow(c);\n                }\n            }), twttr.API.User.bind(\"unfollow.WelcomeLearnFlow unprefollow.WelcomeLearnFlow\", {\n                before: function(b) {\n                    var c = a._steps[a._currentStepId];\n                    ((c.suppress_follow_progress || a._updateProgress(-1)));\n                },\n                success: function(b, c) {\n                    a._previewUnfollow(c);\n                }\n            }), $(window).bind(\"resize.WelcomeLearnFlow\", twttr.bind(this, this._resizeFlow));\n        }).addOnSwitchAway(function() {\n            twttr.app.recalculatePadding(), this._steps = this._firstStep = null, twttr.API.User.unbind(\".WelcomeLearnFlow\"), $(window).unbind(\"resize.WelcomeLearnFlow\"), ((this._profileImageInterval && (window.JSBNG__clearInterval(this._profileImageInterval), this._profileImageInterval = null))), twttr.components.pages.WelcomeLearnFlow.profileImageUploadCallback = $.noop;\n        }).addAfterRender(function() {\n            var a = this;\n            this._rendered = !0, this.streamManager.noInfiniteScroll = !0, this.$find(\".welcome-dashboard div.js-stream-manager-container\").bind(\"JSBNG__scroll\", function(b) {\n                var c = $(this);\n                ((((Math.abs(((((c.scrollTop() + c.height())) - c.children().height()))) < 100)) && a.streamManager.getMoreOldItems(function(a) {\n                    scribble(\"stream-scrolled\", {\n                        page: a._page,\n                        stream: a._cacheKey,\n                        focused_tweet_id: ((a.focusedItemId || \"\"))\n                    });\n                })));\n            }), twttr.helpers.addFormEvents(a.$find(\".js-welcome-search form\"), function(b, c) {\n                var d = c.q;\n                if (((d !== \"\"))) {\n                    var e = function() {\n                        trackClient({\n                            component: \"user_search_form\",\n                            action: \"search\"\n                        }, {\n                            query: d\n                        });\n                        var b = ((((twttr.abdecider.choose(\"welcome_top_people_286\") == \"top_people\")) ? \"SearchTop\" : \"Search\"));\n                        a.routePageTo(a.PATH_ROOT, b, {\n                            query: d\n                        });\n                    };\n                    ((((a._lastStream && a._lastStream.deferFollows)) ? a._lastStream.commitPrefollows(e) : e()));\n                }\n            ;\n            ;\n            }), twttr.helpers.addFormEvents(a.$find(\".js-welcome-zipcode-search form\"), function(b, c) {\n                var d = c.q;\n                if (((d !== \"\"))) {\n                    var e = function() {\n                        trackClient({\n                            component: \"zipcode_search_form\",\n                            action: \"search\"\n                        }, {\n                            query: d\n                        }), a.routePageTo(a.PATH_ROOT, \"LifelineSearch\", {\n                            query: d\n                        });\n                    };\n                    ((((a._lastStream && a._lastStream.deferFollows)) ? a._lastStream.commitPrefollows(e) : e()));\n                }\n            ;\n            ;\n            });\n        }).statics({\n            ROUTES_TO_STEP: {\n                intro: \"intro\",\n                interests: \"interests\",\n                lifeline: \"lifeline\",\n                category: \"interests\",\n                \"import\": \"import\",\n                matches: \"import\",\n                search: \"search\",\n                starter: \"starter\",\n                recommendations: \"recommendations\",\n                profile: \"profile\",\n                tweets: \"tweets\",\n                preview: \"preview\",\n                edit: \"edit\"\n            }\n        }).methods({\n            PATH_ROOT: \"welcome\",\n            noAutoRender: !0,\n            _addressBookAvailable: function() {\n                return twttr.decider.isAvailable(\"wtf_signup_suggestions\");\n            },\n            _previewFollow: function(a) {\n                var b = this, c = this.$find(((((\".js-tweet-preview-container .js-unclickable-tweet[data-user-id=\\\"\" + a.idStr)) + \"\\\"]\")));\n                if (c.length) {\n                    b.trigger(\"followPreviewed\"), c.slideDown();\n                    return;\n                }\n            ;\n            ;\n                var d = function(a) {\n                    b.trigger(\"followPreviewed\");\n                    var c = new twttr.views.UnclickableTweet(a), d = $(c.html()).hide(), e = b.$find(\".js-tweet-preview-container .stream-loading\");\n                    ((e.length ? e.before(d) : b.$find(\".js-tweet-preview-container\").prepend(d))), d.slideDown();\n                };\n                ((((((a.JSBNG__status && !a.JSBNG__status.inReplyToUserId)) && !a.JSBNG__status.attributes.was_retweeted)) ? (a.JSBNG__status.attributes.user = a.attributes, d(a.JSBNG__status)) : a.timeline({\n                    count: 25,\n                    exclude_replies: !0,\n                    success: function(a) {\n                        ((a.length() ? d(a.first()) : b.trigger(\"followPreviewed\")));\n                    },\n                    error: function() {\n                        b.trigger(\"followPreviewed\");\n                    }\n                })));\n            },\n            _previewUnfollow: function(a) {\n                var b = this, c = this.$find(((((\".js-tweet-preview-container .js-unclickable-tweet[data-user-id=\" + a.id)) + \"]\")));\n                c.slideUp();\n            },\n            _setSteps: function() {\n                var a = this;\n                this._steps = {\n                    intro: {\n                        route: twttr.router.welcomeIntroPath(),\n                        title: _(\"Welcome, {{{name}}}.\", twttr.currentUser),\n                        subtitle: _(\"Get started in less than 60 seconds.\"),\n                        next_step: \"recommendations\",\n                        show_progress: !1,\n                        show_search: !1,\n                        next_enabled: !0,\n                        no_drawer: !0,\n                        show_intro_text: !1\n                    },\n                    recommendations: {\n                        route: twttr.router.welcomeRecommendationsPath(),\n                        title: ((((twttr.abdecider.choose(\"timeline_copy_317\") === \"stream\")) ? _(\"Build your stream.\") : _(\"Build your timeline.\"))),\n                        subtitle: _(\"Follow people to get their Tweets.\"),\n                        next_step: \"interests\",\n                        show_search: !0,\n                        show_progress: !0,\n                        initial_progress_copy: _(\"Start by following 5\"),\n                        min_progress: 3,\n                        suggested_progress: 5,\n                        next_enabled: !1,\n                        show_intro_text: !0\n                    },\n                    \"import\": {\n                        route: twttr.router.welcomeImportPath(),\n                        title: _(\"Find people you know.\"),\n                        subtitle: _(\"Add your contacts securely.\"),\n                        next_step: \"finish\",\n                        show_search: !0,\n                        show_progress: !0,\n                        initial_progress_copy: _(\"Try 5 more\"),\n                        min_progress: 2,\n                        suggested_progress: 5,\n                        next_enabled: !1,\n                        show_intro_text: !0\n                    },\n                    matches: {\n                        route: twttr.router.welcomeImportMatchesPath(),\n                        title: _(\"Find people you know.\"),\n                        subtitle: _(\"Add your contacts securely.\"),\n                        next_step: \"finish\",\n                        show_search: !0,\n                        show_progress: !0,\n                        initial_progress_copy: _(\"Try 5 more\"),\n                        min_progress: 2,\n                        suggested_progress: 5,\n                        next_enabled: !1,\n                        show_intro_text: !0\n                    },\n                    interests: {\n                        route: twttr.router.welcomeInterestsPath(),\n                        title: _(\"See who\\u2019s here.\"),\n                        subtitle: _(\"Find and follow well-known people.\"),\n                        next_step: \"finish\",\n                        show_search: !0,\n                        show_progress: !0,\n                        initial_progress_copy: _(\"Try 5 more\"),\n                        min_progress: 3,\n                        suggested_progress: 5,\n                        next_enabled: !1,\n                        show_intro_text: !0\n                    },\n                    lifeline: {\n                        route: twttr.router.welcomeLifelinePath(),\n                        title: _(\"Use Twitter as Lifeline\"),\n                        subtitle: _(\"Enter your Zip Code and search Lifeline accounts.\"),\n                        next_step: \"finish\",\n                        show_search: !1,\n                        show_zipcode_search: !0,\n                        show_progress: !1,\n                        next_enabled: !0\n                    },\n                    profile: {\n                        route: twttr.router.welcomeProfilePath(),\n                        title: _(\"Add character.\"),\n                        subtitle: _(\"Upload a photo and describe yourself.\", twttr.currentUser),\n                        next_step: \"finish\",\n                        show_search: !1,\n                        show_progress: !1,\n                        min_progress: 1,\n                        suggested_progress: 1,\n                        next_enabled: ((twttr.abdecider.choose(\"hide_skip_in_profile_welcome_step_288\") === \"skip_disabled\")),\n                        skip_disabled: ((twttr.abdecider.choose(\"hide_skip_in_profile_welcome_step_288\") === \"skip_disabled\")),\n                        next_handler: function(b) {\n                            a._handleProfileNext(b);\n                        },\n                        show_intro_text: !0\n                    },\n                    building: {\n                        title: _(\"Building your timeline\\u2026\"),\n                        next_step: \"preview\",\n                        no_drawer: !0,\n                        no_nav: !0,\n                        next_enabled: !0\n                    },\n                    tweets: {\n                        route: twttr.router.welcomeTweetsPath()\n                    },\n                    preview: {\n                        route: twttr.router.welcomePreviewPath(),\n                        title: _(\"Here\\u2019s your timeline.\"),\n                        subtitle: _(\"You\\u2019re now following \\u003Cspan class=\\\"js-following-count\\\"\\u003E10\\u003C/span\\u003E people. Check out their Tweets.\"),\n                        next_text: _(\"Continue\"),\n                        next_step: \"finish\",\n                        show_search: !1,\n                        show_progress: !1,\n                        min_progress: 1,\n                        suggested_progress: 1,\n                        next_enabled: !0,\n                        next_highlighted: !0,\n                        edit_enabled: !0,\n                        no_drawer: !0\n                    },\n                    edit: {\n                        route: twttr.router.welcomeEditPath(),\n                        title: _(\"Edit your timeline.\"),\n                        subtitle: _(\"Here are the people you\\u2019re following. \\u003Cbr\\u003E To unfollow someone, click the blue button next to their name.\"),\n                        next_step: \"finish\",\n                        show_search: !0,\n                        show_progress: !1,\n                        min_progress: 1,\n                        suggested_progress: 1,\n                        next_enabled: !0,\n                        next_highlighted: !0\n                    }\n                }, this._firstStep = ((this._showIntro ? \"intro\" : \"recommendations\"));\n                var b = \"interests\", c;\n                ((((!this._resurrect && ((twttr.abdecider.choose(\"optometrist_247\").indexOf(\"opto_\") == 0)))) && (this._firstStep = \"tweets\", b = \"preview\"))), ((this._resurrect && (this._steps[\"import\"].min_progress = 0))), ((((twttr.abdecider.choose(\"welcome_prefollow_213\") == \"prefollow\")) && (this._steps.recommendations.subtitle += ((\" \" + _(\"Here are 3 accounts to get you started.\"))))));\n                var d = twttr.decider.isAvailable(\"contact_import\"), e = ((((twttr.decider.isAvailable(\"welcome_profile\") && twttr.decider.isAvailable(\"avatar_upload\"))) && !this._resurrect));\n                ((d && (c = this._steps[b], c.next_step = \"import\", b = \"import\"))), ((e && (c = this._steps[b], c.next_step = \"profile\", b = \"profile\")));\n                if (((twttr.decider.isAvailable(\"welcome_lifeline\") && ((twttr.pageLocale === \"ja\"))))) {\n                    var f = twttr.abdecider.choose(\"welcome_learn_flow_lifeline_step_for_japan_316\");\n                    ((((f === \"as_last_step\")) ? (this._steps.lifeline.next_step = this._steps.profile.next_step, this._steps.profile.next_step = \"lifeline\") : ((((f !== \"no_lifeline_step\")) && (this._steps.lifeline.next_step = this._steps.intro.next_step, this._steps.intro.next_step = \"lifeline\")))));\n                }\n            ;\n            ;\n                this._runSwapOOPExperiment(d, e), ((twttr.decider.isAvailable(\"welcome_ad_track\") && (this._steps.intro.ad_referal = (($.cookie(\"ad_partner\") == \"adparlor\")), this._steps.intro.ad_parlor = (($.cookie(\"ad_partner\") == \"adparlor\"))))), this._currentSearchStepId = this._steps.intro.next_step, this._steps.matches.next_step = this._steps[\"import\"].next_step, this._steps.edit.next_step = this._steps.preview.next_step;\n            },\n            _runSwapOOPExperiment: function(a, b) {\n                var c, d, e, f;\n                f = ((twttr.abdecider.choose(\"JSBNG__onboarding_swap_contacts_and_profile_328\") == \"swap_import_and_profile\"));\n                if (((((!f || !a)) || !b))) {\n                    return;\n                }\n            ;\n            ;\n                for (e in this._steps) {\n                    if (!this._steps.hasOwnProperty(e)) {\n                        continue;\n                    }\n                ;\n                ;\n                    d = this._steps[e], ((((d.next_step == \"import\")) && (d.next_step = \"profile\")));\n                };\n            ;\n                c = this._steps.profile, this._steps[\"import\"].next_step = c.next_step, c.next_step = \"import\";\n            },\n            _addAmbassadorList: function(a, b) {\n                ((((twttr.currentUser.friendsCount > 0)) ? twttr.currentUser.friends().first(function(c) {\n                    if (!c) {\n                        b();\n                        return;\n                    }\n                ;\n                ;\n                    c.lists(function(c) {\n                        var d = c.JSBNG__find(function(a) {\n                            return a.description.match(/\\#WelcomeToTwitter/i);\n                        });\n                        if (d) {\n                            var e = [], f = -1, g = function() {\n                                d.members({\n                                    cursor: f,\n                                    success: function(c, d) {\n                                        e = e.concat(c.toArray()), ((d.response.next_cursor ? (f = d.response.next_cursor, g()) : (a.unshift(e), a.render(), b())));\n                                    }\n                                });\n                            };\n                            g();\n                        }\n                         else b();\n                    ;\n                    ;\n                    });\n                }) : b()));\n            },\n            _routeToFirstStep: function() {\n                var a = this;\n                window.JSBNG__setTimeout(function() {\n                    ((a._steps ? twttr.router.routeTo(a._steps[a._firstStep].route) : twttr.router.routeTo(twttr.router.welcomePath())));\n                }, 0);\n            },\n            welcome: function(a, b) {\n                ((this._steps ? (trackClient({\n                    action: \"impression\"\n                }), ((this._welcomeSetupSpinner && (this._welcomeSetupSpinner.detach(), this._welcomeSetupSpinner = null))), this._routeToFirstStep()) : (this.render(), this.$find(\".js-welcome-search\").hide(), this.streamManager.setTitle({\n                    _setTitle: function(a) {\n                        a(_(\"Please wait\\u2026\"));\n                    }\n                }), this._welcomeSetupSpinner = (new twttr.views.StreamLoading).render(this.$find(\".js-who-to-follow-stream .stream-container\"), \"html\"))));\n            },\n            _recommendationsStreamOptions: function() {\n                var a = {\n                    inWelcomeFlow: !0,\n                    pathRoot: this.PATH_ROOT,\n                    title: \"\",\n                    scribbler: this._createScribbler(\"recommendations_stream\", {\n                        context: \"starter\"\n                    })\n                };\n                return a;\n            },\n            recommendations: function(a, b) {\n                var c = new twttr.streams.UserRecommendationsStream(this._recommendationsStreamOptions()), d = this, e = function() {\n                    return twttr.router.routeTo(d._nextRoute(d._steps.recommendations));\n                };\n                if (!this._addressBookAvailable()) {\n                    e();\n                    return;\n                }\n            ;\n            ;\n                c.loadRecommendedUsers({\n                    success: function(a, b) {\n                        if (((a.length() > 0))) {\n                            c.scribbler.scribe({\n                                action: \"found_results\",\n                                section: \"recommendations\"\n                            }), d._renderStep(\"recommendations\"), ((d.bqPrefollow && d.$find(\".js-welcome-faux-tweet-stream\").hide()));\n                            var f = d._recommendationsStreamOptions();\n                            f.initialItems = a, f.cursor = b.response.next_cursor;\n                            var g = d.switchToStream(twttr.streams.UserRecommendationsDashboardStream, f);\n                            ((d.bqPrefollow && g.reachedTheEnd())), ((((twttr.decider.isAvailable(\"welcome_warm_signup\") && !d.bqPrefollow)) ? d._addAmbassadorList(g, function() {\n                                d._loadedRecommendations(g);\n                            }) : d._loadedRecommendations(g))), g.bind(\"rendered_recs.WelcomeLearnFlow\", function() {\n                                d._pulseFollowButton();\n                            }), f.scribbler.scribe({\n                                action: \"impression\"\n                            });\n                        }\n                         else c.scribbler.scribe({\n                            action: \"not_found_results\",\n                            section: \"recommendations\"\n                        }), e();\n                    ;\n                    ;\n                    },\n                    error: function(a) {\n                        e();\n                    }\n                });\n            },\n            _loadedRecommendations: function(a) {\n                ((((((twttr.abdecider.choose(\"welcome_prefollow_213\") == \"prefollow\")) && ((twttr.currentUser.friendsCount <= 1)))) && this._prefollow(a, 3))), ((this.bqPrefollow && this._prefollow(a, 100)));\n            },\n            _prefollow: function(a, b) {\n                var c = this, d = this._steps[this._currentStepId];\n                a.deferFollows = !0, window.JSBNG__setTimeout(function() {\n                    c.$find(\".js-welcome-dashboard .js-stream-item .js-follow-combo\").each(function(c, d) {\n                        if (((c >= b))) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        a.userActionPrefollow($(d), \"prefollow.user\");\n                    }), ((d.next_enabled || window.JSBNG__setTimeout(function() {\n                        c._addNextDisableReason(\"progress\");\n                    }, 0)));\n                }, 0);\n            },\n            _showInlineSuggestions: function(a, b) {\n                var c = this, d = b.closest(\".js-stream-item\"), e = b.attr(\"data-user-id\"), f;\n                for (var g = 0; ((g < a.length)); g++) {\n                    ((((a[g].id.toString() == e)) && (f = a[g]))), c.contextStreamIds[a[g].id] = !0;\n                ;\n                };\n            ;\n                if (!f) {\n                    return;\n                }\n            ;\n            ;\n                var i = new twttr.components.t1.UserSimilaritiesDashboardList(f, c.contextStreamIds);\n                i.bind(\"recommendationsLoaded\", function() {\n                    $recItems = i.$node.JSBNG__find(\".js-stream-item\"), ((((!$.browser.msie || (($.browser.version != 7)))) && $recItems.hide())), d.after($recItems), ((((!$.browser.msie || (($.browser.version != 7)))) && $recItems.slideDown(600)));\n                    for (var a = 0; ((a < i.suggestions.length)); a++) {\n                        c.contextStreamIds[i.suggestions[a].id] = !0, c.componentSuggestions.push(i.suggestions[a]);\n                    ;\n                    };\n                ;\n                    $recItems.delegate(\".js-actionable-user .js-action-follow\", \"click\", function(a) {\n                        trackClient({\n                            component: \"user_similarities_dashboard_list\",\n                            element: \"follow_button\",\n                            action: \"click\"\n                        }), c._showInlineSuggestions(c.componentSuggestions, $(this));\n                    });\n                }), i.bind(\"notRendered\", function() {\n                    i.destroy();\n                });\n            },\n            intro: function(a, b) {\n                trackClient({\n                    action: \"impression\"\n                }), this._renderStep(\"intro\"), this.switchToStream(null);\n            },\n            resurrect: function(a, b) {\n                var c = twttr.router.welcomeRecommendationsPath();\n                trackClient({\n                    action: \"impression\"\n                }, \"resurrect\"), c = ((\"/?resurrect=1\" + c.slice(1))), window.JSBNG__location.href = c;\n            },\n            \"import\": function(a, b) {\n                if (!twttr.loggedIn) {\n                    return this.trigger(\"loginRequired\");\n                }\n            ;\n            ;\n                this._renderStep(\"import\"), trackClient({\n                    action: \"impression\"\n                }, \"import\");\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                }), d = this.localizeQuery({\n                    scribbler: c,\n                    pathRoot: this.PATH_ROOT,\n                    JSBNG__onlyMatched: ((twttr.abdecider.choose(\"welcome_flow_no_choice_contact_import_160\") == \"no_choice_contact_import\")),\n                    inWelcomeFlow: !0,\n                    context: \"welcome\"\n                }, b), e = this.switchToStream(twttr.streams.DashboardContactImportServices, d);\n                ((e && (e.setStreamManager(this.streamManager), e.setMatchesStreamKey(this._lastMatchesStreamKey))));\n            },\n            matches: function() {\n                if (!twttr.loggedIn) {\n                    return this.trigger(\"loginRequired\");\n                }\n            ;\n            ;\n                this._renderStep(\"matches\"), trackClient({\n                    action: \"impression\"\n                }, \"import\");\n                var a = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                }), b = {\n                    scribbler: a,\n                    pathRoot: this.PATH_ROOT\n                }, c = this.switchToStream(twttr.streams.DashboardContactImportMatches, b), d = this;\n                c.bind(\"error.WelcomeLearnFlow\", function() {\n                    d._removeNextDisableReason(\"progress\");\n                }), this._lastMatchesStreamKey = c._cacheKey;\n            },\n            interests: function(a, b) {\n                var c = this;\n                this._renderStep(\"interests\"), trackClient({\n                    action: \"impression\"\n                });\n                var d = twttr.Scribbler.clientEvent.spawn({\n                    context: \"interests\"\n                }), e = {\n                    scribbler: d,\n                    noHeaderFooter: !0,\n                    title: \"\",\n                    pathRoot: this.PATH_ROOT\n                };\n                this.switchToStream(twttr.streams.SuggestionCategoriesDashboardStream, this.localizeQuery(e, b));\n            },\n            lifeline: function(a, b) {\n                trackClient({\n                    action: \"impression\"\n                }), this._renderStep(\"lifeline\");\n                var c = twttr.streams.SuggestionLifelineMembersStream.categoryObj, d = twttr.Scribbler.clientEvent.spawn({\n                    context: \"lifeline\"\n                }), e = this.localizeQuery({\n                    category: \"lifeline\",\n                    suggestionCategory: c,\n                    scribbler: d,\n                    noHeaderFooter: !0,\n                    title: ((((((c.JSBNG__name + \" (\")) + c.size)) + \")\")),\n                    pathRoot: this.PATH_ROOT\n                }, b);\n                this.switchToStream(twttr.streams.SuggestionLifelineMembersDashboardStream, e);\n            },\n            category: function(a, c) {\n                var d = this, e = function(a) {\n                    if (!a) {\n                        return d.routePageTo(d.PATH_ROOT, \"Interests\");\n                    }\n                ;\n                ;\n                    var e = twttr.Scribbler.clientEvent.spawn({\n                        context: \"interests\",\n                        query: a.slug\n                    });\n                    d._renderStep(\"interests\"), d.$find(\".js-back-to-stream .js-dashboard-stream-title\").text(a.JSBNG__name), d.$find(\".js-back-to-stream\").show(), d._resizeFlow();\n                    var g = d.localizeQuery({\n                        category: f,\n                        suggestionCategory: a,\n                        scribbler: e,\n                        noHeaderFooter: !0,\n                        title: ((((((a.JSBNG__name + \" (\")) + a.size)) + \")\")),\n                        pathRoot: d.PATH_ROOT\n                    }, c);\n                    d.switchToStream(b.streams.SuggestionCategoryMembersDashboardStream, g);\n                }, f = ((a.category || c.category));\n                trackClient({\n                    action: \"impression\"\n                }, {\n                    query: f,\n                    context: \"interests\"\n                });\n                var g = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP;\n                ((g ? e(g[f]) : twttr.API.SuggestionCategory.getAll(this.localizeQuery({\n                    success: function(a) {\n                        a = twttr.streams.SuggestionCategoriesStream.filterTopTweetsCategories(a), twttr.streams.SuggestionCategoriesStream.cacheCategories(a);\n                        var b = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP[f];\n                        e(b);\n                    }\n                }, c))));\n            },\n            switchToStream: function(a) {\n                ((this._lastStream && (this._lastStream.unbind(\".WelcomeLearnFlow\"), this._lastStream.$node.unbind(\".WelcomeLearnFlow\"), this._lastStream = null))), ((a ? this._lastStream = this.streamManager.switchTo.apply(this.streamManager, arguments) : (this.streamManager.switchOut(), this.streamManager.setCurrent(null), ((this.streamManager.$moreButton && this.streamManager.$moreButton.hide())))));\n                if (((((twttr.abdecider.choose(\"welcome_wtf_slide_down_similar_318\") == \"new_suggestions\")) && this._lastStream))) {\n                    var b = this;\n                    b.contextStreamIds = {\n                    }, b.componentSuggestions = [], b._lastStream.$node.delegate(\".js-actionable-user .js-action-follow\", \"click.WelcomeLearnFlow\", function(a) {\n                        (($(this).closest(\".js-stream-item\").hasClass(\"js-similar-user\") || (trackClient({\n                            component: \"recommendations_stream\",\n                            element: \"follow_button\",\n                            action: \"click\"\n                        }), b._showInlineSuggestions(b._lastStream.items, $(this)))));\n                    });\n                }\n            ;\n            ;\n                return this._lastStream;\n            },\n            search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return twttr.router.routeTo(this._steps[this._currentSearchStepId].route);\n                }\n            ;\n            ;\n                this._renderStep(this._currentSearchStepId);\n                var d = this.$find(\".js-back-to-stream\");\n                d.JSBNG__find(\"h3\").html(_(\"Results for: \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\", {\n                    query: \"\"\n                })).JSBNG__find(\"strong\").text(c), d.show(), this.$find(\".js-welcome-search input[type=\\\"text\\\"]\").JSBNG__focus();\n                var e = this._createScribbler({\n                    section: \"search\",\n                    component: \"full_stream\"\n                }, {\n                    context: \"search\",\n                    query: c\n                });\n                e.scribe({\n                    action: \"impression\"\n                });\n                var f = {\n                    query: c,\n                    scribbler: e,\n                    pathRoot: this.PATH_ROOT\n                };\n                this.switchToStream(twttr.streams.DashboardPeopleSearch, f);\n            },\n            searchByZipcode: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return twttr.router.routeTo(this._steps[this._currentSearchStepId].route);\n                }\n            ;\n            ;\n                this._currentSearchStepId = \"lifeline\", this._renderStep(\"lifeline\");\n                var d = this.$find(\".js-back-to-stream\");\n                d.JSBNG__find(\"h3\").html(_(\"Results for: \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\", {\n                    query: \"\"\n                })).JSBNG__find(\"strong\").text(c), d.show(), this.$find(\".js-zipcode-search input[type=\\\"text\\\"]\").JSBNG__focus(), trackClient({\n                    action: \"impression\"\n                }, {\n                    context: \"search\",\n                    query: c\n                });\n                var e = twttr.Scribbler.clientEvent.spawn({\n                    context: \"search\",\n                    query: c\n                }), f = twttr.streams.SuggestionLifelineMembersStream.categoryObj, g = this.localizeQuery({\n                    category: \"lifeline\",\n                    suggestionCategory: f,\n                    scribbler: e,\n                    noHeaderFooter: !0,\n                    title: ((((((f.JSBNG__name + \" (\")) + f.size)) + \")\")),\n                    pathRoot: this.PATH_ROOT,\n                    zipcode: c\n                }, b);\n                this.switchToStream(twttr.streams.SuggestionLifelineMembersDashboardStream, g);\n            },\n            searchTop: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return twttr.router.routeTo(this._steps[this._currentSearchStepId].route);\n                }\n            ;\n            ;\n                this._renderStep(this._currentSearchStepId);\n                var d = this.$find(\".js-back-to-stream\");\n                d.JSBNG__find(\"h3\").html(_(\"Top results for: \\u003Cstrong\\u003E{{query}}\\u003C/strong\\u003E\", {\n                    query: \"\"\n                })).JSBNG__find(\"strong\").text(c), this.$find(\".js-welcome-search input[type=\\\"text\\\"]\").JSBNG__focus();\n                var e = this._createScribbler({\n                    section: \"search\",\n                    component: \"top_stream\"\n                }, {\n                    context: \"search\",\n                    query: c\n                });\n                e.scribe({\n                    action: \"impression\"\n                });\n                var f = {\n                    query: c,\n                    scribbler: e,\n                    pathRoot: this.PATH_ROOT\n                }, g = this, i = this.switchToStream(twttr.streams.DashboardTopPeopleSearch, f);\n                i.bind(\"results.WelcomeLearnFlow\", function(a, b) {\n                    ((b.isEmpty() ? g.routePageTo(g.PATH_ROOT, \"Search\", {\n                        query: c\n                    }) : d.show()));\n                });\n            },\n            profile: function(a, b) {\n                var c = this;\n                trackClient({\n                    action: \"impression\"\n                });\n                var d = twttr.currentUser.profileImageUrl;\n                ((((d.indexOf(\"default_profile_image\") != -1)) && (d = twttr.assets.path(\"t1/img/upload_placeholder.png\"))));\n                var e = {\n                    description: twttr.currentUser.description,\n                    JSBNG__location: twttr.currentUser.JSBNG__location,\n                    url: twttr.currentUser.url,\n                    profile_image_url: d,\n                    api_url: ((\"//\" + twttr.domains.remote)),\n                    post_authenticity_token: twttr.API.getConfig().postAuthenticityToken\n                };\n                this._renderStep(\"profile\"), this.switchToStream(null), (new twttr.views.WelcomeLearnProfile(e)).render(this.$find(\".js-content-container\"), \"html\");\n                var f = this.$find(\".js-profile-image-input\"), g = this.$find(\".js-profile-form\"), i = this.$find(\".js-bio-count\");\n                f.bind(\"change\", function() {\n                    c._uploadProfileImage();\n                }), twttr.helpers.addFormEvents(g, $.noop), g.JSBNG__find(\"input, textarea\").bind(\"change keypress\", function() {\n                    c._removeNextDisableReason(((\"error_\" + $(this).attr(\"JSBNG__name\")))), c._updateProfileProgress();\n                }), this._updateProfileProgress();\n                var j = function() {\n                    var a = $(this);\n                    window.JSBNG__setTimeout(function() {\n                        var b = ((a.is(\".js-placeholded\") ? 0 : a.val().length));\n                        i.text(((\"\" + b))), i.removeClass(\"warn superwarn\"), ((((b > 150)) ? i.addClass(\"superwarn\") : ((((b > 140)) && i.addClass(\"warn\"))))), ((((b > 160)) ? c._addNextDisableReason(\"bio\") : c._removeNextDisableReason(\"bio\")));\n                    }, 0);\n                };\n                g.JSBNG__find(\"textarea\").bind(\"keyup change\", j).each(j);\n            },\n            _enableProfileImageUploadControls: function() {\n                var a = this.$find(\".js-current-profile-picture-wrapper\"), b = this.$find(\".js-upload-form\");\n                a.removeClass(\"loading\"), b.JSBNG__find(\".btn\").removeClass(\"disabled\"), b.JSBNG__find(\"input[type=\\\"file\\\"]\").attr(\"disabled\", null);\n            },\n            _showImageError: function(a) {\n                this.$find(\".js-image-error .js-image-error-text\").text(a).parent().fadeIn();\n            },\n            _hideImageError: function(a) {\n                this.$find(\".js-image-error\").fadeOut();\n            },\n            _uploadProfileImage: function() {\n                this._hideImageError(), this.$find(\".js-current-profile-picture-wrapper\").addClass(\"loading\");\n                if (twttr.turkey.hasFileReader()) {\n                    var a = this.$find(\".js-profile-image-input\").get(0);\n                    if (((a.files && a.files[0]))) {\n                        var b = a.files[0];\n                        if (!twttr.turkey.validatePhoto(a.value)) {\n                            this._showImageError(_(\"Profile pictures must be JPG, GIF or PNG\")), this._enableProfileImageUploadControls(), trackClient({\n                                section: \"profile\",\n                                component: \"picture\",\n                                action: \"error\"\n                            }), trackClient({\n                                section: \"profile\",\n                                component: \"picture\",\n                                action: \"error_format\"\n                            });\n                            return;\n                        }\n                    ;\n                    ;\n                        if (((!twttr.is.def(b.size) || ((b.size >= this.PROFILE_SIZE_LIMIT))))) {\n                            this._showImageError(_(\"Profile pictures must be smaller than 700K\")), this._enableProfileImageUploadControls(), trackClient({\n                                section: \"profile\",\n                                component: \"picture\",\n                                action: \"error\"\n                            }), trackClient({\n                                section: \"profile\",\n                                component: \"picture\",\n                                action: \"error_size\"\n                            });\n                            return;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                this._submitProfileImageForm();\n            },\n            _submitProfileImageForm: function() {\n                var a = this, b = this.$find(\".js-upload-form\");\n                twttr.components.pages.WelcomeLearnFlow.profileImageUploadCallback = function(b) {\n                    twttr.components.pages.WelcomeLearnFlow.profileImageUploadCallback = $.noop, ((b.error ? (trackClient({\n                        section: \"profile\",\n                        component: \"picture\",\n                        action: \"error\"\n                    }), a._showImageError(b.error), a._enableProfileImageUploadControls()) : (trackClient({\n                        section: \"profile\",\n                        component: \"picture\",\n                        action: \"success\"\n                    }), a._uploadProfileImageCallback())));\n                }, b[0].submit(), b.JSBNG__find(\".btn\").addClass(\"disabled\"), b.JSBNG__find(\"input[type=\\\"file\\\"]\").attr(\"disabled\", \"disabled\");\n            },\n            _uploadProfileImageCallback: function() {\n                var a = this, b = /profile_images\\/.*/, c = twttr.currentUser.profileImageUrl.match(b)[0], d = 0, e = function() {\n                    a._enableProfileImageUploadControls(), window.JSBNG__clearInterval(a._profileImageInterval), a._profileImageInterval = null;\n                };\n                a._profileImageInterval = window.JSBNG__setInterval(function() {\n                    if (((d++ > 20))) {\n                        e();\n                        return;\n                    }\n                ;\n                ;\n                    twttr.currentUser.profileImage(twttr.currentUser.screenName, {\n                        size: \"normal\",\n                        zx: Math.JSBNG__random(),\n                        ssl: !0,\n                        success: function(d) {\n                            var f = d.profile_image_url, g = f.match(b)[0];\n                            ((((g != c)) && (a._updateProfileImageUrl(f), e())));\n                        },\n                        error: function() {\n                            e();\n                        }\n                    });\n                }, 5000);\n            },\n            _updateProfileImageUrl: function(a) {\n                twttr.currentUser.profileImageUrl = a, twttr.currentUser.profileImageUrlHttps = a, twttr.currentUser.attributes.profile_image_url = a, twttr.currentUser.attributes.profile_image_url_https = a, $(\".js-mini-current-user img\").each(function() {\n                    $(this).attr(\"src\", a);\n                });\n                var b = twttr.helpers.transformProfileImageUrl(a, \"reasonably_small\");\n                this.$find(\".js-current-profile-picture-wrapper\").JSBNG__find(\"img\").attr(\"src\", b), this._updateProfileProgress();\n            },\n            _handleProfileNext: function(a) {\n                var b = this, c = this.$find(\".js-profile-form input[type=\\\"text\\\"], .js-profile-form textarea\"), d = this.$find(\".js-profile-form .control-group\"), e = {\n                    success: function() {\n                        c.each(function() {\n                            var a = $(this);\n                            ((((a.val() && ((a.val().length > 1)))) && trackClient({\n                                section: \"profile\",\n                                component: a.attr(\"JSBNG__name\"),\n                                action: \"complete\"\n                            })));\n                        }), a();\n                    },\n                    error: function(a) {\n                        var c = twttr.showError(_(\"Sorry, we weren\\u2019t able to update your profile. Try again or \\u003Ca class=\\\"js-skip-link\\\" href=\\\"#\\\"\\u003Eskip this step\\u003C/a\\u003E.\"));\n                        c.$dom.JSBNG__find(\".js-skip-link\").click(function() {\n                            b.$find(\".js-skip-link\").click();\n                        });\n                    }\n                };\n                if (((c.length == 0))) {\n                    a();\n                    return;\n                }\n            ;\n            ;\n                c.each(function() {\n                    var a = $(this);\n                    ((a.is(\".js-placeholded\") || (e[a.attr(\"JSBNG__name\")] = a.val())));\n                }), d.removeClass(\"error\").JSBNG__find(\".js-error-msg\").remove(), twttr.currentUser.update(e);\n            },\n            _nextRoute: function(a) {\n                var b = this._steps[a.next_step].route;\n                return ((this._resurrect && (b = ((\"/?resurrect=1\" + b.slice(1)))))), b;\n            },\n            _updateProfileProgress: function() {\n                var a = 0;\n                this.$find(\".js-profile-form input[type=\\\"text\\\"], .js-profile-form textarea\").each(function() {\n                    var b = $(this);\n                    ((((b.val() && !b.is(\".js-placeholded\"))) && a++));\n                }), ((((this.$find(\".js-current-profile-picture\").attr(\"src\").indexOf(\"upload_placeholder.png\") == -1)) && a++)), ((((a > 0)) && this._removeNextDisableReason(\"progress\"))), this._setProgress(a);\n            },\n            tweets: function(a, b) {\n                trackClient({\n                    action: \"impression\"\n                }), ((this._rendered || this.render())), this.$find(\".js-dashboard, .js-content-main\").hide(), this.$find(\".js-tweet-game\").remove(), this._setTheme(), this._currentStepId = \"tweets\", this._optoState = {\n                }, this._optoQuery = b, this._optoRound = 1, this._optoSkips = 0;\n                var c = twttr.abdecider.choose(\"optometrist_247\", !0);\n                ((((c.indexOf(\"opto_\") == 0)) ? this._optoMaxRounds = parseInt(c.substring(5), 10) : this._optoMaxRounds = 6));\n                var d = {\n                    JSBNG__name: twttr.currentUser.JSBNG__name,\n                    current_round: 0,\n                    total_rounds: this._optoMaxRounds\n                };\n                (new twttr.views.WelcomeLearnGame(d)).render(this.$node, \"append\"), this._steps.tweets.suggested_progress = this._optoMaxRounds, this._setProgress(0), this._fetchGameTweets();\n            },\n            _fetchGameTweets: function(a, b) {\n                var c = this;\n                $.ajax({\n                    type: \"POST\",\n                    url: \"/i/optometrist/tweets\",\n                    headers: {\n                        \"X-PHX\": !0\n                    },\n                    data: {\n                        state: JSON.stringify(this._optoState),\n                        last_action: ((a || \"\")),\n                        query: ((JSON.stringify(this._optoQuery) || \"\"))\n                    },\n                    dataType: \"json\",\n                    success: function(a) {\n                        c._optoState = a.state;\n                        if (((!a.tweets[0] || !a.tweets[1]))) c._fetchGameTweets(\"skip\", b);\n                         else {\n                            var d = ((b ? Math.max(0, ((b - +(new JSBNG__Date)))) : 0));\n                            window.JSBNG__setTimeout(function() {\n                                ((b ? c.$find(\".js-tweets-container\").css({\n                                    left: \"auto\",\n                                    right: 0\n                                }).animate({\n                                    right: \"100%\"\n                                }, function() {\n                                    c._showGameTweets(a.tweets);\n                                }) : c._showGameTweets(a.tweets)));\n                            }, d);\n                        }\n                    ;\n                    ;\n                    },\n                    error: function() {\n                        trackClient({\n                            component: \"game\",\n                            action: \"error\"\n                        }, {\n                            context: c._optoRound\n                        }), c._buildGameTimeline(a);\n                    }\n                });\n            },\n            _showGameTweets: function(a) {\n                for (var b = 0; ((b < a.length)); ++b) {\n                    a[b] = new twttr.anywhere.api.models.Status(a[b]);\n                ;\n                };\n            ;\n                var c = this.$find(\".js-tweets-container\");\n                $tweet1 = (new twttr.views.WelcomeLearnGameTweet(a[0])).render(this.$find(\".js-tweet-1\").empty(), \"append\"), $tweet2 = (new twttr.views.WelcomeLearnGameTweet(a[1])).render(this.$find(\".js-tweet-2\").empty(), \"append\"), $tweet1.addClass(\"welcome-game-tweet-left\"), $tweet2.addClass(\"welcome-game-tweet-right\"), $(\".js-tweet-separator\").css({\n                    opacity: 1\n                });\n                var d = this;\n                c.css({\n                    left: \"100%\",\n                    right: \"auto\"\n                }).animate({\n                    left: \"0%\"\n                }, \"slow\", function() {\n                    d.$find(\".js-tweets-container\").removeClass(\"js-between-rounds\");\n                });\n            },\n            _nextGameRound: function(a) {\n                var b, c = this, d = this.$find(\".js-tweet-1 .js-game-tweet\"), e = this.$find(\".js-tweet-2 .js-game-tweet\"), f = $(), g = $(), i = $(\"\\u003Cdiv class=\\\"check\\\"\\u003E\\u003C/div\\u003E\").hide();\n                scribeInfo = {\n                    context: this._optoRound,\n                    item_ids: [d.attr(\"data-tweet-id\"),e.attr(\"data-tweet-id\"),],\n                    item_count: 2\n                }, this.$find(\".js-tweets-container\").addClass(\"js-between-rounds\"), ((a.closest(\".js-tweet-1\").length ? (b = \"first\", this._optoRound++, trackClient({\n                    component: \"game\",\n                    element: \"tweet_1\",\n                    action: \"select\"\n                }, scribeInfo), this._optoSkips = 0, f = d, g = e) : ((a.closest(\".js-tweet-2\").length ? (b = \"second\", this._optoRound++, trackClient({\n                    component: \"game\",\n                    element: \"tweet_2\",\n                    action: \"select\"\n                }, scribeInfo), this._optoSkips = 0, f = e, g = d) : (b = \"skip\", trackClient({\n                    component: \"game\",\n                    element: \"skip_link\",\n                    action: \"skip\"\n                }, scribeInfo), this._optoSkips++, g = $([d[0],e[0],]))))));\n                var j = 600;\n                ((f.length && (f.append(i), i.fadeIn(\"fast\"), this._setProgress(((this._optoRound - 1))), this.$find(\".js-current-round\").text(Math.min(((this._optoRound - 1)), this._optoMaxRounds))))), this.$find(\".js-tweet-separator\").animate({\n                    opacity: 0\n                }, j), g.animate({\n                    opacity: 0\n                }, j);\n                var k = ((j + +(new JSBNG__Date)));\n                if (((((this._optoRound <= this._optoMaxRounds)) && ((this._optoSkips < 5))))) this._fetchGameTweets(b, k);\n                 else {\n                    trackClient({\n                        action: ((((this._optoSkips == 5)) ? \"skip\" : \"complete\"))\n                    });\n                    var c = this;\n                    window.JSBNG__setTimeout(function() {\n                        ((f.length ? c.$find(\".js-tweets-container\").css({\n                            left: \"auto\",\n                            right: \"0%\"\n                        }).animate({\n                            right: \"100%\"\n                        }, function() {\n                            c._buildGameTimeline(b);\n                        }) : c._buildGameTimeline(b)));\n                    }, j);\n                }\n            ;\n            ;\n            },\n            _buildGameTimeline: function(a) {\n                var b = this;\n                this._renderStep(\"building\"), this.$find(\".js-stream-end\").hide(), this.$find(\".js-welcome-faux-tweet-stream\").hide(), (new twttr.views.StreamLoading).render(this.$find(\".js-tweet-preview-container\"), \"html\"), $.ajax({\n                    type: \"POST\",\n                    url: \"/i/optometrist/recommendations\",\n                    headers: {\n                        \"X-PHX\": !0\n                    },\n                    data: {\n                        state: JSON.stringify(this._optoState),\n                        last_action: ((a || \"\")),\n                        algo: ((this._optoAlgo || \"\")),\n                        query: ((JSON.stringify(this._optoQuery) || \"\"))\n                    },\n                    dataType: \"json\",\n                    success: function(a) {\n                        twttr.API.User.findAll(a, function(a) {\n                            b._optoUsers = a.toArray(), twttr.router.routeTo(twttr.router.welcomePreviewPath());\n                        });\n                    },\n                    error: function() {\n                        trackClient({\n                            section: \"preview\",\n                            component: \"stream\",\n                            action: \"error\"\n                        }), b.$find(\".stream-loading\").remove(), b.$find(\".js-welcome-faux-tweet-stream\").show(), b.$find(\".js-stream-end\").show(), twttr.router.routeTo(twttr.router.welcomeRecommendationsPath());\n                    }\n                });\n            },\n            preview: function(a, b) {\n                var c = this;\n                if (!c._optoUsers) {\n                    twttr.router.routeTo(twttr.router.welcomeTweetsPath());\n                    return;\n                }\n            ;\n            ;\n                trackClient({\n                    action: \"impression\"\n                }), this._renderStep(\"building\"), this.$find(\".js-stream-end\").hide(), this.$find(\".js-following-count\").text(this._optoUsers.length);\n                var d = {\n                    initialItems: this._optoUsers,\n                    cacheWithInitialItems: !0,\n                    deferFollows: !0\n                }, e = this.switchToStream(twttr.streams.TweetGameDashboardStream, d);\n                window.JSBNG__setTimeout(function() {\n                    c._prefollow(e, c._optoUsers.length);\n                    var a, b = 0, d = !1, f = function() {\n                        if (d) {\n                            return;\n                        }\n                    ;\n                    ;\n                        d = !0, window.JSBNG__clearTimeout(a), c.$find(\".stream-loading\").remove(), c.$find(\".js-stream-end\").show(), c._renderStep(\"preview\");\n                    }, g = function() {\n                        b++, ((((b == c._optoUsers.length)) && (c.unbind(\"followPreviewed\", g), f())));\n                    };\n                    ((((c._optoUsers.length == 0)) ? f() : (c.bind(\"followPreviewed\", g), a = window.JSBNG__setTimeout(f, 10000))));\n                }, 0);\n            },\n            edit: function(a, b) {\n                trackClient({\n                    action: \"impression\"\n                }), this._renderStep(\"edit\");\n                var c = {\n                    initialItems: this._optoUsers,\n                    cacheWithInitialItems: !0,\n                    deferFollows: !0\n                };\n                this.switchToStream(twttr.streams.TweetGameDashboardStream, c);\n            },\n            _addNextDisableReason: function(a) {\n                ((this._nextDisableReasons[a] || (this._nextDisableReasons[a] = !0, this._nextDisableReasons._reasonCount++))), this._setNextButton(!1);\n            },\n            _removeNextDisableReason: function(a) {\n                ((this._nextDisableReasons[a] && (delete this._nextDisableReasons[a], this._nextDisableReasons._reasonCount--, this._setNextButton(((this._nextDisableReasons._reasonCount == 0))))));\n            },\n            _setProgress: function(a) {\n                var b = this._steps[this._currentStepId];\n                this.$find(\".js-progressbar\").progressbar({\n                    value: ((1 + Math.floor(((((100 * a)) / b.suggested_progress)))))\n                });\n            },\n            _updateProgress: function(a) {\n                var b = this._steps[this._currentStepId];\n                ((b._currentProg || (b._currentProg = 0))), b._currentProg += a, ((((b._currentProg < 0)) && (b._currentProg = 0))), this._setProgress(b._currentProg), ((((b._currentProg >= b.min_progress)) && this._removeNextDisableReason(\"progress\"))), ((((b._currentProg >= b.suggested_progress)) ? this.$find(\".js-progress-label\").html(_(\"Great!\")) : ((((b._currentProg == 0)) ? this.$find(\".js-progress-label\").html(b.initial_progress_copy) : ((b.progress_copy_function ? this.$find(\".js-progress-label\").html(b.progress_copy_function(((b.suggested_progress - b._currentProg)))) : this.$find(\".js-progress-label\").html(_(\"Follow {{count}} more!\", {\n                    count: ((b.suggested_progress - b._currentProg))\n                }))))))));\n            },\n            _setNextButton: function(a) {\n                ((a ? (this.$find(\".js-next-btn\").toggleClass(\"disabled\", !1).fadeIn().toggleClass(\"selected\", !0), this.$find(\".js-progressbar\").closest(\"td\").width(\"99%\")) : (this.$find(\".js-next-btn\").toggleClass(\"disabled\", !0).hide().toggleClass(\"selected\", !1), this.$find(\".js-progressbar\").closest(\"td\").width(\"100%\")))), this.$find(\".js-save-btn\").toggleClass(\"primary-btn\", a);\n            },\n            _isOnLastStep: function() {\n                var a = this._steps[this._currentStepId];\n                return ((a && ((a.next_step == \"finish\"))));\n            },\n            finish: function() {\n                this.clearWelcomeSkipCookie(), trackClient({\n                    section: \"finished\",\n                    action: \"impression\"\n                }), this._slideDrawer(!1, function() {\n                    twttr.router.routeTo(twttr.router.homePath());\n                });\n            },\n            _scribeStepCompletion: function(a) {\n                var b = this.constructor.ROUTES_TO_STEP[this._currentStepId];\n                trackClient({\n                    section: b,\n                    action: \"complete\"\n                }), trackClient({\n                    section: b,\n                    component: \"progress\",\n                    action: a\n                });\n            },\n            _renderStep: function(a) {\n                ((this._rendered || this.render())), this.$find(\".js-dashboard, .js-content-main, .js-stream-end\").show(), this._setTheme();\n                var b = this._steps[a];\n                this.$find(\".js-content-container\").empty(), this._customRenderStep(a), this.$find(\".js-welcome-search\").toggle(b.show_search), this.$find(\".js-welcome-zipcode-search\").toggle(!!b.show_zipcode_search), this.$find(\".js-back-to-stream\").hide(), this._currentStepId = a, ((((a != \"search\")) && (this._currentSearchStepId = this._currentStepId)));\n                var c;\n                ((((((a == \"matches\")) || ((a == \"import\")))) ? c = _(\"Find people by name...\") : c = _(\"Search for...\"))), this.$find(\".js-who-to-follow-search input\").attr(\"placeholder\", c), this._slideDrawer(!b.no_drawer), this.$find(\".js-welcome-intro\").hide(), this.$find(\".js-tweet-game\").remove(), this.$find(\".js-welcome-dashboard-footer\").show();\n                var d = ((b.next_step == \"finish\")), e = {\n                    last_step: d,\n                    button_text: ((b.next_text || this._getNextButtonText(d))),\n                    continue_route: ((d ? twttr.router.homePath() : this._nextRoute(b))),\n                    show_progress: b.show_progress,\n                    next_enabled: b.next_enabled,\n                    next_highlighted: b.next_highlighted,\n                    no_nav: b.no_nav,\n                    stream_arrow: !b.no_drawer\n                };\n                twttr.merge(e, b), (new twttr.views.WelcomeLearnHeader(e)).render(this.$find(\".js-flow-step\"), \"html\");\n                var f = this.$find(\".js-next-btn\"), g = this.$find(\".js-skip-link\");\n                f.attr(\"href\", e.continue_route), g.attr(\"href\", e.continue_route).toggle(!b.next_enabled), ((((a == \"intro\")) ? this.$find(\".js-intro-tweet\").show() : this.$find(\".js-intro-tweet\").hide())), this._nextDisableReasons = {\n                    _reasonCount: 0\n                }, ((b.next_enabled || (this._addNextDisableReason(\"progress\"), this._updateProgress(0)))), ((b.skip_disabled && this.$find(\".js-welcome-dashboard-footer\").hide())), this._resizeFlow();\n                var i = this.$find(\".example-tweet-info\");\n                ((b.show_intro_text ? i.show() : i.hide()));\n            },\n            _createScribbler: function(a, b) {\n                ((twttr.is.string(a) && (a = {\n                    component: a\n                })));\n                var c = function(b) {\n                    var c = twttr.Scribbler.clientAppDefaultTerms();\n                    return b = twttr.merge({\n                    }, b, a), twttr.Scribbler.clientAppEventNameGenerator(b, c);\n                };\n                return twttr.Scribbler.clientEvent.spawn(b, c);\n            },\n            _followAll: function(a, b) {\n                var c = a.screenNames, d = a.deviceNotifications;\n                twttr.API.User.JSBNG__find(twttr.currentUser.id, function(a) {\n                    var e = 0;\n                    twttr.API.User.findAll(c, {\n                        success: twttr.bind(this, function(f) {\n                            var g = function(a) {\n                                e++, ((((e == c.length)) && b.complete()));\n                            };\n                            f.each(function(b, c) {\n                                b.follow({\n                                    success: g,\n                                    error: function() {\n                                        twttr.showError(_(\"There was an error following lifeline accounts.\")), g();\n                                    }\n                                });\n                                if (((d[b.screenName] && a.deviceSetup))) {\n                                    var e = {\n                                        success: function() {\n                                            trackClient({\n                                                component: \"stream\",\n                                                action: \"device_follow\"\n                                            });\n                                        },\n                                        error: function(a) {\n                                            twttr.showError(_(\"There was an error device following lifeline accounts.\"));\n                                        }\n                                    };\n                                    b.setNotificationsOn(e);\n                                }\n                            ;\n                            ;\n                            });\n                        })\n                    });\n                });\n            },\n            _onFollowAll: function(a, b) {\n                return ((twttr.cache.local.shownDeviceFollowDialog ? this._followAll(a, b) : (twttr.cache.local.shownDeviceFollowDialog = !0, trackClient({\n                    component: \"device_follow_dialog\",\n                    action: \"impression\"\n                }), (new twttr.widget.DeviceFollowDialog({\n                    JSBNG__onclose: twttr.bind(this, this._followAll, [a,b,])\n                })).show()))), !0;\n            },\n            localizeQuery: function(a, b) {\n                return ((b.lang && (a.lang = b.lang))), ((b.country && (a.country = b.country))), ((b.city && (a.city = b.city))), a.top_tweets = !0, a;\n            },\n            _shouldShowInvite: function() {\n                return ((((this._currentStepId != \"matches\")) ? !1 : ((this.streamManager.streams.current.inviteDialog ? !1 : !0))));\n            },\n            _inviteStepDialog: function() {\n                var a = this;\n                if (((twttr.abdecider.choose(\"welcome_aggressive_invite_modal_345\") === \"aggressive_invite_modal\"))) {\n                    this.streamManager.streams.current.inviteOthers();\n                }\n                 else {\n                    if (((twttr.abdecider.choose(\"welcome_aggressive_invite_modal_345\") === \"invite_step\"))) {\n                        var b = twttr.Scribbler.clientEvent.spawn({\n                            element: \"invite_step\"\n                        }), c = {\n                            scribbler: b,\n                            pathRoot: this.PATH_ROOT,\n                            forceInviteInline: !0\n                        }, d = this.switchToStream(twttr.streams.DashboardContactImportMatches, c);\n                        this._currentStepId = \"invite\", this.$find(\".progressbar-well\").hide(), d.$node.delegate(\".invite-contacts-button\", \"click\", function() {\n                            a.$find(\".js-skip-link\").click();\n                        });\n                    }\n                ;\n                }\n            ;\n            ;\n            }\n        }), a();\n    });\n});\nprovide(\"components/pages/Welcome\", function(a) {\n    using(\"boot/bootstrap_data\").as(function(b) {\n        var c = twttr.components.pages.WelcomeLearnFlow, d = twttr.Router.getCurrentQueryStringParams();\n        if (((((d.welcomePage && d.welcomePage.match(/^Welcome/))) && twttr.components.pages[d.welcomePage]))) {\n            c = twttr.components.pages[d.welcomePage];\n        }\n         else {\n            if (!twttr.isT1) {\n                var e = [];\n                for (var f = 0; ((f < e.length)); ++f) {\n                    var g = e[f][0], i = e[f][1], j = twttr.abdecider.choose(g, !0);\n                    if (j) {\n                        ((((j != \"control\")) && (c = i)));\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        }\n    ;\n    ;\n        twttr.components.pages.Welcome = c, a(twttr.components.pages.Welcome);\n    });\n});\nprovide(\"components/pages/AbstractMediaGallery\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.components.pages.AbstractMediaGallery\").subclassOf(twttr.components.Page).addAfterRender(function() {\n        \n        }).view(twttr.views.MediaGalleryPage).addOnSwitchAway(function() {\n            $(\"#page-container\").show(), $(((twttr.isT1 ? \".js-topbar\" : \"#top-stuff\"))).show(), $(\"body\").removeClass(\"has-media-gallery\"), this.$gallery.remove(), this.$gallery = null, this.$content = null, this._query = null, this._viewMode = null;\n        }).addOnSwitchTo(function() {\n            $(\"#page-container\").hide(), $(((twttr.isT1 ? \".js-topbar\" : \"#top-stuff\"))).hide(), this.$gallery = (new twttr.views.MediaGalleryPage).$html().appendTo(\"#doc\"), this.$content = this.$gallery.JSBNG__find(\".media-gallery-content\"), $(\"body\").addClass(\"has-media-gallery\");\n        }).keydown({\n            left: function() {\n                ((((this._grid && this._grid.showPrev)) && this._grid.showPrev()));\n            },\n            right: function() {\n                ((((this._grid && this._grid.showNext)) && this._grid.showNext()));\n            },\n            esc: function() {\n                this.closeGalleryAction();\n            }\n        }).methods({\n            showSlideshowLoading: function() {\n                this.addClass(\"loading loadingTweet loadingMedia\");\n            },\n            showLoading: function() {\n                this.addClass(\"loading\");\n            },\n            hideTweetLoading: function() {\n                this.removeClass(\"loading loadingTweet\");\n            },\n            hideMediaLoading: function() {\n                this.removeClass(\"loading loadingMedia\");\n            },\n            hideLoading: function() {\n                this.removeClass(\"loading loadingTweet loadingMedia\");\n            },\n            addClass: function(a) {\n                ((this.$content && this.$content.addClass(a)));\n            },\n            removeClass: function(a) {\n                ((this.$content && this.$content.removeClass(a)));\n            },\n            grid: function(a, b) {\n                if (twttr.decider.isAvailable(\"disable_gallery_grid\")) {\n                    this.slideshow(a, b);\n                    return;\n                }\n            ;\n            ;\n                this.setup(a, b), this._viewMode = \"grid\";\n                if (((this.deciderKey && !twttr.decider.isAvailable(this.deciderKey)))) {\n                    this.trigger(\"notFound\");\n                    return;\n                }\n            ;\n            ;\n                this.buildGrid(a, b), this.scribbler.scribe({\n                    component: this._mode,\n                    action: \"impression\"\n                });\n            },\n            buildGrid: function() {\n                throw new Exception(\"buildGrid is an abstract method that must be implemented in your subclass.\");\n            },\n            completeGridRender: function(a) {\n                a.generateItemHref = twttr.bind(this, this.generateItemHref), a.provider = this._provider, a.scribbler = this.scribbler, this._renderControls(\"grid\"), ((this._grid && (this._grid.$node.remove(), this._grid = null))), this.showLoading(), this.$content.addClass(\"grid\"), this._grid = new twttr.components.TheGrid(a, this.$content.width()), this._grid.$node.appendTo(this.$content), ((((this._mode == \"videos\")) && this._grid.$node.addClass(\"grid-videos\"))), this._grid.bind(\"showLoading\", twttr.bind(this, this.showLoading)), this._grid.bind(\"hideLoading\", twttr.bind(this, this.hideLoading)), b.util.lazyBind(window, \"resize\", twttr.bind(this, this.resizeGrid));\n            },\n            slideshow: function(a, b) {\n                if (this.alreadySlideshow(a)) {\n                    return;\n                }\n            ;\n            ;\n                this.setup(a, b), this._viewMode = \"slideshow\", this._displayMode = \"slideshow\";\n                if (((this.deciderKey && !twttr.decider.isAvailable(this.deciderKey)))) {\n                    this.trigger(\"notFound\");\n                    return;\n                }\n            ;\n            ;\n                this._renderControls(\"detail\");\n                var c = {\n                    width: this.$content.width(),\n                    height: (($(window).height() - 300)),\n                    thumbContainerWidth: 880,\n                    url: ((b.url || null)),\n                    mode: this._mode\n                };\n                ((this._grid && (this._grid.$node.remove(), this._grid = null))), this.buildSlideshow(a, b, c), this.$content.removeClass(\"grid\"), this.scribbler.scribe({\n                    component: this._mode,\n                    action: \"impression\"\n                });\n            },\n            buildSlideshow: $.noop,\n            completeSlideshowRender: function(a) {\n                a.generateItemHref = twttr.bind(this, this.generateItemHref), a.provider = this._provider, a.scribbler = this.scribbler, this._grid = new twttr.components.MediaSlideshow(a), this._grid.$node.appendTo(this.$content), this._grid.bind(\"showSlideshowLoading\", twttr.bind(this, this.showSlideshowLoading)), this._grid.bind(\"hideTweetLoading\", twttr.bind(this, this.hideTweetLoading)), this._grid.bind(\"hideMediaLoading\", twttr.bind(this, this.hideMediaLoading)), this.showLoading(), b.util.lazyBind(window, \"resize\", twttr.bind(this, this.resizeSlideshow)), this._grid.bind(\"mediaRendered\", twttr.bind(this, this.resizeSlideshow));\n            },\n            resizeGrid: function() {\n                if (((((this._viewMode == \"slideshow\")) || !this.$content))) {\n                    return;\n                }\n            ;\n            ;\n                var a = this.$content.width();\n                this._grid.setCols(a);\n            },\n            resizeSlideshow: function() {\n                var a = this;\n                if (((((this._viewMode != \"slideshow\")) || !this.$content))) {\n                    return;\n                }\n            ;\n            ;\n                var c = ((((this._mode == \"photos\")) ? b.constants.slideshow.photoMinHeight : b.constants.slideshow.videoMinHeight)), h = (($(window).height() - ((twttr.decider.isAvailable(\"disable_gallery_thumbs\") ? 220 : 300)))), d = this.$content.width();\n                h = Math.max(h, c), this._grid.resizePicture(h, d), ((this._grid._thumbnailViewer && (((this.resizeThumbnailViewerTimer && JSBNG__clearTimeout(this.resizeThumbnailViewerTimer))), this.resizeThumbnailViewerTimer = JSBNG__setTimeout(function() {\n                    ((a._grid._thumbnailViewer && a._grid._thumbnailViewer.updateWidth()));\n                }, 500))));\n            },\n            _renderControls: function(a) {\n                ((this._controls && (this._controls.$node.remove(), this._controls = null)));\n                var b = $.extend(this.getControlsOptions(), {\n                    view: a\n                });\n                this._controls = new twttr.components.MediaGalleryControls(b), this._controls.$node.appendTo(this.$content), this._controls.bind(\"close\", twttr.bind(this, this.closeGalleryAction)), this._controls.bind(\"detailViewSelected\", twttr.bind(this, this.detailViewSelected)), this._controls.bind(\"gridViewSelected\", twttr.bind(this, this.gridViewSelected)), $(\"div.tipsy\").remove(), this._controls.$node.JSBNG__find(\".detailview, .gridview\").tipsy({\n                    gravity: \"s\",\n                    fade: !0\n                });\n            },\n            closeGalleryAction: $.noop,\n            detailViewSelected: $.noop,\n            gridViewSelected: $.noop\n        }), a(twttr.components.pages.AbstractMediaGallery);\n    });\n});\nprovide(\"components/pages/UserMediaGallery\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.pages.UserMediaGallery\").subclassOf(twttr.components.pages.AbstractMediaGallery).methods({\n            setup: function(a) {\n                this.type = \"userMedia\", this.screenName = a.screen_name, this.deciderKey = \"phoenix_user_media_gallery\", this._mode = \"photos\", this._provider = new twttr.media.provider.UserMedia({\n                    screenName: this.screenName\n                }), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                    profile_id: function() {\n                        return ((twttr.profileUser && twttr.profileUser.id));\n                    },\n                    event_info: this._mode\n                }), this.filter = function(a) {\n                    return ((((!a || !a.mediaType)) ? !1 : ((a.mediaType.icon() === twttr.constants.media.photoIcon))));\n                };\n            },\n            getControlsOptions: function() {\n                return {\n                    type: this.type,\n                    screenName: this.screenName,\n                    profilePath: twttr.router.profilePath({\n                        screen_name: this.screenName\n                    }),\n                    mode: this._mode\n                };\n            },\n            generateItemHref: function(a) {\n                return ((((twttr.router.userMediaSlideshowPath({\n                    screen_name: this.screenName\n                }) + \"?url=\")) + encodeURIComponent(a)));\n            },\n            buildGrid: function(a, b) {\n                this.updatePageTitle(_(\"Twitter / Recent images by @{{screen_name}}\", {\n                    screen_name: this.screenName\n                })), this.completeGridRender({\n                    type: this.type,\n                    screenName: this.screenName,\n                    generateItemHref: twttr.bind(this, this.generateItemHref),\n                    filter: this.filter\n                }), this.updateBackButton();\n                var c = this;\n                this._grid.$node.delegate(\"a\", \"click\", function() {\n                    c.scribbler.scribe({\n                        component: c._mode,\n                        action: \"click\"\n                    }, {\n                        url: $(this).attr(\"data-url\")\n                    });\n                });\n            },\n            buildSlideshow: function(a, b, c) {\n                this.updatePageTitle(_(\"Twitter / Recent images by @{{screen_name}}\", {\n                    screen_name: this.screenName\n                })), c.type = this.type, c.screenName = this.screenName, c.filter = this.filter, this.completeSlideshowRender(c), this.updateBackButton();\n            },\n            alreadySlideshow: function(a) {\n                return ((((this.$content && ((a.screen_name === this.screenName)))) && ((this._viewMode === \"slideshow\"))));\n            },\n            detailViewSelected: function() {\n                twttr.router.routeTo(twttr.router.userMediaSlideshowPath({\n                    screen_name: this.screenName\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            gridViewSelected: function() {\n                twttr.router.routeTo(twttr.router.userMediaGridPath({\n                    screen_name: this.screenName\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            closeGalleryAction: function() {\n                twttr.router.routeTo(this.pathBack), this.scribbler.scribe({\n                    component: ((this._mode + \"_back_link\")),\n                    action: \"click\"\n                });\n            },\n            updateBackButton: function() {\n                var a = twttr.audit.trail(), b = null;\n                this.pathBack = twttr.router.profilePath({\n                    screen_name: this.screenName\n                });\n                if (((a.length > 1))) {\n                    for (var c = 0, d = a.length; ((c < d)); c++) {\n                        var e = a[c];\n                        if (((e.page !== \"userMediaGallery\"))) {\n                            b = e.page, this.pathBack = e.path;\n                            break;\n                        }\n                    ;\n                    ;\n                        var f = e.path.split(\"/\")[2];\n                        if (((f !== this.screenName))) {\n                            b = \"profile\";\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                var g = this._controls.$find(\".media-gallery-back-nav span\"), i = \"\";\n                switch (b) {\n                  case \"JSBNG__home\":\n                    i = _(\"Back to Home\");\n                    break;\n                  case \"permalink\":\n                    i = _(\"Back to Tweet page\");\n                    break;\n                  case \"profile\":\n                    ((twttr.helpers.isCurrentUser(this.screenName) ? i = _(\"Back to your profile\", {\n                        screen_name: this.screenName\n                    }) : i = _(\"Back to @{{screen_name}}'s profile\", {\n                        screen_name: this.screenName\n                    })));\n                    break;\n                  case \"list\":\n                    var j = this.pathBack.split(\"/\");\n                    i = _(\"Back to @{{screen_name}}'s list '{{list_name}}'\", {\n                        screen_name: j[2],\n                        list_name: j[3]\n                    });\n                    break;\n                  case \"search\":\n                    i = _(\"Back to search results\");\n                    break;\n                  default:\n                    i = _(\"@{{screen_name}}'s profile\", {\n                        screen_name: this.screenName\n                    });\n                };\n            ;\n                g.text(i);\n            }\n        }), a(twttr.components.pages.UserMediaGallery);\n    });\n});\nprovide(\"components/pages/FacetsMediaGallery\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.pages.FacetsMediaGallery\").subclassOf(twttr.components.pages.AbstractMediaGallery).methods({\n            setup: function(a, b) {\n                var c = this;\n                this.type = \"search\", this.deciderKey = \"phoenix_facets\", this._mode = a.mode, this._query = ((a.query || b.q)), this._provider = new twttr.media.provider.Search, this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                    query: this._query,\n                    event_info: this._mode\n                })));\n            },\n            getControlsOptions: function() {\n                return {\n                    type: this.type,\n                    mode: this._mode,\n                    query: this._query\n                };\n            },\n            slideshow: function() {\n                twttr.components.pages.AbstractMediaGallery.prototype.slideshow.apply(this, arguments);\n            },\n            generateItemHref: function(a) {\n                return ((((twttr.router.searchFacetsSlideshowPath({\n                    query: this._query,\n                    mode: this._mode\n                }) + \"?url=\")) + encodeURIComponent(a)));\n            },\n            buildGrid: function(a, b) {\n                ((((((this._mode != \"videos\")) && ((this._mode != \"photos\")))) && twttr.router.routeTo(twttr.router.searchFacetsGridPath({\n                    query: this._query,\n                    mode: \"photos\"\n                })))), this.updatePageTitle(_(\"Twitter / Gallery - {{{query}}}\", {\n                    query: this._query\n                }));\n                var c = {\n                    query: this._query,\n                    mode: this._mode,\n                    type: this.type\n                };\n                ((((this._mode == \"videos\")) && (c.imageWidth = 200, c.imageHeight = 150, c.margin = 10))), this.completeGridRender(c);\n                var d = this;\n                this._grid.$node.delegate(\"a\", \"click\", function() {\n                    d.scribbler.scribe({\n                        component: d._mode,\n                        action: \"click\"\n                    }, {\n                        url: $(this).attr(\"data-url\")\n                    });\n                });\n            },\n            buildSlideshow: function(a, b, c) {\n                var d = ((b.url || null));\n                if (((((this._query && ((this._mode != \"videos\")))) && ((this._mode != \"photos\"))))) {\n                    var e = twttr.router.searchFacetsSlideshowPath({\n                        query: this._query,\n                        mode: \"photos\"\n                    });\n                    ((d && (e = ((((e + \"?url=\")) + encodeURIComponent(d)))))), twttr.router.routeTo(e);\n                    return;\n                }\n            ;\n            ;\n                ((((this._mode == \"videos\")) && twttr.merge(c, {\n                    thumbHeight: 48,\n                    thumbWidth: 64,\n                    thumbDisplayWidth: 66,\n                    thumbDisplayHeight: 48\n                }))), this.updatePageTitle(_(\"Twitter / Gallery - {{{query}}}\", {\n                    query: this._query\n                })), c.type = this.type, c.query = this._query, this.completeSlideshowRender(c);\n            },\n            alreadySlideshow: function(a) {\n                return ((((((this.$content && ((a.query === this._query)))) && ((a.mode === this._mode)))) && ((this._viewMode === \"slideshow\"))));\n            },\n            detailViewSelected: function() {\n                twttr.router.routeTo(twttr.router.searchFacetsSlideshowPath({\n                    query: this._query,\n                    mode: this._mode\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            gridViewSelected: function() {\n                twttr.router.routeTo(twttr.router.searchFacetsGridPath({\n                    query: this._query,\n                    mode: this._mode\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            closeGalleryAction: function() {\n                twttr.router.routeTo(twttr.router.searchResultsPath({\n                    query: this._query\n                })), this.scribbler.scribe({\n                    component: ((this._mode + \"_back_link\")),\n                    action: \"click\"\n                });\n            }\n        }), a(twttr.components.pages.FacetsMediaGallery);\n    });\n});\nprovide(\"components/pages/EventsMediaGallery\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.pages.EventsMediaGallery\").subclassOf(twttr.components.pages.AbstractMediaGallery).methods({\n            setup: function(a, b) {\n                var c = this;\n                this.type = \"search\", this._mode = \"photos\", this._query = ((a.query || b.q)), this._eventId = this._query, ((twttr.griffin.isEvent(this._eventId) || twttr.router.routeTo(twttr.router.homePath()))), this._provider = new twttr.media.provider.Search, this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent.spawn({\n                    query: this._query,\n                    event_info: \"events\"\n                })));\n            },\n            getControlsOptions: function() {\n                return {\n                    type: this.type,\n                    mode: this._mode,\n                    query: this._query,\n                    eventId: this._eventId\n                };\n            },\n            slideshow: function() {\n                twttr.components.pages.AbstractMediaGallery.prototype.slideshow.apply(this, arguments);\n            },\n            generateItemHref: function(a) {\n                return ((((twttr.router.eventsSlideshowPath({\n                    query: this._query,\n                    mode: this._mode\n                }) + \"?url=\")) + encodeURIComponent(a)));\n            },\n            buildGrid: function(a, b) {\n                ((((((this._mode != \"videos\")) && ((this._mode != \"photos\")))) && twttr.router.routeTo(twttr.router.eventsGridPath({\n                    query: this._query,\n                    mode: \"photos\"\n                })))), this.updatePageTitle(_(\"Twitter / Events - {{{query}}}\", {\n                    query: this._query\n                }));\n                var c = {\n                    query: this._query,\n                    mode: this._mode,\n                    type: this.type\n                };\n                ((((this._mode == \"videos\")) && (c.imageWidth = 200, c.imageHeight = 150, c.margin = 10))), c.isEvent = !0, this.completeGridRender(c);\n                var d = this;\n                this._grid.$node.delegate(\"a\", \"click\", function() {\n                    d.scribbler.scribe({\n                        component: d._mode,\n                        action: \"click\"\n                    }, {\n                        url: $(this).attr(\"data-url\")\n                    });\n                });\n            },\n            buildSlideshow: function(a, b, c) {\n                var d = ((b.url || null));\n                if (((((this._query && ((this._mode != \"videos\")))) && ((this._mode != \"photos\"))))) {\n                    var e = twttr.router.eventsSlideshowPath({\n                        query: this._query,\n                        mode: \"photos\"\n                    });\n                    ((d && (e = ((((e + \"?url=\")) + encodeURIComponent(d)))))), twttr.router.routeTo(e);\n                    return;\n                }\n            ;\n            ;\n                ((((this._mode == \"videos\")) && twttr.merge(c, {\n                    thumbHeight: 48,\n                    thumbWidth: 64,\n                    thumbDisplayWidth: 66,\n                    thumbDisplayHeight: 48\n                }))), this.updatePageTitle(_(\"Twitter / Events - {{{query}}}\", {\n                    query: this._query\n                })), c.type = this.type, c.query = this._query, c.showFirstOnFail = !0, c.isEvent = !0, this.completeSlideshowRender(c);\n            },\n            alreadySlideshow: function(a) {\n                return ((((((this.$content && ((a.query === this._query)))) && ((a.mode === this._mode)))) && ((this._viewMode === \"slideshow\"))));\n            },\n            detailViewSelected: function() {\n                twttr.router.routeTo(twttr.router.eventsSlideshowPath({\n                    query: this._query,\n                    mode: this._mode\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            gridViewSelected: function() {\n                twttr.router.routeTo(twttr.router.eventsGridPath({\n                    query: this._query,\n                    mode: this._mode\n                })), this.scribbler.scribe({\n                    component: ((((\"toggle_\" + this._mode)) + \"_view\")),\n                    action: \"click\"\n                });\n            },\n            closeGalleryAction: function() {\n                twttr.router.routeTo(twttr.router[((this._query + \"StaticPath\"))]()), this.scribbler.scribe({\n                    component: ((this._mode + \"_back_link\")),\n                    action: \"click\"\n                });\n            }\n        }), a(twttr.components.pages.EventsMediaGallery);\n    });\n});\nprovide(\"components/pages/BigPhotoPermalink\", function(a) {\n    using().as(function(b) {\n        var c = twttr.components.pages.AbstractMediaGallery.prototype;\n        twttr.klass(\"twttr.components.pages.BigPhotoPermalink\").subclassOf(twttr.components.pages.AbstractMediaGallery).methods({\n            permalink: function(a) {\n                var b = this;\n                this.$content.empty(), this.index = a.photo_index, twttr.API.Status.JSBNG__find(a.id, {\n                    success: twttr.bind(this, this.renderTweet),\n                    error: function() {\n                        b.trigger(\"notFound\");\n                    }\n                });\n            },\n            renderTweet: function(a) {\n                this.updatePageTitle(_(\"Twitter\"));\n                if (((((!a.entities || !a.entities.media)) || !a.entities.media[((this.index - 1))]))) {\n                    this.trigger(\"notFound\");\n                    return;\n                }\n            ;\n            ;\n                this.$content.addClass(\"big-photo-permalink media-slideshow-tweet\"), (new twttr.views.SlideshowTweet(a)).render(this.$content, \"append\");\n                var b = a.entities.media[((this.index - 1))];\n                this.dimensions = b.sizes.large;\n                var c = ((twttr.isSSL() ? b.media_url_https : b.media_url));\n                c += \":large\", this.loadImage(c);\n            },\n            loadImage: function(a) {\n                this.$image = $(\"\\u003Cimg/\\u003E\", {\n                    class: \"large\",\n                    src: a,\n                    height: this.dimensions.h,\n                    width: this.dimensions.w\n                }).appendTo(this.$content), this.refit(), twttr.util.lazyBind(window, \"resize\", twttr.bind(this, this.refit), 200);\n            },\n            refit: function() {\n                var a = twttr.$win.width(), h = ((((twttr.$win.height() - this.$content.JSBNG__find(\".tweet\").height())) - 40));\n                this.$image.css({\n                    JSBNG__top: Math.max(0, Math.round(((((h - this.dimensions.h)) / 2)))),\n                    left: Math.max(0, Math.round(((((a - this.dimensions.w)) / 2))))\n                });\n            }\n        }), a();\n    });\n});\nprovide(\"components/pages/Discover\", function(a) {\n    using(((twttr.isT1 ? \"mixins/t1/emptyTimelineRecommendations\" : \"mixins/emptyTimelineRecommendations\")), \"components/t1/dashboard/DiscoverNav\", \"components/UserRecommendations\", \"components/Trends\", \"components/Footer\", \"streams/Discover\", \"streams/SuggestionCategoriesStream\", \"mixins/streamablePage\", \"mixins/discoveryHelper\").as(function(b, c) {\n        var d = twttr.klass(\"twttr.components.pages.Discover\").subclassOf(twttr.components.Page).mixin(b.mixins.streamablePage, b.mixins.discoveryHelper, c).view(twttr.views.Page).methods({\n            setupPage: function(a, b) {\n                b = ((b || {\n                })), this.updatePageTitle(a), twttr.themes.loadCurrentUserStyle(), ((b.sideNavRoute ? this.selectSideNav(b.sideNavRoute) : this.selectCurrentSideNav()));\n            },\n            discover: function(a, c) {\n                this.setupPage(_(\"Twitter / Discover\")), this.streamManager.switchTo(b.streams.Discover, {\n                });\n            },\n            networkActivity: function(a, b) {\n                this.setupPage(_(\"Twitter / Activity\")), this.streamManager.switchTo(twttr.streams.ActivityByNetworkStream, {\n                }), this.insertEmptyTimeline();\n            },\n            suggestions: function(a, b) {\n                this.setupPage(_(\"Twitter / Who to follow / Suggestions\"), {\n                    sideNavRoute: \"whoToFollowSuggestions\"\n                }), this.streamManager.switchTo(twttr.streams.UserRecommendationsStream, {\n                });\n            },\n            suggestions_search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.routePageTo(\"whoToFollowSuggestions\");\n                }\n            ;\n            ;\n                this.setupPage(_(\"Twitter / Who to follow / Search\"), {\n                    sideNavRoute: \"whoToFollowSuggestions\"\n                }), this.streamManager.switchTo(twttr.streams.HeadlessPeopleSearch, {\n                    headerStreamClass: \"UserRecommendationsStream\",\n                    backLinkOptions: {\n                        route: twttr.router.whoToFollowSuggestionsPath(),\n                        JSBNG__name: _(\"View suggestions\")\n                    },\n                    query: c\n                });\n            },\n            find_friends: function(a, b) {\n                this.setupPage(_(\"Twitter / Find Friends\"));\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                }), d = this.localizeQuery({\n                    scribbler: c,\n                    pathRoot: \"whoToFollow\"\n                }, b), e = this.streamManager.switchTo(twttr.streams.ContactImportServices, d);\n                ((e && e.setStreamManager(this.streamManager)));\n            },\n            lifeline: function(a, b, c) {\n                this.setupPage(_(\"Twitter / Lifeline\"));\n                var d = twttr.Scribbler.clientEvent.spawn({\n                    context: \"lifeline\"\n                }), e = twttr.streams.SuggestionLifelineMembersStream.categoryObj, f = this.localizeQuery({\n                    category: \"lifeline\",\n                    suggestionCategory: e,\n                    scribbler: d,\n                    noHeaderFooter: !0,\n                    title: ((((((e.JSBNG__name + \" (\")) + e.size)) + \")\")),\n                    pathRoot: this.PATH_ROOT\n                }, b);\n                ((((c && c.zipcode)) && (f = $.extend(f, {\n                    zipcode: c.zipcode\n                }))));\n                var g = this.streamManager.switchTo(twttr.streams.SuggestionLifelineMembersStream, f);\n                ((g && g.setStreamManager(this.streamManager)));\n            },\n            lifeline_search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.routePageTo(\"whoToFollowLifeline\");\n                }\n            ;\n            ;\n                this.lifeline(a, b, {\n                    zipcode: c\n                });\n            },\n            matches: function(a, b) {\n                this.setupPage(_(\"Twitter / Find Friends / Results\"), {\n                    sideNavRoute: \"whoToFollowImport\"\n                });\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"import\"\n                });\n                this.streamManager.switchTo(twttr.streams.ContactImportMatches, {\n                    scribbler: c,\n                    pathRoot: \"whoToFollow\"\n                });\n            },\n            find_friends_search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.routePageTo(\"whoToFollowImport\");\n                }\n            ;\n            ;\n                this.setupPage(_(\"Twitter / Find Friends / Search\"), {\n                    sideNavRoute: \"whoToFollowImport\"\n                }), this.streamManager.switchTo(twttr.streams.HeadlessPeopleSearch, {\n                    headerStreamClass: \"ContactImportServices\",\n                    backLinkOptions: {\n                        route: twttr.router.whoToFollowImportPath(),\n                        JSBNG__name: _(\"View services\")\n                    },\n                    query: c\n                });\n            },\n            interests: function(a, b) {\n                this.setupPage(_(\"Twitter / Categories\"));\n                var c = twttr.Scribbler.clientEvent.spawn({\n                    context: \"interests\"\n                }), d = {\n                    scribbler: c,\n                    pathRoot: \"whoToFollow\"\n                };\n                d = this.localizeQuery(d, b), this.streamManager.switchTo(twttr.streams.SuggestionCategoriesStream, d);\n            },\n            interests_search: function(a, b) {\n                var c = ((a.query || b.q));\n                if (!c) {\n                    return this.routePageTo(\"whoToFollowInterests\");\n                }\n            ;\n            ;\n                this.setupPage(_(\"Twitter / Categories / Search\"), {\n                    sideNavRoute: \"whoToFollowInterests\"\n                }), this.streamManager.switchTo(twttr.streams.HeadlessPeopleSearch, {\n                    headerStreamClass: \"SuggestionCategoriesStream\",\n                    backLinkOptions: {\n                        route: twttr.router.whoToFollowInterestsPath(),\n                        JSBNG__name: _(\"View categories\")\n                    },\n                    query: c\n                });\n            },\n            government_by_zip: function(a, b) {\n                this.setupPage(_(\"Twitter / Government Search\"), {\n                    sideNavRoute: \"whoToFollowInterests\"\n                }), this.streamManager.switchTo(twttr.streams.GovernmentSearchStream, {\n                    zipCode: a.zipCode\n                });\n            },\n            category: function(a, b) {\n                var c = this, d = function(a) {\n                    if (!a) {\n                        return c.routePageTo(\"whoToFollow\", \"Interests\");\n                    }\n                ;\n                ;\n                    var d = twttr.Scribbler.clientEvent.spawn({\n                        context: \"interests\",\n                        query: a.slug\n                    });\n                    c.setupPage(_(\"Twitter / Categories / {{category}}\", {\n                        category: a.JSBNG__name\n                    }), {\n                        sideNavRoute: \"whoToFollowInterests\"\n                    });\n                    var f = {\n                        category: e,\n                        suggestionCategory: a,\n                        scribbler: d,\n                        pathRoot: \"whoToFollow\"\n                    };\n                    f = c.localizeQuery(f, b), c.streamManager.switchTo(twttr.streams.SuggestionCategoryMembersStream, f);\n                }, e = ((a.category || b.category));\n                this._category = e;\n                var f = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP;\n                if (f) d(f[e]);\n                 else {\n                    var g = {\n                        success: function(a) {\n                            a = twttr.streams.SuggestionCategoriesStream.filterTopTweetsCategories(a), twttr.streams.SuggestionCategoriesStream.cacheCategories(a);\n                            var b = twttr.streams.SuggestionCategoriesStream.CATEGORY_MAP[e];\n                            d(b);\n                        }\n                    };\n                    g = this.localizeQuery(g, b), twttr.API.SuggestionCategory.getAll(g);\n                }\n            ;\n            ;\n            },\n            renderDashboard: function() {\n                this.trendsComponent = new b.components.Trends, this.addDashboardComponents([new b.components.t1.dashboard.DiscoverNav,new twttr.components.JapaneseAd,this.trendsComponent,new b.components.Footer,]);\n            },\n            addImpressionData: function(a) {\n                var b = twttr.audit.currentAction();\n                switch (b) {\n                  case \"find_friends\":\n                \n                  case \"matches\":\n                    a.context = \"import\";\n                    break;\n                  case \"interests\":\n                    a.context = \"interests\";\n                    break;\n                  case \"category\":\n                    a.context = \"interests\", a.query = this._category;\n                };\n            ;\n            }\n        }).addAfterRender(function() {\n            this.renderDashboard();\n        }).addOnSwitchTo(function() {\n            ((this.trendsComponent && this.trendsComponent.startUpdatePolling()));\n        }).addOnSwitchAway(function() {\n            ((this.trendsComponent && this.trendsComponent.stopUpdatePolling()));\n        });\n        a(d);\n    });\n});\nprovide(\"components/pages/Connect\", function(a) {\n    using(\"_\", \"components/t1/dashboard/MiniHomeProfile\", \"components/t1/dashboard/ConnectNav\", \"components/Trends\", \"components/UserRecommendations\", \"components/Footer\", \"mixins/streamablePage\", \"multiGlobals/more_views\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.pages.Connect\", function() {\n            twttr.components.Page.apply(this, arguments);\n        }).subclassOf(twttr.components.Page).mixin(b.mixins.streamablePage).view(twttr.views.Page).methods({\n            connect: function(a, b) {\n                this.updatePageTitle(_(\"Twitter / Interactions\")), twttr.themes.loadCurrentUserStyle(), this.selectCurrentSideNav(), this.streamManager.switchTo(twttr.streams.ActivityOfMeStream, {\n                });\n            },\n            mentions: function(a, b) {\n                this.updatePageTitle(_(\"Twitter / Mentions\")), this.selectSideNav(\"mentions\"), twttr.themes.loadCurrentUserStyle(), this.streamManager.switchTo(twttr.streams.Mentions, {\n                });\n            },\n            renderDashboard: function() {\n                this.addDashboardComponents([new b.components.t1.dashboard.ConnectNav,new twttr.components.JapaneseAd,new twttr.components.UserRecommendations({\n                    screenName: null,\n                    showLinks: !0\n                }),new b.components.Footer,]);\n            }\n        }).addAfterRender(function() {\n            this.renderDashboard();\n        });\n        a(c);\n    });\n});\nprovide(\"widget/Banner\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.Banner\", function(a) {\n            this.$node = $(\"\\u003Cdiv/\\u003E\"), this.view = new twttr.views[a.view](a), this.$node.delegate(\".pane-close\", \"click\", twttr.bind(this, this.remove)), this.$node.attr(\"data-component-term\", b.util.underscore(a.view)), this.newBanner = a.newBanner;\n        }).methods(twttr.EventProvider).methods({\n            insert: function() {\n                this.view.render(this.$node), $(((this.newBanner ? \".new-js-banners\" : \".js-banners\"))).append(this.$node), twttr.app.recalculatePadding();\n            },\n            remove: function() {\n                this.$node.remove(), twttr.app.recalculatePadding(), this.trigger(\"JSBNG__closed\");\n            }\n        }), twttr.provide(\"twttr.banners\", twttr.augmentObject({\n            pending_new: 0,\n            pending_changed: 1,\n            pending_bouncing: 2,\n            stacked: 3,\n            nonStacked: 4,\n            display: function() {\n                ((((((((((twttr.currentUser && twttr.profileUser)) && ((twttr.currentUser != twttr.profileUser)))) && twttr.currentUser.isAdmin)) && twttr.profileUser.suspended)) && this.viewing_suspended_user().insert()));\n                if (((twttr.currentUser && twttr.currentUser.states))) {\n                    var a = [], b = !1, c = twttr.currentUser.states;\n                    ((twttr.is.falsy(c.pending_email) || (b = this.pending_new))), ((c.bouncing_email && (a = ((twttr.is.array(c.bouncing_email) ? c.bouncing_email : [c.bouncing_email,]))))), ((((((b !== !1)) && twttr.currentUser.emailAddress)) && (b = this.pending_changed))), ((((((b !== !1)) && (($.inArray(c.pending_email, a) >= 0)))) && (b = this.pending_bouncing)));\n                    if (((twttr.currentUser.emailAddress && (($.inArray(twttr.currentUser.emailAddress, a) >= 0))))) {\n                        var d = ((((b !== !1)) ? this.stacked : this.nonStacked));\n                        this.bouncingEmail(d, twttr.currentUser.emailAddress).insert();\n                    }\n                ;\n                ;\n                    if (((b !== !1))) {\n                        var e = twttr.abdecider.choose(\"email_verification-18\", !0);\n                        ((((!e || ((e == \"control\")))) && this.verifyEmail(b, c.pending_email).insert()));\n                    }\n                ;\n                ;\n                    ((c.detached_email && this.detachedEmail().insert())), ((c.suspended && this.suspended(twttr.currentUser.screenName).insert())), (($.cookie(((\"show_reactivated_\" + twttr.currentUser.id))) && this.reactivated().insert()));\n                }\n            ;\n            ;\n            },\n            detachedEmail: function() {\n                return new twttr.widget.Banner({\n                    view: \"DetachedEmailBanner\",\n                    newBanner: !0\n                });\n            },\n            verifyEmail: function(a, b) {\n                var c = new twttr.widget.Banner({\n                    view: \"VerifyEmailBanner\",\n                    pending_email: b,\n                    pending_new: ((a == this.pending_new)),\n                    pending_changed: ((a == this.pending_changed)),\n                    pending_bouncing: ((a == this.pending_bouncing)),\n                    newBanner: !0\n                });\n                return c.$node.delegate(\".resend-confirmation-email-link\", \"click\", function(a) {\n                    twttr.currentUser.emailResendConfirmation({\n                        success: function(a) {\n                            twttr.showMessage(a.messageForFlash);\n                        },\n                        error: function(a) {\n                            twttr.showError(_(\"Oops!  There was an error sending the confirmation email.\"));\n                        }\n                    });\n                }), c;\n            },\n            bouncingEmail: function(a, b) {\n                var c = new twttr.widget.Banner({\n                    view: \"BouncingEmailBanner\",\n                    current_email: b,\n                    stacked: ((a == this.stacked)),\n                    newBanner: !0\n                });\n                return c.$node.delegate(\".reset-bounce-link\", \"click\", function(a) {\n                    twttr.currentUser.emailBounceReset(function(a) {\n                        twttr.showMessage(_(\"Your email notifications should resume shortly.\")), c.$node.fadeOut(\"fast\", function() {\n                            c.remove();\n                        });\n                    });\n                }), c;\n            },\n            suspended: function(a) {\n                return new twttr.widget.Banner({\n                    view: \"SuspendedBanner\",\n                    screen_name: a,\n                    newBanner: !0\n                });\n            },\n            reactivated: function() {\n                var a = new twttr.widget.Banner({\n                    view: \"ReactivatedBanner\"\n                });\n                return a.bind(\"JSBNG__closed\", function() {\n                    $.cookie(((\"show_reactivated_\" + twttr.currentUser.id)), null);\n                }), a.$node.delegate(\"a.reactivate-settings-link\", \"click\", function(b) {\n                    b.preventDefault(), a.trigger(\"JSBNG__closed\"), window.JSBNG__location.href = b.target;\n                }), a;\n            },\n            emailAlreadyVerified: function() {\n                var a;\n                for (var b = 0; ((b < twttr.currentUser.email.length)); b++) {\n                    ((twttr.currentUser.email[b].current && (a = twttr.currentUser.email[b])));\n                ;\n                };\n            ;\n                return new twttr.widget.Banner({\n                    view: \"EmailAlreadyVerifiedBanner\",\n                    already_verified_message: _(\"Someone has already confirmed the email {{email}}\", {\n                        email: a.address\n                    })\n                });\n            },\n            welcomeToPhoenix: function() {\n                return new twttr.widget.Banner({\n                    view: \"WelcomeToPhoenixBanner\",\n                    welcome_search_results_path: twttr.router.searchResultsPath({\n                        query: \"#NewTwitter\"\n                    })\n                });\n            },\n            becameUser: function() {\n                return new twttr.widget.Banner({\n                    view: \"BecameUserBanner\"\n                });\n            }\n        }, twttr.EventProvider)), twttr.app.waitForSignal(\"init\", function() {\n            twttr.banners.display();\n        }), a(twttr.widget.Banner);\n    });\n});\nprovide(\"components/Promo\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.Promo\").subclassOf(twttr.components.Base).initializer(function() {\n            twttr.API.Promo.JSBNG__random({\n                promo_type: \"\",\n                limit: 1\n            }, twttr.bind(this, function(a) {\n                (($.isEmptyObject(a) || ((new twttr.views.DashboardPromo({\n                    promo: a[0]\n                })).render(this.$node, \"append\"), this.hasRendered())));\n            }));\n        }).click({\n            \".promo .definition\": function(a, b) {\n                var c = {\n                    input: \"click\",\n                    component: \"dashboard\",\n                    subcomponent: \"promo\",\n                    target: \"definition\",\n                    definition: b.JSBNG__find(\"strong\").html()\n                };\n                scribble(\"dashboard_click\", c);\n            }\n        }).deciderKey(\"promo_component\"), a(twttr.components.Promo);\n    });\n});\nprovide(\"components/Promptbird\", function(a) {\n    using(\"_\", \"multiGlobals/more_views\", \"mixins/inviteFriends\", \"mixins/userActionable\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.components.Promptbird\").subclassOf(twttr.components.Base).initializer(function(a) {\n            if (!twttr.views[this.constructor._name]) {\n                var b = new Error(((((\"Promptbird view \\\"\" + this.constructor._name)) + \"\\\" is undefined\")));\n                ((twttr.isLocalhost && JSBNG__console.log(b, ((b.stack || \"error.stack is unavailable :(\")))));\n                return;\n            }\n        ;\n        ;\n            var c = {\n                action: \"impression\",\n                section: ((\"promptbird_\" + a.JSBNG__prompt.prompt_id))\n            };\n            trackClient(c), this.JSBNG__prompt = a, this.$node.addClass(\"promptbird\");\n            var d = ((\"promptbird-\" + a.JSBNG__prompt.format.replace(/_/g, \"-\")));\n            this.$node.addClass(d), a.data.promptId = a.JSBNG__prompt.prompt_id;\n            var e = (new twttr.views[this.constructor._name](a.data)).html();\n            this.$node[0].innerHTML = e, ((((\"below_black_bar\" === a.JSBNG__prompt.format)) && (this.noSpacer = !0))), this.hasRendered();\n        }).click({\n            \".js-dismiss\": function(a) {\n                a.stopImmediatePropagation();\n                var b = {\n                    prompt_id: this.JSBNG__prompt.JSBNG__prompt.prompt_id\n                }, c = {\n                    success: function(a) {\n                    \n                    }\n                };\n                return twttr.API.Promptbird.dismissPrompt(b, c), this.destroy(), !1;\n            },\n            \".call-to-action\": function(a) {\n                var b = this, c = {\n                    action: \"click\",\n                    section: ((\"promptbird_\" + this.JSBNG__prompt.JSBNG__prompt.prompt_id))\n                };\n                trackClient(c);\n                if ($(a.currentTarget).data(\"preserve-prompt\")) {\n                    return;\n                }\n            ;\n            ;\n                var d = {\n                    prompt_id: this.JSBNG__prompt.JSBNG__prompt.prompt_id\n                }, e = {\n                    success: function(a) {\n                    \n                    }\n                };\n                twttr.API.Promptbird.dismissPrompt(d, e), this.destroy();\n            }\n        }), twttr.klass(\"twttr.components.PromptbirdLanguage\").subclassOf(twttr.components.Promptbird).initializer(function(a) {\n            this._superInitializer(a), this.$find(\".call-to-action\").JSBNG__one(\"click\", function() {\n                var b = a.JSBNG__prompt.template_name.split(\"_\");\n                b.shift();\n                var c = b.join(\"-\"), d = {\n                    success: function() {\n                        window.JSBNG__location.reload();\n                    }\n                };\n                twttr.currentUser.setLanguage(c, d);\n            });\n        }), twttr.klass(\"twttr.components.PromptLanguageDe\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageEs\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageHi\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageFr\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageFil\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageId\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageIt\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageJa\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageKo\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageMsa\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageNl\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguagePt\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageRu\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageTr\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageZhCn\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLanguageZhTw\").subclassOf(twttr.components.PromptbirdLanguage), twttr.klass(\"twttr.components.PromptLifelineJa\").subclassOf(twttr.components.Promptbird), twttr.klass(\"twttr.components.PromptImport\").subclassOf(twttr.components.Promptbird), twttr.klass(\"twttr.components.PromptVitDe\").subclassOf(twttr.components.Promptbird).initializer(function(a) {\n            this.registerUserActionEvents(), a.data.id = 16181559, this.constructor.uberclass._initializer.apply(this, arguments), this.$find(\".js-action-follow\").addClass(\"call-to-action\");\n        }).mixin(b.mixins.userActionable), twttr.klass(\"twttr.components.PromptOneClickImport\").subclassOf(twttr.components.Promptbird).initializer(function(a) {\n            this._superInitializer(a), this.$find(\".call-to-action\").JSBNG__one(\"click\", function(a) {\n                var b = $(this);\n                using(\"externalOauthPopup\").as(function(a) {\n                    var c = ((((((((window.JSBNG__location.protocol + \"//\")) + twttr.domains.local)) + \"/invitations/oauth_launch?email=\")) + encodeURIComponent(b.attr(\"data-email\"))));\n                    a.externalOauthPopup({\n                        url: c,\n                        callbackUrl: twttr.router.whoToFollowImportMatchesPath()\n                    });\n                });\n            });\n        }), twttr.klass(\"twttr.components.PromptImportInline\").subclassOf(twttr.components.Promptbird).initializer(function(a) {\n            this.constructor.uberclass._initializer.apply(this, arguments);\n            var b = new twttr.components.ContactImportLauncher, c = this;\n            b.bind(\"servicesLoaded\", function() {\n                b.$find(\".service-button\").addClass(\"call-to-action\").data(\"preserve-prompt\", \"true\"), c.$find(\".import-inline\").append(b.$node);\n            }), b.trigger(\"addedToPage\");\n        }), twttr.klass(\"twttr.components.PromptProfile\").subclassOf(twttr.components.Promptbird), twttr.klass(\"twttr.components.PromptMobile\").subclassOf(twttr.components.Promptbird).initializer(function(a) {\n            var b = twttr.router.mobileGalleryPath(), c = ((((twttr.pageLocale === \"en\")) ? \"\" : ((\"?lang=\" + twttr.pageLocale))));\n            a.data.android_path = ((((b + \"/android\")) + c)), a.data.blackberry_path = ((((b + \"/blackberry\")) + c)), a.data.iphone_path = ((((b + \"/iphone\")) + c)), a.data.ipad_path = ((((b + \"/ipad\")) + c)), a.data.wp7_path = ((((b + \"/wp7\")) + c)), a.data.mobile_gallery_path = ((b + c)), this.constructor.uberclass._initializer.call(this, a);\n        }), twttr.klass(\"twttr.components.PromptInvite\").subclassOf(twttr.components.Promptbird).mixin(twttr.mixins.inviteFriends).initializer(function(a) {\n            this.constructor.uberclass._initializer.apply(this, arguments), this.addFormEvents(), twttr.helpers.handlePopupLinks(this.$node);\n            if (twttr.isT1) this.$find(\".js-submit\").data(\"preserve-prompt\", !0);\n             else {\n                var b = new twttr.components.InviteFriends;\n                b.$find(\".js-submit\").addClass(\"call-to-action\").data(\"preserve-prompt\", !0), this.$find(\".invite\").append(b.$node);\n            }\n        ;\n        ;\n        }), twttr.klass(\"twttr.components.PromptFacebookDe\").subclassOf(twttr.components.Promptbird), a(twttr.components.Promptbird);\n    }), twttr.klass(\"twttr.components.PromptbirdDashboardPlaceholder\").subclassOf(twttr.components.Base).initializer(function() {\n        this.$node.attr(\"id\", \"js-promptbird-dashboard-narrow-hook\");\n    });\n});\nprovide(\"components/RelatedServices\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.RelatedServices\").subclassOf(twttr.components.Base).initializer(function() {\n            var a = this;\n            twttr.API.Promo.JSBNG__random({\n                promo_type: \"related_service\",\n                limit: 2\n            }, function(b) {\n                (($.isEmptyObject(b) || ((new twttr.views.DashboardRelatedServices({\n                    promos: b\n                })).render(a.$node, \"append\"), a.hasRendered())));\n            });\n        }).deciderKey(\"promo_component\"), a(twttr.components.RelatedServices);\n    });\n});\nprovide(\"TrendLocations\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.TrendLocations\", function(a) {\n            this.getLocation(a);\n        }).statics({\n            LOGGED_OUT_TREND_LOCATION_COOKIE: \"trend_location\",\n            install: function(a) {\n                ((twttr.trendLocations ? twttr.trendLocations.getLocation(a) : twttr.trendLocations = new twttr.TrendLocations(a)));\n            }\n        }).methods({\n            getLocation: function(a) {\n                var b = this;\n                twttr.API.Trend.locations({\n                    lang: twttr.pageLocale,\n                    success: function(c) {\n                        b.all = c;\n                        if (twttr.currentUser) twttr.currentUser.trendLocation().first(function(c) {\n                            ((c ? b.current = c : b.current = b.worldwide())), a(b.current);\n                        });\n                         else {\n                            var d = parseInt($.cookie(b.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE), 10);\n                            b.current = ((b.locationForWoeid(d) || b.worldwide())), a(b.current);\n                        }\n                    ;\n                    ;\n                    }\n                });\n            },\n            allLocations: function() {\n                return this.all.array;\n            },\n            ancestorsOf: function(a) {\n                if (!a.parentid) {\n                    return [];\n                }\n            ;\n            ;\n                var b = this.locationForWoeid(a.parentid);\n                return [b,].concat(this.ancestorsOf(b));\n            },\n            withAncestorsOf: function(a) {\n                return [a,].concat(this.ancestorsOf(a));\n            },\n            currentAncestors: function() {\n                return this.ancestorsOf(this.current);\n            },\n            withCurrentAncestors: function() {\n                return this.withAncestorsOf(this.current);\n            },\n            withFilterAncestors: function() {\n                return this.withAncestorsOf(this.currentFilter());\n            },\n            childrenOf: function(a) {\n                return twttr.filter(this.allLocations(), function(b) {\n                    return ((b.parentid === a.woeid));\n                });\n            },\n            currentChildren: function() {\n                return ((this.current.isPersonalized ? this.childrenOf(this.currentFilter(this.worldwide())) : this.childrenOf(this.currentFilter())));\n            },\n            locationForWoeid: function(a) {\n                return ((a ? twttr.filter(this.allLocations(), function(b) {\n                    return ((b.woeid == a));\n                })[0] : null));\n            },\n            locationsForWoeids: function(a) {\n                var b = this;\n                return twttr.map(a, function(a) {\n                    return b.locationForWoeid(a);\n                });\n            },\n            worldwide: function() {\n                return this.locationForWoeid(1);\n            },\n            currentFilter: function(a) {\n                var c = ((a || this.current));\n                return ((((((c.placeType.code === b.constants.placeTypes.city)) || ((this.childrenOf(c).length === 0)))) ? this._currentFilterWoeid = c.parentid : this._currentFilterWoeid = c.woeid)), this.locationForWoeid(this._currentFilterWoeid);\n            },\n            setPersonalized: function(a) {\n                this.current = $.extend(this.current, {\n                    isPersonalized: a\n                });\n            },\n            setCurrent: function(a) {\n                this.current = ((this.locationForWoeid(a.woeid) || this.current)), this.setPersonalized(a.isPersonalized), ((twttr.currentUser ? twttr.currentUser.setTrendLocation(a.woeid, a.isPersonalized) : (twttr.API.CurrentUser.trigger(\"changedLocation_success\"), $.cookie(this.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE, a.woeid)))), scribble(\"switch-trend-location\", {\n                    woeid: a.woeid,\n                    input: \"click\",\n                    origin: a.origin\n                });\n            }\n        }), a(twttr.TrendLocations);\n    });\n});\nprovide(\"components/PeopleResults\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.components.PeopleResults\").subclassOf(twttr.components.Base).mixin(twttr.mixins.userActionable).initializer(function(a) {\n            a = a.replace(/(^|\\b)(from\\:|to\\:|near\\:|source\\:)/g, \"\"), this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                query: a,\n                context: \"user_search\"\n            });\n            if (((a.indexOf(\":\") != -1))) {\n                return;\n            }\n        ;\n        ;\n            var b = {\n                reputable: !0,\n                display_location: \"search-component\",\n                pc: !0\n            }, c = this, d = 4;\n            twttr.API.User.search(a, b).first(d, function(b) {\n                ((c._readyToRender ? c._renderNow(b, a) : c._result = {\n                    users: b,\n                    query: a\n                }));\n            });\n        }).methods({\n            _renderNow: function(a, c) {\n                var d = this;\n                ((((a.length() > 0)) && (a = a.map(twttr.bind(this, function(a, b) {\n                    ((a.promotedContent && twttr.API.util.PromotedContent.logImpression(a.promotedContent.impression_id))), a.socialContext = ((a.socialContext || []));\n                    var c = d.makeSocialContextHtml(a, !1);\n                    return a.clone({\n                        socialcontext: c\n                    });\n                })), d.$node.empty(), (new twttr.views.PeopleResults({\n                    query: c\n                })).subview(\"found_people\", new twttr.views.UserSmallList(a)).render(d.$node, \"append\"), d.$find(\"a.view-all\").click(function(a) {\n                    d.scribbler.scribe({\n                        component: d._getScribeComponentName(),\n                        action: \"view_all\"\n                    });\n                }), twttr.helpers.ellipsify(d.$find(\"div.bio\")), d.registerUserActionEvents(), d.hasRendered())));\n                var e = [], f;\n                a.each(function(a, c) {\n                    e.push(a.id);\n                    if (((a.promotedContent && a.promotedContent.impression_id))) {\n                        var d = {\n                            target_id: a.id,\n                            item_type: b.constants.clientEvent.itemType.promotedUser,\n                            item_token: a.promotedContent.impression_id,\n                            item_position: c\n                        };\n                        f = ((f || {\n                        })), f[((a.id + \"\"))] = d;\n                    }\n                ;\n                ;\n                }), d.scribbler.scribe({\n                    component: d._getScribeComponentName(),\n                    action: \"results\"\n                }, {\n                    item_ids: e,\n                    item_count: e.length,\n                    item_details: f\n                });\n            },\n            render: function() {\n                var a = this._result;\n                ((a ? this._renderNow(a.users, a.query) : this._readyToRender = !0));\n            }\n        }).deciderKey(\"JSBNG__onebox_user_search\"), a(twttr.components.PeopleResults);\n    });\n});\nprovide(\"components/ProfileActions\", function(a) {\n    using(\"_\", \"constants\", \"mixins/serverRenderableObject\", ((twttr.isT1 ? \"mixins/t1/genericComboButton\" : []))).as(function(b, _, c, d, f) {\n        twttr.klass(\"twttr.components.ProfileActions\", function(a, b, c) {\n            this.profileUser = a, this.inProfilePane = !!c, this.$node = this.$domNode(function() {\n                return $(\"\\u003Cdiv /\\u003E\");\n            }), twttr.components.Base.prototype.constructor.apply(this, arguments);\n        }).subclassOf(twttr.components.Base).initializer(function(a, b) {\n            var c = this;\n            this.similarUser = a, this.screenName = a.screenName, this.currentRecommendations = [], this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: this.profileUser.id\n            }), this.whotofollowComponentName = \"whotofollow_dropdown\", this.ignoreScribeItemPosition = !0, twttr.recentlyViewedUsers.push(a);\n            if (twttr.loggedIn) {\n                var d = twttr.bind(this, function(b) {\n                    this._data = {\n                        user: a,\n                        id: a.id,\n                        screen_name: a.screenName,\n                        notifications: b.notifications,\n                        following: b.following,\n                        followed_by: b.followedBy,\n                        blocking: b.blocking,\n                        follow_request_sent: a.followRequestSent,\n                        want_retweets: b.wantRetweets,\n                        can_dm: ((b.canDM && ((twttr.currentUser.id != a.id)))),\n                        reported: !1\n                    }, this._applyMuteMethods(b, a), this._renderActions(), this.registerEvents(), this.wokeUp();\n                });\n                ((b ? d(b) : twttr.currentUser.relationshipWith(this.profileUser, d)));\n            }\n             else {\n                this._data = {\n                    user: a,\n                    id: a.id,\n                    screen_name: a.screenName\n                }, this._renderActions(), this._registerFollowEvents();\n                var e = twttr.abdecider.choose(\"signup_with_profiles_viewed-73\", !0);\n                if (((twttr.recentlyViewedUsers.size() >= 2))) {\n                    var f = (((new JSBNG__Date).getTime() - 86400000));\n                    ((((((e == \"two_profiles\")) && ((((twttr.recentlyViewedUsers.size() == 2)) || ((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 3))]) < f)))))) ? ((((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 2))]) > f)) && (twttr.abdecider.choose(\"signup_with_profiles_viewed-73\"), twttr.dialogs.signupModalDialogGuest(2, function(a) {\n                        a.open();\n                    })))) : ((((((e == \"three_profiles\")) && ((((twttr.recentlyViewedUsers.size() == 3)) || ((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 4))]) < f)))))) ? ((((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 3))]) > f)) && (twttr.abdecider.choose(\"signup_with_profiles_viewed-73\"), twttr.dialogs.signupModalDialogGuest(3, function(a) {\n                        a.open();\n                    })))) : ((((((((e == \"four_profiles\")) && ((((twttr.recentlyViewedUsers.size() == 4)) || ((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 5))]) < f)))))) && ((twttr.recentlyViewedUsers.getLastPushTime(twttr.recentlyViewedUsers.stack[((twttr.recentlyViewedUsers.size() - 4))]) > f)))) && (twttr.abdecider.choose(\"signup_with_profiles_viewed-73\"), twttr.dialogs.signupModalDialogGuest(4, function(a) {\n                        a.open();\n                    }))))))));\n                }\n            ;\n            ;\n                this.wokeUp();\n            }\n        ;\n        ;\n            this.registerUserActionEvents(), this.registerUserRecommendationsActions(\".user-rec-dropdown\");\n        }).mixin(twttr.mixins.userRecommendationsHelper, twttr.mixins.userActionable, d).methods({\n            domNodeSelector: function() {\n                var a = ((this.inProfilePane ? \"div.details-pane \" : \"\"));\n                return ((((((a + \"div.profile-actions-container[data-user-id=\")) + this.profileUser.id)) + \"] div.profile-actions-component\"));\n            },\n            _renderActions: function() {\n                if (((!this.preRendered || this.didInitialRenderActions))) {\n                    this._deregisterTipsy(), this.$node.empty(), (new twttr.views.ProfileActions(this._data)).render(this.$node, \"append\");\n                }\n            ;\n            ;\n                this.didInitialRenderActions = !0, this.scribeComponentName = ((this.$node.closest(\"div.details-pane\").length ? \"mini_profile_actions\" : \"profile_actions\")), this.$userProfileActionController = this.$find(\".user-profile-actions-button\"), this.userProfileActionsDropdown = null, this._registerTipsy();\n            },\n            wokeUp: function() {\n                using(\"\\u003EstreamWokeUp\", function() {\n                    signal(\"\\u003EwokeUp\");\n                });\n            },\n            _applyMuteMethods: function(a, b) {\n                var c = this;\n                if (!twttr.decider.isAvailable(\"muteUsers\")) {\n                    return;\n                }\n            ;\n            ;\n                this.$node.delegate(\".mute-action\", \"click\", function(a) {\n                    var d = $(this);\n                    ((d.hasClass(\"is-muted\") ? (d.removeClass(\"is-muted\"), d.text(_(\"Mute\")), $(((((\".stream-tweet[data-user-id=\" + b.id)) + \"]\"))).parent().show(), c._removeFromMuteList(b.id)) : (d.addClass(\"is-muted\"), d.text(_(\"Unmute\")), $(((((\".stream-tweet[data-user-id=\" + b.id)) + \"]\"))).parent().hide(), c._addToMuteList(b))));\n                }), twttr.merge(this._data, {\n                    show_mute: function() {\n                        return ((a.following && twttr.decider.isAvailable(\"muteUsers\")));\n                    },\n                    is_muted: function() {\n                        var a = twttr.caches.User.get(\"muted\");\n                        if (!a) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        for (var c in a) {\n                            if (((b.id == c))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                });\n            },\n            _addToMuteList: function(a) {\n                var b = {\n                    screenName: a.screenName,\n                    userId: a.id,\n                    profileImageUrl: twttr.helpers.transformProfileImageUrl(a.profileImageUrl, \"mini\")\n                }, c = ((twttr.caches.User.get(\"muted\") || {\n                }));\n                c[a.id] = b, twttr.caches.User.set(\"muted\", c);\n            },\n            _removeFromMuteList: function(a) {\n                var b = ((twttr.caches.User.get(\"muted\") || {\n                }));\n                delete b[a], twttr.caches.User.set(\"muted\", b);\n            },\n            renderSimilarUsers: function() {\n                if (!twttr.decider.isAvailable(\"whotofollow_similarities\")) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                a.profileUser.similarUsers({\n                    limit: 2,\n                    success: function(b) {\n                        var c = a.recsToUsers(b);\n                        a.trackImpressions(c, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: a.profileUser.id\n                        });\n                        if (c.length()) {\n                            var d = (new twttr.views.UserRecommendationsDropdown({\n                                user: a.profileUser.JSBNG__name\n                            })).subview(\"recommended_followers\", new twttr.views.UserSmallList(c)).render(a.$find(\".profile-actions\"), \"after\");\n                            a.attachUserRecommendationHideEvents(\"whotofollow_dropdown_hide\", d), twttr.helpers.ellipsify(a.$find(\".profile-actions div.bio\")), d.slideDown(300);\n                        }\n                    ;\n                    ;\n                    },\n                    error: function(b) {\n                        a.trackImpressions(null, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: a.profileUser.id,\n                            error_status: b.JSBNG__status\n                        });\n                    }\n                });\n            },\n            registerEvents: function() {\n                if (this.$node.attr(\"did-register-events\")) {\n                    return;\n                }\n            ;\n            ;\n                this.$node.attr(\"did-register-events\", !0), this.$node.delegate(\".js-direct-message-action\", \"click\", twttr.bind(this, function(a) {\n                    a.preventDefault(), ((twttr.decider.isExpando() && $(\".twttr-dialog-close\").click())), twttr.dialogs.dmSingle({\n                        user: {\n                            screenName: this.profileUser.screenName,\n                            user_id: this.profileUser.attributes.id,\n                            JSBNG__name: this.profileUser.attributes.JSBNG__name,\n                            profile_image_url: this.profileUser.attributes.profile_image_url\n                        },\n                        origin: \"profile-actions-direct-message\"\n                    }).open(), this.scribbler.scribe({\n                        component: this.scribeComponentName,\n                        action: \"dm\"\n                    }, {\n                        item_ids: [this.profileUser.attributes.id,],\n                        item_details: this._itemDetails()\n                    });\n                })), this._registerDeviceEvents(), this._registerRetweetEvents(), this._registerFollowEvents(), this._registerUnblockEvents(), this._registerAPIListeners();\n            },\n            _registerTipsy: function() {\n                this.$find(\".mute-action\").tipsy({\n                    gravity: \"s\",\n                    delayIn: 150,\n                    delayOut: 500,\n                    fade: !0\n                }), this.$find(\".device-notifications\").tipsy({\n                    gravity: \"s\",\n                    html: !0,\n                    title: function() {\n                        var a = (($(this).hasClass(\"notifying\") ? _(\"Tweets from this user are sent to your mobile phone.\") : _(\"Tweets from this user are not sent to your mobile phone.\")));\n                        return (new twttr.views.Tipsy({\n                            title: a\n                        })).html();\n                    }\n                }), this.$find(\".retweet-setting\").tipsy({\n                    gravity: \"s\",\n                    html: !0,\n                    title: function() {\n                        var a = (($(this).hasClass(\"including\") ? _(\"Retweets from this user will appear in your timeline.\") : _(\"Retweets from this user won't appear in your timeline.\")));\n                        return (new twttr.views.Tipsy({\n                            title: a\n                        })).html();\n                    }\n                });\n            },\n            _deregisterTipsy: function() {\n                this.$find(\".device-notifications\").tipsy({\n                    stopThat: !0\n                }), this.$find(\".retweet-setting\").tipsy({\n                    stopThat: !0\n                }), this.$find(\".mute-action\").tipsy({\n                    stopThat: !0\n                });\n            },\n            _registerDeviceEvents: function() {\n                var a, b, c, d = this;\n                this.$node.delegate(\".js-device-notifications\", \"click\", function(e) {\n                    e.preventDefault();\n                    if (!twttr.currentUser.deviceSetup) {\n                        ((((!twttr.currentUser.deviceVerified && ((!twttr.currentUser.pushTweetsDecidered || !twttr.currentUser.pushDevice)))) ? (a = {\n                            title: _(\"Setup mobile notifications\"),\n                            JSBNG__content: (new twttr.views.PhoneSetupPrompt({\n                                screen_name: d._data.screen_name,\n                                ok: _(\"Set up phone\"),\n                                cancel: _(\"Cancel\")\n                            })).html()\n                        }, b = twttr.router.devicesPath()) : (a = {\n                            title: _(\"Enable mobile notifications for Tweets\"),\n                            JSBNG__content: (new twttr.views.PhoneTweetsOffPrompt({\n                                screen_name: d._data.screen_name,\n                                ok: _(\"Enable Tweet notifications\"),\n                                cancel: _(\"Close\")\n                            })).html()\n                        }, ((((twttr.currentUser.pushDevice && twttr.currentUser.pushTweetsDecidered)) ? b = twttr.router.pushHelpPath() : b = twttr.router.devicesPath()))))), (new twttr.widget.Prompt({\n                            modal: !0,\n                            callback: function(a) {\n                                ((a && (c = function() {\n                                    twttr.router.routeTo(b);\n                                }, twttr.API.User.bind(\"subscribe\", c), d.profileUser.setNotificationsOn())));\n                            },\n                            template: a\n                        })).open();\n                        return;\n                    }\n                ;\n                ;\n                    var f = $(this), g = ((f.hasClass(\"notifying\") ? \"setNotificationsOff\" : \"setNotificationsOn\"));\n                    d.profileUser[g]();\n                });\n            },\n            _registerRetweetEvents: function() {\n                var a = this;\n                this.$node.delegate(\".js-retweet-setting\", \"click\", function(b) {\n                    var c = $(this);\n                    b.preventDefault();\n                    var d = c.hasClass(\"including\"), e = ((d ? \"setWantRetweetsOff\" : \"setWantRetweetsOn\"));\n                    a.profileUser[e]();\n                });\n            },\n            _registerFollowEvents: function() {\n                var a = this;\n                this.$node.delegate(\".js-follow, .profile-follow-button, .follow-request-button\", \"click\", function(b) {\n                    var c = a.profileUser.impressionId;\n                    ((twttr.loggedIn ? a.profileUser.follow({\n                        before: function() {\n                            a._showTweetsFromUserOnHome();\n                        },\n                        success: function() {\n                            a.renderSimilarUsers(), trackClient({\n                                component: a.scribeComponentName,\n                                action: \"follow\"\n                            }, {\n                                profile_id: a.profileUser.id,\n                                item_ids: [a.profileUser.id,],\n                                item_details: a._itemDetails(),\n                                event_info: \"follow\"\n                            });\n                        },\n                        error: function(b) {\n                            a._hideTweetsFromUserOnHome(), twttr.helpers.showErrorFromResponse(b, \"follow\");\n                        },\n                        impression_id: c\n                    }) : twttr.dialogs.signinOrSignup({\n                        follow: a.profileUser,\n                        justSignup: !0\n                    }).open())), b.preventDefault();\n                }), this.$node.delegate(\".js-unfollow, .profile-unfollow-link, .cancel-request-link\", \"click\", function(b) {\n                    if (((a.$node.JSBNG__find(\".follow-state\").hasClass(\"just-followed\") && !!b.clientX))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = a.profileUser.impressionId;\n                    a.profileUser.unfollow({\n                        before: function() {\n                            a._hideTweetsFromUserOnHome();\n                        },\n                        success: function() {\n                            trackClient({\n                                component: a.scribeComponentName,\n                                action: \"unfollow\"\n                            }, {\n                                profile_id: a.profileUser.id,\n                                item_ids: [a.profileUser.id,],\n                                item_details: a._itemDetails(),\n                                event_info: \"unfollow\"\n                            });\n                        },\n                        error: function(b) {\n                            a._showTweetsFromUserOnHome(), twttr.helpers.showErrorFromResponse(b, \"unfollow\");\n                        },\n                        impression_id: c\n                    }), b.preventDefault();\n                }), this.$node.delegate(\".just-followed .profile-unfollow-link\", \"mouseleave\", function(b) {\n                    a.$node.JSBNG__find(\".follow-state\").removeClass(\"just-followed\");\n                });\n            },\n            _registerUnblockEvents: function() {\n                var a = this;\n                this.$node.delegate(\".js-unblock\", \"click\", function(b) {\n                    a.profileUser.unblock({\n                        before: twttr.bind(a, a._showStreamForBlockedUser),\n                        success: function() {\n                            a.scribbler.scribe({\n                                component: a.scribeComponentName,\n                                action: \"unblock\"\n                            }, {\n                                item_ids: [a.profileUser.id,],\n                                item_details: a._itemDetails(),\n                                event_info: \"unblock\"\n                            });\n                        },\n                        error: function(b) {\n                            a._hideStreamForBlockedUser(), twttr.helpers.showErrorFromResponse(b, \"unblock\");\n                        }\n                    }), b.preventDefault();\n                }), this.$node.delegate(\".js-block\", \"click\", function(b) {\n                    a.profileUser.block({\n                        timeout: function(a) {\n                            a.retry();\n                        },\n                        before: twttr.bind(a, a._hideStreamForBlockedUser),\n                        error: function() {\n                            a._showStreamForBlockedUser(), twttr.helpers.showErrorFromResponse(b, \"block\");\n                        }\n                    });\n                });\n            },\n            _updateDisplay: function(a, b) {\n                var c = this, d = !b, e = !!b;\n                switch (a) {\n                  case \"follow\":\n                    c._data.following = d, c._data.want_retweets = d, c._data.just_followed = d;\n                    break;\n                  case \"unfollow\":\n                \n                  case \"cancel_request\":\n                    c._data.following = e, c._data.follow_request_sent = e, c._data.just_followed = e;\n                    break;\n                  case \"follow_request\":\n                    c._data.follow_request_sent = d;\n                    break;\n                  case \"block\":\n                    ((b ? c._data.following = !!c._data.was_following : (c._data.was_following = c._data.following, c._data.following = !1))), c._data.blocking = d, c._data.reported = e;\n                    break;\n                  case \"unblock\":\n                    c._data.following = e, c._data.blocking = e, c._data.reported = e, c._data.followed_by = !1;\n                    break;\n                  case \"report\":\n                    ((b ? c._data.following = !!c._data.was_following : (c._data.was_following = c._data.following, c._data.following = !1))), c._data.blocking = d, c._data.reported = d;\n                    break;\n                  case \"subscribe\":\n                    c._data.notifications = d;\n                    break;\n                  case \"unsubscribe\":\n                    c._data.notifications = e;\n                    break;\n                  case \"does_want_retweets\":\n                    c._data.want_retweets = d;\n                    break;\n                  case \"doesnt_want_retweets\":\n                    c._data.want_retweets = e;\n                };\n            ;\n                $([\"following\",\"blocking\",\"followRequestSent\",\"reported\",\"notifications\",\"wantRetweet\",]).each(function(a, b) {\n                    c._data.user.sync(b, c._data[b]);\n                }), c._renderActions();\n            },\n            _registerAPIListeners: function() {\n                var a = this, b = {\n                    before: function(b, c) {\n                        var d = c.requestParameters[0], e = ((d.user_id || d.user_ids));\n                        ((((e === a._data.id)) && a._updateDisplay(b.type, !1)));\n                    },\n                    error: function(b, c, d) {\n                        var e = d.requestParameters[0], f = ((e.user_id || e.user_ids));\n                        ((((f === a._data.id)) && a._updateDisplay(b.type, !0)));\n                    }\n                };\n                twttr.API.User.bind(\"follow\", b), twttr.API.User.bind(\"unfollow\", b), twttr.API.User.bind(\"follow_request\", b), twttr.API.User.bind(\"cancel_request\", b), twttr.API.User.bind(\"block\", b), twttr.API.User.bind(\"unblock\", b), twttr.API.User.bind(\"report\", b), twttr.API.User.bind(\"subscribe\", b), twttr.API.User.bind(\"unsubscribe\", b), twttr.API.User.bind(\"does_want_retweets\", b), twttr.API.User.bind(\"doesnt_want_retweets\", b);\n            },\n            _getHomeTimeline: function(a) {\n                var b = twttr.app.getPage(\"JSBNG__home\");\n                ((b && b.send(\"getStreamManager\", function(b) {\n                    if (b) {\n                        var c = b.getStream(twttr.streams.Home);\n                        ((c && a(c.$node)));\n                    }\n                ;\n                ;\n                })));\n            },\n            _streamItemsForUserId: function(a, b) {\n                return a.JSBNG__find(((((\".stream .stream-item[data-item-type=\\\"user\\\"][data-item-id=\\\"\" + b)) + \"\\\"]\"))).add(((((\".stream .stream-tweet[data-user-id=\\\"\" + b)) + \"\\\"]\")), a).add(((((\".stream .stream-tweet[data-retweeter-id=\\\"\" + b)) + \"\\\"]\")), a).closest(\".stream-item\");\n            },\n            _hideTweetsFromUserOnHome: function() {\n                var a = this, b = this.profileUser.id, c = this._getHomeTimeline(function(c) {\n                    a._streamItemsForUserId(c, b).hide();\n                });\n            },\n            _showTweetsFromUserOnHome: function() {\n                var a = this, b = this.profileUser.id;\n                this._getHomeTimeline(function(c) {\n                    a._streamItemsForUserId(c, b).show();\n                });\n            },\n            _hideStreamForBlockedUser: function() {\n                this._streamItemsForUserId($(JSBNG__document.body), this.profileUser.id).hide();\n            },\n            _showStreamForBlockedUser: function() {\n                this._streamItemsForUserId($(JSBNG__document.body), this.profileUser.id).show();\n            },\n            _getActionsDropdown: function(a) {\n                var b = this, c = [];\n                return c.push({\n                    label: _(\"Mention {{screen_name}}\", this._data),\n                    icon: \"mention\",\n                    handlers: {\n                        click: function() {\n                            (new twttr.widget.TweetDialog({\n                                template: {\n                                    title: ((\"Mention \" + b.profileUser.screenName))\n                                },\n                                draggable: !0,\n                                defaultContent: ((((\"@\" + b.profileUser.screenName)) + \" \")),\n                                origin: \"profile-actions-dropdown-metion\"\n                            })).open().JSBNG__focus();\n                        }\n                    }\n                }), ((this._data.blocking ? c.push({\n                    label: _(\"Unblock {{screen_name}}\", this._data),\n                    icon: \"block\",\n                    handlers: {\n                        click: function() {\n                            b.profileUser.unblock({\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.profileUser.id)) + \"\\\"]\"))).closest(\".stream-item\").show();\n                                }\n                            });\n                        }\n                    }\n                }) : c.push({\n                    label: _(\"Block {{screen_name}}\", this._data),\n                    icon: \"block\",\n                    handlers: {\n                        click: function() {\n                            b.profileUser.block({\n                                timeout: function(a) {\n                                    a.retry();\n                                },\n                                before: twttr.bind(b, b._hideStreamForBlockedUser),\n                                error: function() {\n                                    b._showStreamForBlockedUser(), twttr.helpers.showErrorFromResponse(e, \"block\");\n                                }\n                            });\n                        }\n                    }\n                }))), ((this._data.blocking || c.push({\n                    label: _(\"Report \\u003Cspan class=\\\"truncate\\\"\\u003E{{screen_name}}\\u003C/span\\u003E for spam\", this._data),\n                    icon: \"spam\",\n                    handlers: {\n                        click: function() {\n                            b.profileUser.report({\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.profileUser.id)) + \"\\\"]\"))).closest(\".stream-item\").hide();\n                                }\n                            });\n                        }\n                    }\n                }))), new twttr.control.Dropdown(a, {\n                    items: c,\n                    direction: \"right\"\n                });\n            },\n            _itemDetails: function() {\n                var a = {\n                }, c = this.profileUser.impressionId;\n                return a[((\"\" + this.profileUser.id))] = {\n                    item_token: c,\n                    target_id: this.profileUser.id,\n                    item_type: b.constants.clientEvent.itemType[((c ? \"promotedUser\" : \"user\"))]\n                }, a;\n            }\n        }), twttr.control.Dropdown.createCache(\"lists\"), ((f && twttr.components.ProfileActions.mixin(f))), a(twttr.components.ProfileActions);\n    });\n});\nprovide(\"components/RecentTweets\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.RecentTweets\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.i18nTweet).initializer(function(a) {\n            var b = this, c = ((((twttr.$win.height() < 600)) ? 2 : 3));\n            a.timeline().first(c, function(a) {\n                ((((a.length() > 0)) && ((new twttr.views.RecentTweets(a)).render(b.$node, \"append\"), b.registerTweetActionEvents(), b.updateI18nDisplay(), b.hasRendered())));\n            });\n        }).deciderKey(\"recent_tweets_component\"), a(twttr.components.RecentTweets);\n    });\n});\nprovide(\"components/RecentlyFollowed\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.RecentlyFollowed\").subclassOf(twttr.components.Base).mixin(twttr.mixins.userActionable, twttr.mixins.userRecommendationsHelper).initializer(function(a) {\n            function b(a, b) {\n                var c = function(a) {\n                    return ((a.screenName == b.screenName));\n                };\n                ((((d._userCollection && !d._userCollection.JSBNG__find(c))) && (d._userCollection.unshift(b), d.rememberHeight(), d.deferredCreateView())));\n            };\n        ;\n            function c(a, b) {\n                var c = function(a) {\n                    return ((a.screenName != b.screenName));\n                };\n                ((d._userCollection && (d._userCollection = d._userCollection.filter(c), d.rememberHeight(), d.deferredCreateView())));\n            };\n        ;\n            if (!twttr.currentUser) {\n                return;\n            }\n        ;\n        ;\n            this.inWelcomeFlow = a, this._maxFollowersCount = 10, this._maxSimilarsCount = 2;\n            var d = this;\n            twttr.currentUser.friends({\n                count: this._maxFollowersCount,\n                success: function(b) {\n                    d._userCollection = b, ((((a || !b.isEmpty())) && d.createView())), d.registerUserActionEvents(), d.registerUserRecommendationsActions();\n                }\n            }), this.$node.delegate(\".followed li a.dynsims\", \"click\", function(a) {\n                var b = $(this);\n                if (b.parent().hasClass(\"active\")) {\n                    return;\n                }\n            ;\n            ;\n                var c = b.attr(\"data-user-id\"), e = d._userCollection.JSBNG__find(function(a, b) {\n                    if (((a.id.toString() == c))) {\n                        return a;\n                    }\n                ;\n                ;\n                });\n                return ((((e && twttr.decider.isAvailable(\"whotofollow_similarities\"))) && (d.rememberHeight(), d.showSimilarUsers(e)))), a.preventDefault(), a.stopPropagation(), !1;\n            }), twttr.API.User.bind(\"follow.RecentlyFollowedComponent\", b), twttr.API.User.bind(\"unfollow.RecentlyFollowedComponent\", c), twttr.app.bind(\"fakeFollow.RecentlyFollowedComponent\", b), twttr.app.bind(\"fakeUnfollow.RecentlyFollowedComponent\", c);\n        }).destructor(function() {\n            twttr.app.unbind(\".RecentlyFollowedComponent\"), twttr.API.User.unbind(\".RecentlyFollowedComponent\");\n        }).methods({\n            rememberHeight: function() {\n                var a = this.$find(\".recently-followed-users\");\n                a.css(\"height\", ((a.height() + \"px\")));\n            },\n            autoHeight: function() {\n                this.$find(\".recently-followed-users\").css(\"height\", \"\");\n            },\n            deferredCreateView: function() {\n                ((this._createViewTimeout && (JSBNG__clearTimeout(this._createViewTimeout), this._createViewTimeout = null)));\n                var a = this;\n                this._createViewTimeout = JSBNG__setTimeout(function() {\n                    a.createView(), a._createViewTimeout = null;\n                }, 1);\n            },\n            createView: function() {\n                var a = this._userCollection.first();\n                (new twttr.views.RecentlyFollowed({\n                    user: new twttr.views.BaseStats(twttr.currentUser),\n                    latest_friends: new twttr.views.UserThumbList(this._userCollection.slice(0, this._maxFollowersCount)),\n                    latest_friend: ((a ? a.screenName : !1)),\n                    welcome_flow: !!this.inWelcomeFlow,\n                    screen_name: twttr.currentUser.screenName,\n                    following_count: twttr.currentUser.friendsCount,\n                    following_10: ((twttr.currentUser.friendsCount >= 10))\n                })).render(this.$node, \"html\");\n                var b = this.$find(\".followed ul\");\n                if (((a && twttr.decider.isAvailable(\"whotofollow_similarities\")))) {\n                    b.JSBNG__find(\"li a\").addClass(\"dynsims\").removeClass(\"user-profile-link\").attr(\"href\", \"#\");\n                    var c = this.$find(\".recently-followed-users .suggestions\");\n                    this.showSimilarUsers(a);\n                }\n                 else this.autoHeight();\n            ;\n            ;\n                if (this.inWelcomeFlow) {\n                    var d = ((b.JSBNG__find(\"li\").length + 1));\n                    for (var e = d; ((e <= 10)); e++) {\n                        b.append(((((\"\\u003Cli\\u003E\\u003Cspan class=\\\"welcome-placeholder\\\"\\u003E\" + e)) + \"\\u003C/span\\u003E\\u003C/li\\u003E\")));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                this.hasRendered();\n            },\n            showSimilarUsers: function(a) {\n                var b = this.$find(\".followed ul\"), c = this.$find(\".suggestions\").css({\n                    opacity: 0\n                });\n                b.JSBNG__find(\"li\").removeClass(\"active\"), a.similarUsers({\n                    limit: this._maxSimilarsCount,\n                    complete: twttr.bind(this, function() {\n                        this.autoHeight();\n                    }),\n                    success: twttr.bind(this, function(d) {\n                        this.similarUser = a, this.screenName = a.screenName;\n                        var e = this.recsToUsers(d).slice(0, this._maxSimilarsCount);\n                        ((((\"florian\" == a.screenName)) && (e = new twttr.API.util.BaseCollection))), this.trackImpressions(e, \"recently_followed_view_similarities\", {\n                            to_user_id: a.id,\n                            tracking_context: \"recently_followed\",\n                            similar_to_user: a.id\n                        }), ((e.length() ? ((new twttr.views.UserDetailedList(e)).render(c.JSBNG__find(\"ul\"), \"html\"), b.JSBNG__find(((((\"li a[data-user-id=\" + a.id)) + \"]\"))).parent(\"li\").addClass(\"active\"), c.JSBNG__find(\"p span\").text(a.JSBNG__name), c.animate({\n                            opacity: 1\n                        }, 200, function() {\n                            $(this).show();\n                        })) : c.hide()));\n                    }),\n                    error: twttr.bind(this, function(b) {\n                        this.trackImpressions(null, \"recently_followed_view_similarities\", {\n                            to_user_id: a.id,\n                            tracking_context: \"recently_followed\",\n                            similar_to_user: a.id,\n                            error_status: b.JSBNG__status\n                        });\n                    })\n                });\n            }\n        }), a(twttr.components.RecentlyFollowed);\n    });\n});\nprovide(\"components/RecentlyViewed\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.RecentlyViewed\").subclassOf(twttr.components.Base).mixin(twttr.mixins.userActionable).initializer(function() {\n            this.createView(), this.registerEvents();\n        }).methods({\n            registerEvents: function() {\n                var a = this;\n                this.$node.delegate(\"h2 .clear-all\", \"click\", function(b) {\n                    b.preventDefault(), twttr.recentlyViewedUsers.clear(), a.$node.slideUp(\"fast\", function() {\n                        a.$node.empty().show();\n                    });\n                }), twttr.recentlyViewedUsers.bind(\"push.RecentlyViewedComponent\", function(b, c) {\n                    ((a.$find(((((\"li[data-user-id=\\\"\" + c)) + \"\\\"]\"))).size() || a.createView()));\n                }), a.registerUserActionEvents(), a.$node.delegate(\".user-profile-link, .follow-action\", \"click\", function() {\n                    var a = $(this), b = ((a.hasClass(\"user-profile-link\") ? \"profile_click\" : \"follow\"));\n                    trackClient({\n                        section: \"dashboard\",\n                        component: \"recently_viewed\",\n                        action: b\n                    }, {\n                        item_ids: [parseInt(a.attr(\"data-user-id\")),],\n                        item_count: 1\n                    });\n                });\n            },\n            createView: function() {\n                var a = this;\n                twttr.recentlyViewedUsers.findAll({\n                    success: function(b) {\n                        b = b.filter(function(a) {\n                            return !a.following;\n                        }).slice(0, 6), ((b.length() ? (trackClient({\n                            section: \"dashboard\",\n                            component: \"recently_viewed\",\n                            action: \"results\"\n                        }, {\n                            item_ids: b.map(function(a) {\n                                return a.id;\n                            }),\n                            item_count: b.length()\n                        }), (new twttr.views.RecentlyViewed(b)).render(a.$node, \"html\"), twttr.helpers.ellipsify(a.$find(\"div.bio\")), a.hasRendered()) : a.trigger(\"notRendered\", \"noRecentlyViewedUsers\")));\n                    }\n                });\n            }\n        }), a(twttr.components.RecentlyViewed);\n    });\n});\nprovide(\"components/InviteContacts\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.InviteContacts\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            b = ((b || {\n            })), this.scribbler = ((b.scribbler || new twttr.Scribbler)), this.clientEventComponent = ((b.clientEventComponent || \"invite_contacts\"));\n            var c;\n            for (var d = 0; ((d < a.contacts.length)); ++d) {\n                c = a.contacts[d], c.index = d, c.truncated_email = twttr.helpers.truncate(c.email), c.truncated_name = twttr.helpers.truncate(c.JSBNG__name);\n            ;\n            };\n        ;\n            (new twttr.views.InviteContacts(a)).render(this.$node, \"append\"), twttr.helpers.handlePopupLinks(this.$node);\n            var e = this.$node.JSBNG__find(\"#select-all-contacts\"), f = this.$node.JSBNG__find(\".invite-contacts-button\"), g = this.$node.JSBNG__find(\".contacts INPUT[type=checkbox]\");\n            e.change(function(a) {\n                return g.attr(\"checked\", this.checked), ((this.checked ? f.removeClass(\"disabled\") : f.addClass(\"disabled\"))), !0;\n            }), g.attr(\"checked\", !0), e.attr(\"checked\", !0), f.removeClass(\"disabled\"), g.change(function(a) {\n                var b = !0;\n                return g.each(function() {\n                    b = ((b && this.checked));\n                }), e.attr(\"checked\", b), ((this.checked ? f.removeClass(\"disabled\") : ((((g.filter(\":checked\").length == 0)) && f.addClass(\"disabled\"))))), !0;\n            });\n            var i = ((b.JSBNG__onSuccess || $.noop)), j = ((b.JSBNG__onSubmit || $.noop)), k = ((b.showError || function(a) {\n                twttr.showError(a);\n            })), l = this;\n            f.click(function(a) {\n                if ($(this).hasClass(\"disabled\")) {\n                    return;\n                }\n            ;\n            ;\n                j();\n                var b = g.filter(\":checked\").map(function() {\n                    var a = $(this), b = a.siblings(\".contact-item-name\").html();\n                    return ((((b == a.val())) ? a.val() : ((((((((\"\\\"\" + b)) + \"\\\" \\u003C\")) + a.val())) + \"\\u003E\"))));\n                }).get();\n                f.addClass(\"disabled\");\n                var c = {\n                    source: \"contact_import\",\n                    success: twttr.bind(this, function(a) {\n                        var b = ((a.invited && a.invited.length));\n                        twttr.showMessage(_(\"We let {{count}} of your contacts know about Twitter.\", {\n                            count: b\n                        })), l.scribbler.scribe({\n                            component: l.clientEventComponent,\n                            action: \"invited\"\n                        }, {\n                            event_value: b,\n                            item_count: b\n                        }), l.scribbler.scribe({\n                            component: l.clientEventComponent,\n                            action: \"invitable\"\n                        }, {\n                            item_count: g.length\n                        }), i();\n                    }),\n                    error: function(a) {\n                        f.removeClass(\"disabled\");\n                        var c = ((twttr.API.util.RemoteRequest.apiErrorCodeFromResponse(a) || a.JSBNG__status));\n                        l.scribbler.scribe({\n                            component: l.clientEventComponent,\n                            action: \"error\"\n                        }, {\n                            status_code: c,\n                            item_count: b.length\n                        });\n                        switch (c) {\n                          case 47:\n                            k(_(\"We couldn't send invitations to any of those addresses.\"));\n                            break;\n                          case 37:\n                            k(_(\"There was an error emailing your contacts. Please try again later.\"));\n                            break;\n                          default:\n                            twttr.showMessage(_(\"We let your contacts know about Twitter.\")), i();\n                        };\n                    ;\n                    }\n                };\n                twttr.API.AddressBook.sendInvitesByEmail(b, c);\n            }), this.hasRendered();\n        }), a(twttr.components.InviteContacts);\n    });\n});\nprovide(\"components/InviteFriends\", function(a) {\n    using(\"_\", \"constants\", \"mixins/inviteFriends\").as(function(b, _) {\n        twttr.klass(\"twttr.components.InviteFriends\").subclassOf(twttr.components.Base).mixin(twttr.mixins.inviteFriends).initializer(function(a) {\n            (new twttr.views.InviteFriends).render(this.$node, \"append\"), twttr.helpers.handlePopupLinks(this.$node), this.addFormEvents(a), this.hasRendered();\n        }), a(twttr.components.InviteFriends);\n    });\n});\nprovide(\"components/Retweeters\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.Retweeters\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            var d = this;\n            a.retweeters({\n                count: ((b || 15)),\n                success: function(b) {\n                    if (b.length()) {\n                        var c = a.retweetCount, e = ((((c > 50)) ? \"50+\" : c));\n                        (new twttr.views.TweetStats({\n                            retweeters: b.array,\n                            retweeters_count: e,\n                            retweeters_length_one: ((c == 1)),\n                            retweeters_length_other: ((c != 1))\n                        })).render(d.$node, \"append\");\n                        var f = b.map(function(a) {\n                            return new twttr.views.BaseUser(a);\n                        });\n                        (new twttr.views.FacePile({\n                            users: f.array\n                        })).render(d.$find(\".js-face-pile-container\"), \"append\"), d.$find(\".js-user-tipsy\").tipsy({\n                            gravity: \"s\"\n                        }), d.hasRendered();\n                    }\n                ;\n                ;\n                }\n            });\n        }).deciderKey(\"retweeters_component\"), a(twttr.components.Retweeters);\n    });\n});\nprovide(\"components/TweetActivity\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.TweetActivity\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this.tweet = a, ((this.tweet.activities && this.loadUsersAndRenderActivity()));\n        }).methods({\n            loadUsersAndRenderActivity: function() {\n                var a = this, b = 33, c = [], d = {\n                    favoriters: {\n                    },\n                    retweeters: {\n                    },\n                    repliers: {\n                    }\n                }, e = {\n                    favoriters: [],\n                    retweeters: [],\n                    repliers: []\n                };\n                for (var f in e) {\n                    var g = this.tweet.activities[f];\n                    for (var i = 0; ((i < g.length)); i++) {\n                        c = c.concat(g.slice(0, b)), d[f][g[i]] = !0;\n                    ;\n                    };\n                ;\n                };\n            ;\n                twttr.API.User.findAll(twttr.util.arrayUniq(c), {\n                    stringifiedIds: !0,\n                    success: function(b) {\n                        b.each(function(a) {\n                            for (var b in e) {\n                                ((d[b][a.id] && e[b].push(a)));\n                            ;\n                            };\n                        ;\n                        }), (new twttr.views.TweetActivity({\n                            counts: {\n                                favoriters_count: a.tweet.activities.favoriters_count,\n                                retweeters_count: a.tweet.activities.retweeters_count,\n                                repliers_count: a.tweet.activities.repliers_count\n                            },\n                            activities: e\n                        })).render(a.$node, \"append\");\n                    }\n                });\n            }\n        }).click({\n            \".tweet-activity-view-all\": function(a, b) {\n                b.closest(\".activity-list-container\").JSBNG__find(\"li.hidden\").show(), b.closest(\".tweet-activity-count-container\").remove(), a.preventDefault();\n            }\n        }).deciderKey(function() {\n            return ((twttr.decider.isActivityEnabled() && twttr.decider.isAvailable(\"activity_social_context\")));\n        }), a(twttr.components.TweetActivity);\n    });\n});\nprovide(\"components/ConversationThread\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.ConversationThread\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            (new twttr.views.ConversationThread(a)).render(this.$node, \"append\"), a.bind(\"newMessage\", function(a, c) {\n                (new twttr.views.Message(c)).render(b.$find(\".messages-pane-header\"), \"after\");\n            }), a.bind(\"deletedMessage\", function(a, c) {\n                b.$find(((((\".js-message[data-message-id=\" + c)) + \"]\"))).remove();\n            }), this.hasRendered();\n        }), a(twttr.components.ConversationThread);\n    });\n});\nprovide(\"components/InReplyTo\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.InReplyTo\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.i18nTweet).initializer(function(a) {\n            var b = this;\n            ((a.isReply && a.inReplyTo(function(a) {\n                (new twttr.views.InReplyTo(a)).render(b.$node, \"append\"), b.registerTweetActionEvents(), b.updateI18nDisplay(), b.hasRendered();\n            })));\n        }).deciderKey(\"in_reply_to_component\").methods({\n            noSpacer: !0\n        }), a(twttr.components.InReplyTo);\n    });\n});\nprovide(\"components/InlineReplyBox\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.InlineReplyBox\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable).mixin(twttr.mixins.streamablePageWithInlineMedia).mixin(twttr.mixins.i18nTweet).initializer(function(a, b, c, d, e) {\n            if (!twttr.decider.hasInlineReplies()) {\n                return null;\n            }\n        ;\n        ;\n            this.registerTweetActionEvents(), b.addClass(\"with-inline-reply\");\n            var f = this.tweetActionReply(a, \"expand\", !0);\n            f = twttr.dialogs.reply(f, !0);\n            var g = (new twttr.views.InlineReplyBox({\n                profile_image_url: twttr.currentUser.profileImageUrl,\n                profile_image_size: ((e ? \"48\" : \"32\"))\n            })).$html();\n            this.tweetbox = new twttr.TweetBox(g.prependTo(b), twttr.merge(f, {\n                condensed: !0,\n                condensedContent: _(\"Reply to @{{username}}\", {\n                    username: f.defaultContent.slice(1)\n                }),\n                width: d,\n                statusAction: \"reply\",\n                whenGeoPopupOpens: function() {\n                    b.parent().scrollTop(0).css(\"overflow\", \"visible\");\n                }\n            }));\n            var i = this;\n            this.tweetbox.bind(\"open\", function() {\n                g.addClass(\"shifted\").JSBNG__find(\".inline-reply-user-image\").show(), ((e && i.tweetbox.$find(\"textarea\").width(e)));\n            }), this.tweetbox.bind(\"close\", function() {\n                g.removeClass(\"shifted\").JSBNG__find(\".inline-reply-user-image\").hide(), ((e && i.tweetbox.$find(\"textarea\").width(d)));\n            }), this.tweetbox.bind(\"tweetSuccess\", function(a, b) {\n                var d = c.show().JSBNG__find(\".tweets-wrapper\");\n                ((d.length || (d = c))), (new twttr.views.SimpleTweet(b)).render(d, \"prepend\"), i.addInlineMediaIcons(d), i.updateI18nDisplay();\n            }), this.tweetbox.bind(\"sendingTweet\", function(c, d) {\n                i.trigger(\"reply.tweet\", [a,b,\"reply\",]);\n            });\n        }).methods({\n            JSBNG__focus: function() {\n                this.tweetbox.JSBNG__focus();\n            }\n        }), a(twttr.components.InReplyTo);\n    });\n});\nprovide(\"components/Conversation\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.Conversation\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.usesRelatedResults, twttr.mixins.i18nTweet, twttr.mixins.streamablePageWithInlineMedia).initializer(function(a, b, c) {\n            var d = this;\n            d._tweetId = a.id;\n            var e = function(a) {\n                if (((a.length > 1))) {\n                    var b = $(\"div.inner-pane\").filter(\"div.active\").JSBNG__find(\"div.pane-components\"), c = b.JSBNG__find(\"div.conversation-last-ancestor-tweet\");\n                    ((((c.length > 0)) && b.animate({\n                        scrollTop: ((c.position().JSBNG__top - 50))\n                    }, 800)));\n                }\n            ;\n            ;\n            }, f = function(b) {\n                var f = ((twttr.isT1 ? new twttr.views.Ancestors(b) : new twttr.views.Conversation(d.conversationGroup, a, b)));\n                f.render(d.$node, \"append\"), d.registerTweetActionEvents(), d.updateI18nDisplay(), ((twttr.isT1 && d.addInlineMediaIcons(d.$node))), d.hasRendered(), ((((twttr.isT1 && !b.length)) && d.$node.hide())), c(d), ((twttr.decider.isExpando() || e(b)));\n            }, g = function(a) {\n                twttr.API.User.JSBNG__find(a, function(a) {\n                    ((twttr.helpers.canViewUser(a) || ((new twttr.views.Ancestors({\n                        protected_ancestor: {\n                            user: new twttr.views.BaseUser(a)\n                        }\n                    })).render(d.$node, \"append\"), c(d))));\n                });\n            };\n            d.withRelatedResults(a, b, {\n                success: function(b) {\n                    d.resultGroups = b, d.conversationGroup = d.conversationGroupFor(b);\n                    var c = ((d.conversationGroup && d.tweetsForConversationRole(d.conversationGroup, \"Ancestor\")));\n                    ((((c && c.length)) ? f(c) : a.inReplyTo({\n                        success: function(a) {\n                            f(((a ? [a,] : [])));\n                        },\n                        error: function() {\n                            ((((twttr.isT1 && a.inReplyToUserId)) ? g(a.inReplyToUserId) : f([])));\n                        }\n                    })));\n                },\n                error: function() {\n                    f([]);\n                }\n            });\n        }).methods({\n            JSBNG__onTweetActionDelete: function(a) {\n                ((((a === this._tweetId)) && this.trigger(\"deleted\")));\n            },\n            noSpacer: !0\n        }), a(twttr.components.Conversation);\n    });\n});\nprovide(\"components/Replies\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.Replies\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.usesRelatedResults, twttr.mixins.i18nTweet, twttr.mixins.profilePopupActionable, twttr.mixins.streamablePageWithInlineMedia).initializer(function(a, b, c, d) {\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            var e = this, f = function(a, b, c) {\n                b = e.filterRetweets(b);\n                if (twttr.decider.isExpando()) {\n                    var f = a.length;\n                    ((((f > 5)) ? a = a.slice(0, 5) : ((((((b.length + f)) > 5)) && (b = b.slice(0, ((5 - f))))))));\n                }\n            ;\n            ;\n                ((((((a.length + b.length)) > 0)) ? ((new twttr.views.Replies(c, a, b)).render(e.$node, \"append\"), e.registerTweetActionEvents(), e.updateI18nDisplay(), e.hasRendered(), ((twttr.isT1 && e.addInlineMediaIcons(e.$node))), ((d && d.apply(e)))) : ((twttr.decider.hasInlineReplies() && ((new twttr.views.Replies(c, a, b)).render(e.$node, \"append\"), e.$node.hide(), e.registerTweetActionEvents(), ((d && d.apply(e))))))));\n            }, g = [], i = [], j = e.conversationGroupFor(c);\n            ((j && (g = e.tweetsForConversationRole(j, \"Descendant\"), i = e.tweetsForConversationRole(j, \"Fork\")))), f(g, i, j);\n        }).methods({\n            filterRetweets: function(a) {\n                var b = {\n                };\n                for (var c = ((a.length - 1)); ((c >= 0)); c--) {\n                    var d = a[c].id;\n                    ((a[c].attributes.retweeting_status ? ((((b[d] === undefined)) && (b[d] = !1))) : b[d] = !0));\n                };\n            ;\n                for (var c = ((a.length - 1)); ((c >= 0)); c--) {\n                    var d = a[c].id;\n                    ((((a[c].attributes.retweeting_status && ((b[d] === !0)))) ? a.splice(c, 1) : ((((a[c].attributes.retweeting_status && ((b[d] === !1)))) && (b[d] = !0)))));\n                };\n            ;\n                return a;\n            }\n        }).deciderKey(\"conversations\"), a(twttr.components.Replies);\n    });\n});\nprovide(\"components/MoreLists\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.MoreLists\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this.render(a), this._registerEvents(a);\n        }).deciderKey(\"more_lists_component\").methods({\n            render: function(a) {\n                var b = this;\n                a.user.lists(function(c) {\n                    ((c.length() && ((new twttr.views.MoreLists({\n                        user: new twttr.views.BaseUser(a.user),\n                        lists: new twttr.views.ListOfLists(c),\n                        create_list_button: {\n                            link_only: !0\n                        }\n                    })).render(b.$node), b.hasRendered())));\n                });\n            },\n            _registerEvents: function(a) {\n                var b = this;\n                this._registerEvent(twttr.API.List, \"update\", function(c, d) {\n                    ((((d.id === a.id)) && b.render(d)));\n                });\n            }\n        }), a(twttr.components.MoreLists);\n    });\n});\nprovide(\"geo/TweetGeo\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.geo.TweetGeo\", function(a, b, c, d) {\n            this.opts = d, this.placeId = b, this.render(a, c);\n        }).methods({\n            render: function(a, b) {\n                var c = this;\n                c.$target = b;\n                var d = $.extend({\n                }, a.data());\n                d.tweet_id = a.id, c.avatarUrl = a.user.profileImageUrl.replace(/(.+)(?:_normal)\\.(\\w+)$/, \"$1_mini.$2\"), ((d.coordinates && (c.coordinates = d.coordinates.coordinates))), d.is_from = !c.placeId;\n                var e = ((c.placeId || ((a.place && a.place.id))));\n                if (e) {\n                    if (((!d.place || ((d.place.id != e))))) {\n                        d.place = {\n                            id: e,\n                            JSBNG__name: _(\"A Place\")\n                        };\n                    }\n                ;\n                ;\n                    twttr.API.Place.JSBNG__find(e, {\n                        success: function(a) {\n                            var b = a.data();\n                            d.place = twttr.geo.getFullPlace(b), c.finishRendering(d);\n                        },\n                        error: function() {\n                            d.place.place_id = e, c.finishRendering(d);\n                        }\n                    });\n                }\n                 else delete d.place, c.finishRendering(d);\n            ;\n            ;\n            },\n            finishRendering: function(a) {\n                var b = this, c = !!b.coordinates, d = !((!a.place || ((!a.place.geometry && !a.place.bounding_box))));\n                a.show_map = ((c || d));\n                if (((a.show_map || a.place))) {\n                    var e = (new twttr.views[b.opts.viewName](a)).$html();\n                    (((($.browser.safari && !JSBNG__navigator.userAgent.match(/Chrome/))) && (e.JSBNG__find(\".map_canvas\").addClass(\"notransform\"), b.opts.mapOptions.draggable = !1))), b.$target.append(e);\n                }\n            ;\n            ;\n                if (a.show_map) {\n                    b.drawMap(e.JSBNG__find(\".map_canvas\"), a.place);\n                    var f = {\n                    }, g = ((a.tweet_id + \"\"));\n                    f[g] = {\n                        item_type: twttr.constants.clientEvent.itemType.tweet\n                    }, trackClient({\n                        component: \"tweet\",\n                        action: \"show\",\n                        element: \"map\"\n                    }, {\n                        event_info: \"dynamic\",\n                        item_details: f,\n                        item_ids: [g,],\n                        item_count: 1\n                    });\n                }\n            ;\n            ;\n            },\n            drawMap: function(a, b) {\n                var c = this;\n                twttr.geo.loadMaps(function() {\n                    c.geoMap = new twttr.geo.Map(a, c.opts.mapOptions);\n                    if (!c.geoMap.initialized) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = !1;\n                    if (b) {\n                        if (b.geometry) {\n                            var e = b.geometry.coordinates;\n                            ((((b.geometry.type == \"Polygon\")) ? c.geoMap.addPlacePolygon(e) : ((((b.geometry.type == \"MultiPolygon\")) ? twttr.each(e, function(a) {\n                                c.geoMap.addPlacePolygon(a);\n                            }) : ((((b.geometry.type == \"Point\")) && (c.geoMap.addPoi(e), d = !0)))))));\n                        }\n                         else {\n                            var e = b.bounding_box.coordinates, f = e[0][0], g = e[0][2];\n                            ((((((f[0] == g[0])) && ((f[1] == g[1])))) ? (c.geoMap.addPoi(e[0][0]), d = !0) : c.geoMap.addPlacePolygon(e)));\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    ((((!d && c.coordinates)) && c.geoMap.addPoint(c.coordinates, c.avatarUrl))), c.geoMap.adjustBounds(13, ((!d && c.coordinates))), a.bind(\"refreshMap\", function() {\n                        c.geoMap.resize();\n                    });\n                });\n            }\n        }), a(twttr.geo.TweetGeo);\n    });\n});\nprovide(\"components/MachineTranslationBackend\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.klass(\"twttr.components.MachineTranslationBackend\", function() {\n        \n        }).statics({\n            getBackend: function() {\n                return new twttr.components.BingMTBackend;\n            }\n        }).methods({\n            translationTextEqual: function(a, b) {\n                return ((((a === b)) ? !0 : (global_spaces = RegExp(twttr.txt.regexen.spaces.toString().slice(1, -1), \"g\"), ((((a.replace(/[MHL]T\\d*KEN/g, \"\").replace(global_spaces, \"\").toLowerCase() === b.replace(/[MHL]T\\d*KEN/g, \"\").replace(global_spaces, \"\").toLowerCase())) ? !0 : !1)))));\n            },\n            shouldShowTranslation: function(a, b, c, d) {\n                return ((((c == d)) ? !1 : ((this.translationTextEqual(a, b) ? !1 : !0))));\n            }\n        }), twttr.klass(\"twttr.components.BingMTBackend\", function() {\n        \n        }).subclassOf(twttr.components.MachineTranslationBackend).methods({\n            attribution: function() {\n                return _(\"Translation powered by \\u003Ca href=\\\"http://bing.com/translator\\\" target=\\\"_new\\\"\\u003EBing Translator\\u003C/a\\u003E\");\n            },\n            translate: function(a, b, c) {\n                var d = this;\n                $.ajax({\n                    url: ((window.JSBNG__location.protocol + \"//api.microsofttranslator.com/v2/ajax.svc/GetTranslations?oncomplete=?\")),\n                    dataType: \"jsonp\",\n                    data: {\n                        appId: \"2ADD5BC2C5139FA743F612F9CE8ECD783FCB899F\",\n                        text: a,\n                        to: b,\n                        maxTranslations: 1\n                    },\n                    success: twttr.bind(this, function(b) {\n                        if (((b && b.Translations))) {\n                            var e = b.Translations[0].TranslatedText, f = b.From;\n                            ((this.shouldShowTranslation(a, e, f, d.destLocale) && c(e, f)));\n                        }\n                    ;\n                    ;\n                    })\n                });\n            }\n        }), twttr.klass(\"twttr.components.MachineTranslatedTweet\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this._initTranslation(a, ((((twttr.pageLocale || $(\"html\").attr(\"lang\"))) || \"en\")));\n        }).deciderKey(\"machine_translated_tweets\").methods({\n            _initTranslation: function(a, b) {\n                ((a.user[\"protected\"] || (this.destLocale = b, this.fetchTranslation(a, this.destLocale))));\n            },\n            _preProcessTweetText: function(a) {\n                var b = a, c = function(a) {\n                    return ((((a && a.replace)) && a.replace(/^\\s+|\\s+$/g, \"\")));\n                };\n                this._mentions = twttr.txt.extractMentions(a);\n                for (i in this._mentions) {\n                    this._mentions[i] = c(this._mentions[i]), b = b.replace(this._mentions[i], ((((((((\"\\u003CM\" + i)) + \"\\u003E\\u003C/M\")) + i)) + \"\\u003E\")));\n                ;\n                };\n            ;\n                this._hashtags = twttr.txt.extractHashtags(a);\n                for (i in this._hashtags) {\n                    this._hashtags[i] = c(this._hashtags[i]), b = b.replace(this._hashtags[i], ((((((((\"\\u003CH\" + i)) + \"\\u003E\\u003C/H\")) + i)) + \"\\u003E\")));\n                ;\n                };\n            ;\n                this._links = twttr.txt.extractUrls(a);\n                for (i in this._links) {\n                    this._links[i] = this._links[i], b = b.replace(this._links[i], ((((((((\"\\u003CL\" + i)) + \"\\u003E\\u003C/L\")) + i)) + \"\\u003E\")));\n                ;\n                };\n            ;\n                return b;\n            },\n            _postProcessTweetText: function(a) {\n                var c = a;\n                if (((this._mentions && ((this._mentions.length > 0))))) {\n                    for (var d = 0; ((d < this._mentions.length)); d++) {\n                        c = c.replace(new RegExp(((((((((\"\\u003CM\" + d)) + \"\\u003E\\\\s?\\u003C/M\")) + d)) + \"\\u003E\")), \"i\"), this._mentions[d]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                if (((this._hashtags && ((this._hashtags.length > 0))))) {\n                    for (var d = 0; ((d < this._hashtags.length)); d++) {\n                        c = c.replace(new RegExp(((((((((\"\\u003CH\" + d)) + \"\\u003E\\\\s?\\u003C/H\")) + d)) + \"\\u003E\")), \"i\"), this._hashtags[d]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                if (((this._links && ((this._links.length > 0))))) {\n                    for (var d = 0; ((d < this._links.length)); d++) {\n                        c = c.replace(new RegExp(((((((((\"\\u003CL\" + d)) + \"\\u003E\\\\s?\\u003C/L\")) + d)) + \"\\u003E\")), \"i\"), this._links[d]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return b.util.linkify(c);\n            },\n            fetchTranslation: function(a, b) {\n                var c = this;\n                this.sourceText = this._preProcessTweetText(a.text);\n                var d = twttr.components.MachineTranslationBackend.getBackend();\n                d.translate(this.sourceText, b, function(b, e) {\n                    (new twttr.views.MachineTranslatedTweet({\n                        translated_text: c._postProcessTweetText(b),\n                        attribution: d.attribution()\n                    })).render(c.$node, \"append\"), eventTerms = {\n                        client: \"web\",\n                        page: \"JSBNG__home\",\n                        section: \"timeline\",\n                        component: \"tweet\",\n                        action: \"translate\"\n                    }, eventDetails = {\n                        item_ids: [a.id,],\n                        i18n_details: {\n                            source_lang: e,\n                            source_length: c.sourceText.length,\n                            translation_lang: c.destLocale,\n                            translation_length: b.length\n                        }\n                    }, trackClient(eventTerms, eventDetails), c.hasRendered();\n                });\n            }\n        }), a(twttr.components.MachineTranslationBackend);\n    });\n});\nprovide(\"components/TweetGeoSmall\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.TweetGeoSmall\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            if (((!b && !a.showGeoMap))) {\n                return;\n            }\n        ;\n        ;\n            if (((((((a.geo || ((a.place && a.place.id)))) || b)) || a.coordinates))) {\n                new twttr.geo.TweetGeo(a, b, this.$node, {\n                    viewName: \"GeoMapSmall\",\n                    mapOptions: ((twttr.isT1 ? {\n                    } : {\n                        draggable: !1,\n                        disableDoubleClickZoom: !0,\n                        navigationControl: !1\n                    }))\n                }), this.hasRendered();\n            }\n        ;\n        ;\n        }).deciderKey(\"tweet_geo_component\"), a(twttr.components.TweetGeoSmall);\n    });\n});\nprovide(\"components/NewestListMembers\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.NewestListMembers\").subclassOf(twttr.components.Base).mixin(twttr.mixins.userActionable).initializer(function(a) {\n            this.render(a), this._registerEvents(a);\n        }).deciderKey(\"newest_list_members_component\").methods({\n            render: function(a) {\n                var b = this;\n                a.members().first(4, function(c) {\n                    (new twttr.views.NewestListMembers({\n                        list: a.attributes\n                    })).render(b.$node), ((c.length() && (c.each(function(a) {\n                        var c = new twttr.views.UserSmallListItem(a);\n                        ((c.is_withheld() || c.render(b.$find(\".js-recent-members\"), \"append\")));\n                    }), twttr.helpers.ellipsify(b.$find(\"div.bio\")), b.hasRendered(), b.registerUserActionEvents())));\n                });\n            },\n            _registerEvents: function(a) {\n                var b = this;\n                this._registerEvent(twttr.API.List, \"add remove\", function(c, d) {\n                    ((((d.id === a.id)) && b.render(d)));\n                });\n            }\n        }), a(twttr.components.NewestListMembers);\n    });\n});\nprovide(\"components/StorkPip\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.StorkPip\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            var c = this;\n            this._opts = b, this._state = \"icon\", this._$streamItem = a, this._scribbler = twttr.Scribbler.clientEvent.spawnWithTerms({\n                component: \"stork\",\n                element: b.id\n            }), ((this.constructor.allPips[b.id] || (this.constructor.allPips[b.id] = []))), this.constructor.allPips[b.id].push(this), (new twttr.views.StorkPipIcon({\n                icon: b.icon\n            })).render(this.$node), this.$node.hide().prependTo(a).fadeIn(\"fast\"), ((b.iconHighlight && this.highlight(b.iconHighlight))), this._scribbler.scribe({\n                action: \"impression\"\n            });\n            var d = a.closest(\".js-stream-items\");\n            if (b.explainOn) {\n                ((twttr.is.string(b.explainOn) && (b.explainOn = {\n                    JSBNG__event: b.explainOn\n                })));\n                var e = ((b.explainOn.selector ? d.JSBNG__find(b.explainOn.selector) : d));\n                this._registerEvent(e, b.explainOn.JSBNG__event, function(a) {\n                    var d = $(a.target).closest(\".js-stream-item\");\n                    if (((d.length && ((!b.matcher || b.matcher(d)))))) {\n                        if (((((d[0] != c._$streamItem[0])) && d.JSBNG__find(\".js-pip\").length))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        if (((c._state == \"icon\"))) c._scribbler.scribe({\n                            action: \"show\"\n                        });\n                         else {\n                            if (((c._state != \"JSBNG__prompt\"))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            c._scribbler.scribe({\n                                action: \"success\"\n                            });\n                        }\n                    ;\n                    ;\n                        c.showState(\"explain\", d);\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            if (b.dismissOn) {\n                ((twttr.is.string(b.dismissOn) && (b.dismissOn = {\n                    JSBNG__event: b.dismissOn\n                })));\n                var e = ((b.dismissOn.selector ? d.JSBNG__find(b.dismissOn.selector) : d));\n                this._registerEvent(e, b.dismissOn.JSBNG__event, function(a) {\n                    var d = $(a.target).closest(\".js-stream-item\");\n                    ((((d.length && ((!b.matcher || b.matcher(d))))) && (((((((d[0] == c._$streamItem[0])) && ((c._state == \"explain\")))) && c._scribbler.scribe({\n                        action: \"complete\"\n                    }))), c.dismissAll())));\n                });\n            }\n        ;\n        ;\n        }).click({\n            \".js-pip\": function() {\n                ((((this._state == \"icon\")) ? (this.showState(\"JSBNG__prompt\"), this._scribbler.scribe({\n                    action: \"open\"\n                })) : ((((this._state == \"explain\")) && (this.dismissAll(), this._scribbler.scribe({\n                    action: \"dismiss\"\n                }))))));\n            },\n            \".js-dismiss\": function() {\n                this.dismissAll(), this._scribbler.scribe({\n                    action: \"dismiss\"\n                });\n            }\n        }).statics({\n            allPips: {\n            },\n            openPip: null\n        }).methods({\n            showState: function(a, b) {\n                function c(a) {\n                    var b = new twttr.views.StorkPipText({\n                        contents: a,\n                        dismiss: !1\n                    });\n                    b.render(e.$node, \"append\"), e.$node.fadeIn(\"fast\");\n                };\n            ;\n                if (((((a == \"JSBNG__prompt\")) && !this._opts.promptHtml))) {\n                    return this.showState(\"explain\", b);\n                }\n            ;\n            ;\n                b = ((b || this._$streamItem));\n                if (((this._state == a))) {\n                    return;\n                }\n            ;\n            ;\n                ((((((this._state == \"icon\")) && ((((a == \"JSBNG__prompt\")) || ((a == \"explain\")))))) && twttr.stork.incrValue(this._opts.counter)));\n                if (((a != \"icon\"))) {\n                    var d = this.constructor.openPip;\n                    ((((d && ((d != this)))) && ((((d._state == \"JSBNG__prompt\")) ? d.showState(\"icon\") : ((((d._state == \"explain\")) && d.dismiss())))))), this.constructor.openPip = this;\n                }\n            ;\n            ;\n                ((((a == \"explain\")) && this.dismissOthers())), ((((this._$streamItem[0] != b[0])) && this.unhighlight())), this._state = a, this._$streamItem = b;\n                var e = this;\n                this.$find(\".js-pip\").prependTo(this.$node.parent()).fadeOut(\"fast\", function() {\n                    $(this).remove();\n                    if (((a == \"icon\"))) {\n                        var b = (new twttr.views.StorkPipIcon({\n                            icon: e._opts.icon\n                        })).render(e.$node);\n                        e.$node.fadeIn(\"fast\");\n                    }\n                     else {\n                        var d = e._opts[((a + \"Html\"))], f = e._opts[((a + \"Highlight\"))];\n                        ((twttr.is.fn(d) ? d(e._$streamItem, c) : c(d))), ((((f && ((f != \"remove\")))) ? e.highlight(f) : e.unhighlight(((f == \"remove\")))));\n                    }\n                ;\n                ;\n                }), this.$node.hide().prependTo(b);\n            },\n            highlight: function(a) {\n                ((this._$streamItem.JSBNG__find(a).is(\".stork-highlighted\") || (this.unhighlight(), this._$streamItem.JSBNG__find(a).each(function() {\n                    var a = $(this), b = $(\"\\u003Cspan\\u003E\").addClass(\"stork-highlight-background\"), c = $(\"\\u003Cspan\\u003E\").addClass(\"stork-highlight-container\").css({\n                        width: a.JSBNG__outerWidth(),\n                        height: a.JSBNG__outerHeight()\n                    });\n                    a.wrap(c).before(b).addClass(\"stork-highlighted\"), b.fadeIn();\n                }))));\n            },\n            unhighlight: function(a) {\n                this._$streamItem.JSBNG__find(\".stork-highlighted\").each(function() {\n                    var b = $(this), c = b.parent().JSBNG__find(\".stork-highlight-background\"), d = function() {\n                        c.remove(), b.unwrap();\n                    };\n                    b.removeClass(\"stork-highlighted\"), ((a ? d() : c.fadeOut(d)));\n                });\n            },\n            dismissOthers: function() {\n                for (var a = 0; ((a < this.constructor.allPips[this._opts.id].length)); ++a) {\n                    var b = this.constructor.allPips[this._opts.id][a];\n                    ((((b != this)) && b.dismiss()));\n                };\n            ;\n                this.constructor.allPips[this._opts.id] = [this,];\n            },\n            dismissAll: function() {\n                var a = this.$node.closest(\".js-stream-items\");\n                for (var b = 0; ((b < this.constructor.allPips[this._opts.id].length)); ++b) {\n                    var c = this.constructor.allPips[this._opts.id][b];\n                    c.dismiss();\n                };\n            ;\n                this.constructor.allPips[this._opts.id] = [], twttr.stork.storkifyTweets(a);\n            },\n            dismiss: function() {\n                var a = this;\n                ((this._$streamItem && this.unhighlight())), this.$node.fadeOut(function() {\n                    a.destroy();\n                }).JSBNG__find(\".js-pip\").removeClass(\"js-pip\");\n            }\n        }), a(twttr.components.StorkPip);\n    });\n});\nprovide(\"components/StreamEnd\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.StreamEnd\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            (new twttr.views.StreamEnd({\n                show_stream_end_bird: ((((b === undefined)) ? !0 : b)),\n                end_text: a\n            })).render(this.$node, \"append\");\n        }), a(twttr.components.StreamEnd);\n    });\n});\nprovide(\"components/StreamEndInviteFriends\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.StreamEndInviteFriends\").subclassOf(twttr.components.StreamEnd).initializer(function(a, b) {\n            var c = new twttr.components.InviteFriends;\n            c.$node.addClass(\"stream-item\"), this.$node.append(c.$node), this._superInitializer.apply(this, arguments);\n        }), a(twttr.components.StreamEndInviteFriends);\n    });\n});\nprovide(\"components/StreamWhaleEnd\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.StreamWhaleEnd\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            (new twttr.views.StreamWhaleEnd({\n                stream_fail_header: a\n            })).render(this.$node, \"append\"), this.$node.delegate(\".try-again-after-whale\", \"click\", function(a) {\n                a.preventDefault(), b.trigger(\"tryAgain\");\n            });\n        }), a(twttr.components.StreamWhaleEnd);\n    });\n});\nprovide(\"components/ContactImportErrorEnd\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.ContactImportErrorEnd\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            (new twttr.views.StreamWhaleEnd({\n                stream_fail_header: a\n            })).render(this.$node, \"append\"), this.$node.delegate(\".try-again-after-whale\", \"click\", function(a) {\n                b.trigger(\"tryImportAgain\");\n            });\n        }), a(twttr.components.ContactImportErrorEnd);\n    });\n});\nprovide(\"components/EmptyHome\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.EmptyHome\").subclassOf(twttr.components.Base).initializer(function() {\n            this.render(), this.hasRendered();\n        }).methods({\n            render: function() {\n                var a = twttr.currentUser;\n                (new twttr.views.EmptyHome({\n                    screen_name: a.screenName,\n                    protected_account: a[\"protected\"]\n                })).render(this.$node.empty(), \"append\");\n            }\n        });\n        ((twttr.isT1 && c.methods({\n            render: function() {\n                (new twttr.views.EmptyHome({\n                    show_stream_end_bird: !0,\n                    end_text: (new twttr.views.EmptyTimelineMessage).html()\n                })).render(this.$node.empty(), \"append\");\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/AddPeople\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.AddPeople\").subclassOf(twttr.components.Base).initializer(function() {\n            this.render();\n            var a = ((twttr.isT1 ? \"userSearchPath\" : \"whoToFollowSearchPath\"));\n            twttr.helpers.addFormEvents(this.$find(\".js-search-for-list-people\"), function() {\n                var b = this.q.value;\n                ((((b != \"\")) && (twttr.router.routeTo(twttr.router[a]({\n                    query: b\n                })), trackClient({\n                    component: \"empty_list_stream\",\n                    action: \"search\"\n                }, \"list\"), _scribble(\"search-for-people\", {\n                    input: \"click\"\n                }))));\n            }), this.hasRendered();\n        });\n        ((twttr.isT1 ? c.methods({\n            render: twttr.util.noopInT1\n        }).setBaseView(twttr.views.AddPeople) : c.methods({\n            render: function() {\n                (new twttr.views.AddPeople).render(this.$node.empty(), \"append\");\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/NoListMembers\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.NoListMembers\").subclassOf(twttr.components.Base).initializer(function() {\n            var a = this;\n            this.render(), this.hasRendered();\n        });\n        ((twttr.isT1 ? c.methods({\n            render: twttr.util.noopInT1\n        }).setBaseView(twttr.views.NoListMembers) : c.methods({\n            render: function() {\n                (new twttr.views.NoListMembers).render(this.$node.empty(), \"append\");\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/Media\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.klass(\"twttr.components.Media\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            this.tweet = a, this.urls = twttr.media.extractUrls(a), this.$node.prepend($(\"\\u003Cdiv class=\\\"tweet-media\\\"/\\u003E\")), this.$mediaNode = this.$node.JSBNG__find(\"div.tweet-media\"), this.width = b, this.options = ((c || {\n            })), this.hasCalledHasRendered = !1, this.notDisplayedClass = \".media-not-displayed\";\n            var d = this;\n            this.checkForMedia(function(a) {\n                ((a && (d.$mediaNode.bind(\"hideMedia\", function() {\n                    $(\"div.tweet-media\").empty();\n                }), d.$mediaNode.bind(\"showMedia\", function() {\n                    ((d.restrictedMedia() ? ((twttr.loggedIn ? d.loggedInBehavior() : d.loggedOutBehavior())) : d.renderMedia()));\n                }), d.$mediaNode.trigger(\"showMedia\"))));\n            });\n        }).deciderKey(\"inline_media_component\").statics({\n            restrictedCategories: {\n                photo: !0,\n                video: !0\n            },\n            dashboardThumbnailOptions: {\n                itemWidth: 66,\n                itemHeight: 66,\n                itemDisplayWidth: 70,\n                width: 276,\n                viewClass: twttr.views.ThumbnailViewerFacet,\n                thumbnailViewClass: twttr.views.ThumbnailFacet\n            }\n        }).methods({\n            checkForMedia: function(a) {\n                var c = this;\n                if (((((b.util.objKeys(this.urls).length === 0)) && !twttr.media.hasMedia(this.tweet)))) {\n                    a(!1);\n                    return;\n                }\n            ;\n            ;\n                var d = c.tweet;\n                ((twttr.Cards.prototype.hasCards(d) ? (this.mediaTypes = [], a(!0)) : twttr.media.mediaTypes(this.urls, function(d) {\n                    c.mediaTypes = d;\n                    if (((b.util.objKeys(c.mediaTypes).length === 0))) {\n                        a(!1);\n                        return;\n                    }\n                ;\n                ;\n                    a(!0);\n                })));\n            },\n            JSBNG__onProfilePage: function() {\n                return ((twttr.profileUser && ((twttr.profileUser.id == this.tweet.user.id))));\n            },\n            restrictedMedia: function() {\n                var a = !1;\n                return $.each(this.mediaTypes, function(b, c) {\n                    var d = twttr.media.iconType(b, c);\n                    ((!twttr.components.Media.restrictedCategories[d] || (a = !0)));\n                }), a;\n            },\n            _getUser: function() {\n                return ((this.tweet.retweetingStatus ? this.tweet.retweetingStatus.user : this.tweet.user));\n            },\n            loggedInBehavior: function() {\n                var a = this, b = this._getUser();\n                if (((twttr.helpers.isCurrentUser(b) || this.hasClickedShowMedia))) {\n                    this.renderMedia();\n                    return;\n                }\n            ;\n            ;\n                this.checkPossiblySensitive();\n            },\n            _isPossiblySensitive: function() {\n                return !!this.tweet.possiblySensitive;\n            },\n            checkPossiblySensitive: function() {\n                ((this._isPossiblySensitive() ? this.possiblySensitiveBehavior() : this.renderMedia()));\n            },\n            checkNotFollowing: function() {\n                var a = this, b = this._getUser();\n                twttr.currentUser.relationshipWith(b, function(c) {\n                    b.sync(\"following\", c.following), a.renderMedia();\n                });\n            },\n            possiblySensitiveBehavior: function() {\n                var a = this;\n                twttr.currentUser.viewPossiblySensitive({\n                    success: function(b) {\n                        ((b ? a.checkNotFollowing() : a.renderBlockedMessage({\n                            possibly_sensitive: !0\n                        })));\n                    }\n                });\n            },\n            loggedOutBehavior: function() {\n                ((((this.JSBNG__onProfilePage() && !this._isPossiblySensitive())) ? this.renderMedia() : ((((this._isPossiblySensitive() && !twttr.media.getViewMediaCookie())) ? this.renderBlockedMessage({\n                    possibly_sensitive: !0\n                }) : this.renderMedia()))));\n            },\n            renderMedia: function() {\n                var a = this, b = (new twttr.media.Embedder(this.tweet, {\n                    DOMContainer: a.$mediaNode,\n                    preProcess: function(b, c) {\n                        c(twttr.aug(a.options, {\n                            maxwidth: a.width\n                        }));\n                    },\n                    afterRender: function(b, c) {\n                        ((a.hasCalledHasRendered || (a.hasRendered(), a.hasCalledHasRendered = !0))), ((a.options.afterRender && a.options.afterRender(b)));\n                    }\n                })).render();\n            },\n            buildNotDisplayedView: function(a) {\n                return new twttr.views.MediaNotDisplayed(a);\n            },\n            renderBlockedMessage: function(a) {\n                var b = this;\n                ((b.hasCalledHasRendered || (b.hasRendered(), b.hasCalledHasRendered = !0)));\n                if (this.$node.JSBNG__find(((this.notDisplayedClass + \":visible\"))).get(0)) {\n                    return;\n                }\n            ;\n            ;\n                this.buildNotDisplayedView(a).render(this.$node, \"prepend\"), ((this.options.whenNotDisplayed && this.options.whenNotDisplayed(this.$node)));\n                var c = twttr.bind(this, function(a) {\n                    this.renderMedia(), this.$node.JSBNG__find(this.notDisplayedClass).hide(), ((twttr.loggedIn ? this.hasClickedShowMedia = !0 : twttr.media.setViewMediaCookie())), a.stopPropagation();\n                });\n                this.$node.JSBNG__find(\".display-this-media\").click(c), this.$node.JSBNG__find(\".always-display-media\").click(function(a) {\n                    twttr.currentUser.updateViewPossiblySensitive(!0, {\n                        success: function() {\n                            twttr.showMessage(_(\"Your media display settings have been changed.\")), c(a);\n                        },\n                        error: function(a) {\n                            twttr.showError(_(\"Couldn't set inline media settings.\"));\n                        }\n                    });\n                });\n            }\n        }), a(twttr.components.Media);\n    });\n});\nprovide(\"components/ProfilePane\", function(a) {\n    using(\"mixins/userActionable\", ((twttr.isT1 ? [\"mixins/userUpdateable\",\"mixins/profilePopupActionable\",] : []))).as(function(b) {\n        var c = twttr.klass(\"twttr.components.ProfilePane\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this.user = a, this.renderPane(), ((twttr.loggedIn && this.$node.append((new twttr.components.ProfileActions(this.user, undefined, !0)).$node))), this.hasRendered();\n        }).methods({\n            renderPane: function() {\n                var a = new twttr.views.ProfilePane(this.user);\n                a.render(this.$node);\n            },\n            renderStats: function() {\n                var a = new twttr.views.MiniProfileStats(this.user);\n                a.render(this.$node.JSBNG__find(\".js-mini-profile-stats\"), \"replaceWith\");\n            }\n        });\n        ((twttr.isT1 && c.mixin(b.mixins.userActionable, b.mixins.userUpdateable, b.mixins.profilePopupActionable).initializer(function(a) {\n            var b = this, c = a.impressionId;\n            this.user = a, this.renderPane(), this.registerUserActionEvents(), ((twttr.loggedIn && (this.registerUserUpdateEvents(this.user), this.bind(\"userUpdated\", function(a, d) {\n                b.user = d, ((c && (b.user = twttr.API.util.PromotedStore.getPromotedUserInstance(b.user, c)))), b.renderStats();\n            })))), this.hasRendered();\n        }).methods({\n            renderPane: function() {\n                var a = this;\n                this.getRelationship(this.user, function(b, c) {\n                    a.updateUserAttributesFromRelationship(b);\n                    var d = new twttr.views.ProfilePane(a.user);\n                    d.render(a.$node), a.showFollowOrUnfollow(a.user), ((twttr.helpers.canViewUser(a.user) && a.showMiniSocialProof(a.user))), a.renderUserProfileMenu(a.$find(\".js-follow-combo\"), a.$find(\".js-action-profilemenu\"), c);\n                });\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/JapaneseAd\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.components.JapaneseAd\").subclassOf(twttr.components.Base).initializer(function() {\n            if (twttr.components.JapaneseAd.shouldBeHidden()) {\n                this.$node.hide();\n                return;\n            }\n        ;\n        ;\n            (new twttr.views.JapaneseAd).render(this.$node, \"append\");\n            if (twttr.decider.isAvailable(\"japanese_new_ad_provider\")) {\n                ((this.constructor.getJapanAd() ? this.constructor.refreshAds() : this.constructor.createIframeAd(this.$node)));\n            }\n             else {\n                if (!this.constructor.loadedOnce) {\n                    this.constructor.loadedOnce = !0;\n                    var a = ((\"loadedJsCallBack\" + parseInt(((Math.JSBNG__random() * 100000)), 10)));\n                    twttr.components.JapaneseAd.callbacks[a] = function(b) {\n                        delete twttr.components.JapaneseAd.callbacks[a], twttr.components.JapaneseAd.loadedJsCallback(b);\n                    }, $.ajax({\n                        cache: !0,\n                        url: ((((window.JSBNG__location.protocol + b.constants.japaneseAdUrl)) + a)),\n                        dataType: \"script\"\n                    });\n                }\n                 else this.constructor.refreshAds();\n            ;\n            }\n        ;\n        ;\n        }).statics({\n            shouldBeHidden: function() {\n                var a = [\"japan_olympic\",\"akiko_lawson\",\"docomo\",\"mhamura\",\"warnerjp\",\"aquarius_sports\",\"usolympic\",\"teamgb\",\"franceolympique\",\"ausolympicteam\",\"nzolympics\",\"swissteam\",\"cdnolympicteam\",\"belgiumolympic\",\"olympiccouncil\",\"london2012\",\"sochi2014oc\",\"rio2016\",\"pyongchang_2018\",];\n                return ((((twttr.pageLocale !== \"ja\")) || ((((twttr.app.currentPageName() === \"profile\")) && (($.inArray(twttr.profileUser.screenName.toLowerCase(), a) != -1))))));\n            },\n            callbacks: {\n            },\n            loadedJsCallback: function(a) {\n                this.etologyAdSrc = a[0];\n                if (((typeof renderAd == \"function\"))) {\n                    var b = renderAd;\n                    renderAd = function(a) {\n                        ((JSBNG__document.getElementById(a.spaceTag) && b.apply(this, arguments)));\n                    };\n                }\n            ;\n            ;\n                this.refreshAds();\n            },\n            createIframeAd: function(a) {\n                $(a).append($(((((\"\\u003Ciframe id=\\\"j_ad\\\" src=\\\"\" + b.constants.japaneseAdIframeUrl)) + \"\\\" width=\\\"300\\\" height=\\\"185\\\" frameborder=\\\"no\\\" border=\\\"0\\\" marginwidth=\\\"0\\\" marginheight=\\\"0\\\" scrolling=\\\"no\\\"\\u003E\\u003C/iframe\\u003E\")))), trackClient({\n                    component: \"japanese_ad\",\n                    action: \"impression\"\n                }, {\n                    url: b.constants.japaneseAdIframeUrl\n                });\n            },\n            getJapanAd: function() {\n                return $(\"#j_ad\")[0];\n            },\n            refreshAds: function() {\n                var a = ((\"t=\" + (new JSBNG__Date).getTime()));\n                ((twttr.decider.isAvailable(\"japanese_new_ad_provider\") ? ((this.getJapanAd() && ($(\"#j_ad\").attr(\"src\", ((((b.constants.japaneseAdIframeUrl + \"&\")) + a))), trackClient({\n                    component: \"japanese_ad\",\n                    action: \"refresh\"\n                }, {\n                    url: b.constants.japaneseAdIframeUrl\n                })))) : ((this.etologyAdSrc && (trackClient({\n                    section: \"dashboard\",\n                    component: \"japanese_ad\",\n                    action: \"refresh\"\n                }, {\n                    url: this.etologyAdSrc\n                }), _scribble(\"japanese-ad-refresh\", {\n                    adSource: this.etologyAdSrc\n                }), $.getScript(((((this.etologyAdSrc + \"?\")) + a))))))));\n            }\n        }).deciderKey(\"japanese_ad_component\"), a(twttr.components.JapaneseAd);\n    });\n});\nprovide(\"components/ProtectedUser\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.ProtectedUser\").subclassOf(twttr.components.Base).initializer(function(a) {\n            (new twttr.views.ProtectedUser(a)).render(this.$node, \"append\");\n        }), a(twttr.components.ProtectedUser);\n    });\n});\nprovide(\"components/TweetStats\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.TweetStats\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            this.maxUsersToShow = b;\n            var d = this;\n            a.summary(function(b) {\n                ((d.shouldRender(b) && ($.extend(b, {\n                    screen_name: a.user.screenName,\n                    id: a.id,\n                    retweeters_length: b.retweeters.length,\n                    favoriters_length: b.favoriters.length,\n                    has_retweets: !!parseInt(b.retweeters_count, 10),\n                    has_favorites: !!parseInt(b.favoriters_count, 10)\n                }), (new twttr.views.TweetStats(b)).render(d.$node, \"append\"), d.$node.closest(\".js-stream-tweet\").addClass(\"with-social-proof\"), d.getFacePile(b), ((c && c())))));\n            });\n        }).methods({\n            shouldRender: function(a) {\n                return ((((a.retweeters.length + a.favoriters.length)) > 0));\n            },\n            getFacePile: function(a) {\n                var b = this, c = twttr.util.arrayUniq(a.retweeters.concat(a.favoriters));\n                c = c.slice(0, this.maxUsersToShow), twttr.API.User.findAll(c, function(a) {\n                    var d = {\n                    };\n                    a.each(function(a) {\n                        d[a.id] = a;\n                    });\n                    var e = new twttr.anywhere.api.util.BaseCollection($.map(c, function(a) {\n                        return d[a];\n                    })), f = e.map(function(a) {\n                        return new twttr.views.BaseUser(a);\n                    });\n                    (new twttr.views.FacePile({\n                        users: f.array\n                    })).render(b.$find(\".js-face-pile-container\"), \"append\"), b.$node.closest(\".js-stream-tweet\").addClass(\"with-social-proof\"), b.$find(\".js-user-tipsy\").tipsy({\n                        gravity: \"s\"\n                    });\n                });\n            }\n        }).deciderKey(function() {\n            return ((twttr.decider.isActivityEnabled() && twttr.decider.isAvailable(\"activity_status_summary\")));\n        });\n        a(c);\n    });\n});\nprovide(\"components/PermalinkTweet\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.PermalinkTweet\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.i18nTweet, twttr.mixins.userActionable, twttr.mixins.profilePopupActionable).initializer(function(a) {\n            this.view = new twttr.views.SingleTweet(a), this.view.render(this.$node, \"append\"), this._tweetId = a.id, this.registerTweetActionEvents(), this.updateI18nDisplay(), this.hasRendered(), this.scribeComponentName = \"tweet\";\n            if (twttr.isT1) {\n                var b = ((twttr.loggedIn ? \"TweetStats\" : \"Retweeters\")), c = new twttr.components[b](a, 9);\n                this.$find(\"div.js-tweet-stats-container\").append(c.$node);\n            }\n        ;\n        ;\n            this.registerUserActionEvents();\n        }).methods({\n            renderWithheld: function() {\n                return this.view.render_withheld();\n            },\n            renderCreatorWithheld: function() {\n                return ((this.view.is_withheld() && this.view.is_current_user()));\n            },\n            faveTweet: function(a) {\n                this.tweetActionFavorite(this.$find(\".tweet\"), a);\n            },\n            replyTweet: function(a) {\n                this.tweetActionReply(this.$find(\".tweet\"), a);\n            },\n            retweetTweet: function(a) {\n                this.tweetActionRetweet(this.$find(\".tweet\"), a);\n            },\n            JSBNG__onTweetActionDelete: function(a) {\n                ((((a === this._tweetId)) && this.trigger(\"deleted\")));\n            }\n        }).click({\n            \"img.user-profile-link\": function(a, b) {\n                this.trigger(\"avatar_click.tweet\", [b.closest(\".js-actionable-tweet\"),\"avatar\",b,]);\n            },\n            \".tweet-user-block-screen-name\": function(a, b) {\n                this.trigger(\"screen_name_click.tweet\", [b.closest(\".js-actionable-tweet\"),\"screen_name\",b,]);\n            },\n            \".stats .js-stat-count a\": function(a, b) {\n                a.stopPropagation(), a.preventDefault();\n            }\n        }), a(twttr.components.PermalinkTweet);\n    });\n});\nprovide(\"components/NoUserExists\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.NoUserExists\").subclassOf(twttr.components.Base).initializer(function() {\n            this.$node.append(((((\"\\u003Cp class='no-user tweet-text tweet-text-large'\\u003E\" + _(\"This user does not exist.\"))) + \"\\u003C/p\\u003E\"))), this.hasRendered();\n        }), a(twttr.components.NoUserExists);\n    });\n});\nprovide(\"components/SignupCallOut\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.SignupCallOut\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            b = ((b || {\n            }));\n            var c;\n            if (b.profileUser) {\n                var d = twttr.merge({\n                    signup_source: a\n                }, b.profileUser.attributes);\n                ((((a == \"permalink\")) ? c = new twttr.views.PermalinkSignupCallOut(d) : c = new twttr.views.ProfileSignupCallOut(d)));\n            }\n             else c = new twttr.views.NewSignupCallOut({\n                signup_source: a,\n                query: b.query\n            });\n        ;\n        ;\n            c.render(this.$node.empty(), \"append\"), this.$node.delegate(\"form.signup-btn\", \"submit\", function() {\n                trackClient({\n                    section: \"signup_callout\",\n                    component: \"form\",\n                    action: \"signup_click\"\n                });\n            });\n            if (((b.profileUser || twttr.isT1))) {\n                var e = this.$find(\"form\");\n                twttr.helpers.addFormEvents(e), twttr.helpers.addHoldingInputEvents(e);\n            }\n        ;\n        ;\n            this.$node.delegate(\".profile-subpage-call-out-button\", \"click\", function() {\n                trackClient({\n                    section: \"signup_callout\",\n                    component: \"discover_link\",\n                    action: \"click\"\n                }, {\n                    profile_id: twttr.profileUser.id,\n                    context: \"profile\"\n                });\n            }), this.hasRendered();\n        }), a(twttr.components.SignupCallOut);\n    });\n});\nprovide(\"components/SuggestionCategoriesList\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.SuggestionCategoriesList\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            var d = this.categoriesToLinks(a, b, c);\n            (new twttr.views.LinkList(d, \"&middot;\")).render(this.$node, \"append\"), this.$find(\"ul\").addClass(\"categories-list\");\n        }).mixin(twttr.mixins.discoveryHelper).methods({\n            categoriesToLinks: function(a, b, c) {\n                var d = this;\n                return ((a ? a.map(function(a, e) {\n                    var f = {\n                        text: a.JSBNG__name\n                    };\n                    if (((c == a.slug))) {\n                        return f;\n                    }\n                ;\n                ;\n                    var g = d.pagePathFor(b, \"InterestsCategory\", {\n                        category: a.slug\n                    });\n                    return twttr.merge(f, {\n                        href: g\n                    });\n                }).array : []));\n            }\n        }), a(twttr.components.SuggestionCategoriesList);\n    });\n});\nprovide(\"components/ContactImportMatchesStats\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.ContactImportMatchesStats\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            var c = ((a.customHeaderView || \"ContactImportMatchesStats\"));\n            (new twttr.views[c](b)).render(this.$node, \"append\"), this.$node.delegate(\".js-action-follow-all\", \"click\", function(b) {\n                a._followAll($(this)), b.preventDefault();\n            }), this.$node.delegate(\".save-as-list\", \"click\", function(b) {\n                a._saveAsList($(this)), b.preventDefault();\n            }), this.$node.delegate(\".invite-contacts\", \"click\", function(b) {\n                a.inviteOthers(), b.preventDefault();\n            });\n        }), a(twttr.components.ContactImportMatchesStats);\n    });\n});\nprovide(\"components/media/Base\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.media.Base\").subclassOf(twttr.components.Base).initializer(function(a) {\n            a = ((a || {\n            })), this.options = a, this.size = ((a.size || \"medium\")), this.count = ((((this.count || a.count)) || 100)), this.offset = ((((this.offset || a.offset)) || 0)), this.score = ((a.score || !0)), this.isDataReady = !1, this._urls = [];\n        }).methods(twttr.EventProvider).methods({\n            render: function() {\n                throw new Error(\"You should implement this.\");\n            },\n            dataReady: function(a, b) {\n                this._urls = a, this.isDataReady = !0, this.trigger(\"urlsLoaded\", [this._urls,!!b,]);\n            }\n        }), a(twttr.components.media.Base);\n    });\n});\nprovide(\"components/media/profile\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.media.profile.Images\").subclassOf(twttr.components.media.Base).initializer(function(a) {\n            var b = this;\n            this._superInitializer.apply(this, arguments), this.user = a.user, this.provider = new twttr.media.provider.UserMedia({\n                user: this.user\n            }), this.options = ((a || {\n            })), this._fetchedMedia = null, this.viewTemplate = twttr.views.FacetMedia, this.filter = ((a.filter || function() {\n                return !0;\n            })), this.thumbnailViewerOptions = $.extend({\n            }, {\n                width: 340,\n                itemWidth: 83,\n                itemHeight: 83,\n                itemDisplayWidth: 85,\n                generateItemHref: function(a) {\n                    return ((((twttr.router.userMediaSlideshowPath({\n                        screen_name: b.user.screenName\n                    }) + \"?url=\")) + encodeURIComponent(a)));\n                }\n            }, this.options), this.noSpacer = !!this.options.noSpacer;\n        }).methods({\n            fetchImages: function() {\n                var a = this;\n                this.provider.fetch({\n                    count: this.count,\n                    page: this.offset,\n                    filter: this.filter,\n                    success: function(b) {\n                        a._fetchedMedia = b;\n                        var c = !1;\n                        a.dataReady($.map(b, function(a) {\n                            return c = ((c || ((((a && a.tweet)) && a.tweet.possiblySensitive)))), a.url;\n                        }), c);\n                    }\n                });\n            },\n            render: function() {\n                var a = this;\n                if (!this.isDataReady) {\n                    return;\n                }\n            ;\n            ;\n                var b = 4, c = ((this._urls.length > b));\n                this.viewAllHref = twttr.router.userMediaGridPath({\n                    screen_name: a.user.screenName\n                });\n                if (((this._urls.length > 0))) {\n                    var d = (new this.viewTemplate({\n                        title: _(\"Recent images\"),\n                        view_all_href: this.viewAllHref,\n                        show_view_all: c\n                    })).$html();\n                    this.$node.append(d), this.thumbnailViewer = new twttr.components.ThumbnailViewer(this._urls, this.thumbnailViewerOptions, this._fetchedMedia), this.thumbnailViewer.renderWithIndex(0), this.thumbnailViewer.bind(\"nextPage prevPage\", function(a, b) {\n                        trackClient({\n                            section: \"dashboard\",\n                            component: \"photos_user_media\",\n                            action: \"page\"\n                        }, {\n                            event_info: \"photos\",\n                            cursor_or_page: b,\n                            profile_id: ((twttr.profileUser && twttr.profileUser.id))\n                        });\n                    }), this.thumbnailViewer.bind(\"allFailed\", function() {\n                        a.trigger(\"failed\");\n                    }), this.$find(\".js-media-images\").replaceWith(this.thumbnailViewer.$node);\n                }\n            ;\n            ;\n                this.hasRendered();\n            }\n        }), a(twttr.components.media.profile);\n    });\n});\nprovide(\"components/media/facets/Base\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.media.facets.Base\").subclassOf(twttr.components.media.Base).initializer(function(a) {\n            this._superInitializer(a);\n        }).methods(twttr.EventProvider).methods({\n            render: function() {\n                throw new Error(\"You should implement this.\");\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/media/facets/Media\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.media.facets.Media\").subclassOf(twttr.components.media.facets.Base).methods({\n            render: function() {\n                var a = this;\n                if (!this.isDataReady) {\n                    return;\n                }\n            ;\n            ;\n                var b = ((((a._type === \"images\")) ? 4 : 3)), c = ((this._urls.length > b));\n                if (((this._urls.length > 0))) {\n                    var d = (new this.viewTemplate({\n                        title: this.title,\n                        view_all_href: ((((!twttr.isT1 || c)) ? this.view_all_href : this.view_slideshow_href)),\n                        show_view_all: c\n                    })).$html();\n                    this.$node.append(d);\n                    var e = {\n                        imageSize: this.imageSize,\n                        cacheSize: this.cacheSize,\n                        width: 340,\n                        itemWidth: ((this.itemWidth || 83)),\n                        itemHeight: ((this.itemHeight || 83)),\n                        itemDisplayWidth: ((this.itemDisplayWidth || 85)),\n                        delayLoading: !0,\n                        generateItemHref: function(b) {\n                            return ((((twttr.router.searchFacetsSlideshowPath({\n                                query: a.options.query,\n                                mode: ((((a._type === \"images\")) ? \"photos\" : a._type))\n                            }) + \"?url=\")) + encodeURIComponent(b)));\n                        },\n                        containsVideos: ((((a._type !== \"images\")) ? !0 : !1))\n                    };\n                    ((twttr.isT1 && twttr.aug(e, twttr.components.Media.dashboardThumbnailOptions))), this.thumbnailViewer = new twttr.components.ThumbnailViewer(this._urls, e), this.thumbnailViewer.renderWithIndex(0), this.thumbnailViewer.bind(\"nextPage prevPage\", function(b, c) {\n                        var d = ((((a._type == \"images\")) ? \"photos\" : a._type));\n                        trackClient({\n                            section: \"dashboard\",\n                            component: ((d + \"_search_facets\")),\n                            action: \"page\"\n                        }, {\n                            event_info: d,\n                            query: a.options.query,\n                            page_or_cursor: c\n                        });\n                    }), this.thumbnailViewer.bind(\"failedToLoad\", function(c, d) {\n                        var e = $.inArray(d, a._urls);\n                        ((((e > -1)) && a._urls.splice(e, 1))), ((((a._urls.length <= b)) && a.hideViewAll()));\n                    }), this.thumbnailViewer.bind(\"allFailed\", function() {\n                        a.trigger(\"failed\");\n                    }), this.$find(\".js-media-images\").replaceWith(this.thumbnailViewer.$node);\n                }\n            ;\n            ;\n                this.afterRender(), this.hasRendered();\n            },\n            hideViewAll: function() {\n                this.$find(\".view-all-link\").remove();\n            },\n            afterRender: function() {\n            \n            },\n            viewTemplate: twttr.views.FacetMedia\n        });\n        a(c);\n    });\n});\nprovide(\"components/media/facets/Images\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.media.facets.Images\").subclassOf(twttr.components.media.facets.Media).initializer(function() {\n            var a = this;\n            this.title = _(\"Top images\"), this._type = \"images\", this._superInitializer.apply(this, arguments), this.view_all_href = twttr.router.searchFacetsGridPath({\n                query: a.options.query,\n                mode: \"photos\"\n            }), this.view_slideshow_href = twttr.router.searchFacetsSlideshowPath({\n                query: a.options.query,\n                mode: \"photos\"\n            }), this.$node.delegate(\".view-all\", \"click\", function() {\n                trackClient({\n                    section: \"dashboard\",\n                    component: \"photos_search_facets\",\n                    action: \"view_all\"\n                }, {\n                    query: a.options.query,\n                    event_info: \"photos\"\n                }), scribble(\"facets_view_all_click\", {\n                    mode: \"images\",\n                    query: a.options.query,\n                    userId: ((twttr.currentUser ? twttr.currentUser.id : null))\n                });\n            }), this.$node.delegate(\".media-thumbnail\", \"click\", function(b) {\n                trackClient({\n                    section: \"dashboard\",\n                    component: \"photos_search_facets\",\n                    action: \"click\"\n                }, {\n                    query: a.options.query,\n                    event_info: \"photos\",\n                    url: $(this).attr(\"data-url\")\n                });\n            }), twttr.SearchAPI.getImageFacets(this.options.query, {\n                experimentId: this.options.expId,\n                count: 100,\n                success: function(b) {\n                    var c = $.map(b, function(a) {\n                        return a.url;\n                    });\n                    a.dataReady(c, !1);\n                }\n            });\n        }).methods({\n            scribeComponentName: \"photos_search_facets\"\n        }).deciderKey(\"phoenix_facets_images\");\n        a(c);\n    });\n});\nprovide(\"components/media/facets/Videos\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.media.facets.Videos\").subclassOf(twttr.components.media.facets.Media).initializer(function() {\n            var a = this;\n            this.itemWidth = 112, this.itemDisplayWidth = 114, this.title = _(\"Top videos\"), this._type = \"videos\", this._superInitializer.apply(this, arguments), this.view_all_href = twttr.router.searchFacetsGridPath({\n                query: a.options.query,\n                mode: \"videos\"\n            }), this.view_slideshow_href = twttr.router.searchFacetsSlideshowPath({\n                query: a.options.query,\n                mode: \"videos\"\n            }), this.$node.delegate(\".view-all\", \"click\", function() {\n                trackClient({\n                    section: \"dashboard\",\n                    component: \"videos_search_facets\",\n                    action: \"view_all\"\n                }, {\n                    query: a.options.query,\n                    event_info: \"videos\"\n                });\n            }), this.$node.delegate(\".media-thumbnail\", \"click\", function(b) {\n                trackClient({\n                    section: \"dashboard\",\n                    component: \"videos_search_facets\",\n                    action: \"click\"\n                }, {\n                    query: a.options.query,\n                    event_info: \"videos\",\n                    url: $(this).attr(\"data-url\")\n                });\n            }), twttr.SearchAPI.getVideoFacets(this.options.query, {\n                experimentId: this.options.expId,\n                count: 100,\n                success: function(b) {\n                    var c = $.map(b, function(a) {\n                        return a.url;\n                    });\n                    a.dataReady(c, !1);\n                }\n            });\n        }).methods({\n            scribeComponentName: \"videos_search_facets\"\n        }).deciderKey(\"phoenix_facets_videos\");\n        a(c);\n    });\n});\nprovide(\"components/ThumbnailViewer\", function(a) {\n    using(\"constants\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.ThumbnailViewer\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            ((b ? (this.imageSize = ((b.imageSize || this.imageSize)), this.cacheSize = ((b.cacheSize || this.cacheSize)), this.itemWidth = ((b.itemWidth || 60)), this.itemHeight = ((b.itemHeight || 60)), this.itemDisplayWidth = ((b.itemDisplayWidth || this.itemWidth)), this.itemDisplayHeight = ((b.itemDisplayHeight || this.itemHeight)), this.containsVideos = ((b.containsVideos || !1)), this.width = ((b.width || 304)), this.viewClass = ((b.viewClass || twttr.views.ThumbnailViewer)), this.thumbnailViewClass = ((b.thumbnailViewClass || twttr.views.Thumbnail)), this.scribbler = ((b.scribbler || twttr.Scribbler.clientEvent)), this.noRender = b.noRender, this.atEnd = !1, this.firstVisibleIndex = 0, ((twttr.is.def(b.fadeOutNav) ? this.fadeOutNav = b.fadeOutNav : this.fadeOutNav = !0)), this.generateItemHref = ((b.generateItemHref || function(a) {\n                return a;\n            }))) : this.scribbler = twttr.Scribbler.clientEvent)), this.originalCount = a.length, this.urls = a, this.embeddedMedia = c, (new this.viewClass).render(this.$node, \"append\"), this.thumbSetup(), this._registerEventHandlers(), this.updatePageNavigation();\n        }).methods({\n            animateTo: function(a) {\n                ((((a < 0)) && (a = 0)));\n                var b = this.getFullyVisibleThumbsPerPage();\n                this.firstVisibleIndex = ((a - ((a % b))));\n                var c = this.determineLeftPosition(a, b), d = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                ((twttr.isRTL ? this.$thumbs[d]({\n                    right: -c\n                }, 400, \"swing\") : this.$thumbs[d]({\n                    left: -c\n                }, 400, \"swing\"))), this.loadSurroundingImages(a, b), this.updatePageNavigation();\n            },\n            determineLeftPosition: function(a, b) {\n                var c = ((this.firstVisibleIndex * this.itemDisplayWidth)), d = this.getThumbsWidth(), e = ((a * this.itemDisplayWidth)), f = this.getThumbsVisibleWidth(), g = ((((c + f)) - d));\n                if (((((g >= 0)) && ((this.firstVisibleIndex >= b))))) c -= g, this.atEnd = !0;\n                 else {\n                    var i = ((d - e));\n                    ((((((this.atEnd === !0)) && ((i < f)))) ? (c -= g, this.atEnd = !0, this.firstVisibleIndex = ((this.urls.length - b))) : this.atEnd = !1));\n                }\n            ;\n            ;\n                return c;\n            },\n            loadNextImages: function(a, b) {\n                if (this.noRender) {\n                    return;\n                }\n            ;\n            ;\n                this.$thumbs.children().slice(a, b).trigger(\"loadImage\");\n            },\n            loadSurroundingImages: function(a, b) {\n                var c = ((a - b));\n                ((((c < 0)) && (c = 0))), this.loadNextImages(c, ((a + ((b * 2)))));\n            },\n            thumbSetup: function() {\n                this.$thumbs = this.$find(\".js-thumbnail-viewer-images\"), this.$container = this.$find(\".js-thumbnail-viewer-container\"), this.$thumbs.width(this.getThumbsWidth()), this.generateThumbs(this.urls);\n            },\n            getThumbsWidth: function() {\n                return ((this.urls.length * this.itemDisplayWidth));\n            },\n            getThumbsVisibleWidth: function() {\n                return ((this.$container.width() || this.width));\n            },\n            getThumbsPerPage: function() {\n                return Math.ceil(((this.getThumbsVisibleWidth() / this.itemDisplayWidth)));\n            },\n            getFullyVisibleThumbsPerPage: function() {\n                var a = ((this.getThumbsVisibleWidth() / this.itemDisplayWidth));\n                return ((((((a - Math.floor(a))) > 1343196)) ? Math.ceil(a) : Math.floor(a)));\n            },\n            renderWithIndex: function(a) {\n                a = this.resetIndex(a), this.animateTo(a);\n            },\n            removeUrl: function(a) {\n                var b = $.inArray(a, this.urls);\n                ((((b !== -1)) && (this.urls.splice(b, 1), this.trigger(\"failedToLoad\", a), this.updatePageNavigation()))), ((((this.urls.length == 0)) && this.trigger(\"allFailed\")));\n            },\n            selectByUrl: function(a) {\n                var b = $.inArray(a, this.urls);\n                return ((((b == -1)) ? !1 : (this.renderWithIndex(b), this._select(this.getThumbnailByUrl(a)), !0)));\n            },\n            selectByIndex: function(a) {\n                a = this.resetIndex(a), this.renderWithIndex(a);\n                var b = this.$thumbs.JSBNG__find(\".media-thumbnail\");\n                this._select($(b[a]));\n            },\n            resetIndex: function(a) {\n                return ((((a > this.urls.length)) ? 0 : a));\n            },\n            getThumbnailByUrl: function(a) {\n                return this.$thumbs.JSBNG__find(((((\".media-thumbnail[data-url='\" + a)) + \"']\"))).first();\n            },\n            generateThumbs: function(a) {\n                var c = this;\n                if (((a.length === 0))) {\n                    return;\n                }\n            ;\n            ;\n                var d = b.constants.imageSizes, e = $(), f = {\n                    width: this.itemWidth,\n                    height: this.itemHeight,\n                    dimension: Math.max(this.itemWidth, this.itemHeight),\n                    size: ((((((this.itemWidth < 80)) && ((this.itemHeight < 80)))) ? d.small : d.medium)),\n                    scalingMode: \"trim\",\n                    delayLoading: !0,\n                    thumbnailViewClass: this.thumbnailViewClass,\n                    componentName: this._namespace.split(\".\").pop()\n                };\n                ((this.embeddedMedia ? e = twttr.images.renderProviderMedia(this.embeddedMedia, f) : e = twttr.images.renderMediaUrls(a, f)));\n                if (e.length) {\n                    var g = this.getFullyVisibleThumbsPerPage(), i = 0, j = 0, k = ((g * 2)), l = k;\n                    function m() {\n                        ((((((((i + j)) === l)) && ((j <= g)))) && (c.loadNextImages(j, ((j + k))), l += k)));\n                    };\n                ;\n                    e.addClass(\"thumbnail-image-wrapper\").bind(\"failedToResolve failedToLoad\", function(a, b) {\n                        var d = $(this).attr(\"data-url\");\n                        twttr.images.scribeImageFailure(c.scribbler, \"photos_thumbnails\", d), c.removeUrl(d), $(this).remove(), i++, m();\n                    }).bind(\"loaded\", function() {\n                        twttr.images.animateImageFadeIn($(this).JSBNG__find(\"img\"), 500), j++, m();\n                    }), e.append(\"\\u003Cdiv class=\\\"thumbnail-active-border\\\"\\u003E\\u003Cdiv class=\\\"thumbnail-active-border-inner\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"), ((twttr.isT1 || e.append(\"\\u003Cdiv class=\\\"media-play-button\\\"\\u003E\\u003C/div\\u003E\"))), ((this.containsVideos && e.addClass(\"video\"))), e.each(function() {\n                        var a = $(this);\n                        a.attr(\"href\", c.generateItemHref(a.attr(\"data-url\")));\n                    }), this.$thumbs.append(e);\n                }\n            ;\n            ;\n            },\n            updateWidth: function(a) {\n                this.width = ((a || this.$node.width())), this.animateTo(this.getActiveThumbnail().index()), this.updatePageNavigation();\n            },\n            prevPage: function() {\n                var a = this.getFullyVisibleThumbsPerPage();\n                this.animateTo(((this.firstVisibleIndex - a))), this.trigger(\"prevPage\", ((Math.round(((this.firstVisibleIndex / a))) + 1)));\n            },\n            nextPage: function() {\n                var a = this.getFullyVisibleThumbsPerPage();\n                this.animateTo(((this.firstVisibleIndex + a))), this.trigger(\"nextPage\", ((Math.round(((this.firstVisibleIndex / a))) + 1)));\n            },\n            updatePageNavigation: function() {\n                var a = this.$find(\".thumbnail-viewer-prev\");\n                ((((this.firstVisibleIndex === 0)) ? a.addClass(\"disabled\") : a.removeClass(\"disabled\")));\n                var b = this.$find(\".thumbnail-viewer-next\");\n                ((((this.atEnd === !0)) ? b.addClass(\"disabled\") : b.removeClass(\"disabled\")));\n                var c = this.$find(\".thumbnail-viewer-nav\");\n                ((((this.getFullyVisibleThumbsPerPage() >= this.urls.length)) ? c.hide() : c.css(\"display\", \"\")));\n            },\n            deselect: function() {\n                this.$node.JSBNG__find(\".media-thumbnail\").removeClass(\"media-thumbnail-active\");\n            },\n            _select: function(a) {\n                if (((a.length === 0))) {\n                    return;\n                }\n            ;\n            ;\n                this.deselect(), a.addClass(\"media-thumbnail-active\"), this.selectedUrl = a.attr(\"data-url\"), this.trigger(\"select\", [{\n                    url: this.selectedUrl,\n                    index: ((a.prevAll().length + 1)),\n                    hasPrev: ((a.prev().length > 0)),\n                    hasNext: ((a.next().length > 0))\n                },]);\n            },\n            prev: function() {\n                this.shiftOne(\"prev\");\n            },\n            next: function() {\n                this.shiftOne(\"next\");\n            },\n            shiftOne: function(a) {\n                var b = this.getActiveThumbnail()[a]();\n                ((((b.length > 0)) && (this._select(b), this.trigger(a, [((b.prevAll().length + 1)),]), twttr.router.routeTo(b.attr(\"href\")))));\n            },\n            getActiveThumbnail: function() {\n                return this.$find(\".media-thumbnail-active\");\n            },\n            _registerEventHandlers: function() {\n                var a = this;\n                this.$node.delegate(\".media-thumbnail\", \"click\", function(b) {\n                    a._select($(this));\n                }), this.$node.delegate(\".thumbnail-viewer-prev\", \"click\", function(b) {\n                    a.prevPage();\n                }), this.$node.delegate(\".thumbnail-viewer-next\", \"click\", function(b) {\n                    a.nextPage();\n                });\n                if (this.fadeOutNav) {\n                    this.$nav = this.$find(\".thumbnail-viewer-nav\").css(\"opacity\", 0);\n                    var b = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                    this.$node.hover(function() {\n                        ((a.fadeTimer && JSBNG__clearTimeout(a.fadeTimer))), a.$nav[b]({\n                            opacity: 1\n                        }, 400, \"swing\");\n                    }, function() {\n                        a.fadeTimer = window.JSBNG__setTimeout(function() {\n                            a.$nav[b]({\n                                opacity: 0\n                            }, 400, \"swing\");\n                        }, 200);\n                    });\n                }\n            ;\n            ;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/TheGrid\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.components.TheGrid\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            (new twttr.views.TheGrid).render(this.$node, \"append\"), this.$grid = this.$find(\".the-grid\"), this.media = [], this.totalCount = 0, this.imageWidth = ((a.imageWidth || 150)), this.imageHeight = ((a.imageHeight || 150)), this.margin = ((a.margin || 10)), this.chunksize = ((a.chunksize || 100)), this.gridCols = 6, this.isEvent = ((a.isEvent || !1)), this.generateItemHref = ((a.generateItemHref || $.noop)), this.provider = a.provider, this.query = a.query, this.mode = a.mode, this.type = a.type, this.screenName = a.screenName, this.filter = a.filter, this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent)), this.provider.fetch({\n                count: 100,\n                score: !0,\n                offset: 0,\n                mode: this.mode,\n                query: this.query,\n                is_event: this.isEvent,\n                filter: this.filter,\n                success: twttr.bind(this, this._loadMedia),\n                error: twttr.bind(this, this.renderNoResults)\n            }), this.setCols(b), this._registerEventHandlers();\n        }).methods({\n            setCols: function(a) {\n                var b = ((((this.mode === \"videos\")) ? this._getWidthVideos(a) : this._getWidthPhotos(a)));\n                this.$grid.width(b);\n            },\n            _getWidthPhotos: function(a) {\n                var b = 960;\n                return ((((((a >= 640)) && ((a < 800)))) ? b = 640 : ((((((a >= 800)) && ((a < 960)))) && (b = 800))))), b;\n            },\n            _getWidthVideos: function(a) {\n                var b = 840;\n                return ((((((a >= 630)) && ((a < 840)))) && (b = 630))), b;\n            },\n            decrementLoaded: function() {\n                this.totalCount--, ((((this.totalCount == 0)) && this.trigger(\"hideLoading\")));\n            },\n            _doLoad: function(a) {\n                var c = this, d = a.length, e = $(), f = {\n                    width: this.imageWidth,\n                    height: this.imageHeight,\n                    size: b.constants.imageSizes.medium,\n                    scalingMode: \"trim\",\n                    componentName: this._namespace.split(\".\").pop()\n                };\n                ((a && (e = twttr.images.renderProviderMedia(a, f)))), ((e.length && (e.addClass(\"grid-square\").bind(\"failedToResolve failedToLoad\", function(a, b) {\n                    var e = $(this).attr(\"data-url\");\n                    twttr.images.scribeImageFailure(c.scribbler, \"photos\", e), $(this).remove(), d--, ((((d == 0)) && c.renderAndResolve())), c.decrementLoaded();\n                }), ((((this.mode == \"videos\")) && e.addClass(\"video\").append(\"\\u003Cdiv class=\\\"media-play-button\\\"\\u003E\\u003C/div\\u003E\"))), e.each(function() {\n                    var a = $(this);\n                    a.attr(\"href\", c.generateItemHref(a.attr(\"data-url\")));\n                }), e.bind(\"loaded\", function() {\n                    d--, ((((d == 0)) && c.renderAndResolve())), c.decrementLoaded(), twttr.images.animateImageFadeIn($(this).JSBNG__find(\"img\"));\n                }), ((((this.mode == \"videos\")) && e.addClass(\"video\").append(\"\\u003Cdiv class=\\\"media-play-button\\\"\\u003E\\u003C/div\\u003E\"))), this.$find(\".the-grid\").prepend(e))));\n            },\n            renderAndResolve: function() {\n                var a = this, b = this.media.splice(0, this.chunksize);\n                ((((b.length > 0)) ? this._doLoad(b) : this.trigger(\"hideLoading\")));\n            },\n            _loadMedia: function(a) {\n                this.media = a, this.totalCount = this.media.length, this.$find(\".the-grid\").empty(), ((((this.media.length > 0)) ? this.renderAndResolve() : this.renderNoResults()));\n            },\n            renderNoResults: function() {\n                (new twttr.views.MediaGalleryNoResults({\n                    is_search: ((this.type === \"search\")),\n                    is_usermedia: ((this.type === \"userMedia\")),\n                    query: this.query,\n                    mode_photos: ((this.mode === \"photos\")),\n                    mode_videos: ((this.mode === \"videos\")),\n                    screen_name: this.screenName\n                })).render(this.$find(\".the-grid\"), \"append\"), this.trigger(\"hideLoading\");\n            },\n            _registerEventHandlers: function() {\n                var a = this;\n                JSBNG__setTimeout(function() {\n                    a.trigger(\"hideLoading\");\n                }, 10000);\n            }\n        }), a(twttr.components.TheGrid);\n    });\n});\nprovide(\"components/MediaGalleryControls\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.components.MediaGalleryControls\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this._options = ((a || {\n            })), this._eventId = ((a.eventId || !1)), this._isEvent = !!this._eventId, this._type = ((a.type || \"search\")), this._view = ((a.view || \"grid\")), this._mode = ((a.mode || \"photos\")), this._query = ((a.query || \"\")), this.screenName = a.screenName, this._render(), this._registerEvents();\n        }).methods({\n            _registerEvents: function() {\n                var a = this;\n                this.$node.delegate(\".media-gallery-back-nav\", \"click\", function(b) {\n                    a.trigger(\"close\");\n                }), this.$detailView = this.$find(\".toggle-button.detailview\"), this.$gridView = this.$find(\".toggle-button.gridview\"), this.$detailView.bind(\"click\", function(b) {\n                    a.setMode(\"detail\");\n                }), this.$gridView.bind(\"click\", function(b) {\n                    a.setMode(\"grid\");\n                });\n            },\n            setMode: function(a) {\n                if (((this._view == a))) {\n                    return;\n                }\n            ;\n            ;\n                ((((a == \"grid\")) ? (this.$gridView.addClass(\"selected\"), this.$detailView.removeClass(\"selected\"), this.trigger(\"gridViewSelected\")) : (this.$gridView.removeClass(\"selected\"), this.$detailView.addClass(\"selected\"), this.trigger(\"detailViewSelected\")))), this._view = a;\n            },\n            _render: function() {\n                (new twttr.views.MediaGalleryControls({\n                    is_search: ((this._type === \"search\")),\n                    is_usermedia: ((this._type === \"userMedia\")),\n                    screen_name: this.screenName,\n                    is_grid_view: ((this._view === \"grid\")),\n                    is_detail_view: ((this._view === \"detail\")),\n                    mode_photos: ((this._mode === \"photos\")),\n                    mode_videos: ((this._mode === \"videos\")),\n                    disable_grid: twttr.decider.isAvailable(\"disable_gallery_grid\"),\n                    disable_thumbs: twttr.decider.isAvailable(\"disable_gallery_thumbs\"),\n                    back_text: ((this._isEvent ? _(\"Back to #{{event}}\", {\n                        JSBNG__event: this._query\n                    }) : _(\"Back to search results\"))),\n                    query: this._query\n                })).render(this.$node, \"append\");\n            }\n        }), a(twttr.components.MediaGalleryControls);\n    });\n});\nprovide(\"components/MediaSlideshow\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.components.MediaSlideshow\").subclassOf(twttr.components.Base).mixin(twttr.mixins.tweetActionable, twttr.mixins.tweetFlagging, twttr.mixins.profilePopupActionable).initializer(function(a) {\n            var b = this;\n            a = ((a || {\n            })), this._media = [], this.options = a, this.width = ((a.width || 530)), this.height = ((a.height || 530)), this.thumbContainerWidth = ((a.thumbContainerWidth || 494)), this.thumbHeight = ((a.thumbHeight || 48)), this.thumbWidth = ((a.thumbWidth || 48)), this.thumbDisplayWidth = ((a.thumbDisplayWidth || 50)), this.thumbDisplayHeight = ((a.thumbDisplayHeight || 48)), this.type = a.type, this.screenName = a.screenName, this.options.mode = ((this.options.mode || \"photos\")), this.showFirstOnFail = ((this.options.showFirstOnFail || !1)), this.arrowOutOpacity = ((twttr.decider.isAvailable(\"disable_gallery_thumbs\") ? 1352920 : 0)), this.isEvent = ((a.isEvent || !1)), this.generateItemHref = ((a.generateItemHref || $.noop)), this.provider = a.provider, this.scribbler = ((a.scribbler || twttr.Scribbler.clientEvent)), this.scribeComponentName = ((this.options.mode + \"_tweet\")), this.render(), this.registerTweetActionEvents(), this.provider.fetch({\n                count: 100,\n                score: !0,\n                mode: this.options.mode,\n                query: this.options.query,\n                is_event: this.isEvent,\n                filter: a.filter,\n                success: function(a) {\n                    b.addMedia(a), b.addMediaComplete();\n                },\n                error: twttr.bind(this, this.renderNoResults)\n            });\n        }).methods(twttr.EventProvider).methods({\n            render: function() {\n                (new twttr.views.MediaSlideshow).render(this.$node, \"append\"), this.$thumbnails = this.$find(\".media-slideshow-thumbnails\"), this.$bigPicture = this.$find(\".media-slideshow-picture\"), this.$bigPictureWrapper = this.$find(\".media-slideshow-pictures\"), this.$mediaContainer = this.$find(\".media-slideshow-media-container\"), this.$prevButton = this.$find(\".media-control-button.prev\"), this.$nextButton = this.$find(\".media-control-button.next\"), this.$nextButton = this.$find(\".media-control-button.next\"), this.$flagcontainer = $(\"\\u003Cdiv class=\\\"flag-container\\\"/\\u003E\"), this.$bigPicture.css({\n                    height: this.height,\n                    width: this.width\n                }), this._registerEventHandlers();\n            },\n            renderNoResults: function() {\n                this.$node.empty(), (new twttr.views.MediaGalleryNoResults({\n                    is_search: ((this.type === \"search\")),\n                    is_usermedia: ((this.type === \"userMedia\")),\n                    query: this.options.query,\n                    mode_photos: ((this.options.mode === \"photos\")),\n                    mode_videos: ((this.options.mode === \"videos\")),\n                    screen_name: this.screenName\n                })).render(this.$node, \"append\"), this.trigger(\"hideLoading\");\n            },\n            addMediaComplete: function() {\n                var a = this;\n                if (((this._media.length > 1))) {\n                    var b = {\n                        itemWidth: this.thumbWidth,\n                        itemHeight: this.thumbHeight,\n                        itemDisplayWidth: this.thumbDisplayWidth,\n                        itemDisplayHeight: this.thumbDisplayHeight,\n                        width: this.thumbContainerWidth,\n                        generateItemHref: this.generateItemHref,\n                        noRender: twttr.decider.isAvailable(\"disable_gallery_thumbs\")\n                    };\n                    ((((this.options.mode == \"videos\")) && (b.containsVideos = !0))), this._thumbnailViewer = new twttr.components.ThumbnailViewer(this._mediaUrls(), b, this._media), this._thumbnailViewer.$node.appendTo(this.$thumbnails), ((twttr.decider.isAvailable(\"disable_gallery_thumbs\") && this._thumbnailViewer.$node.hide())), this._thumbnailViewer.bind(\"select\", function(b, c) {\n                        a.showPicture(a._findMedia(c.url, c.index), c.hasPrev, c.hasNext, c.index);\n                    }), this._thumbnailViewer.bind(\"failedToLoad\", function(b, c) {\n                        a.removeUrl(c);\n                    }), this._thumbnailViewer.bind(\"next prev\", function(b, c) {\n                        a.scribbler.scribe({\n                            component: a.options.mode,\n                            action: \"page\"\n                        }, {\n                            cursor_or_page: c\n                        });\n                    }), this._thumbnailViewer.bind(\"nextPage prevPage\", function(b, c) {\n                        a.scribbler.scribe({\n                            component: ((a.options.mode + \"_thumbnails\")),\n                            action: \"page\"\n                        }, {\n                            cursor_or_page: c\n                        });\n                    }), this.selectUrl(this.options.url);\n                }\n                 else ((((this._media.length == 1)) ? this.showPicture(a._media[0], !1, !1, 1) : this.renderNoResults()));\n            ;\n            ;\n            },\n            _registerEventHandlers: function() {\n                var a = this;\n                this.$nextButton.bind(\"click\", twttr.bind(this, this.showNext)), this.$prevButton.bind(\"click\", twttr.bind(this, this.showPrev)), this.$flagcontainer.delegate(\".flaggable\", \"click\", function(b) {\n                    a.flagLinkClicked(b, a.tweet);\n                }), this.$nav = this.$find(\".media-control-button\").css(\"opacity\", this.arrowOutOpacity);\n                var b = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                this.$bigPictureWrapper.hover(function() {\n                    ((a.fadeTimer && JSBNG__clearTimeout(a.fadeTimer))), a.$nav[b]({\n                        opacity: 1356180\n                    }, 400, \"swing\");\n                }, function() {\n                    a.fadeTimer = window.JSBNG__setTimeout(function() {\n                        a.$nav[b]({\n                            opacity: this.arrowOutOpacity\n                        }, 400, \"swing\");\n                    }, 2000);\n                }), this.$nav = this.$find(\".media-control-button\").css(\"opacity\", this.arrowOutOpacity), this.$bigPictureWrapper.mouseenter(twttr.bind(this, this._attachMouseMove)), this.$bigPictureWrapper.mouseleave(twttr.bind(this, this._detachMouseMove));\n            },\n            _mouseMoveHandler: function() {\n                var a = this;\n                JSBNG__clearTimeout(this.fadeOutTimer), this.fadeOutTimer = JSBNG__setTimeout(twttr.bind(this, this._fadeOutArrows), b.constants.slideshow.fadeOutArrowTimeout);\n                if (this.fadeInTimer) {\n                    return;\n                }\n            ;\n            ;\n                this.fadeInTimer = JSBNG__setTimeout(function() {\n                    a._fadeInArrows(1356808);\n                }, b.constants.slideshow.fadeInArrowTimeout);\n            },\n            _attachMouseMove: function() {\n                var a = this;\n                this.$bigPictureWrapper.bind(\"mousemove\", twttr.bind(this, this._mouseMoveHandler)), a.fadeInTimer = JSBNG__setTimeout(function() {\n                    a._fadeInArrows(1357029);\n                }, b.constants.slideshow.fadeInArrowTimeout);\n            },\n            _detachMouseMove: function() {\n                this.$bigPictureWrapper.unbind(\"mousemove\"), ((this.fadeInTimer && (JSBNG__clearTimeout(this.fadeInTimer), this.fadeInTimer = undefined))), this._fadeOutArrows();\n            },\n            _fadeInArrows: function(a) {\n                var c = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                this.$nav[c]({\n                    opacity: a\n                }, b.constants.slideshow.fadeAnimationTime, \"swing\"), JSBNG__clearTimeout(this.fadeInTimer), this.fadeInTimer = undefined;\n            },\n            _fadeOutArrows: function() {\n                var a = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                this.$nav[a]({\n                    opacity: this.arrowOutOpacity\n                }, b.constants.slideshow.fadeAnimationTime, \"swing\");\n            },\n            addMedia: function(a) {\n                this._media = this._media.concat(a);\n            },\n            _findMedia: function(a, b) {\n                var c = this._media[((b - 1))];\n                if (((c && ((c.url == a))))) {\n                    return c;\n                }\n            ;\n            ;\n                var d = this._mediaUrls(), e = $.inArray(a, d);\n                return ((((e >= 0)) ? this._media[e] : !1));\n            },\n            _mediaUrls: function() {\n                return twttr.map(this._media, function(a) {\n                    return a.url;\n                });\n            },\n            selectUrl: function(a) {\n                a = ((a || this._mediaUrls()[0]));\n                var b = this._thumbnailViewer.selectByUrl(a);\n                ((b || ((this.showFirstOnFail ? this._thumbnailViewer.selectByIndex(0) : (this._showNotFound(a), this._thumbnailViewer.deselect(), this._thumbnailViewer.animateTo(0), this._updateArrows(!1, !1))))));\n            },\n            removeUrl: function(a) {\n                for (var b = 0; ((b < this._media.length)); b++) {\n                    if (((this._media[b].url === a))) {\n                        this._media.splice(b, 1);\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                ((((this.currentUrl === a)) && ((((((b == 0)) && this._mediaUrls().length)) ? this._thumbnailViewer.selectByUrl(this._mediaUrls()[0]) : this._showNotFound()))));\n            },\n            _showNotFound: function(a) {\n                this._resetMediaContainer(), (new twttr.views.MediaSlideshowNotFound({\n                })).render(this.$mediaContainer, \"append\"), this.$mediaContainer.addClass(\"not-found\"), this.trigger(\"hideLoading\");\n            },\n            _resetMediaContainer: function() {\n                return this._removeTweet(), this.$flagcontainer.detach(), this.$mediaContainer.css({\n                    JSBNG__top: null\n                }).empty();\n            },\n            _updateArrows: function(a, b) {\n                ((a ? this.$prevButton.addClass(\"enabled\") : this.$prevButton.removeClass(\"enabled\"))), ((b ? this.$nextButton.addClass(\"enabled\") : this.$nextButton.removeClass(\"enabled\")));\n            },\n            showPicture: function(a, b, c, d) {\n                if (((a && ((this.currentUrl != a.url))))) {\n                    this.currentUrl = a.url, this.trigger(\"showSlideshowLoading\"), this.$mediaContainer.removeClass(\"not-found\"), ((((this.options.mode == \"photos\")) ? this.renderPicture() : this.renderVideo()));\n                    if (this.tweetFlaggable(a.tweet)) {\n                        this.$flagcontainer.html(((((\"\\u003Ca href='#' class='flaggable'\\u003E\" + _(\"Flag this media\"))) + \"\\u003C/a\\u003E\")));\n                        var e = this.$flagcontainer.JSBNG__find(\".flaggable\");\n                        ((a.tweetId && e.attr(\"tweet-id\", a.tweetId)));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                this._renderMedia(a), this._updateArrows(b, c), this.scribbler.scribe({\n                    component: ((this.options.mode + \"_slide\")),\n                    action: \"impression\"\n                }, {\n                    url: a.url,\n                    cursor_or_page: d\n                });\n            },\n            _removeTweet: function() {\n                this.$find(\".media-slideshow-tweet\").empty().addClass(\"loading\");\n            },\n            _renderMedia: function(a) {\n                var b = this;\n                ((((a.tweet && a.tweet.entities)) ? this._renderTweet(a.tweet, a.url) : ((a.tweetId && (this.tweetId = a.tweetId, twttr.API.Status.JSBNG__find(a.tweetId, {\n                    success: function(c, d) {\n                        b._renderTweet(c, a.url);\n                    },\n                    error: function() {\n                        b.trigger(\"hideLoading\");\n                    }\n                }))))));\n            },\n            _renderTweet: function(a, b) {\n                this.tweet = a, this._removeTweet(), ((twttr.isT1 ? (a.attributes.is_slideshow = !0, (new twttr.views.SimpleTweet(a)).render(this.$find(\".media-slideshow-tweet\"), \"append\")) : (new twttr.views.SlideshowTweet(a)).render(this.$find(\".media-slideshow-tweet\"), \"append\"))), this.$find(\".media-slideshow-tweet\").removeClass(\"loading\");\n                var c = this, d = twttr.media.types.Twimg.matchers.twimg, e = twttr.media.types.Twimg.matchers.media;\n                if (((((((((b && ((b.match(d) || b.match(e))))) && a)) && a.entities)) && a.entities.media))) {\n                    var f = a.entities.media.length, g = b.split(\"/\").pop().split(\".\")[0];\n                    for (var i = 0; ((i < f)); i++) {\n                        var j = a.entities.media[i];\n                        if (((((j.display_url.indexOf(g) >= 0)) || ((j.media_url.indexOf(g) >= 0))))) {\n                            c.$imageDiv.attr(\"href\", j.url);\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                this.scribbler.scribe({\n                    component: ((this.options.mode + \"_tweet\")),\n                    action: \"impression\"\n                }, {\n                    url: a.url,\n                    item_ids: [a.id,]\n                }), this.trigger(\"hideTweetLoading\");\n            },\n            renderVideo: function() {\n                var a = this, c = twttr.media.matchInstance(this.currentUrl);\n                this._resetMediaContainer();\n                if (!c) {\n                    this._showNotFound(this.currentUrl);\n                    return;\n                }\n            ;\n            ;\n                c.process(function() {\n                    c.render(a.$mediaContainer), JSBNG__setTimeout(function() {\n                        a.trigger(\"mediaRendered\"), a.trigger(\"hideMediaLoading\"), a._renderAttribution(a.currentUrl);\n                    }, 1);\n                }, {\n                    maxwidth: b.constants.slideshow.videoMaxWidth\n                });\n            },\n            renderPicture: function() {\n                var a = this, c;\n                this._resetMediaContainer();\n                var d = twttr.filter(this._media, function(b) {\n                    if (((a.currentUrl == b.url))) {\n                        return b;\n                    }\n                ;\n                ;\n                });\n                ((d && (d = [d[0],]))), this.$imageDiv = twttr.images.renderProviderMedia(d, {\n                    width: this.width,\n                    height: this.height,\n                    size: b.constants.imageSizes.large,\n                    scalingMode: \"fit\",\n                    divMode: \"snap\",\n                    componentName: this._namespace.split(\".\").pop()\n                }).bind(\"failedToResolve failedToLoad\", function(b, c) {\n                    var d = $(this).attr(\"data-url\");\n                    twttr.images.scribeImageFailure(a.scribbler, \"photos_slide\", d), $(this).remove(), a._showNotFound(a.currentUrl);\n                }).bind(\"loaded\", function() {\n                    a.trigger(\"mediaRendered\"), a.trigger(\"hideMediaLoading\"), a._renderAttribution(a.currentUrl), a.renderTwimgAttribution();\n                }).attr(\"target\", \"_blank\"), this.$mediaContainer.append(this.$imageDiv);\n            },\n            _renderAttribution: function(a) {\n                var b = twttr.media.matchInstance(a);\n                if (b) {\n                    var c = $(\"\\u003Cdiv class='media-attribution-and-flag'/\\u003E\"), d = $(b.attribution()).appendTo(c);\n                    if (this.tweetFlaggable(this.tweet)) {\n                        var e = $(twttr.at(b._namespace).flagActionTemplate);\n                        this.$flagcontainer.html(e.html());\n                        var f = this.$flagcontainer.JSBNG__find(\".flaggable\");\n                        ((this.tweetId && f.attr(\"tweet-id\", this.tweetId))), this.$flagcontainer.appendTo(c);\n                    }\n                ;\n                ;\n                    c.appendTo(this.$mediaContainer);\n                }\n            ;\n            ;\n            },\n            renderTwimgAttribution: function() {\n                var a = this, b = this.currentUrl.match(twttr.media.types.CopiedTwimg.matchers.media);\n                if (((b && b[1]))) {\n                    var c = b[1];\n                    twttr.API.Status.JSBNG__find(c, function(b) {\n                        var c = b.user.screenName, d = new twttr.views.CopiedTwimgAttribution({\n                            screen_name: c,\n                            time_ago: twttr.helpers.timeAgo(twttr.helpers.parseDateString(b.createdAt), !0)\n                        });\n                        a.$imageDiv.append(d.html()).JSBNG__find(\".attribution-wrapper\").css(\"display\", \"none\").fadeIn(\"fast\"), a.$imageDiv.JSBNG__find(\".user-profile-link\").click(function() {\n                            return twttr.router.routeTo(twttr.router.profilePath({\n                                screen_name: c\n                            })), !1;\n                        });\n                    });\n                }\n            ;\n            ;\n            },\n            resizePicture: function(h, a) {\n                var b, c;\n                this.$bigPicture.css({\n                    height: h,\n                    width: a\n                });\n                if (((this.options.mode == \"photos\"))) twttr.images.resizeImageInDiv(this.$imageDiv, {\n                    width: a,\n                    height: h,\n                    size: \"large\",\n                    scalingMode: \"fit\",\n                    divMode: \"snap\"\n                }), b = this.$imageDiv.JSBNG__find(\"img\").width(), c = this._offset(h, this.$imageDiv.height());\n                 else {\n                    var d = this.$mediaContainer.children().first();\n                    b = d.width(), c = this._offset(h, d[0].height);\n                }\n            ;\n            ;\n                this.$mediaContainer.css({\n                    width: b,\n                    JSBNG__top: c\n                });\n            },\n            _offset: function(a, b) {\n                return Math.max(0, Math.floor(((((a - b)) / 2))));\n            },\n            showNext: function() {\n                ((this._thumbnailViewer && this._thumbnailViewer.next()));\n            },\n            showPrev: function() {\n                ((this._thumbnailViewer && this._thumbnailViewer.prev()));\n            }\n        }), a(twttr.components.MediaSlideshow);\n    });\n});\nprovide(\"components/SearchFacets\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.SearchFacets\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            this.query = a, this.shouldShowBlockMessage = !0, this.darkMode = !1;\n            if (((((twttr.loggedIn && ((twttr.decider.isAvailable(\"phoenix_facets_dark\") || twttr.decider.isAvailable(\"phoenix_facets\"))))) || ((!twttr.loggedIn && twttr.decider.isAvailable(\"phoenix_facets_logged_out\")))))) {\n                ((((((twttr.loggedIn && !twttr.decider.isAvailable(\"phoenix_facets\"))) && twttr.decider.isAvailable(\"phoenix_facets_dark\"))) && (this.darkMode = !0))), this.renderFacets();\n            }\n        ;\n        ;\n        }).methods({\n            renderFacets: function() {\n                var a = this, b = twttr.Router.getCurrentQueryStringParams().experimentId;\n                if (!this.darkMode) {\n                    this.facetsImages = new twttr.components.media.facets.Images({\n                        query: this.query,\n                        expId: b\n                    }), this.facetsVideos = new twttr.components.media.facets.Videos({\n                        query: this.query,\n                        expId: b\n                    }), this.registerEventTracker(), this.facetsImages.bind(\"urlsLoaded\", function(b, c) {\n                        if (((!c || ((c.length == 0))))) {\n                            a._scribeResults(\"photos\", c);\n                            return;\n                        }\n                    ;\n                    ;\n                        a.facetsImages.$node.appendTo(a.$node), ((a.shouldShowBlockMessage ? a.showBlockedMessage() : a.facetsImages.render())), a._scribeResults(\"photos\", c);\n                    }), this.facetsImages.bind(\"failed\", function() {\n                        a.facetsImages.$node.hide(), a._scribeResults(\"photos\");\n                    }), this.facetsVideos.bind(\"urlsLoaded\", function(b, c) {\n                        if (((!c || ((c.length == 0))))) {\n                            a._scribeResults(\"videos\", c);\n                            return;\n                        }\n                    ;\n                    ;\n                        a.facetsVideos.$node.appendTo(a.$node), ((a.shouldShowBlockMessage ? a.showBlockedMessage() : a.facetsVideos.render())), a._scribeResults(\"videos\", c);\n                    }), this.facetsVideos.bind(\"failed\", function() {\n                        a._scribeResults(\"videos\"), a.facetsVideos.$node.hide();\n                    });\n                    if (twttr.loggedIn) a.shouldShowBlockMessage = !1, a.hideBlockedMessage();\n                     else {\n                        var c = twttr.media.getViewMediaCookie();\n                        ((c ? (a.renderFacetsMedia(), a.shouldShowBlockMessage = !1) : (a.shouldShowBlockMessage = !0, a.renderBlockedMessage())));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            renderFacetsMedia: function() {\n                if (this.darkMode) {\n                    return;\n                }\n            ;\n            ;\n                this.facetsImages.render(), this.facetsVideos.render();\n            },\n            showBlockedMessage: function() {\n                ((this.$notDisplayed || this.renderBlockedMessage())), this.$notDisplayed.show();\n            },\n            hideBlockedMessage: function() {\n                ((this.$notDisplayed && this.$notDisplayed.hide()));\n            },\n            _scribeResults: function(a, b) {\n                var c = ((((b && b.length)) ? \"results\" : \"no_results\")), d = ((a + \"_search_facets\"));\n                b = ((b || [])), trackClient({\n                    section: \"dashboard\",\n                    component: d,\n                    action: c\n                }, {\n                    item_names: b.slice(0, 4),\n                    item_count: b.length,\n                    event_info: a,\n                    query: this.query\n                });\n            },\n            registerEventTracker: function() {\n                function a(a, f) {\n                    ((a ? c = !0 : d = !0)), e = ((e || ((f && f.length)))), allLoaded = ((c && d)), ((((c || d)) && b.trigger(\"urlsLoaded\", [!!e,!!allLoaded,])));\n                };\n            ;\n                var b = this, c = !1, d = !1, e = !1;\n                this.facetsImages.JSBNG__one(\"urlsLoaded failed\", function(b, c) {\n                    a(!0, c);\n                }), this.facetsVideos.JSBNG__one(\"urlsLoaded failed\", function(b, c) {\n                    a(!1, c);\n                });\n            },\n            renderBlockedMessage: function() {\n                var a = this;\n                if (((this.$notDisplayed || this.darkMode))) {\n                    return;\n                }\n            ;\n            ;\n                (new twttr.views.FacetsMediaNotDisplayed).render(this.$node), this.$notDisplayed = this.$node.JSBNG__find(\".facets-media-not-displayed\"), this.$notDisplayed.hide();\n                var b = twttr.bind(this, function() {\n                    this.renderFacetsMedia(), this.$notDisplayed.hide(), ((twttr.loggedIn || twttr.media.setViewMediaCookie()));\n                });\n                this.$node.delegate(\".display-this-media\", \"click\", b);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/FollowerRequestLink\", function(a) {\n    using(\"_\", \"components/Base\", \"multiGlobals/more_views\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.FollowerRequestLink\").subclassOf(b.components.Base).initializer(function() {\n            ((((twttr.currentUser && twttr.currentUser[\"protected\"])) && twttr.currentUser.friends.pending({\n                success: twttr.bind(this, function(a) {\n                    this.pendingFriendRequests = a, this.renderRequestButton();\n                }),\n                error: function(a) {\n                \n                }\n            }))), this.noSpacer = !0, this.hasRendered();\n        }).methods({\n            renderRequestButton: function() {\n                if (((!this.pendingFriendRequests || ((this.pendingFriendRequests.length === 0))))) {\n                    this.destroy();\n                    return;\n                }\n            ;\n            ;\n                var a;\n                ((((this.pendingFriendRequests.length === 1)) ? a = _(\"{{num}} new follower request\", {\n                    num: this.pendingFriendRequests.length\n                }) : a = _(\"{{num}} new follower requests\", {\n                    num: this.pendingFriendRequests.length\n                }))), (new twttr.views.DashboardFollowerRequestLink({\n                    button_label: a,\n                    screen_name: twttr.currentUser.screenName\n                })).render(this.$node, \"append\");\n            }\n        });\n        ((twttr.isT1 && c.setBaseView(twttr.views.Module))), a(c);\n    });\n});\nprovide(\"components/WebPersonalizationSettings\", function(a) {\n    using(\"_\", \"components/Base\", \"mixins/userActionable\", \"mixins/profilePopupActionable\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.WebPersonalizationSettings\").subclassOf(b.components.Base).mixin(b.mixins.userActionable, b.mixins.profilePopupActionable).initializer(function() {\n            var a = this;\n            ((((twttr.inEU || twttr.doNotTrack)) ? (a._render({\n                in_eu: twttr.inEU,\n                do_not_track: !0\n            }), a.trigger(\"disallow\")) : ((twttr.loggedIn ? (a._hasAllowed = !1, a._render({\n                loading: !0\n            }), twttr.currentUser.personalizationSettings({\n                success: function(b) {\n                    ((((!b.cookie_personalization_prompt_displayed || !b.use_cookie_personalization)) ? a._render({\n                        show_results: !1\n                    }) : (a._render({\n                        show_results: !0,\n                        results_loading: !0\n                    }), a._displayResults())));\n                },\n                error: function() {\n                    twttr.showError(_(\"We can&#8217;t show you tailored suggestions at this time. Please try again later.\")), a.trigger(\"disallow\");\n                }\n            })) : a._render({\n                show_results: !1\n            }))))), this.registerUserActionEvents();\n        }).methods({\n            _render: function(a) {\n                a = ((a || {\n                })), ((a.users && (a.results = new twttr.views.WebPersonalizationResults(a.users)))), (new twttr.views.WebPersonalizationSettings(a)).render(this.$node.empty());\n            },\n            _allow: function() {\n                var a = this;\n                a._render({\n                    show_results: !0,\n                    results_loading: !0\n                }), a._hasAllowed = !0, this._updateSettings(!0, function(b) {\n                    ((b ? (twttr.showError(_(\"We&#8217;re not able to set your preference at this time. Please try again later.\")), a._render({\n                        show_results: !1\n                    })) : a._displayResults()));\n                });\n            },\n            _disallow: function() {\n                var a = this;\n                ((twttr.loggedIn ? twttr.showError(_(\"Thanks. We&#8217;ve set your preference. This will go into effect on other browsers once you log into Twitter on that browser.\")) : twttr.showMessage(_(\"Thanks. We&#8217;ve set your preference.\")))), a._render({\n                    show_results: !1\n                }), this._updateSettings(!1, function(b) {\n                    ((b ? (twttr.showError(_(\"We&#8217;re not able to set your preference at this time. Please try again later.\")), a._render({\n                        show_results: a._hasAllowed,\n                        results_loading: !a._users,\n                        users: a._users\n                    })) : a.trigger(\"disallow\")));\n                });\n            },\n            _displayResults: function() {\n                var a = this;\n                this._render({\n                    show_results: !0,\n                    results_loading: !0\n                }), twttr.API.User.recommendedUsers2({\n                    personalized: !0,\n                    force_bq: !0,\n                    limit: 60,\n                    success: function(b, c) {\n                        var d = b.map(function(a) {\n                            return a.user;\n                        });\n                        a._users = d, a._render({\n                            users: d,\n                            show_results: !0\n                        }), trackClient({\n                            component: \"user_recommendations\",\n                            element: \"initial\",\n                            action: \"results\"\n                        }, {\n                            item_count: ((d.length() || 0))\n                        }), ((d.length() || trackClient({\n                            component: \"user_recommendations\",\n                            element: \"initial\",\n                            action: \"no_results\"\n                        }, {\n                            item_count: 0\n                        })));\n                    },\n                    error: function() {\n                        twttr.showError(_(\"We can&#8217;t show you tailored suggestions at this time. Please try again later.\"));\n                    }\n                });\n            },\n            _updateSettings: function(a, b) {\n                ((twttr.loggedIn ? twttr.currentUser.updatePersonalizationSettings({\n                    use_cookie_personalization: a,\n                    cookie_personalization_prompt_displayed: !0\n                }, {\n                    error: function() {\n                        b(\"error :(\");\n                    },\n                    complete: function() {\n                        b();\n                    }\n                }) : ((a ? b() : $.ajax({\n                    type: \"POST\",\n                    dataType: \"json\",\n                    url: \"/account/turn_off_cookie_personalization.json\",\n                    data: {\n                        authenticity_token: twttr.API.getConfig().postAuthenticityToken\n                    },\n                    complete: function() {\n                        b();\n                    },\n                    error: function() {\n                        b(\"error :(\");\n                    }\n                })))));\n            }\n        }).click({\n            \".js-web-personalization-allow\": function(a, b) {\n                this._allow(), trackClient({\n                    element: \"allow\",\n                    action: \"click\"\n                });\n            },\n            \".js-web-personalization-disallow\": function(a, b) {\n                this._disallow(), trackClient({\n                    element: \"disallow\",\n                    action: \"click\"\n                });\n            },\n            \".js-web-personalization-turnoff\": function(a, b) {\n                this._disallow(), trackClient({\n                    element: \"turnoff\",\n                    action: \"click\"\n                });\n            },\n            \".js-web-personalization-signup .signup-btn\": function(a, b) {\n                trackClient({\n                    section: \"signup_callout\",\n                    component: \"form\",\n                    action: \"signup_click\"\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"photo/turkey\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.turkey\", {\n            tweetBoxId: 1,\n            imageMaxDim: 2048,\n            turkeyCallbacks: {\n            },\n            swfCallbacks: {\n            },\n            swfErrorCallbacks: {\n            },\n            swfPath: \"/phoenix/flash/PhotoHelper.swf\",\n            swfPreloaded: !1,\n            errorTypes: {\n                tooLarge: \"tooLarge\",\n                notImage: \"notImage\",\n                ioError: \"ioError\",\n                maxFiles: \"maxFiles\",\n                dupe: \"duplicate\"\n            },\n            getTweetBoxId: function() {\n                return twttr.turkey.preloadSwf(), ((\"tweetbox_\" + this.tweetBoxId++));\n            },\n            getFileName: function(a) {\n                if (((((a.indexOf(\"/\") == -1)) && ((a.indexOf(\"\\\\\") == -1))))) {\n                    return a;\n                }\n            ;\n            ;\n                var b = a.match(/(.*)[\\/\\\\]([^\\/\\\\]+\\.\\w+)$/);\n                return b[2];\n            },\n            validatePhoto: function(a) {\n                return /(.*)\\.(jpg|jpeg|png|gif)/i.test(a);\n            },\n            getThumbnailOffsets: function(h, a, b) {\n                var c = {\n                };\n                if (((a == h))) {\n                    return {\n                        height: b,\n                        width: b,\n                        left: 0,\n                        JSBNG__top: 0\n                    };\n                }\n            ;\n            ;\n                if (((((h < b)) || ((a < b))))) {\n                    ((((((h < b)) && ((a < b)))) ? (c.JSBNG__top = ((((b - h)) / 2)), c.left = ((((b - a)) / 2))) : ((((a > h)) ? c.JSBNG__top = ((((b - h)) / 2)) : c.left = ((((b - a)) / 2))))));\n                }\n                 else {\n                    if (((a > h))) {\n                        var d = ((((b / h)) * a));\n                        c = {\n                            height: b,\n                            width: d,\n                            left: ((-((d - b)) / 2)),\n                            JSBNG__top: 0\n                        };\n                    }\n                     else if (((h > a))) {\n                        var e = ((((b / a)) * h));\n                        c = {\n                            height: e,\n                            width: b,\n                            JSBNG__top: ((-((e - b)) / 2)),\n                            left: 0\n                        };\n                    }\n                    \n                ;\n                }\n            ;\n            ;\n                return c;\n            },\n            hasFileReader: function() {\n                try {\n                    return twttr.is.object(new JSBNG__FileReader);\n                } catch (a) {\n                    return !1;\n                };\n            ;\n            },\n            resizeImage: function(a, b) {\n                var c = new JSBNG__FileReader;\n                c.JSBNG__onerror = function() {\n                    b(!1);\n                }, c.JSBNG__onload = function(a) {\n                    var c = new JSBNG__Image, d = JSBNG__document.createElement(\"canvas\"), e = d.getContext(\"2d\");\n                    c.JSBNG__onload = function() {\n                        if (((((c.width < twttr.turkey.imageMaxDim)) && ((c.height < twttr.turkey.imageMaxDim))))) {\n                            b(a.target.result.split(\";base64,\")[1]);\n                            return;\n                        }\n                    ;\n                    ;\n                        var f, h;\n                        ((((c.width > c.height)) ? (f = twttr.turkey.imageMaxDim, h = ((((c.height / c.width)) * twttr.turkey.imageMaxDim))) : (h = twttr.turkey.imageMaxDim, f = ((((c.width / c.height)) * twttr.turkey.imageMaxDim))))), d.width = f, d.height = h, e.drawImage(c, 0, 0, f, h);\n                        var g = d.toDataURL(\"image/jpeg\");\n                        b(g.split(\"data:image/jpeg;base64,\")[1]);\n                    }, c.JSBNG__onerror = function() {\n                        b(!1);\n                    }, c.src = a.target.result;\n                }, c.readAsDataURL(a);\n            },\n            hasFlash: function() {\n                try {\n                    return (($.flash.available && $.flash.hasVersion(10)));\n                } catch (a) {\n                    return !1;\n                };\n            ;\n            },\n            shouldUseFlash: function() {\n                return ((((!twttr.turkey.hasFileReader() && twttr.turkey.hasFlash())) && twttr.decider.isAvailable(\"phoenix_turkey_flash\")));\n            },\n            tweetboxMode: function() {\n                return ((twttr.turkey.hasFileReader() ? \"html5\" : ((twttr.turkey.shouldUseFlash() ? \"flash\" : \"html4\"))));\n            },\n            preloadSwf: function() {\n                if (((twttr.turkey.swfPreloaded || !twttr.turkey.shouldUseFlash()))) {\n                    return;\n                }\n            ;\n            ;\n                $node = twttr.turkey.loadSwf($(\"#flash-object-container\"), 0), JSBNG__setTimeout(function() {\n                    (($node && $node.remove()));\n                }, 1000);\n            },\n            loadSwf: function(a, b) {\n                return a.flash({\n                    swf: twttr.turkey.swfPath,\n                    height: 25,\n                    width: 28,\n                    wmode: \"transparent\",\n                    AllowScriptAccess: \"sameDomain\",\n                    flashvars: {\n                        tweetBoxId: b\n                    }\n                }), a.JSBNG__find(\"object\");\n            },\n            shouldShowTurkeyPrompt: function() {\n                return twttr.promptbird.getPromptByFormat([\"modal\",]);\n            },\n            dismissShowTurkeyPrompt: function(a) {\n                var b = {\n                    prompt_id: a\n                }, c = {\n                    success: $.noop\n                };\n                twttr.API.Promptbird.dismissPrompt(b, c), delete twttr.promptbird.cache;\n            },\n            showFirstTimeTurkey: function() {\n                if (twttr.loggedIn) {\n                    var a = this;\n                    using(\"boot/bootstrap_data\", function(b) {\n                        var c = a.shouldShowTurkeyPrompt();\n                        if (((((c && ((c.JSBNG__prompt.format === \"modal\")))) && ((c.JSBNG__prompt.template_name == \"first_time_turkey\"))))) {\n                            a.dismissShowTurkeyPrompt(c.JSBNG__prompt.prompt_id);\n                            var d = 600, e = new twttr.widget.Dialog({\n                                view: \"FirstTimeTurkey\",\n                                modal: !0,\n                                draggable: !1,\n                                css: {\n                                    width: 530\n                                },\n                                positioning: {\n                                    JSBNG__top: ((((twttr.$win.height() <= d)) ? 20 : 150))\n                                }\n                            });\n                            e.$container.JSBNG__find(\".button.ok-thanks\").bind(\"click\", function(a) {\n                                a.preventDefault(), a.stopPropagation(), e.destroy();\n                            }), e.open();\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n            }\n        }), a(twttr.turkey);\n    });\n});\nprovide(\"photo/photo_thumbnails\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.turkey.PhotoThumbnails\").subclassOf(twttr.components.Base).deciderKey(\"turkey\").initializer(function(a, b, c, d) {\n            this.FILE_SIZE_LIMIT = 3145728, this.TIMEOUT_BY_BYTES = 10240, this.defaultTimeoutDelay = 120000, this.timeoutDelay = this.defaultTimeoutDelay, this.maxFiles = 1, this.useIframe = !1, this.enabled = !0, this.files = [], this.$selectedFiles = b, this.$camera = c, this.$swf = this.$camera.JSBNG__find(\".swf\"), this.tweetBoxId = d, this.editor = a, this.$thumbsWrapper = $(\"\\u003Cdiv/\\u003E\").addClass(\"twitter-media-thumbs\"), this.$thumbsWrapper.appendTo(this.editor.$container), this.thumbnailsMessage = _(\"Images will appear as links\"), this.thumbnailMessage = _(\"Image will appear as a link\"), this.$thumbnailMessage = $(\"\\u003Cdiv/\\u003E\").addClass(\"media-thumbnails-message\"), this.$thumbnailMessage.appendTo(this.$thumbsWrapper), this.maxPhotosMessage = _(\"Maximum number of images reached.\"), this.addPhotoMessage = _(\"Add an image\"), this.hasFileReader = twttr.turkey.hasFileReader(), this.shouldUseFlash = twttr.turkey.shouldUseFlash(), this.html4Mode = ((!this.hasFileReader && !this.shouldUseFlash)), this.$editorTextarea = this.editor.$container.JSBNG__find(\"textarea\"), this.textareaPaddingBottom = this.$editorTextarea.css(\"padding-bottom\"), this.createThumbnails(), this.createTipsy();\n        }).methods(twttr.EventProvider).methods({\n            animateShow: function(a) {\n                var b = this;\n                ((this.html4Mode ? (this.$editorTextarea.css(\"padding-bottom\", a), this.editor.$container.addClass(\"has-thumbnails\"), this.$camera.addClass(\"has-turkeys\"), this.$thumbsWrapper.show()) : (this.$camera.addClass(\"has-turkeys\"), this.$editorTextarea.animate({\n                    paddingBottom: a\n                }, 300, \"linear\", function() {\n                    b.editor.$container.addClass(\"has-thumbnails\"), b.$thumbsWrapper.show();\n                }))));\n            },\n            animateHide: function(a, b) {\n                var c = this;\n                this.editor.$container.removeClass(\"has-thumbnails\").addClass(\"closing\"), ((((!this.html4Mode && !b)) ? (this.$camera.removeClass(\"has-turkeys\"), this.$editorTextarea.animate({\n                    paddingBottom: a\n                }, 200, \"linear\", function() {\n                    c.editor.$container.removeClass(\"has-thumbnails\").removeClass(\"closing\");\n                })) : (this.$editorTextarea.css(\"padding-bottom\", a), this.$camera.removeClass(\"has-turkeys\")))), this.$thumbsWrapper.hide();\n            },\n            updateEmptyFeedback: function() {\n                ((((this.inst.$feedback.text() == \"\")) && this.updateFeedback()));\n            },\n            tweet: function(a, b) {\n                var c = this, d = {\n                };\n                ((this.useIframe && (d.iframe_callback = ((\"window.JSBNG__top.twttr.turkey.turkeyCallbacks.\" + this.tweetBoxId)))));\n                switch (a) {\n                  case \"update\":\n                    d.JSBNG__status = b[0], $.extend(d, b[1]);\n                    break;\n                  case \"reply\":\n                    d.JSBNG__status = b[1], d.in_reply_to_status_id = b[0], $.extend(d, b[2]);\n                };\n            ;\n                ((this.useIframe ? this.tweetIframe(d) : this.tweetAjax(d)));\n            },\n            tweetAjax: function(a) {\n                var b = this;\n                a[\"media_data[]\"] = this.files[0].input.val(), a.timeout = $.noop;\n                var c = a.error;\n                a.error = function(a) {\n                    c(a), b.scribeEvent(\"failure\", {\n                        message: \"serverError\"\n                    });\n                };\n                var d = a.success;\n                a.success = function(a) {\n                    d(a, twttr.turkey.tweetboxMode());\n                }, twttr.API.Status.updateWithMedia(a.JSBNG__status, a);\n            },\n            tweetIframe: function(a) {\n                var b = this, c = JSBNG__setTimeout(function() {\n                    twttr.turkey.turkeyCallbacks[b.tweetBoxId] = $.noop, a.error({\n                        error: !0,\n                        response: {\n                            error: \"Tweeting a photo timed out.\"\n                        }\n                    }), a.complete(), b.scribeEvent(\"failure\", {\n                        message: \"timeout\",\n                        duration_ms: b.timeoutDelay\n                    });\n                }, this.timeoutDelay);\n                twttr.turkey.turkeyCallbacks[this.tweetBoxId] = function(d) {\n                    if (d.error) {\n                        var e = {\n                            error: !0,\n                            JSBNG__status: 500,\n                            response: d,\n                            reason: \"An error occured\"\n                        };\n                        a.error(e), a.complete(), JSBNG__clearTimeout(c), b.scribeEvent(\"failure\", {\n                            message: \"serverError\"\n                        });\n                    }\n                     else a.success(d, twttr.turkey.tweetboxMode()), a.complete(), JSBNG__clearTimeout(c);\n                ;\n                ;\n                }, this._submitTweetOptions(a);\n            },\n            _submitTweetOptions: function(a) {\n                this.resetForm();\n                for (var b in a) {\n                    ((((!twttr.is.fn(a[b]) && !twttr.is.object(a[b]))) && $(\"\\u003Cinput type=\\\"hidden\\\" reset=\\\"true\\\"/\\u003E\").attr(\"JSBNG__name\", b).attr(\"value\", a[b]).appendTo(this.$selectedFiles)));\n                ;\n                };\n            ;\n                this.$selectedFiles.submit();\n            },\n            resetForm: function() {\n                this.$selectedFiles.JSBNG__find(\"input[reset='true']\").remove();\n            },\n            enable: function() {\n                ((((this.files.length > 0)) && this.animateShow(this.getPadding(this.files.length)))), this.$camera.show(), this.enabled = !0;\n            },\n            disable: function() {\n                ((((this.files.length > 0)) && this.animateHide(this.getPadding(0)))), this.$camera.hide(), this.enabled = !1;\n            },\n            hasItems: function() {\n                return ((((this.files.length > 0)) && this.enabled));\n            },\n            count: function() {\n                return this.files.length;\n            },\n            hasDuplicate: function(a) {\n                for (var b = 0; ((b < this.files.length)); b++) {\n                    if (((this.files[b].input.value == a.value))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            getPadding: function(a) {\n                return ((((a === 0)) ? this.textareaPaddingBottom : ((this.html4Mode ? ((((12 + ((25 * a)))) + ((2 * ((a - 1)))))) : 60))));\n            },\n            checkFiles: function() {\n                var a = this.files.length;\n                ((((a >= this.maxFiles)) ? (this.$camera.addClass(\"max-turkeys\"), this.editor.trigger(\"heightChange\"), this.destroySwf()) : (this.$camera.removeClass(\"max-turkeys\"), this.editor.trigger(\"heightChange\"), this.createSwf())));\n                var b = this.getPadding(a);\n                ((((a > 0)) ? (this.animateShow(b), ((((a == 1)) ? this.$thumbnailMessage.text(this.thumbnailMessage) : this.$thumbnailMessage.text(this.thumbnailsMessage)))) : this.animateHide(b))), this.trigger(\"photoChanged\");\n            },\n            removeAllFiles: function() {\n                $.each(this.files, function(a, b) {\n                    $(b.input).remove(), b.item.remove();\n                }), this.files = [];\n            },\n            removeFile: function(a) {\n                var b = this;\n                $(a.input).remove(), a.item.remove();\n                var c = $.inArray(a, b.files);\n                ((((c != -1)) && b.files.splice(c, 1))), b.checkFiles(), this.scribeEvent(\"remove\");\n            },\n            hasMaxFiles: function() {\n                return ((this.files.length >= this.maxFiles));\n            },\n            addFileError: function(a, b) {\n                this.killTipsy();\n                if (((a == twttr.turkey.errorTypes.tooLarge))) {\n                    twttr.showError(_(\"The file you selected is greater than the 3MB limit.\"));\n                }\n                 else {\n                    if (((((a == twttr.turkey.errorTypes.notImage)) || ((a == twttr.turkey.errorTypes.ioError))))) {\n                        twttr.showError(_(\"You did not select an image\"));\n                    }\n                     else {\n                        if (((a == twttr.turkey.errorTypes.maxFiles))) {\n                            var c;\n                            ((((this.maxFiles === 1)) ? c = _(\"Can only tweet one image at a time.\") : c = _(\"Cannot tweet more than {{numberOfPhotos}} images at a time.\", {\n                                numberOfPhotos: this.maxFiles\n                            }))), twttr.showError(c);\n                        }\n                         else ((((a == twttr.turkey.errorTypes.dupe)) && twttr.showError(_(\"You already selected this file\"))));\n                    ;\n                    }\n                ;\n                }\n            ;\n            ;\n                this.scribeEvent(\"failure\", {\n                    message: a\n                });\n            },\n            killTipsy: function() {\n                ((((this.$camera.data(\"tipsy\") && this.$camera.data(\"tipsy\").$tip)) && this.$camera.data(\"tipsy\").$tip.hide()));\n            },\n            scribeEvent: function(a, b) {\n                var c = ((b ? b : {\n                }));\n                c.context = \"photo_uploader\", c.event_info = twttr.turkey.tweetboxMode(), trackClient({\n                    component: \"tweetbox\",\n                    action: a\n                }, c);\n            },\n            createThumbnailImage: function(a, b, c) {\n                var d = this, e = $(\"\\u003Cimg/\\u003E\").attr(\"alt\", a);\n                return e.appendTo(c.item), e.bind(\"load\", function() {\n                    var a = twttr.turkey.getThumbnailOffsets(e[0].height, e[0].width, 55);\n                    e.css(a), c.item.JSBNG__find(\".upload-file-close\").bind(\"click\", function(a) {\n                        a.stopPropagation(), a.preventDefault(), d.removeFile(c);\n                    }), c.item[((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"))]({\n                        opacity: 100\n                    }, 200, ((Modernizr.csstransitions ? \"default\" : \"linear\"))), d.checkFiles();\n                }), e.attr(\"src\", b), e;\n            },\n            createThumbnail: function() {\n                var a;\n                return ((this.html4Mode ? a = $(\"\\u003Cdiv class=\\\"upload-file upload-filename\\\"\\u003E        \\u003Cspan class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003Ca href=\\\"#\\\" class=\\\"thumbnail-close upload-file-close\\\"\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/a\\u003E        \\u003C/div\\u003E\") : a = $(\"\\u003Cdiv class=\\\"upload-file upload-thumbnail\\\"\\u003E        \\u003Ca href=\\\"#\\\" class=\\\"thumbnail-close upload-file-close\\\"\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/a\\u003E        \\u003C/div\\u003E\").css({\n                    opacity: 0\n                }))), a.appendTo(this.$thumbs), a;\n            },\n            addFileItem: function(a, b) {\n                var c = {\n                    input: a,\n                    item: b\n                };\n                return this.files.push(c), this.$selectedFiles.append(a), this.resetAddPhoto(), this.scribeEvent(\"add\"), this.checkFiles(), c;\n            },\n            addFileData: function(a, b, c) {\n                this.setTimeoutBySize(a.length);\n                var d = $(((((\"\\u003Cinput type=\\\"hidden\\\" maxlength=\\\"\" + this.FILE_SIZE_LIMIT)) + \"\\\" name=\\\"media_data[]\\\"/\\u003E\")));\n                d.val(a);\n                var e = this.createThumbnail(), f = this.addFileItem(d, e), g = this.createThumbnailImage(c, ((\"data:image/jpeg;base64,\" + b)), f);\n                this.killTipsy();\n            },\n            addFileInput: function(a) {\n                var b = this, c = this.createThumbnail(), d = this.addFileItem(a, c);\n                if (((this.hasFileReader && a.files))) {\n                    var e = a.files[0];\n                    this.setTimeoutBySize(e.size);\n                    var f = new JSBNG__FileReader;\n                    f.JSBNG__onloadend = function(c) {\n                        var e = c.target.result, f = b.createThumbnailImage(twttr.turkey.getFileName(a.value), e, d);\n                    }, f.readAsDataURL(e);\n                }\n                 else twttr.helpers.ellipsify(c.JSBNG__find(\".filename\").text(twttr.turkey.getFileName(a.value))), c.JSBNG__find(\".upload-file-close\").bind(\"click\", function(a) {\n                    a.stopPropagation(), a.preventDefault(), b.removeFile(d);\n                }), ((this.inst && this.inst.setFeedback(this.tweetboxFeedback)));\n            ;\n            ;\n            },\n            addFile: function(a) {\n                var b = this;\n                if (this.hasMaxFiles()) {\n                    this.addFileError(twttr.turkey.errorTypes.maxFiles);\n                    return;\n                }\n            ;\n            ;\n                if (!twttr.turkey.validatePhoto(a.value)) {\n                    this.addFileError(twttr.turkey.errorTypes.notImage);\n                    return;\n                }\n            ;\n            ;\n                if (this.hasDuplicate(a)) {\n                    this.addFileError(twttr.turkey.errorTypes.dupe);\n                    return;\n                }\n            ;\n            ;\n                var c;\n                ((((a.files && a.files[0])) && (c = a.files[0])));\n                var d = function(c) {\n                    ((c ? b.addFileData(c, c, twttr.turkey.getFileName(a.value)) : b.addFileError(twttr.turkey.errorTypes.notImage)));\n                };\n                if (c) {\n                    if (((!twttr.decider.isAvailable(\"phoenix_turkey_html5_resize\") || !this.hasFileReader))) {\n                        if (!this.checkFileSize(c)) {\n                            this.addFileError(twttr.turkey.errorTypes.tooLarge);\n                            return;\n                        }\n                    ;\n                    ;\n                        this.useIframe = !0, this.addFileInput(a);\n                    }\n                     else twttr.turkey.resizeImage(c, d);\n                ;\n                }\n                 else {\n                    this.useIframe = !0, this.addFileInput(a);\n                }\n            ;\n            ;\n                this.killTipsy();\n            },\n            checkFileSize: function(a) {\n                return ((!twttr.is.def(a.size) || ((a.size <= this.FILE_SIZE_LIMIT))));\n            },\n            getTimeoutBySize: function(a) {\n                var b = Math.ceil(((((a / this.TIMEOUT_BY_BYTES)) * 1000)));\n                return ((((b < this.defaultTimeoutDelay)) ? this.defaultTimeoutDelay : b));\n            },\n            setTimeoutBySize: function(a) {\n                this.timeoutDelay = this.getTimeoutBySize(a);\n            },\n            resetPhotoPost: function() {\n                this.useIframe = !1, this.$selectedFiles.empty();\n                var a = twttr.API.getConfig().postAuthenticityToken;\n                $(((((\"\\u003Cinput type=\\\"hidden\\\" name=\\\"post_authenticity_token\\\" value=\\\"\" + a)) + \"\\\"/\\u003E\\\"\"))).appendTo(this.$selectedFiles), $(\"\\u003Cinput type=\\\"hidden\\\" name=\\\"include_entities\\\" value=\\\"true\\\"/\\u003E\").appendTo(this.$selectedFiles);\n            },\n            reset: function() {\n                this.removeAllFiles(), this.$camera.removeClass(\"max-turkeys\"), this.editor.trigger(\"heightChange\"), this.animateHide(this.getPadding(0), !0), this.timeoutDelay = this.defaultTimeoutDelay;\n            },\n            createThumbnails: function() {\n                var a = this;\n                this.$thumbs = $(\"\\u003Cdiv class='media-thumbnails' /\\u003E\"), this.$thumbs.prependTo(this.$thumbsWrapper), ((this.html4Mode && this.editor.$container.addClass(\"html4\"))), this.resetPhotoPost(), this.resetAddPhoto(), this.createSwf();\n            },\n            destroySwf: function() {\n                if (!this.shouldUseFlash) {\n                    return;\n                }\n            ;\n            ;\n                this.$swf.empty();\n            },\n            createSwf: function() {\n                if (!this.shouldUseFlash) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                JSBNG__setTimeout(function() {\n                    twttr.turkey.swfErrorCallbacks[a.tweetBoxId] = twttr.bind(a, a.addFileError), twttr.turkey.swfCallbacks[a.tweetBoxId] = twttr.bind(a, a.addFileData), twttr.turkey.loadSwf(a.$swf, a.tweetBoxId);\n                }, 500);\n            },\n            createTipsy: function() {\n                var a = this;\n                this.$camera.tipsy({\n                    gravity: \"nw\",\n                    fade: !0,\n                    opacity: 1384725,\n                    title: twttr.bind(this, this.getTipsyTitle)\n                }), this.$camera.click(function() {\n                    JSBNG__setTimeout(function() {\n                        ((a.$camera.data(\"tipsy\") && a.$camera.data(\"tipsy\").hide()));\n                    }, 750);\n                });\n            },\n            getTipsyTitle: function() {\n                return ((((this.files.length >= this.maxFiles)) ? \"\" : this.addPhotoMessage));\n            },\n            resetAddPhoto: function() {\n                var a = this;\n                this.$camera.JSBNG__find(\"input[type=\\\"file\\\"]\").remove();\n                var b = $(\"\\u003Cinput type=\\\"file\\\" class=\\\"turkey-file-input\\\" name=\\\"media[]\\\"\\u003E\\u003C/input\\u003E\");\n                this.$camera.append(b), b.bind(\"change\", function(b) {\n                    a.addFile(b.target);\n                }), this.$camera.bind(\"click\", function() {\n                    a.scribeEvent(\"click\");\n                });\n            },\n            remove: function() {\n                this.$thumbsWrapper.remove();\n            }\n        }), a(twttr.turkey.PhotoThumbnails);\n    });\n});\nprovide(\"images\", function(a) {\n    using().as(function(b) {\n        twttr.images = {\n            renderProviderMedia: function(a, b) {\n                var a = a.concat(), c = twttr.images.generateDivs($.map(a, function(a) {\n                    return a.url;\n                }), b);\n                this.bindLoadImageHandler(c, b.componentName);\n                var d = function(a, b) {\n                    JSBNG__setTimeout(function() {\n                        a.trigger(\"failedToResolve\", [b,]);\n                    }, 0);\n                };\n                return $.each(a, function(a, e) {\n                    var f = $(c[a]);\n                    e.mediaType.getImageURL(b.size, function(a) {\n                        ((a ? twttr.images.scaleImageIntoDiv(f, a, b) : d(f, \"getImageUrl did not return a resolvedURL\")));\n                    }, b.dimension);\n                }), c;\n            },\n            renderMediaUrls: function(a, b, c) {\n                var d = twttr.images.generateDivs(a, b);\n                this.bindLoadImageHandler(d, b.componentName);\n                var e = {\n                    success: function(a, c) {\n                        twttr.images.scaleImageIntoDiv(a, c, b);\n                    },\n                    error: function(a, b) {\n                        JSBNG__setTimeout(function() {\n                            a.trigger(\"failedToResolve\", [b,]);\n                        }, 0);\n                    }\n                };\n                return twttr.images.resolveDataUrls(d, b, e, c), d;\n            },\n            animateImageFadeIn: function(a, b, c) {\n                var d = ((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"));\n                a.css(\"opacity\", 0), a[d]({\n                    opacity: ((c || 1))\n                }, ((b || 500)), \"swing\");\n            },\n            renderMediaUrl: function(a, b, c) {\n                return this.renderMediaUrls([a,], b, c);\n            },\n            generateDivs: function(a, b) {\n                var c = $(), d = ((b.thumbnailViewClass || twttr.views.Thumbnail));\n                return $.each(a, function(a, e) {\n                    var f = $((new d({\n                        url: e,\n                        width: b.width,\n                        height: b.height,\n                        lineHeight: ((b.height + \"px\"))\n                    })).html());\n                    c = c.add(f);\n                }), c;\n            },\n            bindLoadImageHandler: function(a, b) {\n                var c = this;\n                a.bind(\"loadImage\", function() {\n                    var a = $(this);\n                    if (((a.data(\"loaded\") === !0))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = a.data(\"resolvedUrl\"), e = a.data(\"childImg\");\n                    if (((d && e))) {\n                        if (twttr.decider.isAvailable(\"profile_image_latency\")) {\n                            var f = twttr.media.matchInstance(a.data(\"url\")), g = new twttr.Profiler(c.createProfilingDescription(f.partnerName, d, b));\n                            $(e[0]).load(function() {\n                                g.done();\n                            });\n                        }\n                    ;\n                    ;\n                        e[0].src = d, a.data(\"loaded\", !0);\n                    }\n                     else a.data(\"loadWhenResolved\", !0);\n                ;\n                ;\n                });\n            },\n            createProfilingDescription: function(a, b, c) {\n                return c = ((c ? c : \"\")), [a.toLowerCase(),JSON.stringify(b),c.toLowerCase(),].join(\".\");\n            },\n            resolveDataUrls: function(a, b, c, d) {\n                a.each(function(a, e) {\n                    var f = $(e), g = ((f.attr(\"data-url\") || e.href));\n                    twttr.media.resolveImageUrl(g, b.size, {\n                        success: function(a) {\n                            ((c.success && c.success(f, a)));\n                        },\n                        error: function(a) {\n                            ((c.error && c.error(f, a)));\n                        },\n                        tweet: d,\n                        filter: b.filter\n                    }, b.dimension);\n                });\n            },\n            scaleImageIntoDiv: function(a, b, c) {\n                b = b.replace(/([^:])\\/\\//g, \"$1/\");\n                var d = $(\"\\u003Cimg/\\u003E\").addClass(\"scaled-image\");\n                d.bind(\"load\", function() {\n                    var b = twttr.images.calculateScaleDimensions({\n                        containerWidth: c.width,\n                        containerHeight: c.height,\n                        itemWidth: this.width,\n                        itemHeight: this.height,\n                        scalingMode: c.scalingMode\n                    });\n                    d.attr({\n                        origHeight: this.height,\n                        origWidth: this.width\n                    }), ((((c.divMode === \"snap\")) ? a.css(b).css(\"line-height\", ((b.height + \"px\"))) : (d.css(b), d.css({\n                        JSBNG__top: Math.floor(((((c.height / 2)) - ((b.height / 2))))),\n                        left: Math.floor(((((c.width / 2)) - ((b.width / 2)))))\n                    })))), JSBNG__setTimeout(function() {\n                        d.appendTo(a.JSBNG__find(\"div.thumbnail-wrapper\")), twttr.images.addPrivacyCover(d), a.trigger(\"loaded\");\n                    }, 0);\n                }).bind(\"error\", function() {\n                    a.trigger(\"failedToLoad\");\n                }), a.data(\"resolvedUrl\", b).data(\"childImg\", d), ((((!c.delayLoading || a.data(\"loadWhenResolved\"))) && a.trigger(\"loadImage\")));\n            },\n            resizeImageInDiv: function(a, b) {\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                var c = a.JSBNG__find(\"img.scaled-image\");\n                if (((c.length == 0))) {\n                    return;\n                }\n            ;\n            ;\n                var d = twttr.images.calculateScaleDimensions({\n                    containerWidth: b.width,\n                    containerHeight: b.height,\n                    itemWidth: parseInt(c.attr(\"origWidth\"), 10),\n                    itemHeight: parseInt(c.attr(\"origHeight\"), 10),\n                    scalingMode: b.scalingMode\n                });\n                c.attr(d).trigger(\"resize\"), ((((b.divMode === \"snap\")) ? a.css(d).css(\"line-height\", ((d.height + \"px\"))) : c.css({\n                    JSBNG__top: Math.floor(((((b.height / 2)) - ((d.height / 2))))),\n                    left: Math.floor(((((b.width / 2)) - ((d.width / 2)))))\n                })));\n            },\n            calculateScaleDimensions: function(a) {\n                function b() {\n                    return {\n                        width: i,\n                        height: g\n                    };\n                };\n            ;\n                function c() {\n                    return {\n                        width: f,\n                        height: ((g / k))\n                    };\n                };\n            ;\n                function d() {\n                    return {\n                        width: ((i / l)),\n                        height: e\n                    };\n                };\n            ;\n                var e = a.containerHeight, f = a.containerWidth, g = a.itemHeight, i = a.itemWidth, j = a.scalingMode, k = ((i / f)), l = ((g / e));\n                switch (j) {\n                  case \"fit\":\n                    return ((((((k < 1)) && ((l < 1)))) ? b() : ((((k > l)) ? c() : d()))));\n                  case \"trim\":\n                    return ((((((k < 1)) || ((l < 1)))) ? b() : ((((k > l)) ? d() : c()))));\n                  default:\n                    return {\n                        width: f,\n                        height: e\n                    };\n                };\n            ;\n            },\n            addPrivacyCover: function(a, b) {\n                if (((((a.length <= 0)) || !twttr.decider.isAvailable(\"prevent_right_click_on_images\")))) {\n                    return;\n                }\n            ;\n            ;\n                var c = function() {\n                    var b = a[0], d = ((d || a.parent()));\n                    d.JSBNG__find(\".cover\").remove(), d.addClass(\"has-cover\").height(b.height).width(b.width), d.closest(\".media-instance-container\").width(b.width), $(\"\\u003Cdiv/\\u003E\", {\n                        class: \"cover\",\n                        height: b.height,\n                        width: b.width\n                    }).appendTo(d), a.bind(\"resize\", c);\n                }, d = 0, e = function() {\n                    ((((a[0].complete === !0)) ? JSBNG__setTimeout(c, 0) : (a.bind(\"load\", function() {\n                        JSBNG__setTimeout(c, 0);\n                    }), ((((d < 10)) && JSBNG__setTimeout(e, 500))), d++)));\n                };\n                e();\n            },\n            SCRIBABLE_PROVIDERS: [\"dailybooth\",\"flickr\",\"instagram\",\"lockerz\",\"photobucket\",\"twimg\",\"twitpic\",\"yfrog\",\"youtube\",],\n            scribeImageFailure: function(a, b, c) {\n                if (!twttr.decider.isAvailable(\"scribe_image_failures\")) {\n                    return;\n                }\n            ;\n            ;\n                var d = twttr.media.match(c);\n                if (((d && d.partnerName))) {\n                    var e = d.partnerName.toLowerCase();\n                    (($.inArray(e, this.SCRIBABLE_PROVIDERS) && a.scribe({\n                        component: b,\n                        action: \"third_party_error\"\n                    }, {\n                        url: c,\n                        event_info: e\n                    })));\n                }\n            ;\n            ;\n            }\n        }, a(twttr.images);\n    });\n});\nprovide(\"components/ContactImportLauncher\", function(a) {\n    using(\"externalOauthPopup\").as(function(b) {\n        twttr.klass(\"twttr.components.ContactImportLauncher\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            this.bind(\"addedToPage\", function() {\n                if (!twttr.decider.isAvailable(\"contact_import\")) {\n                    return;\n                }\n            ;\n            ;\n                twttr.API.AddressBook.contactsServices({\n                    success: function(c) {\n                        if (((!c || !c.length))) {\n                            b.trigger(\"notRendered\", \"no_items\");\n                            return;\n                        }\n                    ;\n                    ;\n                        (new twttr.views.DashboardContactImport({\n                            services: c,\n                            compact: a\n                        })).render(b.$node, \"append\"), b.$node.delegate(\".service-link\", \"click\", function(a) {\n                            b.launchService($(this));\n                        }), b.trigger(\"servicesLoaded\");\n                    },\n                    error: function() {\n                        b.trigger(\"notRendered\", \"darkmoded\");\n                    }\n                });\n            });\n        }).methods({\n            launchService: function(a) {\n                var c = a.attr(\"data-url\"), d = a.attr(\"data-width\"), e = a.attr(\"data-height\");\n                if (c) {\n                    ((((a.attr(\"data-popup\") == \"true\")) ? b.externalOauthPopup({\n                        url: c,\n                        width: d,\n                        height: e,\n                        callbackUrl: twttr.router.whoToFollowImportMatchesPath()\n                    }) : window.open(c, \"_blank\").JSBNG__focus()));\n                    var f = a.JSBNG__find(\"strong.service-name\").attr(\"data-service-id\");\n                    trackClient({\n                        section: \"dashboard\",\n                        component: \"contact_import_launcher\",\n                        action: \"launch_service\"\n                    }, {\n                        event_info: f,\n                        context: \"import\"\n                    });\n                }\n            ;\n            ;\n            }\n        }), a(twttr.components.ContactImportLauncher);\n    });\n});\nprovide(\"streams/ListStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.ListStream\", function(a, b) {\n            this._cursor = -1, twttr.streams.Stream.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent, ((((twttr.loggedIn && !twttr.isT1)) && this._registerUpdateStreamEvent(twttr.API.List, \"follow unfollow\", function(a, b) {\n                return b.sync(\"following\", ((a.type === \"follow\"))), b;\n            })));\n        }).subclassOf(twttr.streams.Stream).methods({\n            itemViewClass: \"StreamList\",\n            streamItemType: \"list\",\n            streamItemId: function(a) {\n                return a.uri;\n            },\n            rerenderItem: function(a, b) {\n                var c = this.selectedItem(a);\n                ((((c.length === 0)) && (c = this.$find(((((\"div.js-list[data-list-id='\" + a)) + \"']\"))).closest(\".js-stream-item\")))), c.replaceWith(this._renderItemHtml(b));\n            },\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            _fetchItems: function(a) {\n                var b = this;\n                if (((!twttr.decider.isAvailable(\"list_streams\") || ((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))))) {\n                    a(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                twttr.API.User.JSBNG__find(this.screenName)[this.API_METHOD]({\n                    cursor: this._cursor,\n                    success: function(c, d) {\n                        b._cursor = d.response.next_cursor, b.push(c.array), a(b, twttr.streams.SUCCESS), ((b._cursor || b.reachedTheEnd()));\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                    },\n                    timeout: function(a) {\n                        a.retry();\n                    },\n                    cancel: function() {\n                        a(b, twttr.streams.TIMEOUT);\n                    }\n                });\n            },\n            _scribeResults: function(a, b, c) {\n                this._scribeEmptyResults(a, b, c);\n                if (b.length) {\n                    var d = twttr.map(b, function(a) {\n                        return a.fullName;\n                    });\n                    this.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"results\"\n                    }, {\n                        item_names: d,\n                        item_count: d.length,\n                        event_value: d.length,\n                        referring_event: a\n                    });\n                }\n            ;\n            ;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"streams/OwnListsStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.OwnLists\", function(a, b) {\n            twttr.streams.ListStream.apply(this, arguments), this._registerEvents(a);\n        }).subclassOf(twttr.streams.ListStream).methods({\n            API_METHOD: \"lists\",\n            _setTitle: function(a) {\n                ((this.stream_user_is_current_user() ? a(_(\"Your lists\")) : a(_(\"{{username}}'s lists\", {\n                    username: this.screenName\n                }))));\n            },\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You haven't created any lists yet.\") : _(\"@{{screen_name}} hasn't created any lists yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c) {\n                        return ((twttr.helpers.isCurrentUser(a.screenName) ? c : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.List, \"create\", b), this._registerRemoveFromStreamEvent(twttr.API.List, \"delete\", b, \"uri\"), this._registerUpdateStreamEvent(twttr.API.List, \"update\", b);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"list_stream_own_lists\"\n        });\n        a(c);\n    });\n});\nprovide(\"streams/SubscriptionsStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.Subscriptions\", function(a, b) {\n            twttr.streams.ListStream.apply(this, arguments), this.scribbler = twttr.Scribbler.clientEvent, this._registerEvents(a);\n        }).subclassOf(twttr.streams.ListStream).methods({\n            API_METHOD: \"subscriptions\",\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You aren't following any lists yet.\") : _(\"@{{screen_name}} isn't following any lists yet.\", {\n                    screen_name: this.screenName\n                })));\n            },\n            _registerEvents: function(a) {\n                if (twttr.loggedIn) {\n                    var b = function(b, c) {\n                        return ((twttr.helpers.isCurrentUser(a.screenName) ? c : null));\n                    };\n                    this._registerAddToStreamEvent(twttr.API.List, \"follow\", b), this._registerRemoveFromStreamEvent(twttr.API.List, \"unfollow\", b, \"uri\"), this._registerUpdateStreamEvent(twttr.API.List, \"update\", b);\n                }\n            ;\n            ;\n            }\n        }).statics({\n            _deciderKey: \"list_stream_subscriptions\"\n        });\n        ((twttr.isT1 ? c.methods({\n            _setTitle: function(a) {\n                a(_(\"Lists\"));\n            },\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.ListsStreamViewToggler(!1));\n            },\n            _setHeaderButton: function(a, b) {\n                a(new twttr.views.CreateListButton);\n            }\n        }) : c.methods({\n            _setTitle: function(a) {\n                a(_(\"Lists {{username}} follows\", {\n                    username: this.screenName\n                }));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"streams/MembershipsStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.Memberships\", function(a, b) {\n            twttr.streams.ListStream.apply(this, arguments);\n        }).subclassOf(twttr.streams.ListStream).methods({\n            API_METHOD: \"memberships\",\n            _getEmptyStreamHtml: function() {\n                return ((this.stream_user_is_current_user() ? _(\"You aren't listed yet.\") : _(\"@{{screen_name}} isn't listed yet.\", {\n                    screen_name: this.screenName\n                })));\n            }\n        }).statics({\n            _deciderKey: \"list_stream_memberships\"\n        });\n        ((twttr.isT1 ? c.methods({\n            _setTitle: function(a) {\n                a(_(\"Lists\"));\n            },\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.ListsStreamViewToggler(!0));\n            },\n            _setHeaderButton: function(a, b) {\n                ((twttr.helpers.isCurrentUser(b.screenName) && a(new twttr.views.CreateListButton)));\n            }\n        }) : c.methods({\n            _setTitle: function(a) {\n                a(_(\"Lists following {{username}}\", {\n                    username: this.screenName\n                }));\n            }\n        }))), a(c);\n    });\n});\nprovide(\"streams/MembershipsStreamUser\", function(a) {\n    using(\"_\", \"streams/MembershipsStream\").as(function(b, _) {\n        var c = twttr.stream(\"twttr.streams.MembershipsUser\", function(a, b) {\n            twttr.streams.Memberships.apply(this, arguments);\n        }).subclassOf(twttr.streams.Memberships).methods({\n            _setViewToggler: function(a, b) {\n                a(new twttr.views.ProfileListsStreamViewToggler(!1, {\n                    screen_name: b.screenName\n                }));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"multiGlobals/trackSession\", function(a) {\n    var b = {\n    };\n    b._maxLength = 1000, b._cookieName = \"session_buffer\", b._defaultJson = \"[]\", b._getStorage = function() {\n        var a = (($.cookie(b._cookieName) || b._defaultJson)), c;\n        try {\n            c = JSON.parse(a);\n        } catch (d) {\n            c = JSON.parse(b._defaultJson);\n        };\n    ;\n        return c;\n    }, b._setStorage = function(a) {\n        var c = JSON.stringify(a);\n        if (((c.length > b._maxLength))) {\n            var d = Math.floor(((a.length / 2)));\n            a.splice(d, a.length), c = JSON.stringify(a);\n        }\n    ;\n    ;\n        $.cookie(b._cookieName, c);\n    }, b._setSession = function(a) {\n        var c = b._getStorage();\n        c = $.grep(c, function(b) {\n            return ((a.key !== b.key));\n        }), c.unshift(a), b._setStorage(c);\n    }, b._extractSessions = function(a) {\n        var c = b._getStorage(), d = [];\n        return c = $.grep(c, function(b) {\n            return (((($.inArray(b.key, a) > -1)) ? (d.unshift(b), !1) : !0));\n        }), b._setStorage(c), d;\n    }, b.start = function(a, c) {\n        c = ((c || {\n        })), b._setSession({\n            key: a,\n            data: c\n        });\n        var d = {\n            component: a,\n            action: \"session_start\"\n        };\n        trackClient(d, c);\n    }, b.JSBNG__stop = function(a, c) {\n        ((((\"string\" == typeof a)) && (a = [a,])));\n        var d = b._extractSessions(a);\n        $.each(d, function(a, b) {\n            var d = {\n                component: b.key,\n                action: \"session_stop\"\n            };\n            trackClient(d, b.data), ((c && c(b)));\n        });\n    }, window.startTrackSession = b.start, window.stopTrackSession = b.JSBNG__stop, a(b);\n});\nprovide(\"streams/SuggestionCategoriesStream\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"mixins/SuggestionCategoriesStreamT1\" : \"\")), \"mixins/discoveryHelper\").as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.SuggestionCategoriesStream\", function(a, b) {\n            a.pathRoot = ((a.pathRoot || \"whoToFollow\")), twttr.streams.Stream.apply(this, arguments), this.$node.addClass(\"suggestion-categories\");\n            var c = this;\n            this.$node.delegate(\"div[data-item-type=suggestion_category]\", \"click\", function(a) {\n                var b = $(this).attr(\"data-item-id\"), d = {\n                };\n                return d[b] = {\n                    item_position: $(\"div.js-stream-manager-container div.js-stream-item\").index($(a.target).closest(\".js-stream-item\"))\n                }, ((b && (trackClient({\n                    component: \"suggestion_category\",\n                    action: \"click\"\n                }, {\n                    step: \"interests\",\n                    query: b,\n                    item_details: d\n                }), c.routePageTo(c.params.pathRoot, \"InterestsCategory\", {\n                    category: b\n                })))), !1;\n            });\n        }).subclassOf(twttr.streams.Stream).statics({\n            cacheCategories: function(a) {\n                this.CATEGORIES = a, this.CATEGORY_MAP = this.buildCategoryMap(a);\n            },\n            buildCategoryMap: function(a) {\n                return a.reduce({\n                }, function(a, b) {\n                    return a[b.slug] = b, a;\n                });\n            },\n            filterTopTweetsCategories: function(a) {\n                var b = this.buildCategoryMap(a);\n                return a.filter(function(a) {\n                    if (a.slug.match(/^(.+)[_-]top-tweets$/i)) {\n                        var c = b[RegExp.$1];\n                        return ((c && (c.topTweetsCategory = a))), !1;\n                    }\n                ;\n                ;\n                    return !0;\n                });\n            }\n        }).methods({\n            itemViewClass: \"StreamSuggestionCategory\",\n            streamItemType: \"suggestion_category\",\n            sampleSize: \"\",\n            streamItemId: function(a) {\n                return a.slug;\n            },\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            addTipsies: function() {\n            \n            },\n            _fetchItems: function(a) {\n                var b = this;\n                if (!twttr.decider.isAvailable(\"suggestion_categories_streams\")) {\n                    a(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var c = {\n                    sample_size: this.sampleSize,\n                    samples: !0,\n                    success: function(c) {\n                        c = b.constructor.filterTopTweetsCategories(c), b.constructor.cacheCategories(c);\n                        var d = c.map(function(a) {\n                            var c, d;\n                            return ((((((a.topTweetsCategory && a.topTweetsCategory.sample)) && (d = a.topTweetsCategory.sample.shift()))) && (c = d.id))), a.clone({\n                                category_link: b.pagePathFor(b.params.pathRoot, \"InterestsCategory\", {\n                                    category: a.slug\n                                }),\n                                category_top_tweets_user_id: c,\n                                category_top_tweets_is_current_user: ((!!twttr.currentUser && ((twttr.currentUser.id == c)))),\n                                following_category_top_tweets: ((a.topTweetsCategory ? a.topTweetsCategory.followingTopTweets : null))\n                            });\n                        });\n                        b.push(d.array), a(b, twttr.streams.SUCCESS), b.addTipsies(), b.reachedTheEnd();\n                        var e = c.map(function(a, b) {\n                            return a.JSBNG__name;\n                        });\n                        b.scribbler.scribe({\n                            component: \"stream\",\n                            action: \"results\"\n                        }, {\n                            item_names: e,\n                            item_count: e.length()\n                        });\n                    },\n                    error: function() {\n                        a(b, twttr.streams.ERROR);\n                    }\n                };\n                ((b.defaultOpts && (c = twttr.merge(b.defaultOpts, c)))), ((b.params.lang && (c.lang = b.params.lang))), ((b.params.country && (c.country = b.params.country))), ((b.params.city && (c.city = b.params.city))), c.top_tweets = !0, twttr.API.SuggestionCategory.getAll(c);\n            },\n            _setTitle: function(a) {\n                ((((this.params.title !== undefined)) ? a(this.params.title) : a(_(\"Select the topics you are interested in. Find a few people you want to hear from, then follow them.\"))));\n            },\n            _getHeaderComponent: function() {\n                return ((this.params.noHeaderFooter ? null : new twttr.components.SuggestionCategoriesList(this.constructor.CATEGORIES, this.params.pathRoot)));\n            },\n            _getStreamEndComponent: function() {\n                return this._getHeaderComponent();\n            }\n        }).mixin(twttr.mixins.discoveryHelper);\n        ((c && d.mixin(c))), a(d);\n    });\n});\nprovide(\"streams/SuggestionCategoryMembersStream\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"mixins/SuggestionCategoryMembersStreamT1\" : \"\"))).as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.SuggestionCategoryMembersStream\", function(a, b) {\n            var c = this;\n            a.pathRoot = ((a.pathRoot || \"whoToFollow\")), twttr.streams.UserStream.apply(this, arguments), this.category = a.suggestionCategory, this.ignoreScribeItemPosition = !1;\n        }).subclassOf(twttr.streams.UserStream).statics({\n            _deciderKey: \"suggestion_categories_streams\"\n        }).methods({\n            update: function(a) {\n                ((this.params.lang && (a.lang = this.params.lang))), ((this.params.country && (a.country = this.params.country))), ((this.params.city && (a.city = this.params.city))), ((this.params.zipcode && (a.zipcode = this.params.zipcode))), this.category.members(a);\n            },\n            isCursorPagination: function() {\n                return !1;\n            },\n            _setTitle: function(a) {\n                var b = {\n                    category: this.category.JSBNG__name,\n                    size: this.category.size\n                };\n                a(((this.params.title || _(\"View {{category}} ({{size}})\", b))));\n            },\n            _getHeaderComponent: function() {\n                return ((this.params.noHeaderFooter ? null : new twttr.components.SuggestionCategoriesList(twttr.streams.SuggestionCategoriesStream.CATEGORIES, this.params.pathRoot, this.category.slug)));\n            },\n            _getStreamEndComponent: function() {\n                return ((this.params.noHeaderFooter ? twttr.streams.SuggestionCategoryMembersStream.uber._getStreamEndComponent.call(this) : this._getHeaderComponent()));\n            }\n        });\n        ((c && d.mixin(c))), a(d);\n    });\n});\nprovide(\"streams/SuggestionCategoriesDashboardStream\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.streams.SuggestionCategoriesDashboardStream\", function(a, b) {\n            a = ((a || {\n            })), twttr.streams.SuggestionCategoriesStream.call(this, a, b);\n        }).subclassOf(twttr.streams.SuggestionCategoriesStream).methods({\n            itemViewClass: ((twttr.isT1 ? \"DashboardStreamInterestCategory\" : \"StreamSuggestionCategory\")),\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            addTipsies: function() {\n            \n            }\n        }), a();\n    });\n});\nprovide(\"streams/SuggestionCategoryMembersDashboardStream\", function(a) {\n    using(\"streams/SuggestionCategoryMembersStream\").as(function(b) {\n        twttr.klass(\"twttr.streams.SuggestionCategoryMembersDashboardStream\", function(a, c) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", b.streams.SuggestionCategoryMembersStream.call(this, a, c);\n        }).subclassOf(b.streams.SuggestionCategoryMembersStream).methods({\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), a(twttr.streams.SuggestionCategoryMembersDashboardStream);\n    });\n});\nprovide(\"streams/SuggestionLifelineMembersStream\", function(a) {\n    using(\"streams/SuggestionCategoryMembersStream\").as(function(b) {\n        twttr.klass(\"twttr.streams.SuggestionLifelineMembersStream\", function(a, c) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", b.streams.SuggestionCategoryMembersStream.call(this, a, c), this._registerEvents();\n        }).subclassOf(b.streams.SuggestionCategoryMembersStream).statics({\n            categoryObj: new twttr.anywhere.api.models.SuggestionCategory({\n                locale_type: \"\",\n                JSBNG__name: \"lifeline\",\n                size: 24,\n                slug: \"lifeline\"\n            })\n        }).methods({\n            _setHeader: function(a, b) {\n                b.query = b.zipcode, b.placeholder = _(\"Enter your ZIP Code\"), b.header_help = ((((_(\"Enter your ZIP Code and search Lifeline accounts.\") + \"\\u003Cbr\\u003E\")) + _(\"You can receive tweet mobile notifications to your device. See \\u003Ca href=\\\"https://support.twitter.com/articles/20169887\\\" target=\\\"_blank\\\"\\u003Ethis\\u003C/a\\u003E for more details.\")));\n                var c = new twttr.components.t1.PeopleSearchStreamHeader(twttr.router.whoToFollowLifelineSearchPath, b);\n                a(c.$node);\n            },\n            _setTitle: function(a) {\n                a(_(\"Lifeline\"));\n            },\n            _setViewToggler: function(a) {\n                a(\"\");\n            },\n            setStreamManager: function(a) {\n                this._streamManager = a;\n            },\n            _registerEvents: function() {\n                var a = this;\n                this.$node.delegate(\".js-action-follow, .js-action-follow-request\", \"click\", function(b) {\n                    var c = $(this), d = parseInt(c.closest(\".js-actionable-user\").attr(\"data-user-id\"), 10), e = ((c.closest(\".js-actionable-user\").attr(\"data-device-notification\") === \"true\"));\n                    return ((twttr.cache.local.shownDeviceFollowDialog || (twttr.cache.local.shownDeviceFollowDialog = !0, trackClient({\n                        component: \"device_follow_dialog\",\n                        action: \"impression\"\n                    }), (new twttr.widget.DeviceFollowDialog({\n                        JSBNG__onclose: twttr.bind(a, a.deviceFollow, [d,e,])\n                    })).show()))), !0;\n                });\n            },\n            deviceFollow: function(a, b) {\n                if (!b) {\n                    return;\n                }\n            ;\n            ;\n                twttr.API.User.JSBNG__find(twttr.currentUser.id, function(b) {\n                    ((b.deviceSetup && twttr.API.User.JSBNG__find(a, function(a) {\n                        var b = {\n                            success: function() {\n                                trackClient({\n                                    component: \"stream\",\n                                    action: \"device_follow\"\n                                });\n                            },\n                            error: function(a) {\n                                twttr.showError(_(\"There was an error following your contacts.\"));\n                            }\n                        };\n                        a.setNotificationsOn(b);\n                    })));\n                });\n            },\n            usersToFollow: function() {\n                var a = [], b = {\n                };\n                return this.$find(\"#stream-items-id .js-follow-combo:not(.following)\").each(function() {\n                    var c = $(this).attr(\"data-screen-name\");\n                    a.push(c), b[c] = (($(this).attr(\"data-device-notification\") === \"true\"));\n                }), {\n                    screenNames: a,\n                    deviceNotifications: b\n                };\n            },\n            JSBNG__onUserActionFollowSuccess: function(a, b, c) {\n                var d = ((c.attr(\"data-device-notification\") === \"true\"));\n                this.deviceFollow(a, d);\n            }\n        }), a(twttr.streams.SuggestionLifelineMembersStream);\n    });\n});\nprovide(\"streams/SuggestionLifelineMembersDashboardStream\", function(a) {\n    using(\"streams/SuggestionLifelineMembersStream\").as(function(b) {\n        twttr.klass(\"twttr.streams.SuggestionLifelineMembersDashboardStream\", function(a, c) {\n            a = ((a || {\n            })), a.streamItemClass = \"unfocusable-stream-item\", b.streams.SuggestionLifelineMembersStream.call(this, a, c);\n        }).subclassOf(b.streams.SuggestionLifelineMembersStream).methods({\n            _setHeader: function(a, b) {\n                a(\"\");\n            },\n            _setTitle: function(a) {\n                a(\"\");\n            },\n            _setViewToggler: function(a) {\n                a(\"\");\n            },\n            itemViewClass: \"DashboardStreamUser\"\n        }), a(twttr.streams.SuggestionLifelineMembersDashboardStream);\n    });\n});\nprovide(\"streams/GovernmentSearchStream\", function(a) {\n    using(\"_\", \"mixins/hasGovernmentSearchHeader\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.streams.GovernmentSearchStream\", function(a, b) {\n            var c = this;\n            twttr.streams.UserStream.apply(this, arguments);\n        }).subclassOf(twttr.streams.UserStream).mixin(b.mixins.hasGovernmentSearchHeader).methods({\n            itemViewClass: \"StreamUser\",\n            streamItemType: \"user\",\n            afterFirstSwitchingTo: function(a) {\n                this.getMoreOldItems(a);\n            },\n            streamItemId: function(a) {\n                return a.id;\n            },\n            _fetchItems: function(a) {\n                var b = this;\n                twttr.API.UsPoliticalRep.findByZip(this.params.zipCode, {\n                    success: function(c, d) {\n                        b.push(c.map(function(a) {\n                            return a.user;\n                        }).array), a(b, twttr.streams.SUCCESS), b.reachedTheEnd();\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : ((((c.JSBNG__status === 404)) ? (a(b, twttr.streams.SUCCESS), b.reachedTheEnd()) : a(b, twttr.streams.ERROR)))));\n                    },\n                    timeout: function(a) {\n                        a.retry();\n                    },\n                    cancel: function() {\n                        a(b, twttr.streams.TIMEOUT);\n                    }\n                });\n            },\n            _setTitle: function(a) {\n                a(_(\"Government\"));\n            },\n            _getEmptyStreamHtml: function() {\n                return _(\"Sorry, we couldn't find any representatives for that Zip Code.\");\n            },\n            _setViewToggler: function(a) {\n                var b = {\n                    route: twttr.router.whoToFollowInterestsPath(),\n                    JSBNG__name: _(\"View all categories\")\n                };\n                a(new twttr.views.BackLink(b));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"widget/VerifyEmailDialog\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass(\"twttr.widget.VerifyEmailDialog\", function(a, b) {\n            this.bucket = a, twttr.widget.Dialog.call(this, twttr.merge({\n                modal: !0,\n                draggable: !1,\n                css: {\n                    width: 530\n                },\n                email: ((b.email_address || b.attributes.states.pending_email))\n            }, b.attributes));\n        }).subclassOf(twttr.widget.Dialog).methods({\n            registerEvents: function() {\n                twttr.widget.Dialog.prototype.registerEvents.call(this), this.$container.JSBNG__find(\".button.ok-thanks\").bind(\"click\", twttr.bind(this, function(a) {\n                    twttr.abdecider.track(\"email_verification-18\", \"dialog_dismissed\"), a.preventDefault(), a.stopPropagation(), $.cookie(\"abtest_email_verification_18\", \"1\", {\n                        expires: 1407729\n                    }), this.destroy();\n                })), this.$container.JSBNG__find(\".send-verify-email\").bind(\"click\", twttr.bind(this, function(a) {\n                    twttr.abdecider.track(\"email_verification-18\", \"resend_verification_email\"), $.ajax({\n                        url: \"/account/resend_confirmation_email\",\n                        dataType: \"json\",\n                        success: twttr.bind(this, function(a) {\n                            var b = this.$container.JSBNG__find(\".twttr-dialog-verify-email\");\n                            ((b.length ? b.fadeOut(300, function() {\n                                b.JSBNG__find(\"h2\").html(_(\"Confirmation email sent!\")), b.JSBNG__find(\".verify-email-text\").html(_(\"Please take this time to check your email for the confirmation message and to verify your email address by \\u003Cstrong\\u003Eclicking the link in the email\\u003C/strong\\u003E.\")), b.fadeIn();\n                            }) : twttr.showMessage(a.messageForFlash)));\n                        }),\n                        error: function(a) {\n                            twttr.showError(_(\"Oops!  There was an error sending the confirmation email.\"));\n                        }\n                    }), a.preventDefault(), a.stopPropagation();\n                })), this.$container.JSBNG__find(\".change-email\").bind(\"click\", twttr.bind(this, function(a) {\n                    twttr.abdecider.track(\"email_verification-18\", \"change_email\"), this.destroy();\n                }));\n            }\n        }), a(twttr.widget.VerifyEmailDialog);\n    });\n});\nprovide(\"SearchAPI\", function(a) {\n    using().as(function(b) {\n        twttr.SearchAPI = {\n            _generateFacetsQuery: function(a) {\n                var b = a.query, c = a.facets, d = {\n                    q: b,\n                    imageResults: ((c.images ? c.images.count : null)),\n                    videoResults: ((c.videos ? c.videos.count : null))\n                };\n                return ((a.experimentId && (d.experimentId = a.experimentId))), d;\n            },\n            getImageFacets: function(a, b) {\n                twttr.SearchAPI._wrapInCache(\"imageFacets\", a, b);\n            },\n            getVideoFacets: function(a, b) {\n                twttr.SearchAPI._wrapInCache(\"videoFacets\", a, b);\n            },\n            _wrapInCache: function(a, b, c) {\n                var d = this, e = twttr.SearchAPI.cacheKey(a, b, c);\n                ((this._facetsCache[e] ? JSBNG__setTimeout(function() {\n                    ((c.success && c.success(d._facetsCache[e])));\n                }, 0) : twttr.API.Search[a](b, twttr.merge({\n                }, c, {\n                    success: function(a) {\n                        var b = [];\n                        a.each(function(a) {\n                            b.push({\n                                url: a.url,\n                                tweet: a\n                            });\n                        }), d._facetsCache[e] = b, ((c.success && c.success(b)));\n                    },\n                    error: function() {\n                        ((c.error && c.error()));\n                    }\n                }))));\n            },\n            cacheKey: function() {\n                return JSON.stringify(Array.prototype.slice.apply(arguments));\n            },\n            _facetsCache: {\n            },\n            flushCache: function() {\n                this._facetsCache = {\n                };\n            }\n        }, a(twttr.SearchAPI);\n    });\n});\nprovide(\"media/providers\", function(a) {\n    using().as(function(b) {\n        var c = function(a, b) {\n            return b = ((b || function() {\n                return !0;\n            })), function(c) {\n                var d = [];\n                $.each(c, function(a, c) {\n                    c.mediaType = twttr.media.matchInstance(c.url, c.tweet), ((((c.mediaType && b(c))) && d.push(c)));\n                }), a(d);\n            };\n        };\n        twttr.klass(\"twttr.media.provider.Search\", function(a) {\n            this.options = ((a || {\n            }));\n        }).methods({\n            fetch: function(a) {\n                var b = a.query;\n                a.success = c(a.success, a.filter), ((((a.mode == \"videos\")) ? twttr.SearchAPI.getVideoFacets(b, a) : twttr.SearchAPI.getImageFacets(b, a)));\n            }\n        }), twttr.klass(\"twttr.media.provider.UserMedia\", function(a) {\n            this.defaults = {\n                offset: 0,\n                count: 20\n            }, this.screenName = ((a.screenName || null)), this.user = ((a.user || null));\n        }).methods({\n            fetchWithUser: function(a) {\n                var b = ((a.success || $.noop));\n                a.success = function(a) {\n                    var c = [];\n                    twttr.each(a.array, function(a) {\n                        ((((a.entities && a.entities.media)) && $.each(a.entities.media, function(b, d) {\n                            if (((((d.type && ((d.type == \"photo\")))) && d.display_url))) {\n                                var d = {\n                                    url: d.display_url,\n                                    tweet: a\n                                };\n                                c.push(d);\n                            }\n                        ;\n                        ;\n                        }))), ((((a.entities && a.entities.urls)) && $.each(a.entities.urls, function(b, d) {\n                            var e = {\n                                url: ((d.expanded_url || d.url)),\n                                tweet: a\n                            };\n                            c.push(e);\n                        })));\n                    }), b(c);\n                }, this.user.media(a);\n            },\n            fetchWithScreenName: function(a) {\n                var b = this;\n                twttr.API.User.JSBNG__find(this.screenName, function(c) {\n                    b.user = c, b.fetchWithUser(a);\n                });\n            },\n            fetch: function(a) {\n                a = $.extend({\n                }, this.defaults, a), a.success = c(a.success, a.filter), ((this.user ? this.fetchWithUser(a) : ((this.screenName && this.fetchWithScreenName(a)))));\n            }\n        }), a(twttr.media.provider);\n    });\n});\nprovide(\"mixins/userRecommendationsHelper\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.userRecommendationsHelper\", function(a) {\n            return a.methods({\n                INTERESTING_RATING: 6,\n                BLOCK_RATING: 5,\n                USEFUL_RATING: 1,\n                LIST_ITEM_SELECTOR: \"ul.recommended-followers \\u003E li.user-small-list-item\",\n                userRecommendationsAvailable: function(a) {\n                    return ((twttr.loggedIn ? ((a ? twttr.decider.isAvailable(\"whotofollow_similarities\") : twttr.decider.isAvailable(\"whotofollow_recommendations\"))) : twttr.decider.isAvailable(\"whotofollow_logged_out_similarities\")));\n                },\n                trackImpressions: function(a, c, d, e, f) {\n                    var g = [], i = [], j;\n                    ((((a && a.length())) && (a.each(function(a, c) {\n                        g.push(a.id), i.push(a.feedback);\n                        if (((a.promotedContent && a.promotedContent.impression_id))) {\n                            var d = {\n                                target_id: a.id,\n                                item_type: b.constants.clientEvent.itemType.promotedUser,\n                                item_token: a.promotedContent.impression_id,\n                                item_position: c\n                            };\n                            j = ((j || {\n                            })), j[((a.id + \"\"))] = d;\n                        }\n                    ;\n                    ;\n                    }), ((e ? this.currentRecommendations = twttr.map(this.currentRecommendations, function(a, b) {\n                        return ((((a == e)) ? g[0] : a));\n                    }) : this.currentRecommendations = g))))), this._trackOldImpressions(c, g, i, d), this._trackNewImpressions(g, i, j, f);\n                },\n                trackError: function(a, b) {\n                    this._trackOldImpressions(a, [], [], b), this.getScribbler().scribe({\n                        component: this._getScribeComponentName(),\n                        action: \"error\"\n                    });\n                },\n                _trackOldImpressions: function(a, b, c, d) {\n                    var e = {\n                        recommended_users: b,\n                        recommended_users_count: b.length,\n                        tokens: c\n                    };\n                    twttr.merge(e, ((d || {\n                    })));\n                    var f = this.mergeSimilarUserId(e);\n                    _scribble(a, f, \"whotofollow\");\n                },\n                _trackNewImpressions: function(a, b, c, d) {\n                    var e = {\n                        profile_id: this.getSimilarUserId(),\n                        item_ids: a,\n                        item_count: a.length,\n                        event_value: a.length,\n                        item_names: b,\n                        referring_event: ((d ? \"get_newer\" : \"initial\")),\n                        duration_ms: ((new JSBNG__Date - this.initTime))\n                    };\n                    ((c && (e.item_details = c))), this.getScribbler().scribe({\n                        component: this._getScribeComponentName(),\n                        action: ((a.length ? \"results\" : \"no_results\"))\n                    }, e);\n                },\n                _scribeResults: function(a, b, c) {\n                    twttr.streams.Stream.prototype._scribeResults.apply(this, arguments);\n                    var b = ((b || []));\n                    c = ((c || {\n                    }));\n                    if (((((a == \"error\")) || ((((a == \"initial\")) && !b.length))))) {\n                        this.scribbler.scribe({\n                            component: \"stream\",\n                            action: ((((a == \"error\")) ? \"error\" : \"no_results\"))\n                        }, twttr.merge(c, {\n                            item_ids: [0,],\n                            item_count: 0,\n                            event_value: 0,\n                            cursor_or_page: this._cursorOrPage(),\n                            referring_event: a\n                        }));\n                    }\n                     else {\n                        if (b.length) {\n                            var d = this, e = [], f = [], g;\n                            twttr.each(b, function(a, b) {\n                                e.push(a.id), f.push(a.feedback);\n                                if (((d.constructor._namespace.indexOf(\"UserRecommendations\") != -1))) {\n                                    var c;\n                                    ((((a.promotedContent && a.promotedContent.impression_id)) && (c = {\n                                        item_type: twttr.constants.clientEvent.itemType.promotedUser,\n                                        item_token: a.promotedContent.impression_id\n                                    }))), ((c && (g = ((g || {\n                                    })), c.item_position = b, g[((a.id + \"\"))] = c)));\n                                }\n                            ;\n                            ;\n                            }), ((g && (c.item_details = g))), this.scribbler.scribe({\n                                component: this._getScribeComponentName(),\n                                action: \"results\"\n                            }, twttr.merge(c, {\n                                item_ids: e,\n                                item_names: f,\n                                item_count: e.length,\n                                event_value: e.length,\n                                cursor_or_page: this._cursorOrPage(),\n                                referring_event: a\n                            }));\n                        }\n                    ;\n                    }\n                ;\n                ;\n                },\n                logPromotedImpressions: function(a) {\n                    a.each(function(a) {\n                        ((a.promotedContent && twttr.API.util.PromotedContent.logImpression(a.promotedContent.impression_id)));\n                    });\n                },\n                getSimilarUserId: function() {\n                    return ((((this.similarUser && this.similarUser.id)) || ((twttr.profileUser && twttr.profileUser.id))));\n                },\n                mergeSimilarUserId: function(a) {\n                    return ((this.screenName && $.extend(a, {\n                        to_user_id: this.getSimilarUserId()\n                    }))), a.phoenix_enabled = !0, a;\n                },\n                recsToUsers: function(a) {\n                    return a.map(twttr.bind(this, function(a, b) {\n                        var c = ((((this._namespace == \"twttr.streams.UserRecommendationsStream\")) || ((this._namespace == \"twttr.streams.UserSimilaritiesStream\"))));\n                        return a.user.clone({\n                            following: ((a.user.following === !0)),\n                            feedback: a.token,\n                            dismissable: ((!this.screenName || ((((c && twttr.profileUser)) && ((twttr.currentUser.id == twttr.profileUser.id)))))),\n                            socialcontext: this.makeSocialContextHtml(a, c)\n                        });\n                    }));\n                },\n                fetch: function(a) {\n                    ((this.screenName ? ((((this._namespace == \"twttr.components.t1.UserSimilaritiesDashboardList\")) ? this.profileUser.similarUsers(a) : twttr.profileUser.similarUsers(a))) : (a.force_new_signup = this.forceNewSignup, twttr.currentUser.recommendedUsers(a))));\n                },\n                registerUserRecommendationsActions: function(a) {\n                    var b = this, c = function(b) {\n                        return ((!a || b.parents(a).length));\n                    };\n                    this.bind(\"avatar_click.user screen_name_click.user select.user\", function(a, d, e, f) {\n                        if (!c(d)) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var g = parseInt(d.attr(\"data-user-id\")), i = b.mergeSimilarUserId({\n                            rating: b.INTERESTING_RATING,\n                            recommended_user_id: g,\n                            token: ((d.attr(\"data-feedback-token\") || \"0\"))\n                        });\n                        if (!g) {\n                            return;\n                        }\n                    ;\n                    ;\n                        i.recommendation_position = b.getRecPosition(d), scribble(((b.whotofollowComponentName + \"_profile_click\")), i, \"whotofollow\"), scribble(\"view-profile\", {\n                            profile_user_id: g,\n                            component: ((b._namespace.indexOf(\".stream.\") ? \"stream\" : \"dashboard\")),\n                            subcomponent: \"who-to-follow\",\n                            target: ((e.is(\"a\") ? \"link\" : \"image\"))\n                        });\n                    }), this.bind(\"follow.user\", function(a, d, e, f) {\n                        if (!c(d)) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var g = parseInt(d.attr(\"data-user-id\")), i = b.mergeSimilarUserId({\n                            rating: b.USEFUL_RATING,\n                            recommended_user_id: g,\n                            token: ((d.attr(\"data-feedback-token\") || \"0\"))\n                        });\n                        if (!g) {\n                            return;\n                        }\n                    ;\n                    ;\n                        twttr.API.UserRecommendation.rate(i), i.recommendation_position = b.getRecPosition(d), scribble(((b.whotofollowComponentName + \"_follow\")), i, \"whotofollow\"), scribble(\"follow-user\", {\n                            profile_user_id: g,\n                            component: ((b._namespace.indexOf(\".stream.\") ? \"stream\" : \"dashboard\")),\n                            subcomponent: \"who-to-follow\"\n                        });\n                    }), this.bind(\"dismiss.user\", function(a, d, e, f) {\n                        if (!c(d)) {\n                            return;\n                        }\n                    ;\n                    ;\n                        ((((twttr.isT1 && d.hasClass(\"js-follow-combo\"))) && (d = d.parent(\".js-actionable-user\"))));\n                        var g = parseInt(d.attr(\"data-user-id\")), i = d.attr(\"data-impression-id\"), j = b.getRecPosition(d), k = ((d.attr(\"data-feedback-token\") || \"0\")), l = ((d.JSBNG__find(\"a.js-action-follow, div.js-action-follow, .follow-action, .follow-button\").length || b.screenName)), m = {\n                        };\n                        twttr.cache.local.dismissedIDs = ((twttr.cache.local.dismissedIDs || [])), twttr.cache.local.dismissedIDs.push(g), d.animate({\n                            opacity: 0\n                        }, 200);\n                        var n = function(a) {\n                            var c;\n                            if (e.closest(\"[data-section-id=\\\"wtf\\\"]\").length) if (((((a && a.length())) && !twttr.is.inArray(a.first().user.id, ((b.currentRecommendations || [])))))) {\n                                c = b.recsToUsers(a);\n                                var f = c.first();\n                                if (f) {\n                                    var i = b.renderItemView(f).$html();\n                                    i.css({\n                                        opacity: 0\n                                    }), d.replaceWith(i), i.animate({\n                                        opacity: 1\n                                    }, 300), b.trackImpressions(c, \"whotofollow_sidebar_replace_dismissed\", twttr.merge({\n                                        recommended_user_id: g,\n                                        recommendation_position: j\n                                    }, m), g);\n                                }\n                            ;\n                            ;\n                            }\n                             else d.fadeOut(200, function() {\n                                d.animate({\n                                    height: 1\n                                }, 100, null, function() {\n                                    d.remove(), ((((b.$find(b.LIST_ITEM_SELECTOR).length == 0)) && (b.trigger(\"notRendered\", \"noMoreRecommendations\"), b.$node.empty())));\n                                });\n                            });\n                            \n                             else {\n                                var n = d.parent(\".stream-item\");\n                                n.slideUp(100, function() {\n                                    n.remove();\n                                });\n                            }\n                        ;\n                        ;\n                            ((l && scribble(((b.whotofollowComponentName + \"_block\")), b.mergeSimilarUserId({\n                                token: k,\n                                recommended_user_id: g,\n                                rating: b.BLOCK_RATING,\n                                recommendation_position: j\n                            }), \"whotofollow\")));\n                        }, o = function() {\n                            twttr.showError(_(\"Whoops! Something went wrong. Please try again!\")), d.css({\n                                opacity: 1\n                            });\n                        };\n                        m = b.mergeSimilarUserId({\n                        });\n                        var p = twttr.merge({\n                            user_id: m.to_user_id,\n                            excluded: b.currentRecommendations.concat(((twttr.cache.local.dismissedIDs || []))).join(\",\"),\n                            success: n,\n                            error: o,\n                            pc: !!i\n                        }, m);\n                        ((d.JSBNG__find(\"a.js-action-unfollow:visible, div.js-action-unfollow:visible\").length ? b.fetch(twttr.merge(p, {\n                            limit: 1\n                        })) : ((((d.JSBNG__find(\".unfollow-button\").length && ((twttr.audit.currentPage() != \"similar_to\")))) ? n() : (p = twttr.merge({\n                            connections: !0\n                        }, p), twttr.API.UserRecommendation.hide(g, k, p))))));\n                    });\n                },\n                attachUserRecommendationHideEvents: function() {\n                    this.$find(\"a.js-user-dropdown-dismiss\").click(twttr.bind(this, function() {\n                        this.$find(\"a.js-user-dropdown, div.js-user-dropdown\").fadeOut(300);\n                    }));\n                },\n                renderItemView: function(a) {\n                    return new twttr.views.UserSmallListItem(a);\n                },\n                getRecPosition: function(a) {\n                \n                }\n            }), a;\n        }), a(twttr.mixins.userRecommendationsHelper);\n    });\n});\nprovide(\"mixins/t1/genericComboButton\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.t1.genericComboButton\", function() {\n            this.methods({\n                getButton: function(a) {\n                    return a.closest(\".js-combo-btn\");\n                },\n                setState: function(a, b, c) {\n                    ((((b && ((c !== b)))) && (a.removeClass(c), a.addClass(b), a.attr(\"data-state\", b))));\n                }\n            }).click({\n                \".js-combo-btn-dropdown\": function(a, b) {\n                    var c = this.getButton(b);\n                    c.toggleClass(\"open\"), ((c.hasClass(\"open\") && ($(JSBNG__document).bind(\"click.button\", function() {\n                        c.removeClass(\"open\"), $(JSBNG__document).unbind(\"click.button\");\n                    }), a.stopPropagation())));\n                },\n                \".js-combo-btn-action, .js-combo-btn-dropdown-options a\": function(a, b) {\n                    var c = this.getButton(b);\n                    this.setState(c, b.attr(\"data-state\"), c.attr(\"data-state\"));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/userUpdateable\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.userUpdateable\", function() {\n            return this.methods({\n                registerUserUpdateEvents: function(a) {\n                    var b = this;\n                    if (!twttr.loggedIn) {\n                        return;\n                    }\n                ;\n                ;\n                    twttr.API.User.bind(\"follow unfollow\", function(c, d) {\n                        var e = ((a.id == d.id)), f = twttr.helpers.isCurrentUser(a);\n                        if (((!e && !f))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        ((twttr.helpers.isCurrentUser(b.user) ? b.trigger(\"userUpdated\", twttr.currentUser) : b.trigger(\"userUpdated\", d)));\n                    });\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"components/UserMedia\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.components.UserMedia\").subclassOf(twttr.components.Media).deciderKey(\"phoenix_user_media_gallery\").initializer(function(a, b) {\n            this.user = a, this.options = ((b || {\n            })), this.notDisplayedClass = \".user-media-not-displayed\", this.hasCalledHasRendered = !0, this.buildSubComponents();\n        }).methods({\n            buildSubComponents: function() {\n                var a = this, b = function() {\n                    a.$node.hide();\n                }, c = twttr.aug({\n                    user: this.user,\n                    filter: function(a) {\n                        return ((((!a || !a.mediaType)) ? !1 : ((a.mediaType.icon() === twttr.constants.media.photoIcon))));\n                    }\n                }, this.options);\n                ((twttr.isT1 && twttr.aug(c, twttr.components.Media.dashboardThumbnailOptions))), this.images = new twttr.components.media.profile.Images(c), this.images.bind(\"urlsLoaded\", function(c, d, e) {\n                    a._possiblySensitive = e, ((((d.length === 0)) ? b() : ((twttr.loggedIn ? a.loggedInBehavior() : a.loggedOutBehavior())))), a._scribeResults(\"photos\", d);\n                }), this.images.bind(\"failed\", function() {\n                    b(), a._scribeResults(\"photos\");\n                }), this.images.fetchImages();\n            },\n            _isPossiblySensitive: function() {\n                return !!this._possiblySensitive;\n            },\n            _getUser: function() {\n                return this.user;\n            },\n            JSBNG__onProfilePage: function() {\n                return !0;\n            },\n            renderMedia: function() {\n                this.images.$node.appendTo(this.$node), this.images.render(), this.$node.delegate(\".view-all\", \"click\", function() {\n                    trackClient({\n                        section: \"dashboard\",\n                        component: \"photos_user_media\",\n                        action: \"view_all\"\n                    }, {\n                        event_info: \"photos\",\n                        profile_id: ((twttr.profileUser && twttr.profileUser.id))\n                    });\n                }), this.$node.delegate(\".media-thumbnail\", \"click\", function(a) {\n                    trackClient({\n                        section: \"dashboard\",\n                        component: \"photos_user_media\",\n                        action: \"click\"\n                    }, {\n                        event_info: \"photos\",\n                        url: $(this).attr(\"data-url\"),\n                        profile_id: ((twttr.profileUser && twttr.profileUser.id))\n                    });\n                });\n            },\n            buildNotDisplayedView: function(a) {\n                var b = \"\";\n                return ((a.possibly_sensitive ? b = _(\"This media may contain sensitive content\") : ((a.not_following && (b = _(\"This media was shared by {{screen_name}}, someone you don&#8217;t follow.\", {\n                    screen_name: this.user.screenName\n                })))))), new twttr.views.UserMediaNotDisplayed({\n                    screenName: this.user.screenName,\n                    reason: b,\n                    renderHr: this.options.renderHr\n                });\n            },\n            _scribeResults: function(a, b) {\n                var c = ((((b && b.length)) ? \"results\" : \"no_results\")), d = ((a + \"_user_media\"));\n                b = ((b || [])), trackClient({\n                    section: \"dashboard\",\n                    component: d,\n                    action: c\n                }, {\n                    item_names: b.slice(0, 4),\n                    item_count: b.length,\n                    event_info: a,\n                    profile_id: ((twttr.profileUser && twttr.profileUser.id))\n                });\n            }\n        }), a(twttr.components.UserMedia);\n    });\n});\nprovide(\"components/UserRecommendations\", function(a) {\n    using(\"_\", \"mixins/userRecommendationsHelper\", \"mixins/userActionable\", ((twttr.isT1 ? \"mixins/UserRecommendationsT1\" : \"mixins/UserRecommendationsP1\"))).as(function(b, _, c, d, e) {\n        var f = twttr.klass(\"twttr.components.UserRecommendations\").subclassOf(twttr.components.Base).initializer(function(a) {\n            a = ((a || {\n            })), this.screenName = a.screenName, this.showLinks = a.showLinks, this.currentRecommendations = [], this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: ((((this.screenName && twttr.profileUser)) && twttr.profileUser.id))\n            }), this.scribeComponentName = this._determineScribeComponentName(a), this.whotofollowComponentName = this._determineWhotofollowComponentName(this.scribeComponentName), this.initTime = +(new JSBNG__Date), this.JSBNG__onDeck = [], this.scribbler.scribe({\n                component: this.scribeComponentName,\n                action: \"impression\"\n            }), this.noSpacer = !this._shouldHaveSpacer(), this.bind(\"addedToPage\", twttr.bind(this, function() {\n                ((this.userRecommendationsAvailable() ? this.loadRecommendations() : this.trigger(\"notRendered\", \"darkmoded\")));\n            })), this.registerUserActionEvents(), this.registerUserRecommendationsActions();\n        }).mixin(c, d, e).statics({\n            wtfCycleTimeout: 1000\n        }).click({\n            \".title-link\": function(a, b) {\n                var c = {\n                    input: \"click\",\n                    component: \"dashboard\",\n                    subcomponent: \"who_to_follow\",\n                    target: \"dashboard_title\",\n                    item: b.JSBNG__find(\".dashboard-component-title\").html()\n                };\n                scribble(\"dashboard_click\", c);\n            },\n            \".user-rec-inner h3 a\": function(a, b) {\n                var c = {\n                    input: \"click\",\n                    component: \"dashboard\",\n                    subcomponent: \"who_to_follow\",\n                    target: \"view_all_recommendations\",\n                    recommendations: this.currentRecommendations\n                };\n                scribble(\"dashboard_click\", c);\n            },\n            \".user-rec-inner .view-all\": function(a, b) {\n                trackClient({\n                    component: this.scribeComponentName,\n                    action: \"view_all\"\n                });\n            },\n            \".flex-module-footer a[data-element-term=interests_link]\": function(a, b) {\n                trackClient({\n                    component: this.scribeComponentName,\n                    element: \"interests_link\",\n                    action: \"click\"\n                });\n            },\n            \".flex-module-footer a[data-element-term=import_link]\": function(a, b) {\n                trackClient({\n                    component: this.scribeComponentName,\n                    element: \"import_link\",\n                    action: \"click\"\n                });\n            },\n            \".user-rec-links a\": function(a, b) {\n                var c = {\n                    input: \"click\",\n                    component: \"dashboard\",\n                    subcomponent: \"who_to_follow\",\n                    target: b.html(),\n                    target_type: \"recommendation_link\",\n                    recommendations: this.currentRecommendations\n                };\n                scribble(\"dashboard_click\", c);\n            },\n            \"a.js-action-follow, div.js-action-follow\": function(a, b) {\n                if (((((twttr.app.currentPageName() === \"JSBNG__home\")) && ((this.scribeComponentName !== \"empty_timeline_recommendations\"))))) {\n                    var c = this, d = b.closest(\".js-actionable-user\");\n                    window.JSBNG__setTimeout(function() {\n                        c.loadRecommendations(d);\n                    }, twttr.components.UserRecommendations.wtfCycleTimeout);\n                }\n            ;\n            ;\n            }\n        }).methods({\n            forceNewSignup: !1,\n            renderItemView: function(a) {\n                return new twttr.views.UserSmallListItem(a);\n            },\n            renderModuleView: function(a, b) {\n                var c = this._getModuleViewName();\n                (new twttr.views[c](a)).subview(\"recommended_followers\", new twttr.views.UserSmallList(b)).render(this.$node, \"append\");\n            },\n            loadRecommendations: function(a) {\n                var b, c;\n                ((this.screenName ? (b = \"whotofollow_view_similar_users\", c = \"profile\") : (b = \"whotofollow_view_recommended_users\", c = \"JSBNG__home\"))), this.fetch({\n                    limit: ((a ? 1 : this._recommendationsLimit())),\n                    excluded: this.JSBNG__onDeck.concat(((twttr.cache.local.dismissedIDs || []))).join(\",\"),\n                    display_location: ((this.screenName ? \"st-component\" : \"wtf-component\")),\n                    pc: !0,\n                    connections: !this.screenName,\n                    algorithm: ((this.useUserToUserRec() ? \"UserToUserRec\" : null)),\n                    success: twttr.bind(this, function(d) {\n                        var e = this.recsToUsers(d);\n                        this.trackImpressions(e, b, {\n                            tracking_context: c\n                        });\n                        if (((e.length() > 0))) {\n                            this.logPromotedImpressions(e);\n                            var f;\n                            if (a) {\n                                f = this.renderItemView(e.first()).$html();\n                                var g = parseInt(f.attr(\"data-user-id\"));\n                                if (this.JSBNG__onDeck.JSBNG__find(function(a) {\n                                    return ((a == g));\n                                })) this.trigger(\"notRendered\", \"recommendationAlreadyOnDeck\");\n                                 else {\n                                    var i = parseInt(a.attr(\"data-user-id\"));\n                                    this.JSBNG__onDeck = this.JSBNG__onDeck.map(function(a) {\n                                        return ((((a == i)) ? g : a));\n                                    }), a.css({\n                                        opacity: 1\n                                    }), f.css({\n                                        opacity: 0\n                                    }), a.animate({\n                                        opacity: 0\n                                    }, 400, function() {\n                                        a.replaceWith(f), f.animate({\n                                            opacity: 1\n                                        }, 400, function() {\n                                            f.css({\n                                                opacity: \"\"\n                                            });\n                                        });\n                                    });\n                                }\n                            ;\n                            ;\n                            }\n                             else {\n                                this.JSBNG__onDeck = e.map(function(a) {\n                                    return $(a).attr(\"id\");\n                                });\n                                var j = ((this.screenName ? {\n                                    screen_name: this.screenName,\n                                    self_sims: twttr.helpers.isCurrentUser(this.screenName),\n                                    profile_name: twttr.profileUser.JSBNG__name,\n                                    small_avatar: !0\n                                } : {\n                                    show_links: this.showLinks\n                                }));\n                                this.renderModuleView(j, e), this.attachUserRecommendationRefreshEvents(), this.hasRendered(), this.trigger(\"recommendationsLoaded\"), f = this.$node;\n                            }\n                        ;\n                        ;\n                            twttr.helpers.ellipsify(f.JSBNG__find(\".user-screen-and-full-name\")), twttr.helpers.ellipsify(f.JSBNG__find(\"div.bio\"));\n                        }\n                         else this.trigger(\"notRendered\", \"noMoreRecommendations\");\n                    ;\n                    ;\n                    }),\n                    error: twttr.bind(this, function(a) {\n                        this.trackError(b, {\n                            tracking_context: c,\n                            error_status: a.JSBNG__status\n                        }), this.trigger(\"notRendered\", a);\n                    })\n                });\n            },\n            refreshRecommendations: function(a) {\n                var b = this.$find(\".js-recommended-followers\");\n                b.animate({\n                    opacity: 0\n                }, 200);\n                var c = ((this.screenName ? \"whotofollow_refresh_similar_users\" : \"whotofollow_refresh_recommended_users\"));\n                twttr.cache.local.dismissedIDs = ((twttr.cache.local.dismissedIDs || [])).concat(this.currentRecommendations), this.fetch({\n                    limit: this._recommendationsLimit(),\n                    excluded: this.JSBNG__onDeck.concat(twttr.cache.local.dismissedIDs).join(\",\"),\n                    pc: a,\n                    display_location: \"wtf-component\",\n                    connections: !0,\n                    algorithm: ((this.useUserToUserRec() ? \"UserToUserRec\" : null)),\n                    success: twttr.bind(this, function(d) {\n                        var e = this.recsToUsers(d);\n                        if (((e.length() > 0))) {\n                            this.scribbler.scribe({\n                                component: this.scribeComponentName,\n                                action: \"refresh\"\n                            }), this.trackImpressions(e, c, {\n                            }, !1, !0), ((a && this.logPromotedImpressions(e)));\n                            var f = this._generateUserList(e);\n                            f.css({\n                                opacity: 0\n                            }), b.replaceWith(f), twttr.helpers.ellipsify(f.JSBNG__find(\".user-screen-and-full-name\")), f.animate({\n                                opacity: 1\n                            }, 200);\n                        }\n                         else twttr.showMessage(_(\"You have no more recommendations today!\")), this._removeRefreshLink(), b.css({\n                            opacity: 1\n                        });\n                    ;\n                    ;\n                    }),\n                    error: function(a) {\n                        this.trackError(c, {\n                            error_status: err.JSBNG__status\n                        }), twttr.helpers.showErrorFromResponse(a), b.css({\n                            opacity: 1\n                        });\n                    }\n                });\n            },\n            attachUserRecommendationRefreshEvents: function() {\n                var a = this;\n                this.$find(\"a.js-refresh-suggestions\").click(twttr.bind(this, function(a) {\n                    this.refreshRecommendations(!0);\n                }));\n            },\n            _recommendationsLimit: function() {\n                return 3;\n            },\n            useUserToUserRec: function() {\n                return ((((this.screenName != null)) && ((twttr.abdecider.choose(\"wtf_user_to_user_rec_155\") == \"user_to_user_rec\"))));\n            },\n            _determineScribeComponentName: function(a) {\n                return a = ((a || {\n                })), ((a.scribeComponentName ? a.scribeComponentName : ((a.screenName ? \"similar_user_recommendations\" : \"user_recommendations\"))));\n            },\n            _determineWhotofollowComponentName: function(a) {\n                return ((((a === \"empty_timeline_recommendations\")) ? \"whotofollow_empty_timeline\" : \"whotofollow_sidebar\"));\n            }\n        });\n        a(twttr.components.UserRecommendations);\n    });\n});\nprovide(\"components/Footer\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.Footer\").subclassOf(twttr.components.Base).initializer(function(a) {\n            this.renderFooter(a), ((twttr.loggedIn || this.$node.delegate(\"a\", \"click\", function(a) {\n                var b = {\n                    url: $(this).attr(\"href\"),\n                    context: twttr.audit.currentPage()\n                }, c = {\n                    section: \"footer\",\n                    component: \"link\",\n                    action: \"click\"\n                };\n                trackClient(c, b);\n            }))), this.hasRendered();\n        }).method(\"renderFooter\", function(a) {\n            (new ((twttr.isT1 ? twttr.views.Footer : twttr.views.GenericFooter))({\n                year: 2012,\n                is_slim: ((a == \"slim\"))\n            })).render(this.$node, \"append\");\n        });\n        a(c);\n    });\n});\nprovide(\"components/Trends\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.Trends\").subclassOf(twttr.components.Base).initializer(function(a) {\n            var b = this;\n            trackClient({\n                component: \"trends\",\n                action: \"impression\"\n            }), b.isFullPage = ((!!a && !!a.isFullPage)), this.renderTrends(), ((((a && a.wide)) && b.$find(\".trends-inner\").addClass(\"wide-trends\"))), b.hasRendered(), b.registerEventHandlers(), twttr.API.CurrentUser.bind(\"changedLocation\", function() {\n                b.trendLocationUpdated = !0, b.updateTrends();\n            }), twttr.TrendLocations.install(function() {\n                b.trendLocationsLocated = !0, b.startUpdatePolling(), b.trigger(\"trendLocationsLocated\");\n            });\n        }).statics({\n            trendUpdateTime: 300000\n        }).methods({\n            registerEventHandlers: function() {\n                var a = this, b = a.$find(\".js-trend-toggle\");\n                b.click(function(b) {\n                    var c = function() {\n                        a.dialog().open(), scribble(\"open-trend-dialog\", {\n                            input: \"click\",\n                            woeid: a.currentWoeid()\n                        });\n                    };\n                    ((a.trendLocationsLocated ? c() : a.bind(\"trendLocationsLocated\", c))), b.preventDefault();\n                }), b.hover(function(b) {\n                    scribble(\"trend-location-selector-hover\", {\n                        input: \"hover\",\n                        woeid: a.currentWoeid()\n                    });\n                });\n            },\n            currentWoeid: function() {\n                return twttr.trendLocations.current.woeid;\n            },\n            dialog: function() {\n                return ((this._dialog ? this._dialog : this._dialog = twttr.dialogs.trends()));\n            },\n            startUpdatePolling: function() {\n                var a = this;\n                ((((!a.trendUpdateInterval && a.trendLocationsLocated)) && (a.updateTrends(), a.trendUpdateInterval = JSBNG__setInterval(function() {\n                    ((twttr.decider.isAvailable(\"trends_component_polling\") && a.updateTrends(!0)));\n                }, twttr.components.Trends.trendUpdateTime))));\n            },\n            stopUpdatePolling: function() {\n                ((this.trendUpdateInterval && (JSBNG__clearInterval(this.trendUpdateInterval), this.trendUpdateInterval = !1)));\n            },\n            prettyHash: function(a) {\n                return ((((a && ((a[0] === \"#\")))) ? a.slice(1) : null));\n            },\n            updateTrends: function(a) {\n                var b = this;\n                b.$node.addClass(\"loading\");\n                var c = {\n                    pc: twttr.loggedIn,\n                    promoted_location: twttr.util.params().promoted_location,\n                    success: function(c) {\n                        var d = twttr.anywhere.api.util.buildCollection(twttr.anywhere.api.models.Trend, c.get(0).trends), e = c.get(0).personalized;\n                        ((((twttr.trendLocations.current.isPersonalized != e)) && twttr.trendLocations.setPersonalized(e))), b.updateTrendsLocation(), ((b._dialog && b.dialog().rerender()));\n                        var f = [], g = [], i = {\n                        };\n                        $trends = b.$find(\".js-trends\").empty(), d.each(function(c, d) {\n                            var e = $.extend({\n                                attributes: {\n                                }\n                            }, c);\n                            e.attributes = $.extend({\n                                index: ((d + 1)),\n                                is_full_page: b.isFullPage,\n                                pretty_hash: b.prettyHash(e.attributes.JSBNG__name)\n                            }, e.attributes), ((twttr.isRTL && (e.attributes.JSBNG__name = e.attributes.JSBNG__name.replace(/^#/, \"\\u200e#\"))));\n                            var j = (new twttr.views.TrendItem(e)).$html();\n                            ((c.promotedContent && (((a || twttr.API.util.PromotedContent.logTrendImpression(c.promotedContent.id))), j.bind(\"click\", function(a) {\n                                twttr.API.util.PromotedContent.logTrendClick(c.promotedContent.id);\n                            }))));\n                            var k = {\n                                rank: d,\n                                woeid: b.currentWoeid(),\n                                component: \"dashboard\",\n                                input: \"click\",\n                                trend: c.JSBNG__name,\n                                dialog_open: ((b._dialog && b._dialog.isOpen()))\n                            };\n                            ((c.promotedContent ? (k.promoted_content_id = c.promotedContent.id, i[c.JSBNG__name] = {\n                                item_description: c.JSBNG__name,\n                                item_token: c.promotedContent.id,\n                                item_position: d,\n                                item_type: 9\n                            }) : ((j.hasClass(\"event-trend\") && (i[c.JSBNG__name] = {\n                                item_description: c.JSBNG__name,\n                                item_position: d,\n                                item_type: 15\n                            }))))), j.bind(\"click\", function(a) {\n                                scribble(\"show-trend\", k), trackClient({\n                                    section: \"dashboard\",\n                                    component: \"trend\",\n                                    action: \"click\"\n                                }, {\n                                    query: c.JSBNG__name,\n                                    woeid: b.currentWoeid(),\n                                    position: d\n                                }), ((c.promotedContent && trackClient({\n                                    section: \"dashboard\",\n                                    component: \"promoted_trend\",\n                                    action: \"click\"\n                                }, {\n                                    query: c.JSBNG__name,\n                                    woeid: b.currentWoeid(),\n                                    position: d\n                                })));\n                                var e = ((c.promotedContent ? \"promoted_trend_click\" : ((j.hasClass(\"event-trend\") ? \"event_trend_click\" : \"trend_click\"))));\n                                twttr.abdecider.track(\"olympic_trends_320\", e);\n                            }), j.appendTo($trends), f.push(k), g.push(c.JSBNG__name);\n                        }), b.$node.removeClass(\"loading\"), ((b.isFullPage && $(\".trends-page\").removeClass(\"trends-page-loading\"))), b.showTrends();\n                        var j = ((((a || b.trendLocationUpdated)) ? \"newer\" : \"initial\"));\n                        trackClient({\n                            component: \"trends\",\n                            element: j,\n                            action: \"results\"\n                        }, {\n                            item_names: g,\n                            item_count: g.length,\n                            referring_event: j,\n                            event_initiator: ((a ? twttr.constants.scribe.CLIENT_SIDE_APP : twttr.constants.scribe.CLIENT_SIDE_USER)),\n                            item_details: i\n                        }), scribble(\"trend-impression\", {\n                            component: \"dashboard\",\n                            trends: f\n                        });\n                    },\n                    error: function(c) {\n                        ((b.isFullPage && ($(\".trends-page\").removeClass(\"trends-page-loading\"), ((a || twttr.helpers.showErrorFromResponse(c)))))), b.hideTrends();\n                    }\n                };\n                twttr.trendLocations.current.trends(c);\n            },\n            updateTrendsLocation: function() {\n                var a = twttr.trendLocations.current, b = ((((twttr.decider.isAvailable(\"personalized_trends\") && a.isPersonalized)) ? _(\"Trends\") : ((((1 === a.woeid)) ? _(\"Worldwide trends\") : Mustache.to_html(_(\"{{location}} trends\"), {\n                    JSBNG__location: a.JSBNG__name\n                })))));\n                this.$find(\".js-trend-location\").text(b).attr(\"woeid\", a.woeid);\n            },\n            showTrends: function() {\n                ((!this.isFullPage && this.$node.show()));\n            },\n            hideTrends: function() {\n                ((!this.isFullPage && this.$node.hide()));\n            }\n        }).deciderKey(\"trends_component\");\n        ((twttr.isT1 ? (c.setBaseView(twttr.views.DashboardTrends), c.methods({\n            renderTrends: function() {\n                this.hideTrends();\n            }\n        })) : c.methods({\n            renderTrends: function() {\n                var a = ((this.isFullPage ? twttr.views.FullPageTrends : twttr.views.DashboardTrends));\n                (new a).render(this.$node, \"append\"), this.noSpacer = this.isFullPage;\n            }\n        }))), a(c);\n    });\n});\nprovide(\"components/onebox/News\", function(a) {\n    using(\"_\", \"helpers\").as(function(b, _, c) {\n        var d = twttr.klass.component(\"twttr.components.JSBNG__onebox.News\").initializer(function(a) {\n            var b = this, c = b.getArticle(a);\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            b.$node.append((new twttr.views.CardNewsOnebox(c)).html()), b.$node.css(\"visibility\", \"hidden\");\n        }).deciderKey(\"news_onebox\").click({\n            \".js-news-headline,.onebox-news-url\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"news\",\n                    action: \"click\"\n                });\n            }\n        }).methods({\n            getTopicName: function() {\n                return _(\"Top news\");\n            },\n            getArticle: function(a) {\n                var b = twttr.at(\"JSBNG__content.articles\", a);\n                return ((b ? b.get(0) : null));\n            },\n            render: function() {\n                var a = this.$find(\".js-news-headline\"), c = this.$find(\".js-news-snippet\"), d = a.JSBNG__innerHeight();\n                ((((d >= 36)) ? c.css(\"height\", \"18px\") : ((((d >= 18)) && c.css(\"height\", \"36px\"))))), b.helpers.ellipsify([a,c,], !1, !0, null, {\n                    setTitle: \"always\",\n                    ellipsis: \"&ellip;\"\n                }), b.helpers.ellipsify(this.$find(\".JSBNG__onebox-news-url-text\")), this.$node.css(\"visibility\", \"\");\n            }\n        });\n        a(d);\n    });\n});\nprovide(\"components/onebox/User\", function(a) {\n    using(\"_\", \"helpers\", \"mixins/userActionable\").as(function(b, _) {\n        var c = twttr.klass.component(\"twttr.components.JSBNG__onebox.User\").initializer(function(a, b) {\n            this.items = [];\n            var c = this.getUsers(a);\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            this.scribbler = twttr.Scribbler.clientEvent.spawnWithTerms({\n                section: \"JSBNG__onebox\"\n            }, {\n                query: b\n            }), this.$node.append((new twttr.views.CardAccountsOnebox(c, this.getViewAllPath(b))).html()), this.$node.css(\"visibility\", \"hidden\"), this.registerUserActionEvents();\n        }).mixin(b.mixins.userActionable).statics({\n            maxUsers: 2\n        }).deciderKey(\"user_onebox\").methods({\n            getTopicName: function() {\n                return _(\"Top people\");\n            },\n            getViewAllPath: function(a) {\n                var b = {\n                    query: a\n                };\n                return ((twttr.isT1 ? twttr.router.userSearchPath(b) : ((twttr.loggedIn ? twttr.router.whoToFollowSearchPath(b) : twttr.router.userSearchPath(b)))));\n            },\n            getUsers: function(a) {\n                var b = twttr.at(\"JSBNG__content.users\", a), c = this;\n                return ((((!b || b.isEmpty())) ? null : (b.array = b.array.splice(0, twttr.components.JSBNG__onebox.User.maxUsers), b.each(function(a) {\n                    c.items.push(a.idStr), ((a.promotedContent && twttr.API.util.PromotedContent.logImpression(a.promotedContent.impression_id)));\n                }), b)));\n            },\n            render: function() {\n                ((twttr.isT1 ? b.helpers.ellipsify(this.$find(\".js-onebox-ellipsis\")) : b.helpers.ellipsify(this.$find(\".bio\"), !1, !0, null, {\n                    setTitle: \"always\",\n                    ellipsis: \"&ellip;\"\n                }))), this.$node.css(\"visibility\", \"\");\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/onebox/Sports\", function(a) {\n    using(\"_\", \"helpers\", \"mixins/profilePopupActionable\").as(function(b, _, c) {\n        var d = twttr.klass.component(\"twttr.components.JSBNG__onebox.Sports\").initializer(function(a, b) {\n            this._timerId = 0, this._event = 0;\n            var c = this, d = c.getEvent(a);\n            if (!d) {\n                return;\n            }\n        ;\n        ;\n            if (((d.sport !== \"soccer\"))) {\n                return;\n            }\n        ;\n        ;\n            c._event = d, c.$node.append((new twttr.views.CardSoccerOnebox(d)).html()), ((((d.events.getMatchState().current_status !== \"final\")) && c._startPolling(d))), this.$node.css(\"visibility\", \"hidden\");\n        }).deciderKey(\"sports_onebox\").click({\n            \".team-logo\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"profile_click\"\n                }, {\n                    event_info: \"avatar\"\n                });\n            },\n            \".fullname\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"profile_click\"\n                }, {\n                    event_info: \"screen_name\"\n                });\n            },\n            \".follow-team\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"profile_click\"\n                }, {\n                    event_info: \"follow\"\n                });\n            },\n            \".detail\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"open_link\"\n                }, {\n                    url: this._event.events.getMatchedEventData().preview_url\n                });\n            },\n            \".recap\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"open_link\"\n                }, {\n                    url: this._event.events.getMatchedEventData().recap_url\n                });\n            },\n            \".hashtag\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"search\"\n                }, {\n                    query: $(a.currentTarget).data(\"hashtag\")\n                });\n            },\n            \".ticker-event\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"search\"\n                }, {\n                    query: $(a.currentTarget).data(\"hashtag\")\n                });\n            },\n            \".matched-score\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"search\"\n                }, {\n                    query: $(a.currentTarget).data(\"hashtag\")\n                });\n            },\n            \".js-follow-news\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"profile_click\"\n                }, {\n                    event_info: \"news_link\"\n                });\n            },\n            \".js-signup-callout\": function(a) {\n                if (!twttr.loggedIn) {\n                    a.preventDefault(), a.stopPropagation();\n                    var b = $(a.currentTarget).data(\"user-id\");\n                    twttr.API.User.JSBNG__find(b, {\n                        success: function(a) {\n                            twttr.dialogs.signinOrSignup({\n                                follow: a\n                            }).open();\n                        },\n                        error: function(a) {\n                            twttr.errors.showErrorFromResponse(a);\n                        }\n                    });\n                }\n            ;\n            ;\n            }\n        }).mixin(twttr.mixins.profilePopupActionable).methods({\n            getEvent: function(a) {\n                return twttr.at(\"JSBNG__content\", a);\n            },\n            _renderTicker: function(a) {\n                if (((a.events.data().follow_news || ((a.events.getOtherMatchState().length > 0))))) {\n                    ((((this.$node.JSBNG__find(\".tickercontainer\").size() === 0)) && this.$node.JSBNG__find(\".js-onebox-soccer-item\").append(\"\\u003Cdiv class=\\\"tickercontainer\\\"\\u003E\\u003C/div\\u003E\"))), this.$node.JSBNG__find(\".tickercontainer\").empty().append((new twttr.views.SoccerTicker(a)).html());\n                }\n            ;\n            ;\n            },\n            _renderMatchedEvent: function(a) {\n                this.$node.JSBNG__find(\".matched-event\").empty().append((new twttr.views.SoccerMatchedEvent(a)).html()), ((twttr.loggedIn || this.$find(\".js-user-profile-link\").removeClass(\"js-user-profile-link\").addClass(\"js-signup-callout\")));\n            },\n            render: function() {\n                ((this._event && (this.$node.empty(), this.$node.append((new twttr.views.CardSoccerOnebox(this._event)).html()), this._renderMatchedEvent(this._event), this._renderTicker(this._event), ((((this._event.events.getMatchState().current_status === \"final\")) && $(\".score a\").removeClass(\"live\")))))), this.$node.css(\"visibility\", \"\"), trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"sports\",\n                    action: \"impression\"\n                }), ((((this.$find(\".ticker\").length !== 0)) && this._tickerScroll(this.$find(\".tickercontainer\"))));\n            },\n            _tickerScroll: function(a) {\n                function b() {\n                    var a = c.JSBNG__find(\"li\")[((m - 1))];\n                    $(a).animate({\n                        opacity: 0\n                    }, l, \"linear\"), c.animate({\n                        JSBNG__top: ((((-m * 100)) + \"%\"))\n                    }, l, \"linear\", function() {\n                        if (!k) {\n                            return;\n                        }\n                    ;\n                    ;\n                        ++m, ((((((m - 1)) >= c.JSBNG__find(\"li\").length)) ? (i._renderTicker(i._event), i._tickerScroll(i.$find(\".tickercontainer\"))) : (JSBNG__clearTimeout(j), j = JSBNG__setTimeout(function() {\n                            b();\n                        }, g))));\n                    });\n                };\n            ;\n                this._scrollStarted = !0;\n                var c = $(a.children()[0]), d = 0, e = 0;\n                c.JSBNG__find(\".event-item\").each(function(a) {\n                    var b = $(this, a).JSBNG__outerHeight(!0);\n                    d += b, ((((e < b)) && (e = b)));\n                }), a.height(e), c.height(d);\n                var f = 1439711, g = 2000, i = this, j, k = !0, l = ((e / f)), m = 0;\n                ((((c.JSBNG__find(\"li\").length === 1)) ? JSBNG__setTimeout(function() {\n                    i._renderTicker(i._event), i._tickerScroll(i.$find(\".tickercontainer\"));\n                }, g) : (c.css(\"JSBNG__top\", e), j = JSBNG__setTimeout(function() {\n                    b();\n                }, g), c.hover(function() {\n                    k = !1, JSBNG__clearTimeout(j);\n                }, function() {\n                    k = !0, j = JSBNG__setTimeout(function() {\n                        b();\n                    }, g);\n                }))));\n            },\n            _getEventIds: function(a) {\n                var b = [];\n                return $.each(a, function(a, c) {\n                    b.push(a);\n                }), b.join();\n            },\n            _startPolling: function(a) {\n                var b = this;\n                b._timerId = JSBNG__setInterval(function() {\n                    var c = {\n                        statuses: !1,\n                        stories: !0,\n                        is_t1: twttr.isT1,\n                        trim_user: !0,\n                        event_ids: b._getEventIds(a.events.items),\n                        success: function(a) {\n                            if (((a.stories.length() === 0))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            var c = a.stories.get(0), d = $.extend(!0, b._event.events.data().items, b.getEvent(c).events.data().items);\n                            b._event.events.data().items = d, b._renderMatchedEvent(b._event), ((((b.$find(\".ticker\").length === 0)) && b._renderTicker(b._event))), ((((((b.$find(\".ticker\").length !== 0)) && !b._scrollStarted)) && b._tickerScroll(b.$find(\".tickercontainer\")))), ((((b._event.events.getMatchState().current_status === \"final\")) && (JSBNG__clearInterval(b._timerId), $(\".score a\").removeClass(\"live\"))));\n                        }\n                    };\n                    (((((($(b.$node).parents(\"body\").size() === 0)) || !twttr.decider.isAvailable(\"sports_onebox_polling\"))) ? JSBNG__clearInterval(b._timerId) : ((((((new JSBNG__Date - a.events.getMatchedEventData().scheduled_start_time_utc)) > 0)) && twttr.API.Search.search(query, c)))));\n                }, 30000);\n            }\n        });\n        a(d);\n    });\n});\nprovide(\"components/onebox/Event\", function(a) {\n    using(\"_\", \"helpers\").as(function(b, _) {\n        var c = twttr.klass.component(\"twttr.components.JSBNG__onebox.JSBNG__Event\").initializer(function(a, b) {\n            this.scribbler = twttr.Scribbler.clientEvent.spawnWithTerms({\n                section: \"JSBNG__onebox\",\n                component: \"JSBNG__event\"\n            }, {\n                query: b\n            });\n            var c = a.JSBNG__content.events[0];\n            if (c) {\n                if (((c.takeover === !0))) {\n                    var d = twttr.griffin.isEvent(c.title);\n                    if (twttr.griffin.redirectOnSearch(d)) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                this.$node.append((new twttr.views.CardEventOnebox(c)).html());\n            }\n        ;\n        ;\n        }).deciderKey(\"swift_events_reroute\").click({\n            \".js-onebox-event-item\": function(a) {\n                trackClient({\n                    section: \"JSBNG__onebox\",\n                    component: \"JSBNG__event\",\n                    action: \"click\"\n                });\n            }\n        }).methods({\n            render: function() {\n                this.$node.css(\"visibility\", \"\");\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/EmptyTimelineRecommendations\", function(a) {\n    using(\"components/UserRecommendations\").as(function(b) {\n        twttr.klass(\"twttr.components.t1.EmptyTimelineRecommendations\").subclassOf(twttr.components.UserRecommendations).initializer(function(a) {\n            var b = this;\n            this.bucket = twttr.abdecider.chooseWithoutImpression(\"empty_timeline_176\"), this.JSBNG__one(\"recommendationsLoaded.EmptyTimelineRecommendations\", function() {\n                using(\"\\u003EallCurrentUserDataLoaded\", function() {\n                    twttr.currentUser.friends({\n                        success: function(a) {\n                            b.friends = a, b.conditionallyEnableDoneButton(), twttr.API.User.bind(\"follow.EmptyTimelineRecommendations\", function(a, c) {\n                                b.friends.push(c);\n                                var d = b.$find(((((\".js-list-item[data-user-id=\\\"\" + c.id)) + \"\\\"]\")));\n                                ((((d.length !== 0)) && (b.followEvent = !0, b.loadRecommendations(d)))), b.conditionallyEnableDoneButton(), b.renderModuleHeaders();\n                            }), twttr.API.User.bind(\"unfollow.EmptyTimelineRecommendations\", function(a, c) {\n                                b.friends = b.friends.filter(function(a) {\n                                    return ((a.id !== c.id));\n                                }), b.conditionallyDisableDoneButton(), b.renderModuleHeaders();\n                            });\n                        }\n                    });\n                });\n            }), this._superInitializer(a);\n        }).destructor(function() {\n            this.unbind(\".EmptyTimelineRecommendations\"), twttr.API.User.unbind(\".EmptyTimelineRecommendations\");\n        }).statics({\n            avatarLimit: 5\n        }).methods({\n            forceNewSignup: !0,\n            LIST_ITEM_SELECTOR: \".js-empty-timeline .js-list-item\",\n            conditionallyEnableDoneButton: function() {\n                ((((this.friends.length() > ((twttr.components.t1.EmptyTimelineRecommendations.avatarLimit - 1)))) && this.$find(\".js-done\").removeClass(\"disabled\")));\n            },\n            conditionallyDisableDoneButton: function() {\n                ((((this.friends.length() < twttr.components.t1.EmptyTimelineRecommendations.avatarLimit)) && this.$find(\".js-done\").addClass(\"disabled\")));\n            },\n            renderItemView: function(a) {\n                var b = new twttr.views.BigAvatarListItem(a);\n                return b.dismissable = !1, b;\n            },\n            renderModuleView: function(a, b) {\n                var c = this, d = {\n                }, e;\n                d.following = this.setupFollowingContext(), d.avatar_limit = twttr.components.t1.EmptyTimelineRecommendations.avatarLimit, d.recommendations = [], b.each(function(a) {\n                    var b = c.renderItemView(a);\n                    d.recommendations.push(b);\n                }), (new twttr.views.EmptyTimelineRecommendationsModuleShort(d)).render(this.$node, \"append\");\n            },\n            getRecPosition: function(a) {\n                var b;\n                return this.$find(\".js-account-group\").each(function(c, d) {\n                    if (((a.attr(\"data-user-id\") == $(d).attr(\"data-user-id\")))) {\n                        return b = c, !1;\n                    }\n                ;\n                ;\n                }), b;\n            },\n            renderModuleHeaders: function() {\n                var a = {\n                }, b = this.$find(\"h2\"), c = this.$find(\"h3\");\n                a.following = this.setupFollowingContext(), ((((b.length > 0)) && b.html((new twttr.views.EmptyTimelineTitle(a)).html()))), ((((c.length > 0)) && c.html((new twttr.views.EmptyTimelineSubtitle(a)).html())));\n            },\n            setupFollowingContext: function() {\n                if (((twttr.currentUser.friendsCount !== 0))) {\n                    return {\n                        goal: twttr.components.t1.EmptyTimelineRecommendations.avatarLimit,\n                        count: twttr.currentUser.friendsCount,\n                        follow_event: ((this.followEvent || !1)),\n                        zero: ((twttr.currentUser.friendsCount === 0)),\n                        JSBNG__one: ((twttr.currentUser.friendsCount === 1)),\n                        two: ((twttr.currentUser.friendsCount === 2)),\n                        several: ((((twttr.currentUser.friendsCount >= 3)) && ((twttr.currentUser.friendsCount < ((twttr.components.t1.EmptyTimelineRecommendations.avatarLimit - 1)))))),\n                        almost: ((twttr.currentUser.friendsCount === ((twttr.components.t1.EmptyTimelineRecommendations.avatarLimit - 1)))),\n                        done: ((twttr.currentUser.friendsCount >= twttr.components.t1.EmptyTimelineRecommendations.avatarLimit))\n                    };\n                }\n            ;\n            ;\n            },\n            _generateUserList: function(a) {\n                var b = this;\n                return (new twttr.views.EmptyTimelineRecommendationsModuleFollowers({\n                    recommendations: a.map(function(a) {\n                        return b.renderItemView(a);\n                    }).toArray()\n                })).$html();\n            }\n        }).click({\n            \".js-done\": function(a, b) {\n                if (b.hasClass(\"disabled\")) {\n                    return;\n                }\n            ;\n            ;\n                twttr.mixins.emptyTimelineRecommendations.showing = !1, this.destroy();\n            }\n        }), a(twttr.components.t1.EmptyTimeline);\n    });\n});\nprovide(\"components/t1/dashboard/AbstractDashboard\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.AbstractDashboard\").subclassOf(twttr.components.Base).setBaseView(twttr.views.Module).initializer(function(a) {\n            var b = this;\n            a = ((a || {\n            })), this.$sections = {\n            }, this.$itemsContainer = this.$find(\".js-items-container\"), ((this.$itemsContainer.length || (this.$itemsContainer = this.$node))), this.noSpacer = !0;\n        }).methods(twttr.EventProvider).methods({\n            addSection: function(a) {\n                if (((!a.id || !!this.$sections[a.id]))) {\n                    return !1;\n                }\n            ;\n            ;\n                a.tag = ((a.tag || \"div\")), a.operation = ((a.operation || \"append\"));\n                var b = (new twttr.views.ModuleSection({\n                    tag: a.tag,\n                    id: a.id\n                })).$html();\n                return ((a.className && b.addClass(a.className))), this.$sections[a.id] = b, a.operation = ((a.operation || \"append\")), this.$itemsContainer[a.operation](b), b;\n            },\n            getSection: function(a) {\n                return ((this.$sections[a] ? this.$sections[a] : !1));\n            },\n            removeSection: function(a) {\n                if (!this.$sections[a]) {\n                    return !1;\n                }\n            ;\n            ;\n                this.$sections[a].remove(), delete this.$sections[a];\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/Tweetbox\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.Tweetbox\").subclassOf(twttr.components.t1.dashboard.AbstractDashboard).initializer(function(a) {\n            this.$node.html(a.addClass(\"flex-module\"));\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ProfileTweetbox\", function(a) {\n    using(\"components/t1/dashboard/Tweetbox\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ProfileTweetbox\").subclassOf(b.components.t1.dashboard.Tweetbox).initializer(function(a) {\n            this._superInitializer(a);\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ProfileFollowCard\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\", \"mixins/userActionable\", \"mixins/userUpdateable\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ProfileFollowCard\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseViewOptions({\n            class_name: \"profile-card\"\n        }).mixin(b.mixins.userActionable, b.mixins.userUpdateable).initializer(function(a) {\n            function b() {\n                c.registerUserActionEvents(), c.registerUserUpdateEvents(c.user), c.bind(\"userUpdated\", function(a, b) {\n                    c.user = b, c.renderStats();\n                });\n            };\n        ;\n            var c = this;\n            this._superInitializer(), this.user = a;\n            if (twttr.helpers.isCurrentUser(a)) {\n                var d = this.renderCard();\n                (new twttr.views.ScreenNameFollowedBy({\n                    screen_name: a.screenName,\n                    is_current_user: !0\n                })).render(d.$dom.JSBNG__find(\".js-username\")), b();\n            }\n             else this.getRelationship(a, function(d, e) {\n                c.updateUserAttributesFromRelationship(d);\n                var f = c.renderCard();\n                (new twttr.views.ScreenNameFollowedBy({\n                    screen_name: a.screenName,\n                    followed_by: d.followedBy\n                })).render(f.$dom.JSBNG__find(\".js-username\")), c.renderUserProfileMenu(c.$find(\".js-follow-combo\"), c.$find(\".js-action-profilemenu\"), e), b();\n            });\n        ;\n        ;\n        }).methods({\n            renderCard: function() {\n                var a = this, b = new twttr.views.ProfileFollowCard(this.user), c = this.user.impressionId;\n                return b.render(this.$node), JSBNG__setTimeout(function() {\n                    a.trigger(\"followCardRendered\");\n                }, 0), b;\n            },\n            renderStats: function() {\n                this.$find(\".js-mini-profile-stats\").remove(), (new twttr.views.MiniProfileStats(this.user)).render(this.$find(\".js-profile-card-actions\"), \"append\");\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/Flex\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.Flex\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseView(twttr.views.FlexModule).initializer(function(a) {\n            this._superInitializer(a);\n        }).methods({\n            addTitle: function(a) {\n                this.$itemsContainer.JSBNG__find(\".flex-module-title\").remove(), (new twttr.views.FlexModuleTitle({\n                    title: a.title,\n                    view_all_route: a.viewAllRoute\n                })).render(this.$itemsContainer, \"prepend\");\n            },\n            addMoreLinks: function(a) {\n                this.$itemsContainer.JSBNG__find(\".js-more-links\").remove(), ((a.length && (a[((a.length - 1))].is_last = !0))), (new twttr.views.FlexModuleMoreLinks({\n                    links: a\n                })).render(this.$itemsContainer, \"append\");\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/Nav\", function(a) {\n    using(\"util\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.Nav\").subclassOf(twttr.components.Base).initializer(function(a) {\n            a = ((a || {\n            })), this.$itemsContainer = this.$find(\".js-items-container\"), ((a.items && (a.items = twttr.map(a.items, function(a) {\n                ((twttr.is.def(a.JSBNG__name) || (a.JSBNG__name = twttr.router.findMatchingRoute(a.route).JSBNG__name)));\n                if (((a.type || a.JSBNG__name))) {\n                    a.element_term = ((b.util.underscore(((a.type || a.JSBNG__name))) + \"_item\"));\n                }\n            ;\n            ;\n                return twttr.merge({\n                    show_metadata_container: a.metadata,\n                    active: ((twttr.router.getCurrentRoute().JSBNG__name == a.JSBNG__name)),\n                    count_commaized: ((a.count ? b.util.formatNumber(a.count, twttr.pageLocale) : \"\")),\n                    visible: !0\n                }, a);\n            })))), (new twttr.views.Nav(a)).render(this.$node), this.afterRender(this.$node);\n        }).methods({\n            afterRender: $.noop\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/MiniHomeProfile\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass.component(\"twttr.components.t1.dashboard.MiniHomeProfile\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseView(twttr.views.MiniHomeProfile).initializer(function(a) {\n            var b = this;\n            this._superInitializer(), this.showStats = !!a, this.user = twttr.currentUser, this.renderUser(), ((this.showStats && (this.renderStats(), this.attachEvents()))), using([twttr.bundleMore,\"TweetBox\",], function() {\n                b.renderTweetBox();\n            });\n        }).methods({\n            insertTweetbox: function() {\n                if (this.tweetBox) {\n                    return this.tweetBoxNode;\n                }\n            ;\n            ;\n                var a = this, b = this.tweetBoxNode = $(\"\\u003Cdiv class=\\\"tweet-box\\\"/\\u003E\");\n                return this.tweetBox = new twttr.TweetBox(b.empty(), twttr.merge(this.getTweetBoxOptions(), {\n                    defaultContent: \"\",\n                    id: \"main-tweet-box\",\n                    condensed: !0,\n                    statusAction: \"update\",\n                    width: 258,\n                    height: 75,\n                    explainLinkShortening: !1,\n                    enableDraft: !0,\n                    enableAutoGrow: !0,\n                    template: {\n                        suppress_geo_text: !0,\n                        button_text: _(\"Tweet\"),\n                        show_title: !1\n                    }\n                })), this.tweetBox.bind(\"tweetSuccess\", function(a, b) {\n                    twttr.showMessage(_(\"Your Tweet has been sent!\"));\n                }), b;\n            },\n            getTweetBoxOptions: function() {\n                return {\n                    condensedContent: _(\"Compose new Tweet...\"),\n                    autocompleteSuggestionLimit: 5\n                };\n            },\n            renderUser: function() {\n                (new twttr.views.MiniCurrentUser(this.user)).render(this.$find(\".js-profile-summary\"), \"append\");\n            },\n            renderStats: function() {\n                (new twttr.views.MiniProfileStats(this.user)).render(this.$find(\".js-mini-profile-stats-container\"));\n            },\n            renderTweetBox: function() {\n                this.$tweetBox = this.insertTweetbox(), this.$find(\".js-mini-profile-tweet-box\").remove(), this.$itemsContainer.append(this.$tweetBox.addClass(\"tweet-user\"));\n            },\n            tweetHandler: function() {\n                twttr.currentUser.sync(\"statusesCount\", ((twttr.currentUser.statusesCount + 1))), this.renderStats();\n            },\n            deleteTweetHandler: function() {\n                twttr.currentUser.sync(\"statusesCount\", ((twttr.currentUser.statusesCount - 1))), this.renderStats();\n            },\n            attachEvents: function() {\n                var a = this;\n                $(JSBNG__document).bind(\"currentUserUpdated\", function() {\n                    a.renderStats();\n                }), twttr.API.Status.bind(\"update retweet\", function() {\n                    a.tweetHandler();\n                }), twttr.API.Status.bind(\"delete unretweet\", function() {\n                    a.deleteTweetHandler();\n                });\n            },\n            _isCJK: function() {\n                var a = twttr.pageLocale;\n                return ((((((((a === \"ja\")) || ((a === \"ko\")))) || ((a === \"zh-cn\")))) || ((a === \"zh-tw\"))));\n            }\n        }).click({\n            \".js-profile-summary\": function() {\n                twttr.router.routeTo(twttr.router.profilePath({\n                    screen_name: this.user.screenName\n                }));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ConnectNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ConnectNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function() {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"connect-nav\",\n                items: [{\n                    title: _(\"Interactions\"),\n                    route: twttr.router.connectPath(),\n                    visible: twttr.decider.isActivityEnabled(),\n                    type: \"activity\"\n                },{\n                    JSBNG__name: \"mentions\",\n                    title: _(\"Mentions\"),\n                    route: twttr.router.mentionsPath(),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name === \"replies\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"mentions\")))),\n                    type: \"mentions\"\n                },]\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ProfileNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ProfileNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function(a) {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"profile-nav\",\n                items: [{\n                    title: _(\"Tweets\"),\n                    route: twttr.router.profilePath({\n                        screen_name: a.screenName\n                    })\n                },{\n                    title: _(\"Following\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"followingPath\" : \"userFollowingPath\"))]({\n                        screen_name: a.screenName\n                    })\n                },{\n                    title: _(\"Followers\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"followersPath\" : \"userFollowersPath\"))]({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((((twttr.router.getCurrentRoute().JSBNG__name == \"followers\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"userFollowers\")))) || ((twttr.router.getCurrentRoute().JSBNG__name == \"followersYouFollow\")))),\n                    show_metadata_container: !0\n                },{\n                    title: _(\"Favorites\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"favoritesPath\" : \"userFavoritesPath\"))]({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name == \"favorites\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"userFavorites\"))))\n                },{\n                    title: _(\"Requests\"),\n                    route: twttr.router.followerRequestsPath({\n                        screen_name: a.screenName\n                    }),\n                    visible: ((twttr.helpers.isCurrentUser(a) && a[\"protected\"]))\n                },{\n                    title: _(\"Lists\"),\n                    route: twttr.router.subscriptionsPath({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name == \"subscriptions\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"memberships\"))))\n                },]\n            }), ((twttr.helpers.canViewUser(a) && this.renderMedia()));\n        }).methods({\n            renderMedia: function() {\n                this.$find(\"ul\").append((new twttr.components.UserMedia(twttr.profileUser, {\n                    view_all_href: twttr.router.userMediaGridPath({\n                        screen_name: twttr.profileUser.screenName\n                    }),\n                    renderHr: !0\n                })).$node);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/SettingsNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.SettingsNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function() {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"settings-nav\",\n                items: [{\n                    title: _(\"Accounts & Settings\"),\n                    route: twttr.router.settingsPath()\n                },]\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ListNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ListNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function(a) {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"list-nav\",\n                items: [{\n                    title: _(\"Tweets\"),\n                    route: twttr.router.userListPath({\n                        screen_name: a.user.screenName,\n                        list_slug: a.slug\n                    })\n                },{\n                    title: _(\"List members\"),\n                    route: twttr.router.listMembersPath({\n                        screen_name: a.user.screenName,\n                        list_slug: a.slug\n                    })\n                },{\n                    title: _(\"List subscribers\"),\n                    route: twttr.router.listSubscribersPath({\n                        screen_name: a.user.screenName,\n                        list_slug: a.slug\n                    })\n                },]\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/SearchNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\", \"components/SearchFacets\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.SearchNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function(a) {\n            this._query = a, this._superInitializer.call(this, {\n                JSBNG__name: \"search-nav\",\n                items: [{\n                    title: _(\"Tweets\"),\n                    route: twttr.router.searchResultsPath({\n                        query: a\n                    }),\n                    type: \"tweets\"\n                },{\n                    title: _(\"People\"),\n                    route: twttr.router.userSearchPath({\n                        query: a\n                    }),\n                    JSBNG__name: \"userSearch\",\n                    show_metadata_container: !0,\n                    type: \"people\"\n                },]\n            }), this.renderFacets(a);\n        }).methods({\n            loadUsers: function(a, b) {\n                var c = this, d = {\n                    display_location: \"search-component\",\n                    pc: !1\n                };\n                twttr.API.User.search(a, twttr.merge(d, {\n                    success: function(a) {\n                        var c = new twttr.components.t1.AvatarRow(a);\n                        b.JSBNG__find(\".js-metadata\").html(c.$node);\n                    }\n                }));\n            },\n            afterRender: function(a) {\n                query = this._query.replace(/(^|\\b)(from\\:|to\\:|near\\:|source\\:)/g, \"\");\n                if (((query.indexOf(\":\") != -1))) {\n                    return;\n                }\n            ;\n            ;\n                this.loadUsers(query, a);\n            }\n        }).methods({\n            renderFacets: function(a) {\n                var c = this, d = !1;\n                this.facets = new b.components.SearchFacets(a), this.facets.bind(\"urlsLoaded\", function(a, b, e) {\n                    ((b ? ((d || (c.facets.$node.appendTo(c.$find(\".js-items-container\")), d = !0))) : ((e && c.facets.$node.remove()))));\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/DiscoverNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\", \"components/t1/AvatarRow\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.DiscoverNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function() {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"discover-nav\",\n                items: [{\n                    title: _(\"Stories\"),\n                    route: twttr.router.discoverPath(),\n                    type: \"discover\"\n                },{\n                    title: _(\"Activity\"),\n                    route: twttr.router.networkActivityPath(),\n                    visible: twttr.decider.isActivityEnabled(),\n                    type: \"activity\"\n                },{\n                    title: _(\"Lifeline\"),\n                    route: twttr.router.whoToFollowLifelinePath(),\n                    visible: ((twttr.decider.isAvailable(\"discover_lifeline\") && ((twttr.pageLocale === \"ja\")))),\n                    type: \"lifeline\"\n                },{\n                    title: _(\"Who to follow\"),\n                    route: twttr.router.whoToFollowSuggestionsPath(),\n                    show_metadata_container: !0,\n                    type: \"suggestions\"\n                },{\n                    title: _(\"Find friends\"),\n                    route: twttr.router.whoToFollowImportPath(),\n                    type: \"import\"\n                },{\n                    title: _(\"Browse categories\"),\n                    route: twttr.router.whoToFollowInterestsPath(),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name == \"whoToFollowInterestsCategory\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"whoToFollowInterests\")))),\n                    type: \"interests\"\n                },]\n            }), ((twttr.loggedIn && this.renderWTFFacePile()));\n        }).methods({\n            renderWTFFacePile: function() {\n                var a = this;\n                twttr.currentUser.recommendedUsers2(function(b) {\n                    var c = b.map(function(a) {\n                        return a.user;\n                    }), d = new twttr.components.t1.AvatarRow(c);\n                    a.$find(\"[data-name=\\\"whoToFollowSuggestions\\\"] .js-metadata\").html(d.$node);\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ProfileSummary\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ProfileSummary\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseView(twttr.views.ModuleProfileSummary).initializer(function(a) {\n            this._superInitializer(a);\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ListFollowCard\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass.component(\"twttr.components.t1.dashboard.ListFollowCard\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseViewOptions({\n            class_name: \"follow-card\"\n        }).initializer(function(a) {\n            this._superInitializer(), this.render(a), this._registerEvents(a);\n        }).methods({\n            render: function(a) {\n                (new twttr.views.ListFollowCard(a)).render(this.$node);\n            },\n            _registerEvents: function(a) {\n                var b = this;\n                this._registerEvent(twttr.API.List, \"update follow unfollow add remove\", function(c, d) {\n                    ((((d.id === a.id)) && (((((((c.type === \"follow\")) || ((c.type === \"unfollow\")))) && d.sync(\"following\", ((c.type === \"follow\"))))), b.render(d))));\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/SearchImages\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.SearchImages\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseView(twttr.views.ModuleSearchImages).initializer(function(a) {\n            this._superInitializer(a);\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/SearchVideos\", function(a) {\n    using(\"components/t1/dashboard/AbstractDashboard\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.SearchVideos\").subclassOf(b.components.t1.dashboard.AbstractDashboard).setBaseView(twttr.views.ModuleSearchVideos).initializer(function(a) {\n            this._superInitializer(a);\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/AvatarRow\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.AvatarRow\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            var b = ((b || {\n            }));\n            this.avatarLimit = ((b.avatarLimit || 7)), this.renderFacePile(a);\n        }).methods({\n            renderFacePile: function(a) {\n                var b = a.slice(0, this.avatarLimit);\n                ((((b.length() > 0)) && ((new twttr.views.AvatarRow(b)).render(this.$node, \"html\"), this.$find(\".js-user-tipsy\").tipsy({\n                    gravity: \"s\"\n                }))));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/SearchHeader\", function(a) {\n    using(\"helpers\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.SearchHeader\").subclassOf(twttr.components.Base).mixin(twttr.mixins.i18nTweetBox).setBaseView(twttr.views.SearchHeader).initializer(function(a) {\n            this.setQuery(a), this.registerEvents(), this.registerSearchMenuAction(), ((twttr.search.isSavedSearch(a) && this.toggleSavedSearchOn()));\n        }).methods({\n            registerEvents: function() {\n                var a = this;\n                this.$find(\".js-search-header-query\").bind(\"keydown keypress keyup\", function(b) {\n                    a.markPunctuation(b, $(this));\n                });\n                var c = this.$find(\"form.js-search-form\");\n                b.helpers.addFormEvents(c, function(a, b) {\n                    var c = b.q;\n                    ((c ? (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch(c)) : twttr.showMessage(_(\"Enter your query before submitting the search form!\"))));\n                }), twttr.search.formifyLatestQuery(c);\n            },\n            toggleSavedSearchOn: function() {\n                this.$find(\".js-toggle-saved-search-link\").html(_(\"Remove saved search\")).addClass(\"saved\").removeClass(\"not-saved\"), this.$find(\".js-search-title\").html(_(\"Saved search results\"));\n            },\n            toggleSavedSearchOff: function() {\n                this.$find(\".js-toggle-saved-search-link\").html(_(\"Save search\")).addClass(\"not-saved\").removeClass(\"saved\"), this.$find(\".js-search-title\").html(_(\"Search results\"));\n            },\n            registerSearchMenuAction: function() {\n                var a = this;\n                this.$node.delegate(\".js-search-dropdown-button\", \"click\", function(b) {\n                    return a.toggleSearchMenu(), b.preventDefault(), b.stopPropagation(), !1;\n                });\n            },\n            showSearchMenu: function(a) {\n                var b = this;\n                a.addClass(\"open\"), $(JSBNG__document).bind(\"click.button\", function() {\n                    b.hideSearchMenu(a);\n                });\n            },\n            hideSearchMenu: function(a) {\n                a.removeClass(\"open\"), $(JSBNG__document).unbind(\"click.button\");\n            },\n            toggleSearchMenu: function(a) {\n                var b = this, c = this.$node.JSBNG__find(\".js-search-dropdown\");\n                ((c.hasClass(\"open\") ? this.hideSearchMenu(c) : this.showSearchMenu(c)));\n            },\n            setQuery: function(a) {\n                this.$find(\".js-search-header-query\").val(a);\n            },\n            focusQuery: function() {\n                this.$find(\".js-search-header-query\").JSBNG__focus();\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/PeopleSearchStreamHeader\", function(a) {\n    using(\"helpers\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.PeopleSearchStreamHeader\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            b = ((b || {\n            })), b.placeholder = ((b.placeholder || _(\"Search using a person\\u2019s full name or @username\"))), b.button_text = ((b.buttonText || _(\"Search Twitter\"))), this.searchRoute = b.searchRoute = a, (new twttr.views.StreamHeaderPeopleSearch(b)).render(this.$node, \"append\"), this.registerEvents();\n        }).methods({\n            registerEvents: function() {\n                var a = this.$find(\"form.js-search-form\"), c = this;\n                b.helpers.addFormEvents(a, function(b, d) {\n                    ((((!a.JSBNG__find(\"input[name=\\\"q\\\"]\").hasClass(\"js-placeholded\") && ((d.q != \"\")))) && (trackClient({\n                        component: \"user_search_form\",\n                        action: \"search\"\n                    }, {\n                        query: d.q\n                    }), twttr.router.routeTo(c.searchRoute({\n                        query: d.q\n                    })))));\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/UserSimilaritiesList\", function(a) {\n    using(\"_\", \"mixins/userRecommendationsHelper\", \"mixins/userActionable\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.t1.UserSimilaritiesList\").subclassOf(twttr.components.Base).initializer(function(a, b) {\n            b = ((b || {\n            })), this.profileUser = a, this.screenName = this.profileUser.screenName, this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: this.profileUser.id\n            }), this.whotofollowComponentName = \"whotofollow_dropdown\", this.ignoreScribeItemPosition = !0, this.initTime = +(new JSBNG__Date), ((this.userRecommendationsAvailable() ? this.loadRecommendations() : this.trigger(\"notRendered\", \"darkmoded\"))), this.registerUserActionEvents(), this.registerUserRecommendationsActions();\n        }).mixin(b.mixins.userRecommendationsHelper, b.mixins.userActionable).click({\n            \".js-close\": function(a) {\n                a.preventDefault(), this.trigger(\"close\");\n            }\n        }).methods({\n            renderView: function(a) {\n                var b = (new twttr.views.UserSimilaritiesList).$html(), c = b.JSBNG__find(\".js-users-list\");\n                a.map(function(a) {\n                    var b = new twttr.views.StreamUser(a);\n                    (new twttr.views.StreamItem({\n                        item_html: b.html(),\n                        item_type: \"user\",\n                        item_class: \"stream-item\"\n                    })).render(c, \"append\");\n                }), c.children(\":last-child\").addClass(\"stream-end-item\"), this.$node.append(b);\n            },\n            loadRecommendations: function(a) {\n                this.fetch({\n                    limit: 2,\n                    success: twttr.bind(this, function(a) {\n                        var b = this.recsToUsers(a);\n                        this.trackImpressions(b, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: this.profileUser.id\n                        }), ((((b.length() > 0)) ? (this.renderView(b), this.hasRendered(), this.trigger(\"recommendationsLoaded\")) : this.trigger(\"notRendered\", \"noMoreRecommendations\")));\n                    }),\n                    error: twttr.bind(this, function(a) {\n                        this.trackImpressions(null, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: this.profileUser.id,\n                            error_status: a.JSBNG__status\n                        }), this.trigger(\"notRendered\", a);\n                    })\n                });\n            }\n        });\n        a(twttr.components.UserSimilaritiesList);\n    });\n});\nprovide(\"components/t1/UserSimilaritiesDashboardList\", function(a) {\n    using(\"_\", \"mixins/userRecommendationsHelper\", \"mixins/userActionable\").as(function(b, _) {\n        var c = twttr.klass(\"twttr.components.t1.UserSimilaritiesDashboardList\").subclassOf(twttr.components.Base).initializer(function(a, b, c) {\n            c = ((c || {\n            })), this.profileUser = a, this.screenName = this.profileUser.screenName, this.suggestions = new Array, this.contextStreamIds = b, this.scribbler = twttr.Scribbler.clientEvent.spawn({\n                profile_id: this.profileUser.id\n            }), this.whotofollowComponentName = \"whotofollow_dropdown\", this.ignoreScribeItemPosition = !0, this.initTime = +(new JSBNG__Date), ((this.userRecommendationsAvailable() ? this.loadRecommendations() : this.trigger(\"notRendered\", \"darkmoded\"))), this.registerUserActionEvents(), this.registerUserRecommendationsActions();\n        }).mixin(b.mixins.userRecommendationsHelper, b.mixins.userActionable).methods({\n            renderView: function(a) {\n                var b = (new twttr.views.UserSimilaritiesDashboardList).$html(), c = b.JSBNG__find(\".js-users-list\"), d = 0, e = this;\n                a.map(function(a) {\n                    if (!e.contextStreamIds[a.id]) {\n                        d++;\n                        if (((d < 3))) {\n                            e.suggestions.push(a);\n                            var b = new twttr.views.DashboardStreamUser(a);\n                            (new twttr.views.StreamItem({\n                                item_html: b.html(),\n                                item_type: \"user\",\n                                item_class: \"unfocusable-stream-item js-similar-user\"\n                            })).render(c, \"append\");\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }), this.$node.append(b);\n            },\n            loadRecommendations: function(a) {\n                this.fetch({\n                    limit: 10,\n                    success: twttr.bind(this, function(a) {\n                        var b = this.recsToUsers(a);\n                        this.trackImpressions(b, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: this.profileUser.id\n                        }), ((((b.length() > 0)) ? (this.renderView(b), this.hasRendered(), this.trigger(\"recommendationsLoaded\")) : this.trigger(\"notRendered\", \"noMoreRecommendations\")));\n                    }),\n                    error: twttr.bind(this, function(a) {\n                        this.trackImpressions(null, \"whotofollow_post_follow_similar_users\", {\n                            tracking_context: \"profile\",\n                            profile_user: this.profileUser.id,\n                            error_status: a.JSBNG__status\n                        }), this.trigger(\"notRendered\", a);\n                    })\n                });\n            }\n        });\n        a(twttr.components.t1.UserSimilaritiesDashboardList);\n    });\n});\nprovide(\"components/pages/mixins/profileT1\", function(a) {\n    using(\"_\", \"components/t1/dashboard/ProfileNav\", \"components/t1/dashboard/ProfileFollowCard\", \"components/SignupCallOut\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.components.pages.mixins.profileT1\", function() {\n            this.view(twttr.views.PageProfile).methods({\n                allLists: function(a) {\n                    var b = this, c = this._defaultedScreenName(a.screen_name);\n                    this.getUserInfo(c, function() {\n                        ((twttr.helpers.canViewUser(b.profileUser) ? (b.updatePageTitle(_(\"Twitter / {{screenName}}'s Subscriptions\", {\n                            screenName: c\n                        })), b._highlightNavIfCurrentUser(c), b.selectCurrentSideNav(), b._switchToStream({\n                            screenName: c,\n                            stream: twttr.streams.AllSubscriptionsUser\n                        })) : twttr.router.routeTo(twttr.router.profilePath({\n                            screen_name: c\n                        }))));\n                    }, {\n                        batch: !twttr.loggedIn,\n                        profiler: !0\n                    });\n                },\n                memberships: function(a) {\n                    var b = this, c = a.screen_name;\n                    this.updatePageTitle(_(\"Twitter / Lists following {{screenName}}\", {\n                        screenName: c\n                    })), this._highlightNavIfCurrentUser(c), this._switchToStream({\n                        screenName: c,\n                        stream: twttr.streams.MembershipsUser\n                    });\n                },\n                with_replies: function(a, b) {\n                    var c = this, d = a.screen_name.toLowerCase();\n                    this.loading(d), this.getUserInfo(d, function() {\n                        c.updatePageTitle(_(\"{{{fullName}}} ({{{screenName}}}) on Twitter\", {\n                            fullName: c.profileUser.JSBNG__name,\n                            screenName: d\n                        })), c._highlightNavIfCurrentUser(d), c._switchToStream({\n                            screenName: d,\n                            stream: twttr.streams.User,\n                            tab: \"tweets\"\n                        }), c.selectSideNav(\"profile\"), c.checkWithheld();\n                    }, {\n                        batch: !twttr.loggedIn,\n                        profiler: !0\n                    }, twttr.bind(this, this.noUserFoundCallback));\n                },\n                similarTo: function(a) {\n                    var b = this, c = a.screen_name;\n                    this.updatePageTitle(_(\"Twitter / Similar to {{screenName}}\", {\n                        screenName: c\n                    })), this._highlightNavIfCurrentUser(c), this.selectCurrentSideNav(), this._switchToStream({\n                        screenName: c,\n                        stream: twttr.streams.UserSimilaritiesStream\n                    });\n                },\n                getTweetBoxOptions: function() {\n                    return {\n                        width: 258,\n                        height: 75,\n                        explainLinkShortening: !1,\n                        condensedContent: ((((\"@\" + this.profileUser.screenName)) + \" \")),\n                        dynamicTitle: !1,\n                        autoCompleteSuggestionLimit: 5,\n                        template: {\n                            suppress_geo_text: !0,\n                            JSBNG__name: this.profileUser.JSBNG__name,\n                            button_text: _(\"Tweet\")\n                        }\n                    };\n                },\n                getDashboardComponents: function() {\n                    var a = [], c = this;\n                    ((twttr.loggedIn || a.push(new b.components.SignupCallOut(\"profile\", {\n                        profileUser: this.profileUser\n                    })))), ((this.shouldShowTweetBox() && a.push(new twttr.components.t1.dashboard.ProfileTweetbox(this.renderTweetbox()))));\n                    var d = new twttr.components.UserRecommendations({\n                        screenName: twttr.profileUser.screenName\n                    });\n                    return d.bind(\"recommendationsLoaded\", function() {\n                        ((((\"similarTo\" === twttr.router.getCurrentRoute().JSBNG__name)) && c.selectSideNav(\"similarTo\")));\n                    }), a.concat([new twttr.components.t1.dashboard.ProfileNav(this.profileUser),new twttr.components.JapaneseAd,d,new twttr.components.Footer,]);\n                },\n                addSimilarUsersDropdown: function() {\n                    var a = this, b = new twttr.components.t1.UserSimilaritiesList(this.profileUser);\n                    b.bind(\"recommendationsLoaded\", function() {\n                        a.userSimilaritiesListComponent = b, ((((!$.browser.msie || (($.browser.version != 7)))) && b.$node.hide())), a.addContainerComponent(a.$find(\".js-content-main\"), b, \"before\"), ((((!$.browser.msie || (($.browser.version != 7)))) && b.$node.slideDown(300))), twttr.router.JSBNG__one(\"routed\", function() {\n                            a.removeSimilarUsersDropdown();\n                        });\n                    }), b.bind(\"notRendered\", function() {\n                        b.destroy();\n                    }), b.bind(\"close\", function() {\n                        a.removeSimilarUsersDropdown();\n                    });\n                },\n                removeSimilarUsersDropdown: function() {\n                    var a = this.userSimilaritiesListComponent;\n                    this.userSimilaritiesListComponent = null, ((a && (((($.browser.msie && (($.browser.version == 7)))) ? a.destroy() : a.$node.slideUp(300, function() {\n                        a.destroy();\n                    })))));\n                },\n                addBanner: function() {\n                    var a = ((this.bannerPreviewUrl || this.profileUser.profileBannerUrl));\n                    if (a) {\n                        var b = (new twttr.views.ProfileBanner({\n                            banner_url: decodeURIComponent(a)\n                        })).html();\n                        this.$topContent.JSBNG__find(\".profile-card\").append(b);\n                    }\n                ;\n                ;\n                },\n                addImpressionData: function(a) {\n                    a.profile_id = ((((this.profileUser && this.profileUser.id)) || ((twttr.profileUser && twttr.profileUser.id))));\n                }\n            }).addAfterRender(function() {\n                var a = this, c = new b.components.t1.dashboard.ProfileFollowCard(this.profileUser);\n                c.bind(\"follow.user\", function() {\n                    a.addSimilarUsersDropdown();\n                }), c.bind(\"unfollow.user\", function() {\n                    a.removeSimilarUsersDropdown();\n                }), c.bind(\"followCardRendered\", function() {\n                    a.addBanner();\n                }), this.addTopContentComponent(c);\n            }).addOnSwitchTo(function() {\n                var a = this;\n                $(JSBNG__document).bind(\"tweetSuccess\", function(b, c) {\n                    var d = a.streamManager.getCurrent().trigger(\"didTweet\", [c,]);\n                });\n            }).addOnSwitchAway(function() {\n                $(JSBNG__document).unbind(\"tweetSuccess\");\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/pages/mixins/profileP1\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.components.pages.mixins.profileP1\", function() {\n            this.methods({\n                getTweetBoxOptions: function() {\n                    return {\n                        width: 482,\n                        condensedContent: _(\"Tweet to {{screen_name}}\", {\n                            screen_name: ((\"@\" + this.profileUser.screenName))\n                        }),\n                        template: {\n                            button_text: _(\"Tweet\"),\n                            show_title: !1\n                        }\n                    };\n                },\n                getDashboardComponents: function() {\n                    var a = [];\n                    a.push(new twttr.components.JapaneseAd), this.renderTweetbox(), ((twttr.loggedIn || a.push(new twttr.components.SignupCallOut(\"profile\", {\n                        profileUser: twttr.profileUser\n                    }))));\n                    var c = twttr.helpers.userNoobLevel(twttr.currentUser), d = twttr.helpers.isProfileUser();\n                    return ((((d && ((c >= b.constants.noob.total)))) ? a = a.concat(this.getNoobDashboardComponents(c)) : (a.push(new twttr.components.DashboardProfileStats(twttr.profileUser)), a.push(new twttr.components.UserMedia(twttr.profileUser, {\n                        renderHr: !0\n                    })), ((this._isSocialContextAvailable() && a.push(new twttr.components.SocialContext))), ((((twttr.loggedIn && twttr.decider.isAvailable(\"whotofollow_similarities\"))) && a.push(new twttr.components.UserRecommendations({\n                        screenName: twttr.profileUser.screenName\n                    })))), ((twttr.loggedIn && a.push(new twttr.components.RecentProfileActivity(twttr.profileUser)))), twttr.API.User.bind(\"block\", this.userWasBlocked)))), a.push(new twttr.components.Footer), a;\n                },\n                getNoobDashboardComponents: function(a) {\n                    var c = [], d = twttr.profileUser;\n                    c.push(new twttr.components.DashboardProfileStats(d, this.dashStatsTitle()), new twttr.components.UserMedia(twttr.profileUser, {\n                        renderHr: !0\n                    }));\n                    var e = b.constants.noob;\n                    switch (a) {\n                      case e.invited:\n                    \n                      case e.silent:\n                    \n                      case e.popular:\n                    \n                      case e.struggling:\n                        c.push(new twttr.components.RecentProfileActivity(d));\n                        break;\n                      case e.friendless:\n                    \n                      case e.lonely:\n                        c.push(new twttr.components.RecentlyFollowed);\n                        break;\n                      case e.total:\n                    \n                      case e.talking:\n                    \n                      default:\n                    \n                    };\n                ;\n                    return c.push(new twttr.components.GettingStarted(a)), c;\n                },\n                memberships: function(a) {\n                    var b = this, c = a.screen_name;\n                    this.updatePageTitle(_(\"Twitter / Lists following {{screenName}}\", {\n                        screenName: c\n                    })), this._highlightNavIfCurrentUser(c), this._switchToStream({\n                        screenName: c,\n                        stream: twttr.streams.Memberships\n                    });\n                }\n            }).click({\n                \".stream-tab-lists\": function(a, b) {\n                    (($(a.target).is(\".tab-text, .tab-text *\") && twttr.viewHelpers.superListDropdown(twttr.profileUser, b, function(a) {\n                        a.render(b, \"append\"), a.open();\n                    })));\n                },\n                \".stream-tab-following.dropdown-link\": function(a, b) {\n                    a.preventDefault();\n                    if (this._followingDropDown) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = twttr.profileUser.screenName, d = [{\n                        JSBNG__name: _(\"View as list of people &rarr;\"),\n                        href: twttr.router.userFollowingPath({\n                            screen_name: c\n                        })\n                    },{\n                        JSBNG__name: _(\"View as timeline &rarr;\"),\n                        href: twttr.router.userFollowingTweetsPath({\n                            screen_name: c\n                        })\n                    },];\n                    (($(a.target).hasClass(\"tab-text\") && (this._followingDropDown = new twttr.control.Dropdown(b, {\n                        itemView: \"StreamLink\",\n                        items: d\n                    }), this._followingDropDown.render(b, \"append\"), this._followingDropDown.open())));\n                },\n                \".stream-tab-followers.dropdown-link\": function(a, b) {\n                    if (!this._isSocialContextAvailable()) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = twttr.profileUser.screenName;\n                    if (this._followersDropDown) {\n                        return;\n                    }\n                ;\n                ;\n                    (($(a.target).hasClass(\"tab-text\") && (this._followersDropDown = new twttr.control.Dropdown(b, {\n                        itemView: \"StreamLink\",\n                        items: [{\n                            JSBNG__name: _(\"All followers &rarr;\"),\n                            href: twttr.router.userFollowersPath({\n                                screen_name: c\n                            })\n                        },{\n                            JSBNG__name: _(\"Followers you follow &rarr;\"),\n                            href: twttr.router.followersYouFollowPath({\n                                screen_name: c\n                            })\n                        },]\n                    }), this._followersDropDown.render(b, \"append\"), this._followersDropDown.open())));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/t1/dashboard/ProfileNav\", function(a) {\n    using(\"components/t1/dashboard/Nav\").as(function(b) {\n        var c = twttr.klass(\"twttr.components.t1.dashboard.ProfileNav\").subclassOf(b.components.t1.dashboard.Nav).initializer(function(a) {\n            this._superInitializer.call(this, {\n                JSBNG__name: \"profile-nav\",\n                items: [{\n                    title: _(\"Tweets\"),\n                    route: twttr.router.profilePath({\n                        screen_name: a.screenName\n                    })\n                },{\n                    title: _(\"Following\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"followingPath\" : \"userFollowingPath\"))]({\n                        screen_name: a.screenName\n                    })\n                },{\n                    title: _(\"Followers\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"followersPath\" : \"userFollowersPath\"))]({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((((twttr.router.getCurrentRoute().JSBNG__name == \"followers\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"userFollowers\")))) || ((twttr.router.getCurrentRoute().JSBNG__name == \"followersYouFollow\")))),\n                    show_metadata_container: !0\n                },{\n                    title: _(\"Favorites\"),\n                    route: twttr.router[((twttr.helpers.isCurrentUser(a) ? \"favoritesPath\" : \"userFavoritesPath\"))]({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name == \"favorites\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"userFavorites\"))))\n                },{\n                    title: _(\"Requests\"),\n                    route: twttr.router.followerRequestsPath({\n                        screen_name: a.screenName\n                    }),\n                    visible: ((twttr.helpers.isCurrentUser(a) && a[\"protected\"]))\n                },{\n                    title: _(\"Lists\"),\n                    route: twttr.router.subscriptionsPath({\n                        screen_name: a.screenName\n                    }),\n                    active: ((((twttr.router.getCurrentRoute().JSBNG__name == \"subscriptions\")) || ((twttr.router.getCurrentRoute().JSBNG__name == \"memberships\"))))\n                },]\n            }), ((twttr.helpers.canViewUser(a) && this.renderMedia()));\n        }).methods({\n            renderMedia: function() {\n                this.$find(\"ul\").append((new twttr.components.UserMedia(twttr.profileUser, {\n                    view_all_href: twttr.router.userMediaGridPath({\n                        screen_name: twttr.profileUser.screenName\n                    }),\n                    renderHr: !0\n                })).$node);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"components/pages/mixins/listT1\", function(a) {\n    using(\"components/t1/dashboard/ListNav\", \"components/t1/dashboard/ListFollowCard\", \"components/NewestListMembers\", \"components/MoreLists\", \"components/Footer\").as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.components.pages.mixins.listT1\", function() {\n            this.view(twttr.views.Page).methods({\n                _registerEvents: function(a) {\n                    var c = this;\n                    twttr.API.List.bind(\"update\", function(d, e) {\n                        if (((e.id === a.id))) {\n                            var f = c.$find(\".list-nav\").closest(\".component\"), g = c.$find(\".dashboard \\u003E *\").index(f);\n                            f.remove(), c.addDashboardComponent(new b.components.t1.dashboard.ListNav(e), ((g + 1)));\n                        }\n                    ;\n                    ;\n                    });\n                },\n                getDashboardComponents: function(a) {\n                    return this.listFollowCard = new b.components.t1.dashboard.ListFollowCard(a), [this.listFollowCard,new b.components.t1.dashboard.ListNav(a),new b.components.NewestListMembers(a),new b.components.MoreLists(a),new b.components.Footer,];\n                },\n                addImpressionData: function(a) {\n                    a.profile_id = ((((this.owner && this.owner.id)) || ((twttr.profileUser && twttr.profileUser.id)))), a.message = this._listSlug;\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"multiGlobals/MessageManagerMonitor\", function(a) {\n    using().as(function(a) {\n        if (twttr.isT1) {\n            var b;\n            ((twttr.decider.isAvailable(\"phoenix_use_conversation_endpoint\") ? b = twttr.messageManager = new twttr.ConversationManager : b = twttr.messageManager = new twttr.MessageManager)), b.bind(\"pendingThreads\", function() {\n                var a = b.hasPendingThreads();\n                ((a ? ($(\"div.js-topbar li.js-session\").addClass(\"new\"), $(\"div.js-topbar span.js-direct-message-count\").addClass(\"new\").text(a)) : ($(\"div.js-topbar li.js-session\").removeClass(\"new\"), $(\"div.js-topbar span.js-direct-message-count\").removeClass(\"new\").text(\"\"))));\n            }), b.setupContinuousPoll();\n        }\n    ;\n    ;\n    }), a();\n});\nprovide(\"google\", function(a) {\n    using().as(function(b) {\n        using(twttr.bundleMore, function() {\n            if (twttr.isTestEnv) {\n                return;\n            }\n        ;\n        ;\n            ((((jQuery.active > 0)) ? $(JSBNG__document).JSBNG__one(\"ajaxComplete\", twttr.insertGAScriptElement) : twttr.insertGAScriptElement()));\n        }), a();\n    });\n});\nprovide(\"ttft_ajax\", function(a) {\n    using().as(function(b) {\n        using(twttr.bundleMore, function() {\n            var a = 0, b = 0, c = function() {\n                ((((++b >= a)) && (window.ttft.ajaxComplete(a), $(JSBNG__document).unbind(\"ajaxComplete\", c))));\n            };\n            ((((window.ttft && $.active)) && ($(JSBNG__document).ajaxComplete(c), activeAjaxCount = $.active)));\n        }), a();\n    });\n});\nprovide(\"bundle/t1-more\", function(a) {\n    using(\"bundle/t1-core\", function() {\n        using([\"mixins/ActivityViewHelpers\",\"/account/templates_t1_more.js\",\"multiGlobals/more_views\",\"multiGlobals/more_views_t1\",\"$lib/easyXDM.js\",\"libwrap/easyxdm\",\"lib/lazyload\",\"phoenix-more-css-wrapper\",\"$lib/jquery.ui.core.js\",\"$lib/jquery.ui.widget.js\",\"$lib/jquery.ui.mouse.js\",\"$lib/jquery.ui.draggable.js\",\"$lib/jquery.ui.progressbar.js\",\"$lib/jquery.swfobject.js\",\"$lib/jquery.hotkeys.js\",\"$lib/jquery.autoellipsis.js\",\"mixins/tweetFlagging\",\"promptbird\",\"MessageManager\",\"ConversationManager\",\"externalOauthPopup\",\"mixins/photoBox\",\"mixins/profileStreamMixin\",\"streams/Mentions\",\"streams/Favorites\",\"streams/User\",\"streams/Profile\",\"streams/FollowingTweets\",\"streams/List\",\"streams/Search\",\"streams/UserStream\",\"streams/Friends\",\"streams/FollowerRequests\",\"streams/Followers\",\"streams/SocialContextStream\",\"streams/SuggestionCategoriesStream\",\"streams/PeopleSearch\",\"streams/t1/HeadlessPeopleSearch\",\"streams/DashboardPeopleSearch\",\"streams/DashboardTopPeopleSearch\",\"streams/ListFollowers\",\"streams/ListMembers\",\"streams/Discover\",\"streams/SavedSearches\",\"mixins/SinceMaxPagination\",\"mixins/PollingStream\",\"mixins/activityStreamEvents\",\"mixins/inviteFriends\",\"mixins/newStreamItemsBar\",\"mixins/typeaheadScribing\",\"mixins/discoveryHelper\",\"mixins/usesRelatedResults\",\"mixins/profileHelper\",\"mixins/commonDashboardClickHandlers\",\"mixins/t1/cardActionable\",\"mixins/t1/discoveryStoryHelpers\",\"mixins/UserSimilaritiesStreamT1\",\"mixins/SuggestionCategoriesStreamT1\",\"mixins/SuggestionCategoryMembersStreamT1\",\"mixins/UserRecommendationsT1\",\"mixins/hasGovernmentSearchHeader\",\"mixins/prefollowingStream\",\"streams/StarterList\",\"streams/StarterFriends\",\"streams/UserRecommendationsStream\",\"streams/UserRecommendationsDashboardStream\",\"streams/UserSimilaritiesStream\",\"streams/ContactImportMatches\",\"streams/DashboardContactImportMatches\",\"streams/ContactImportServices\",\"mixins/ContactImportServicesT1\",\"streams/DashboardContactImportServices\",\"streams/TweetGameDashboardStream\",\"StoredUserStack\",\"PasswordStrength\",\"mixins/urlShortener\",\"mixins/caretHelper\",\"geo\",\"components/Autocomplete\",\"components/Typeahead\",\"components/TypeaheadDatasource\",\"components/TypeaheadSearchQueryDatasource\",\"components/TypeaheadAccountsDatasource\",\"components/GlobalNavTypeahead\",\"components/Editor\",\"TweetBox\",\"components/TweetboxAutocomplete\",\"shortcuts_t1\",\"stork\",\"streams/ActivityStream\",\"streams/ActivityByUserStream\",\"streams/ActivityByNetworkStream\",\"streams/ActivityOfMeStream\",\"streams/AllSubscriptions\",\"streams/AllSubscriptionsUser\",\"media\",\"media/Iconifier\",\"media/Embedder\",\"media/mediaType\",\"media/expandodo\",\"platform/BaseApplication\",\"platform/EmbeddedApplication\",\"platform/SandboxedApplication\",\"sandboxedAjax\",\"media/types\",\"geo/Map\",\"geo/Location\",\"control/Dropdown\",\"widget/Dialog\",\"dialogs\",\"widget/TweetDialog\",\"widget/Prompt\",\"widget/DeviceSetupDialog\",\"widget/DeviceFollowDialog\",\"widget/InviteContactsDialog\",\"widget/ListDialog\",\"components/t1/DirectMessageDialog\",\"widget/MuteDialog\",\"widget/DiscoveryDialog\",\"widget/GeoPromoDialog\",\"widget/RetweetDialog\",\"widget/TrendsDialog\",\"widget/ReplyDialog\",\"widget/ListMembershipDialog\",\"widget/MiniProfileDialog\",\"widget/EmbedDialog\",\"components/pages/mixins/searchT1\",\"components/pages/ProfileAbstract\",\"components/pages/Search\",\"components/pages/SearchHome\",\"components/pages/Front\",\"components/pages/Login\",\"components/pages/Logout\",\"components/pages/Profile\",\"components/pages/List\",\"components/pages/Permalink\",\"components/pages/WhoToFollow\",\"components/pages/WebPersonalizationPreview\",\"components/pages/404\",\"components/pages/403\",\"components/pages/PlaceT1\",\"components/pages/RateLimit\",\"components/pages/mixins/welcomeLearnFlowT1\",\"components/pages/WelcomeLearnFlow\",\"components/pages/Welcome\",\"components/pages/AbstractMediaGallery\",\"components/pages/UserMediaGallery\",\"components/pages/FacetsMediaGallery\",\"components/pages/EventsMediaGallery\",\"components/pages/BigPhotoPermalink\",\"components/pages/Discover\",\"components/pages/Connect\",\"widget/Banner\",\"components/Promo\",\"components/Promptbird\",\"components/RelatedServices\",\"TrendLocations\",\"components/PeopleResults\",\"components/ProfileActions\",\"components/RecentTweets\",\"components/RecentlyFollowed\",\"components/RecentlyViewed\",\"components/InviteContacts\",\"components/InviteFriends\",\"components/Retweeters\",\"components/TweetActivity\",\"components/ConversationThread\",\"components/InReplyTo\",\"components/InlineReplyBox\",\"components/Conversation\",\"components/Replies\",\"components/MoreLists\",\"geo/TweetGeo\",\"components/MachineTranslationBackend\",\"components/TweetGeoSmall\",\"components/NewestListMembers\",\"components/StorkPip\",\"components/StreamEnd\",\"components/StreamEndInviteFriends\",\"components/StreamWhaleEnd\",\"components/ContactImportErrorEnd\",\"components/EmptyHome\",\"components/AddPeople\",\"components/NoListMembers\",\"components/Media\",\"components/ProfilePane\",\"components/JapaneseAd\",\"components/ProtectedUser\",\"components/TweetStats\",\"components/PermalinkTweet\",\"components/NoUserExists\",\"components/SignupCallOut\",\"components/SuggestionCategoriesList\",\"components/ContactImportMatchesStats\",\"components/media/Base\",\"components/media/profile\",\"components/media/facets/Base\",\"components/media/facets/Media\",\"components/media/facets/Images\",\"components/media/facets/Videos\",\"components/ThumbnailViewer\",\"components/TheGrid\",\"components/MediaGalleryControls\",\"components/MediaSlideshow\",\"components/SearchFacets\",\"components/FollowerRequestLink\",\"components/WebPersonalizationSettings\",\"photo/turkey\",\"photo/photo_thumbnails\",\"images\",\"components/ContactImportLauncher\",\"streams/ListStream\",\"streams/OwnListsStream\",\"streams/SubscriptionsStream\",\"streams/MembershipsStream\",\"streams/MembershipsStreamUser\",\"multiGlobals/trackSession\",\"streams/SuggestionCategoriesStream\",\"streams/SuggestionCategoryMembersStream\",\"streams/SuggestionCategoriesDashboardStream\",\"streams/SuggestionCategoryMembersDashboardStream\",\"streams/SuggestionLifelineMembersStream\",\"streams/SuggestionLifelineMembersDashboardStream\",\"streams/GovernmentSearchStream\",\"widget/VerifyEmailDialog\",\"SearchAPI\",\"media/providers\",\"mixins/userRecommendationsHelper\",\"mixins/t1/genericComboButton\",\"mixins/userUpdateable\",\"components/UserMedia\",\"components/UserRecommendations\",\"components/Footer\",\"components/Trends\",\"components/onebox/News\",\"components/onebox/User\",\"components/onebox/Sports\",\"components/onebox/Event\",\"components/t1/EmptyTimelineRecommendations\",\"components/t1/dashboard/AbstractDashboard\",\"components/t1/dashboard/Tweetbox\",\"components/t1/dashboard/ProfileTweetbox\",\"components/t1/dashboard/ProfileFollowCard\",\"components/t1/dashboard/Flex\",\"components/t1/dashboard/Nav\",\"components/t1/dashboard/MiniHomeProfile\",\"components/t1/dashboard/ConnectNav\",\"components/t1/dashboard/ProfileNav\",\"components/t1/dashboard/SettingsNav\",\"components/t1/dashboard/ListNav\",\"components/t1/dashboard/SearchNav\",\"components/t1/dashboard/DiscoverNav\",\"components/t1/dashboard/ProfileSummary\",\"components/t1/dashboard/ListFollowCard\",\"components/t1/dashboard/SearchImages\",\"components/t1/dashboard/SearchVideos\",\"components/t1/AvatarRow\",\"components/t1/SearchHeader\",\"components/t1/PeopleSearchStreamHeader\",\"components/t1/UserSimilaritiesList\",\"components/t1/UserSimilaritiesDashboardList\",\"components/pages/mixins/profileT1\",\"components/pages/mixins/profileP1\",\"components/t1/dashboard/ProfileNav\",\"components/pages/mixins/listT1\",\"multiGlobals/MessageManagerMonitor\",\"google\",\"ttft_ajax\",], function() {\n            a();\n        });\n    });\n});");
// 37633
cb(); return null; }
finalize(); })();
